//This file contains the utilities used to perform a fingerprint of the device
//--- GLOBAL VAR SECTION - START ---
//Fingerprint array
var currentFingerprint = null;
//Local IP array
var localIps = null;
//Google geolocation key
var geolocationKey = 'AIzaSyDDswkVWL3-wCAfEI0j4sVeCqI7PHziyeg';
//--- GLOBAL VAR SECTION - END ---

//Function used to continue the fingerprint
function continueFingerprint() {
    //We retrieve the GPU info
    getGPU();
    //Then the CPU info
    getCPU();
    //And the battery info
    getBattery();
};

//Function used to retrieve the battery info
function getBattery() {
    try {
        navigator.getBattery().then(function(battery) {
            //Charging Info
            currentFingerprint.setBatteryCharging(battery.charging ? 'charging' : 'not charging');
            //Battery Level
            currentFingerprint.setBatteryLevel((Math.round(battery.level * 10000) / 100) + '%');
            //Remaining time
            currentFingerprint.setBatteryDischargingTime(battery.dischargingTime === Infinity ? 'Infinity' : (Math.round(100 * battery.dischargingTime / 3600) / 100) + 'h');
            //Charging time
            currentFingerprint.setBatteryChargingTime(battery.chargingTime === Infinity ? 'Infinity' : (Math.round(100 * battery.chargingTime / 3600) / 100) + 'h');
             //After that we can log the fingerprint
             logFingerprint();
        });
    } catch (err) {
        logFingerprint();
    }
};

//Function used to retrieve the CPU info
function getCPU() {
    var cpuInfo = navigator.platform;
    if (navigator.hardwareConcurrency) {
        cpuInfo += ", " + navigator.hardwareConcurrency + " Cores";
    }
    currentFingerprint.setCPUInfo(cpuInfo);
}

//Function used to retrieve the GPU info
function getGPU() {
    //We try to retrieve the canvas
    var canvas = document.getElementById('canvasId');
    //If it doesn't exists
    if (!canvas) {
        //We have to create it
        canvas = document.createElement('canvas');
        canvas.id = 'canvasId';
        document.body.appendChild(canvas);
    }
    //We retrieve the experimental context
    var gl = canvas.getContext("experimental-webgl");
    //And the extension
    var extension = gl.getExtension('WEBGL_debug_renderer_info');
    //If the extension exists
    if (extension) {
        //We can set the specific info
        currentFingerprint.setVendor(gl.getParameter(extension.UNMASKED_VENDOR_WEBGL));
        currentFingerprint.setRenderer(gl.getParameter(extension.UNMASKED_RENDERER_WEBGL));
    } else {
        //Otherwise we have to set the generic one
        currentFingerprint.setVendor(gl.getParameter(gl.UNMASKED_VENDOR_WEBGL));
        currentFingerprint.setRenderer(gl.getParameter(gl.UNMASKED_RENDERER_WEBGL));
    }
}

//Function used to retrieve the local IP
function getLocalIp() {
    //We reset the local ip array
    localIp = [];
    var ip_dups = {};
    //compatibility for firefox and chrome
    var RTCPeerConnection = window.RTCPeerConnection || window.mozRTCPeerConnection || window.webkitRTCPeerConnection;
    var useWebKit = !!window.webkitRTCPeerConnection;
    window.RTCPeerConnection = window.RTCPeerConnection || window.mozRTCPeerConnection || window.webkitRTCPeerConnection; //compatibility for firefox and chrome
    //bypass naive webrtc blocking using an iframe
    if (!RTCPeerConnection || isEdge) {
        //local ip not supported
		continueFingerprint();
		return;
    }
    //minimal requirements for data connection
    var mediaConstraints = {
        optional: [{
            RtpDataChannels: true
        }]
    };

    var servers = {
        iceServers: [{
            urls: "stun:stun.services.mozilla.com"
        }]
    };

    //construct a new RTCPeerConnection
    var pc = new RTCPeerConnection(servers, mediaConstraints);

    function handleCandidate(candidate) {
        //match just the IP address
        var parts = candidate.split(' '),
            ip_addr = parts[4],
            type = parts[7];
        if (type === "host" && ip_dups[ip_addr] === undefined) {
            localIp.push(ip_addr)
            ip_dups[ip_addr] = true;
        }
    }

    //listen for candidate events
    pc.onicecandidate = function(ice) {
        if (ice.candidate) {
            handleCandidate(ice.candidate.candidate);
        }
    };
    //create a bogus data channel
    pc.createDataChannel("");

    //create an offer sdp
    pc.createOffer(function(result) {

        //trigger the stun server request
        pc.setLocalDescription(result, function() {}, function() {});

    }, function() {});

    //wait for a while to let everything done
    setTimeout(function() {
        if (pc.localDescription) {
            var lines = pc.localDescription.sdp.split('\n');

            lines.forEach(function(line) {
                if (line.indexOf('a=candidate:') === 0)
                    handleCandidate(line);
            });

            processLocalIp();
        } else {
            continueFingerprint();
        }
    }, 1000);

};

//Function used to retrieve the public IP
function getPublicIp() {
    //We create an xml http request wrapper
    var xhttpPublicIp = new XmlHttpRequestWrapper(
        getPublicIpOnLoad,
        getServiceProvider,
        "GET",
        "https://api.ipify.org?format=json",
        true,
        null,
        getServiceProvider,
        null,
        null,
        null
    );
    //And we send the request
    xhttpPublicIp.sendRequest();
};

//Function used to retrieve the plugins and the plugin version
function getPlugins(client) {
    var plugins = client.getPlugins();
    var pluginsToCheck = currentFingerprint.getPluginNames();
    for (var i = 0; i < pluginsToCheck.length; i++) {
        if (i != pluginsToCheck.length) {
            plugins += ",";
        }
        var version = PluginDetect.getVersion(pluginsToCheck[i]);
        if (version) {
            version = version.replaceAll(",", ".");
        }
        plugins += pluginsToCheck[i] + ":" + version;
    }
    return plugins.replaceAll(", ", ",");
};

function getPublicIpOnLoad(oEvent) {
    //If the request was succesfull
    if (oEvent.currentTarget.readyState == 4 && oEvent.currentTarget.status == 200) {
        //We set the IP
        currentFingerprint.setPublicIp(JSON.parse(oEvent.currentTarget.responseText).ip);
    }
    //Then we continue the fingerprint
    getServiceProvider();
};

//Function used to retrieve the service provider
function getServiceProvider() {
    //We create an xml http request wrapper
    var xhttpServiceProvider = new XmlHttpRequestWrapper(
        getServiceProviderOnLoad,
        getLocalIp,
        "GET",
        "http://ip-api.com/json",
        true,
        null,
        getLocalIp,
        null,
        null,
        null
    );
    //And we send the request
    xhttpServiceProvider.sendRequest();
};

function getServiceProviderOnLoad(oEvent) {
    //If the request was succesfull
    if (oEvent.currentTarget.readyState == 4 && oEvent.currentTarget.status == 200) {
        //We set the Service Provider
        currentFingerprint.setServiceProvider(JSON.parse(oEvent.currentTarget.responseText).isp);
        var publicIP = JSON.parse(oEvent.currentTarget.responseText).query;
        if (currentFingerprint.getPublicIp() === null || currentFingerprint.getPublicIp() === undefined) {
            currentFingerprint.setPublicIp(publicIP);
        } else if (publicIP !== currentFingerprint.getPublicIp()) {
            currentFingerprint.setPublicIp(currentFingerprint.getPublicIp() + "_" + publicIP);
        }
    }
    //Then we continue the fingerprint
    getLocalIp();
};

//Function used to log the fingerprint
function logFingerprint() {
    //And we write it into the log file
    writeLogLine(currentFingerprint.toString(), currentFingLog, extensionFing);
}

//Function used to populate the fingerprint array with the device info
function populateDeviceInfo() {
    var client = new ClientJS();
    currentFingerprint.setOS(client.getOS());
    currentFingerprint.setBrowser(client.getBrowser() + " " + client.getBrowserVersion());
    currentFingerprint.setOSVersion(client.getOSVersion());
    currentFingerprint.setDevice(client.getDevice());
    currentFingerprint.setDeviceType(client.getDeviceType());
    currentFingerprint.setDeviceVendor(client.getDeviceVendor());
    currentFingerprint.setCPU(client.getCPU());
    currentFingerprint.setScreenPrint(client.getScreenPrint());
    currentFingerprint.setColorDepth(client.getColorDepth());
    currentFingerprint.setCurrentResolution(client.getCurrentResolution());
    currentFingerprint.setAvailableResolution(client.getAvailableResolution());
    var plugins = getPlugins(client);
    currentFingerprint.setPlugins(plugins);
    currentFingerprint.setMimeTypes(client.getMimeTypes());
    currentFingerprint.setFonts(client.getFonts());
    currentFingerprint.setIsLocalStorage(client.isLocalStorage());
    currentFingerprint.setIsSessionStorage(client.isSessionStorage());
    currentFingerprint.setIsCookie(client.isCookie());
    currentFingerprint.setTimeZone(client.getTimeZone());
    currentFingerprint.setLanguage(client.getLanguage());
};

//Function used to populate the geolocation info
function populateGeolocation() {
    var errorFunction = function() {
        populateDeviceInfo();
        populateNetInfo();
    };
    //We create an xml http request wrapper
    var xhrGeo = new XmlHttpRequestWrapper(
        populateGeolocationOnLoad,
        errorFunction,
        "POST",
        'https://www.googleapis.com/geolocation/v1/geolocate?key=' + geolocationKey,
        true,
        null,
        errorFunction,
        null,
        null,
        null
    );
    //And we send the request
    xhrGeo.sendRequest();
};

function populateGeolocationOnLoad(oEvent) {
    if (oEvent.currentTarget.readyState == 4 && oEvent.currentTarget.status == 200) {
        //We retrieve and push the latitute and the longitude
        var position = JSON.parse(oEvent.currentTarget.responseText);
        currentFingerprint.setLatitude(position.location.lat);
        currentFingerprint.setLongitude(position.location.lng);
    }
    populateDeviceInfo();
    populateNetInfo();
};

//Function used to populate the fingerprint array with the net info
function populateNetInfo() {
    getPublicIp();
};

//Function used to process the local ip
function processLocalIp() {
    //Firstable we remove the duplicates
    localIp = localIp.removeDuplicates();
    //After that we concatenate the local ip in a single string
    var localIpString = localIp.join("_");
    //And we push it into the info array
    currentFingerprint.setLocalIp(localIpString);
    //then we process the other info
    continueFingerprint();
};

//Function used to log the fingerprint
function startFingerprint() {
    //We retrieve the current timestamp
    var currentTimestamp = Math.floor(Date.now());
    if (!lastFingerprintUpdate || (currentTimestamp - lastFingerprintUpdate > minutesForUpdate * 60 * 1000)) {
        //We have to update the fingerprint
        //We reset the info array
        lastFingerprintUpdate = currentTimestamp;
        currentFingerprint = new Fingerprint();
        populateGeolocation();
    }

};