(function (w, d, config) {
	var url = config.url !== undefined
			? config.url.replace('http:', 'https:')
			: 'https://creatives.livejasmin.com/pu/w2/',
		cookieName = config.cookieName || 'lj_popunder';

	var isToleratedDomain = function () {
		var toleratedDomains = [
			'creatives.livejasmin.com',
			'adson.awempire.com',
			'static.awempire.com',
			'promo.awempire.com',
			'jmp.awempire.com',
			'awejmp.com',
			'jsmjmp.com',
			'jasmin.com',
			'live-cams-1.livejasmin.com',
			'cameraboys.com',
			'joyourself.com',
			'livesexasian.com',
			'liveprivates.com',
			'lsawards.com',
			'maturescam.com',
			'mycams.com',
			'mytrannycams.com',
			'lsl.com'
		];

		for (var i = 0; i < toleratedDomains.length; i++) {
			if (new RegExp(toleratedDomains[i], 'i').test(url)) {
				return true;
			}
		}

		return false;
	};

	var addScript = function (src, onLoad) {
		var scriptElement = d.createElement('script'),
			body = d.getElementsByTagName('body')[0];

		scriptElement.src = src;
		scriptElement.async = true;
		scriptElement.onload = onLoad;

		body.appendChild(scriptElement);
	};

	var getPsTool = function () {
		var psToolConfig = {
			'200_11' : '/pu/w2',
			'200_12' : '/pu/li/jsm',
			'200_13' : '/pu/li/cmb',
			'200_14' : '/pu/brand',
			'200_9'  : '/pu/wl/ad',
			'200_1'  : '/pu/sr_n',
			'200_2'  : '/pu/sr',
			'200_3'  : '/pu/ss',
			'200_4'  : '/pu/sr_6',
			'200_5'  : '/pu/sr_8',
			'200_7'  : '/pu/gp',
			'200_8'  : '/pu/gp2',
			'200_15' : '/pu/mobile'
		};

		for (var key in psToolConfig) {
			if (new RegExp(psToolConfig[key] + '(?:[^\\w].*|)$', 'i').test(url)) {
				return key;
			}
		}

		return false;
	};

	var getQueryParameters = function () {
		var result = '',
			psTool = getPsTool();

		switch (typeof config.additionalParameters) {
			case 'string':
				result = config.additionalParameters;
				break;
			case 'object':
				for (var key in config.additionalParameters) {
					if (config.additionalParameters.hasOwnProperty(key)) {
						result += (config.additionalParameters[key] === null)
							? key + '&'
							: key + '=' + config.additionalParameters[key] + '&';
					}
				}

				result = result.substring(0, result.length - 1);
				break;
		}

		if (!psTool) {
			return result;
		}

		if (result.toLowerCase().indexOf('pstool=') !== -1) {
			return result.replace(/pstool=\w*/i, 'pstool=' + psTool);
		}

		return result + (result ? '&' : '') + 'pstool=' + psTool;
	};

	w.popns = 'AweCrPu';

	var init = function () {
		var getWidth = function () {
			return Math.min(w.screen.availWidth, 1100);
		};

		var getHeight = function () {
			return Math.min(w.screen.availHeight, 900);
		};

		var getLeft = function () {
			return (w.screen.width - getWidth()) / 2;
		};

		var getTop = function () {
			return (w.screen.height - getHeight()) / 2;
		};

		w.AweCrPu
			.config({
				perpage            : 1,
				coverTags          : ['iframe'],
				ignoreListener     : false,
				coverScrollbar     : false,
				webkitAnchorBlank  : false,
				forceUnder         : false,
				popFallbackOptions : {under : true, newTab : true},
				initOnload         : false
			})
			.add(url + (url.indexOf('?') === -1 ? '?' : '&') + getQueryParameters(), {
				cookieName    : cookieName,
				cookieExpires : config.reRuntime !== undefined ? config.reRuntime * 3600 : 86400,
				width         : config.width || getWidth(),
				height        : config.height || getHeight(),
				left          : config.left || getLeft(),
				top           : config.top || getTop()
			});
	};

	if (!isToleratedDomain()) {
		return;
	}

	if (document.cookie.indexOf(cookieName + '=1') !== -1) {
		return;
	}

	var initInterval = setInterval(function () {
		if (document.readyState !== 'complete') {
			return;
		}

		clearInterval(initInterval);

		addScript(
			'//static1.awestatic.com/Scripts/pu_script.js',
			function () {
				addScript(
					'//static1.awestatic.com/Scripts/pu_license.js',
					init
				)
			}
		);
	}, 10);
}(window, document, phantomPopunder || {}));
