/*
 * jQuery UI Accordion 1.8.11
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Accordion
 *
 * Depends:
 *	jquery.ui.core.js
 *	jquery.ui.widget.js
 */
(function( $, undefined ) {

$.widget( "ui.accordion", {
	options: {
		active: 0,
		animated: "slide",
		autoHeight: false,
		clearStyle: true,
		collapsible: true,
		event: "click",
		fillSpace: false,
		heightStyle:"content",
		header: "> li > :first-child,> :not(li):even",
		icons: {
			header: "ui-icon-triangle-1-e",
			headerSelected: "ui-icon-triangle-1-s"
		},
		navigation: false,
		navigationFilter: function() {
			return this.href.toLowerCase() === location.href.toLowerCase();
		}
	},

	_create: function() {
		var self = this,
			options = self.options;

		self.running = 0;

		self.element
			.addClass( "ui-accordion ui-widget ui-helper-reset" )
			// in lack of child-selectors in CSS
			// we need to mark top-LIs in a UL-accordion for some IE-fix
			.children( "li" )
				.addClass( "ui-accordion-li-fix" );

		self.headers = self.element.find( options.header )
			.addClass( "ui-accordion-header ui-helper-reset ui-state-default ui-corner-all" )
			.bind( "mouseenter.accordion", function() {
				if ( options.disabled ) {
					return;
				}
				$( this ).addClass( "ui-state-hover" );
			})
			.bind( "mouseleave.accordion", function() {
				if ( options.disabled ) {
					return;
				}
				$( this ).removeClass( "ui-state-hover" );
			})
			.bind( "focus.accordion", function() {
				if ( options.disabled ) {
					return;
				}
				$( this ).addClass( "ui-state-focus" );
			})
			.bind( "blur.accordion", function() {
				if ( options.disabled ) {
					return;
				}
				$( this ).removeClass( "ui-state-focus" );
			});

		self.headers.next()
			.addClass( "ui-accordion-content ui-helper-reset ui-widget-content ui-corner-bottom" );

		if ( options.navigation ) {
			var current = self.element.find( "a" ).filter( options.navigationFilter ).eq( 0 );
			if ( current.length ) {
				var header = current.closest( ".ui-accordion-header" );
				if ( header.length ) {
					// anchor within header
					self.active = header;
				} else {
					// anchor within content
					self.active = current.closest( ".ui-accordion-content" ).prev();
				}
			}
		}

		self.active = self._findActive( self.active || options.active )
			.addClass( "ui-state-default ui-state-active" )
			.toggleClass( "ui-corner-all" )
			.toggleClass( "ui-corner-top" );
		self.active.next().addClass( "ui-accordion-content-active" );

		self._createIcons();
		self.resize();
		
		// ARIA
		self.element.attr( "role", "tablist" );

		self.headers
			.attr( "role", "tab" )
			.bind( "keydown.accordion", function( event ) {
				return self._keydown( event );
			})
			.next()
				.attr( "role", "tabpanel" );

		self.headers
			.not( self.active || "" )
			.attr({
				"aria-expanded": "false",
				"aria-selected": "false",
				tabIndex: -1
			})
			.next()
				.hide();

		// make sure at least one header is in the tab order
		if ( !self.active.length ) {
			self.headers.eq( 0 ).attr( "tabIndex", 0 );
		} else {
			self.active
				.attr({
					"aria-expanded": "true",
					"aria-selected": "true",
					tabIndex: 0
				});
		}

		// only need links in tab order for Safari
		if ( !$.browser.safari ) {
			self.headers.find( "a" ).attr( "tabIndex", -1 );
		}

		if ( options.event ) {
			self.headers.bind( options.event.split(" ").join(".accordion ") + ".accordion", function(event) {
				self._clickHandler.call( self, event, this );
				event.preventDefault();
			});
		}
	},

	_createIcons: function() {
		var options = this.options;
		if ( options.icons ) {
			$( "<span></span>" )
				.addClass( "ui-icon " + options.icons.header )
				.prependTo( this.headers );
			this.active.children( ".ui-icon" )
				.toggleClass(options.icons.header)
				.toggleClass(options.icons.headerSelected);
			this.element.addClass( "ui-accordion-icons" );
		}
	},

	_destroyIcons: function() {
		this.headers.children( ".ui-icon" ).remove();
		this.element.removeClass( "ui-accordion-icons" );
	},

	destroy: function() {
		var options = this.options;

		this.element
			.removeClass( "ui-accordion ui-widget ui-helper-reset" )
			.removeAttr( "role" );

		this.headers
			.unbind( ".accordion" )
			.removeClass( "ui-accordion-header ui-accordion-disabled ui-helper-reset ui-state-default ui-corner-all ui-state-active ui-state-disabled ui-corner-top" )
			.removeAttr( "role" )
			.removeAttr( "aria-expanded" )
			.removeAttr( "aria-selected" )
			.removeAttr( "tabIndex" );

		this.headers.find( "a" ).removeAttr( "tabIndex" );
		this._destroyIcons();
		var contents = this.headers.next()
			.css( "display", "" )
			.removeAttr( "role" )
			.removeClass( "ui-helper-reset ui-widget-content ui-corner-bottom ui-accordion-content ui-accordion-content-active ui-accordion-disabled ui-state-disabled" );
		if ( options.autoHeight || options.fillHeight ) {
			contents.css( "height", "" );
		}

		return $.Widget.prototype.destroy.call( this );
	},

	_setOption: function( key, value ) {
		$.Widget.prototype._setOption.apply( this, arguments );
			
		if ( key == "active" ) {
			this.activate( value );
		}
		if ( key == "icons" ) {
			this._destroyIcons();
			if ( value ) {
				this._createIcons();
			}
		}
		// #5332 - opacity doesn't cascade to positioned elements in IE
		// so we need to add the disabled class to the headers and panels
		if ( key == "disabled" ) {
			this.headers.add(this.headers.next())
				[ value ? "addClass" : "removeClass" ](
					"ui-accordion-disabled ui-state-disabled" );
		}
	},

	_keydown: function( event ) {
		if ( this.options.disabled || event.altKey || event.ctrlKey ) {
			return;
		}

		var keyCode = $.ui.keyCode,
			length = this.headers.length,
			currentIndex = this.headers.index( event.target ),
			toFocus = false;

		switch ( event.keyCode ) {
			case keyCode.RIGHT:
			case keyCode.DOWN:
				toFocus = this.headers[ ( currentIndex + 1 ) % length ];
				break;
			case keyCode.LEFT:
			case keyCode.UP:
				toFocus = this.headers[ ( currentIndex - 1 + length ) % length ];
				break;
			case keyCode.SPACE:
			case keyCode.ENTER:
				this._clickHandler( { target: event.target }, event.target );
				event.preventDefault();
		}

		if ( toFocus ) {
			$( event.target ).attr( "tabIndex", -1 );
			$( toFocus ).attr( "tabIndex", 0 );
			toFocus.focus();
			return false;
		}

		return true;
	},

	resize: function() {
		var options = this.options,
			maxHeight;

		if ( options.fillSpace ) {
			if ( $.browser.msie ) {
				var defOverflow = this.element.parent().css( "overflow" );
				this.element.parent().css( "overflow", "hidden");
			}
			maxHeight = this.element.parent().height();
			if ($.browser.msie) {
				this.element.parent().css( "overflow", defOverflow );
			}

			this.headers.each(function() {
				maxHeight -= $( this ).outerHeight( true );
			});

			this.headers.next()
				.each(function() {
					$( this ).height( Math.max( 0, maxHeight -
						$( this ).innerHeight() + $( this ).height() ) );
				})
				.css( "overflow", "auto" );
		} else if ( options.autoHeight ) {
			maxHeight = 0;
			this.headers.next()
				.each(function() {
					maxHeight = Math.max( maxHeight, $( this ).height( "" ).height() );
				})
				.height( maxHeight );
		}

		return this;
	},

	activate: function( index ) {
		// TODO this gets called on init, changing the option without an explicit call for that
		this.options.active = index;
		// call clickHandler with custom event
		var active = this._findActive( index )[ 0 ];
		this._clickHandler( { target: active }, active );

		return this;
	},

	_findActive: function( selector ) {
		return selector
			? typeof selector === "number"
				? this.headers.filter( ":eq(" + selector + ")" )
				: this.headers.not( this.headers.not( selector ) )
			: selector === false
				? $( [] )
				: this.headers.filter( ":eq(0)" );
	},

	// TODO isn't event.target enough? why the separate target argument?
	_clickHandler: function( event, target ) {
		var options = this.options;
		if ( options.disabled ) {
			return;
		}

		// called only when using activate(false) to close all parts programmatically
		if ( !event.target ) {
			if ( !options.collapsible ) {
				return;
			}
			this.active
				.removeClass( "ui-state-active ui-corner-top" )
				.addClass( "ui-state-default ui-corner-all" )
				.children( ".ui-icon" )
					.removeClass( options.icons.headerSelected )
					.addClass( options.icons.header );
			this.active.next().addClass( "ui-accordion-content-active" );
			var toHide = this.active.next(),
				data = {
					options: options,
					newHeader: $( [] ),
					oldHeader: options.active,
					newContent: $( [] ),
					oldContent: toHide
				},
				toShow = ( this.active = $( [] ) );
			this._toggle( toShow, toHide, data );
			return;
		}

		// get the click target
		var clicked = $( event.currentTarget || target ),
			clickedIsActive = clicked[0] === this.active[0];

		// TODO the option is changed, is that correct?
		// TODO if it is correct, shouldn't that happen after determining that the click is valid?
		options.active = options.collapsible && clickedIsActive ?
			false :
			this.headers.index( clicked );

		// if animations are still active, or the active header is the target, ignore click
		if ( this.running || ( !options.collapsible && clickedIsActive ) ) {
			return;
		}

		// find elements to show and hide
		var active = this.active,
			toShow = clicked.next(),
			toHide = this.active.next(),
			data = {
				options: options,
				newHeader: clickedIsActive && options.collapsible ? $([]) : clicked,
				oldHeader: this.active,
				newContent: clickedIsActive && options.collapsible ? $([]) : toShow,
				oldContent: toHide
			},
			down = this.headers.index( this.active[0] ) > this.headers.index( clicked[0] );

		// when the call to ._toggle() comes after the class changes
		// it causes a very odd bug in IE 8 (see #6720)
		this.active = clickedIsActive ? $([]) : clicked;
		this._toggle( toShow, toHide, data, clickedIsActive, down );

		// switch classes
		active
			.removeClass( "ui-state-active ui-corner-top" )
			.addClass( "ui-state-default ui-corner-all" )
			.children( ".ui-icon" )
				.removeClass( options.icons.headerSelected )
				.addClass( options.icons.header );
		if ( !clickedIsActive ) {
			clicked
				.removeClass( "ui-state-default ui-corner-all" )
				.addClass( "ui-state-active ui-corner-top" )
				.children( ".ui-icon" )
					.removeClass( options.icons.header )
					.addClass( options.icons.headerSelected );
			clicked
				.next()
				.addClass( "ui-accordion-content-active" );
		}

		return;
	},

	_toggle: function( toShow, toHide, data, clickedIsActive, down ) {
		var self = this,
			options = self.options;

		self.toShow = toShow;
		self.toHide = toHide;
		self.data = data;

		var complete = function() {
			if ( !self ) {
				return;
			}
			return self._completed.apply( self, arguments );
		};

		// trigger changestart event
		self._trigger( "changestart", null, self.data );

		// count elements to animate
		self.running = toHide.size() === 0 ? toShow.size() : toHide.size();

		if ( options.animated ) {
			var animOptions = {};

			if ( options.collapsible && clickedIsActive ) {
				animOptions = {
					toShow: $( [] ),
					toHide: toHide,
					complete: complete,
					down: down,
					autoHeight: options.autoHeight || options.fillSpace
				};
			} else {
				animOptions = {
					toShow: toShow,
					toHide: toHide,
					complete: complete,
					down: down,
					autoHeight: options.autoHeight || options.fillSpace
				};
			}

			if ( !options.proxied ) {
				options.proxied = options.animated;
			}

			if ( !options.proxiedDuration ) {
				options.proxiedDuration = options.duration;
			}

			options.animated = $.isFunction( options.proxied ) ?
				options.proxied( animOptions ) :
				options.proxied;

			options.duration = $.isFunction( options.proxiedDuration ) ?
				options.proxiedDuration( animOptions ) :
				options.proxiedDuration;

			var animations = $.ui.accordion.animations,
				duration = options.duration,
				easing = options.animated;

			if ( easing && !animations[ easing ] && !$.easing[ easing ] ) {
				easing = "slide";
			}
			if ( !animations[ easing ] ) {
				animations[ easing ] = function( options ) {
					this.slide( options, {
						easing: easing,
						duration: duration || 700
					});
				};
			}

			animations[ easing ]( animOptions );
		} else {
			if ( options.collapsible && clickedIsActive ) {
				toShow.toggle();
			} else {
				toHide.hide();
				toShow.show();
			}

			complete( true );
		}

		// TODO assert that the blur and focus triggers are really necessary, remove otherwise
		toHide.prev()
			.attr({
				"aria-expanded": "false",
				"aria-selected": "false",
				tabIndex: -1
			})
			.blur();
		toShow.prev()
			.attr({
				"aria-expanded": "true",
				"aria-selected": "true",
				tabIndex: 0
			})
			.focus();
	},

	_completed: function( cancel ) {
		this.running = cancel ? 0 : --this.running;
		if ( this.running ) {
			return;
		}

		if ( this.options.clearStyle ) {
			this.toShow.add( this.toHide ).css({
				height: "",
				overflow: ""
			});
		}

		// other classes are removed before the animation; this one needs to stay until completed
		this.toHide.removeClass( "ui-accordion-content-active" );
		// Work around for rendering bug in IE (#5421)
		if ( this.toHide.length ) {
			this.toHide.parent()[0].className = this.toHide.parent()[0].className;
		}

		this._trigger( "change", null, this.data );
	}
});

$.extend( $.ui.accordion, {
	version: "1.8.11",
	animations: {
		slide: function( options, additions ) {
			options = $.extend({
				easing: "swing",
				duration: 300
			}, options, additions );
			if ( !options.toHide.size() ) {
				options.toShow.animate({
					<!--height: "show",-->
					paddingTop: "show",
					paddingBottom: "show"
				}, options );
				return;
			}
			if ( !options.toShow.size() ) {
				options.toHide.animate({
					height: "hide",
					paddingTop: "hide",
					paddingBottom: "hide"
				}, options );
				return;
			}
			var overflow = options.toShow.css( "overflow" ),
				percentDone = 0,
				showProps = {},
				hideProps = {},
				fxAttrs = [ "height", "paddingTop", "paddingBottom" ],
				originalWidth;
			// fix width before calculating height of hidden element
			var s = options.toShow;
			originalWidth = s[0].style.width;
			s.width( parseInt( s.parent().width(), 10 )
				- parseInt( s.css( "paddingLeft" ), 10 )
				- parseInt( s.css( "paddingRight" ), 10 )
				- ( parseInt( s.css( "borderLeftWidth" ), 10 ) || 0 )
				- ( parseInt( s.css( "borderRightWidth" ), 10) || 0 ) );

			$.each( fxAttrs, function( i, prop ) {
				hideProps[ prop ] = "hide";

				var parts = ( "" + $.css( options.toShow[0], prop ) ).match( /^([\d+-.]+)(.*)$/ );
				showProps[ prop ] = {
					value: parts[ 1 ],
					unit: parts[ 2 ] || "px"
				};
			});
			options.toShow.css({ height: 0, overflow: "hidden" }).show();
			options.toHide
				.filter( ":hidden" )
					.each( options.complete )
				.end()
				.filter( ":visible" )
				.animate( hideProps, {
				step: function( now, settings ) {
					// only calculate the percent when animating height
					// IE gets very inconsistent results when animating elements
					// with small values, which is common for padding
					if ( settings.prop == "height" ) {
						percentDone = ( settings.end - settings.start === 0 ) ? 0 :
							( settings.now - settings.start ) / ( settings.end - settings.start );
					}

					options.toShow[ 0 ].style[ settings.prop ] =
						( percentDone * showProps[ settings.prop ].value )
						+ showProps[ settings.prop ].unit;
				},
				duration: options.duration,
				easing: options.easing,
				complete: function() {
					if ( !options.autoHeight ) {
						options.toShow.css( "height", "" );
					}
					options.toShow.css({
						width: originalWidth,
						overflow: overflow
					});
					options.complete();
				}
			});
		},
		bounceslide: function( options ) {
			this.slide( options, {
				easing: options.down ? "easeOutBounce" : "swing",
				duration: options.down ? 1000 : 200
			});
		}
	}
});

})( jQuery );
;
/*!
 *  * jQuery Browser Plugin 0.0.6
 *   * https://github.com/gabceb/jquery-browser-plugin
 *    *
 *     * Original jquery-browser code Copyright 2005, 2013 jQuery Foundation, Inc. and other contributors
 *      * http://jquery.org/license
 *       *
 *        * Modifications Copyright 2014 Gabriel Cebrian
 *         * https://github.com/gabceb
 *          *
 *           * Released under the MIT license
 *            *
 *             * Date: 30-03-2014
 *              */!function(a,b){"use strict";var c,d;if(a.uaMatch=function(a){a=a.toLowerCase();var b=/(opr)[\/]([\w.]+)/.exec(a)||/(chrome)[ \/]([\w.]+)/.exec(a)||/(version)[ \/]([\w.]+).*(safari)[ \/]([\w.]+)/.exec(a)||/(webkit)[ \/]([\w.]+)/.exec(a)||/(opera)(?:.*version|)[ \/]([\w.]+)/.exec(a)||/(msie) ([\w.]+)/.exec(a)||a.indexOf("trident")>=0&&/(rv)(?::| )([\w.]+)/.exec(a)||a.indexOf("compatible")<0&&/(mozilla)(?:.*? rv:([\w.]+)|)/.exec(a)||[],c=/(ipad)/.exec(a)||/(iphone)/.exec(a)||/(android)/.exec(a)||/(windows phone)/.exec(a)||/(win)/.exec(a)||/(mac)/.exec(a)||/(linux)/.exec(a)||/(cros)/i.exec(a)||[];return{browser:b[3]||b[1]||"",version:b[2]||"0",platform:c[0]||""}},c=a.uaMatch(b.navigator.userAgent),d={},c.browser&&(d[c.browser]=!0,d.version=c.version,d.versionNumber=parseInt(c.version)),c.platform&&(d[c.platform]=!0),(d.android||d.ipad||d.iphone||d["windows phone"])&&(d.mobile=!0),(d.cros||d.mac||d.linux||d.win)&&(d.desktop=!0),(d.chrome||d.opr||d.safari)&&(d.webkit=!0),d.rv){var e="msie";c.browser=e,d[e]=!0}if(d.opr){var f="opera";c.browser=f,d[f]=!0}if(d.safari&&d.android){var g="android";c.browser=g,d[g]=!0}d.name=c.browser,d.platform=c.platform,a.browser=d}(jQuery,window);
;
(function ($) {
	$(document).ready(function(){
		var openClass = "open";//made into var in case it needs to change	    
		
/*From js injector, may not be needed
jQuery( ".accordion" ).accordion({ heightStyle: "content" });
jQuery( ".accordion" ).accordion( "refresh" );
jQuery( ".accordion" ).accordion({ active: 0 });
*/
    //Initialize accordions on class 'accordion' with a changestart event
    $(".accordion").accordion({changestart: function( event, ui ) {
			if ($(ui.oldHeader).offset() != null && 
			    (($(ui.oldHeader).offset().top + $(ui.oldHeader).height()) < $(window).scrollTop() ||  
			    ($(ui.oldHeader).offset().top > $(window).height() + $(window).scrollTop()))) 
			  {
    		//ui.oldHeader, // $ object, activated header
    		$("html, body").animate({scrollTop: ($(ui.oldHeader).offset().top)-100}, 300);
    		}     	
    	}
		});
    //Set the aria-hidden attributts for each ui-accordion-content element, make sure the one that is show is set to aria-hidden:false, all others are set to true
    $(".ui-accordion-header").not($(".ui-accordion-header.ui-state-active")).next(".ui-accordion-content").attr("aria-hidden","true");
    $(".ui-accordion-header.ui-state-active").next(".ui-accordion-content").attr("aria-hidden","false");

    $(".ui-accordion-header").attr("tabindex", "0");
    /*Fix for the jquery bug that does not set aria-expanded to false for when an accordion is collapsed*/
    $(".ui-accordion-header").click( function() {
        $(".ui-accordion-header").attr("aria-expanded", "false").next(".ui-accordion-content").attr("aria-hidden","true");
        $(".ui-accordion-header").attr("tabindex", "0");
        $(".ui-accordion-header.ui-state-active").attr("aria-expanded", "true" ).next(".ui-accordion-content").attr("aria-hidden","false");
    });

    $(".ui-accordion-header").keydown( function() {
        $(".ui-accordion-header").attr("aria-expanded", "false").next(".ui-accordion-content").attr("aria-hidden","true");
        $(".ui-accordion-header").attr("tabindex", "0");
        $(".ui-accordion-header.ui-state-active").attr("aria-expanded", "true" ).next(".ui-accordion-content").attr("aria-hidden","false");
    });


  
    // use a styling hook for users with js
    //$("body").addClass("js");
    // hide all but the first toggled content
    $(".toggleReveal").not($(".toggleReveal").first()).hide();
    
    // loop through toggle-able content and add aria support
    var countTog = 1;
    $(".toggleWrap .toggleReveal").each(function(){
           $(this).prev(":header").wrapInner('<button id="tog' + countTog + '-label" aria-controls="tog' + countTog + '" aria-expanded="false"></button>' );  	
           $(this).attr({role: "region", tabindex: "-1", "aria-labeledby": "tog" + countTog + "-label", id: "tog" + countTog + "", "aria-hidden":"true" });
           countTog++;
    });
    //Turn on first page toggle
    var firstToggle = $(".toggleReveal").first();
    firstToggle.attr("aria-hidden","false");
   	firstToggle.prev(":header").addClass(openClass).children("button").attr("aria-expanded","true");

    //Turn on the first toggle in each accordion, repeats for first toggle
    $(".accordion_toggles").each(function(){
    	$(".toggleWrap :header",this).first().addClass(openClass).children("button").attr("aria-expanded","true"); ;
    	$(".toggleWrap .toggleReveal",this).first().show().attr("aria-hidden","false");
    });
    		

       // toggle event, swap text, 508 aria support
       $(".toggleWrap :header button").click(function() {
              // the "a" should get styled with left padding and an image sprite for the +/- toggle
              // create a class called "open" in the CSS that modifies the original positioning of the image sprite to show the "-" instead
              //$(this).toggleClass("open");
              var reveal = $(this).parent().next('.toggleReveal');
              // if a toggle is clicked, check to see if its Reveal is already closed
              if($(this).attr('aria-expanded') == "false") {
                      // if its closed, slide down the content and animate the opacity to fade it in
                      $(this).attr("aria-expanded", "true");
                      reveal.css({"opacity": 0}).slideDown(300).animate({opacity: "1"}, 600).attr("aria-hidden","false");
                      $(this).parent().addClass(openClass);
              }
              else {
                      // if its open, animate the opacity to fade it out, slide it up
                      $(this).attr("aria-expanded", "false");
                      reveal.css({"opacity": 1}).animate({opacity: "0"}, 300).slideUp(300).attr("aria-hidden","true");
                      $(this).parent().removeClass(openClass);
              }
              return false;
       });
        $(".toggleWrap :header").click(function() {
					$(this).children("button").click();
				});

        //Expand and collapse alls for when only one toggle group is on the page
        $("#expand, .expand_all").click(function(){
    			$('.toggleReveal').css({"opacity": 0}).slideDown(300).animate({opacity: "1"}, 600).addClass(openClass).attr("aria-hidden","false");
    			$(".toggleWrap :header").addClass(openClass).children("button").attr("aria-expanded", "true");//prop('tagName');//$('.answer').show();
    			return false;
  			});
  			$("#collapse, .collapse_all").click(function(){
    			$('.toggleReveal').css({"opacity": 1}).animate({opacity: "0"}, 300).slideUp(300).removeClass(openClass).attr("aria-hidden","true");//	$('.answer').hide();
    			$(".toggleWrap :header").removeClass(openClass).children("button").attr("aria-expanded", "false");//prop('tagName');//$('.answer').show();
     			return false;
 				});
        //Expand and collapse alls for when there is more that one toggle group present, this was designed for use within accordions
        $(".acc_expand_all").click(function(){
        	var parentAccordion = $(this).closest(".accordion_toggles");
        	parentAccordion.find('.toggleReveal').each(function() {
    				$(this).css({"opacity": 0}).slideDown(300).animate({opacity: "1"}, 600).addClass(openClass).attr("aria-hidden","false");
    				$(this).closest(".toggleWrap").find(":header").addClass(openClass).children("button").attr("aria-expanded", "true");//prop('tagName');//$('.answer').show();
    			});
    			return false;
  			});
  			$(".acc_collapse_all").click(function(){
        	var parentAccordion = $(this).closest(".accordion_toggles");
        	parentAccordion.find('.toggleReveal').each(function() {
    				$(this).css({"opacity": 1}).animate({opacity: "0"}, 300).slideUp(300).removeClass(openClass).attr("aria-hidden","true");
    				$(this).closest(".toggleWrap").find(":header").removeClass(openClass).children("button").attr("aria-expanded", "false");//prop('tagName');//$('.answer').show();
    			});
     			return false;
 				});

});
	}( jQuery ) );;
/*! matchMedia() polyfill - Test a CSS media type/query in JS. Authors & copyright (c) 2012: Scott Jehl, Paul Irish, Nicholas Zakas, David Knight. Dual MIT/BSD license */

window.matchMedia || (window.matchMedia = function() {
    "use strict";

    // For browsers that support matchMedium api such as IE 9 and webkit
    var styleMedia = (window.styleMedia || window.media);

    // For those that don't support matchMedium
    if (!styleMedia) {
        var style       = document.createElement('style'),
            script      = document.getElementsByTagName('script')[0],
            info        = null;

        style.type  = 'text/css';
        style.id    = 'matchmediajs-test';

        script.parentNode.insertBefore(style, script);

        // 'style.currentStyle' is used by IE <= 8 and 'window.getComputedStyle' for all other browsers
        info = ('getComputedStyle' in window) && window.getComputedStyle(style, null) || style.currentStyle;

        styleMedia = {
            matchMedium: function(media) {
                var text = '@media ' + media + '{ #matchmediajs-test { width: 1px; } }';

                // 'style.styleSheet' is used by IE <= 8 and 'style.textContent' for all other browsers
                if (style.styleSheet) {
                    style.styleSheet.cssText = text;
                } else {
                    style.textContent = text;
                }

                // Test if media query is true or false
                return info.width === '1px';
            }
        };
    }

    return function(media) {
        return {
            matches: styleMedia.matchMedium(media || 'all'),
            media: media || 'all'
        };
    };
}());
;
/*! matchMedia() polyfill addListener/removeListener extension. Author & copyright (c) 2012: Scott Jehl. Dual MIT/BSD license */
(function(){
    // Bail out for browsers that have addListener support
    if (window.matchMedia && window.matchMedia('all').addListener) {
        return false;
    }

    var localMatchMedia = window.matchMedia,
        hasMediaQueries = localMatchMedia('only all').matches,
        isListening     = false,
        timeoutID       = 0,    // setTimeout for debouncing 'handleChange'
        queries         = [],   // Contains each 'mql' and associated 'listeners' if 'addListener' is used
        handleChange    = function(evt) {
            // Debounce
            clearTimeout(timeoutID);

            timeoutID = setTimeout(function() {
                for (var i = 0, il = queries.length; i < il; i++) {
                    var mql         = queries[i].mql,
                        listeners   = queries[i].listeners || [],
                        matches     = localMatchMedia(mql.media).matches;

                    // Update mql.matches value and call listeners
                    // Fire listeners only if transitioning to or from matched state
                    if (matches !== mql.matches) {
                        mql.matches = matches;

                        for (var j = 0, jl = listeners.length; j < jl; j++) {
                            listeners[j].call(window, mql);
                        }
                    }
                }
            }, 30);
        };

    window.matchMedia = function(media) {
        var mql         = localMatchMedia(media),
            listeners   = [],
            index       = 0;

        mql.addListener = function(listener) {
            // Changes would not occur to css media type so return now (Affects IE <= 8)
            if (!hasMediaQueries) {
                return;
            }

            // Set up 'resize' listener for browsers that support CSS3 media queries (Not for IE <= 8)
            // There should only ever be 1 resize listener running for performance
            if (!isListening) {
                isListening = true;
                window.addEventListener('resize', handleChange, true);
            }

            // Push object only if it has not been pushed already
            if (index === 0) {
                index = queries.push({
                    mql         : mql,
                    listeners   : listeners
                });
            }

            listeners.push(listener);
        };

        mql.removeListener = function(listener) {
            for (var i = 0, il = listeners.length; i < il; i++){
                if (listeners[i] === listener){
                    listeners.splice(i, 1);
                }
            }
        };

        return mql;
    };
}());
;
/* Respond.js: min/max-width media query polyfill. (c) Scott Jehl. MIT Lic. j.mp/respondjs  */
(function( w ){

	"use strict";

	//exposed namespace
	var respond = {};
	w.respond = respond;

	//define update even in native-mq-supporting browsers, to avoid errors
	respond.update = function(){};

	//define ajax obj
	var requestQueue = [],
		xmlHttp = (function() {
			var xmlhttpmethod = false;
			try {
				xmlhttpmethod = new w.XMLHttpRequest();
			}
			catch( e ){
				xmlhttpmethod = new w.ActiveXObject( "Microsoft.XMLHTTP" );
			}
			return function(){
				return xmlhttpmethod;
			};
		})(),

		//tweaked Ajax functions from Quirksmode
		ajax = function( url, callback ) {
			var req = xmlHttp();
			if (!req){
				return;
			}
			req.open( "GET", url, true );
			req.onreadystatechange = function () {
				if ( req.readyState !== 4 || req.status !== 200 && req.status !== 304 ){
					return;
				}
				callback( req.responseText );
			};
			if ( req.readyState === 4 ){
				return;
			}
			req.send( null );
		},
		isUnsupportedMediaQuery = function( query ) {
			return query.replace( respond.regex.minmaxwh, '' ).match( respond.regex.other );
		};

	//expose for testing
	respond.ajax = ajax;
	respond.queue = requestQueue;
	respond.unsupportedmq = isUnsupportedMediaQuery;
	respond.regex = {
		media: /@media[^\{]+\{([^\{\}]*\{[^\}\{]*\})+/gi,
		keyframes: /@(?:\-(?:o|moz|webkit)\-)?keyframes[^\{]+\{(?:[^\{\}]*\{[^\}\{]*\})+[^\}]*\}/gi,
		comments: /\/\*[^*]*\*+([^/][^*]*\*+)*\//gi,
		urls: /(url\()['"]?([^\/\)'"][^:\)'"]+)['"]?(\))/g,
		findStyles: /@media *([^\{]+)\{([\S\s]+?)$/,
		only: /(only\s+)?([a-zA-Z]+)\s?/,
		minw: /\(\s*min\-width\s*:\s*(\s*[0-9\.]+)(px|em)\s*\)/,
		maxw: /\(\s*max\-width\s*:\s*(\s*[0-9\.]+)(px|em)\s*\)/,
		minmaxwh: /\(\s*m(in|ax)\-(height|width)\s*:\s*(\s*[0-9\.]+)(px|em)\s*\)/gi,
		other: /\([^\)]*\)/g
	};

	//expose media query support flag for external use
	respond.mediaQueriesSupported = w.matchMedia && w.matchMedia( "only all" ) !== null && w.matchMedia( "only all" ).matches;

	//if media queries are supported, exit here
	if( respond.mediaQueriesSupported ){
		return;
	}

	//define vars
	var doc = w.document,
		docElem = doc.documentElement,
		mediastyles = [],
		rules = [],
		appendedEls = [],
		parsedSheets = {},
		resizeThrottle = 30,
		head = doc.getElementsByTagName( "head" )[0] || docElem,
		base = doc.getElementsByTagName( "base" )[0],
		links = head.getElementsByTagName( "link" ),

		lastCall,
		resizeDefer,

		//cached container for 1em value, populated the first time it's needed
		eminpx,

		// returns the value of 1em in pixels
		getEmValue = function() {
			var ret,
				div = doc.createElement('div'),
				body = doc.body,
				originalHTMLFontSize = docElem.style.fontSize,
				originalBodyFontSize = body && body.style.fontSize,
				fakeUsed = false;

			div.style.cssText = "position:absolute;font-size:1em;width:1em";

			if( !body ){
				body = fakeUsed = doc.createElement( "body" );
				body.style.background = "none";
			}

			// 1em in a media query is the value of the default font size of the browser
			// reset docElem and body to ensure the correct value is returned
			docElem.style.fontSize = "100%";
			body.style.fontSize = "100%";

			body.appendChild( div );

			if( fakeUsed ){
				docElem.insertBefore( body, docElem.firstChild );
			}

			ret = div.offsetWidth;

			if( fakeUsed ){
				docElem.removeChild( body );
			}
			else {
				body.removeChild( div );
			}

			// restore the original values
			docElem.style.fontSize = originalHTMLFontSize;
			if( originalBodyFontSize ) {
				body.style.fontSize = originalBodyFontSize;
			}


			//also update eminpx before returning
			ret = eminpx = parseFloat(ret);

			return ret;
		},

		//enable/disable styles
		applyMedia = function( fromResize ){
			var name = "clientWidth",
				docElemProp = docElem[ name ],
				currWidth = doc.compatMode === "CSS1Compat" && docElemProp || doc.body[ name ] || docElemProp,
				styleBlocks	= {},
				lastLink = links[ links.length-1 ],
				now = (new Date()).getTime();

			//throttle resize calls
			if( fromResize && lastCall && now - lastCall < resizeThrottle ){
				w.clearTimeout( resizeDefer );
				resizeDefer = w.setTimeout( applyMedia, resizeThrottle );
				return;
			}
			else {
				lastCall = now;
			}

			for( var i in mediastyles ){
				if( mediastyles.hasOwnProperty( i ) ){
					var thisstyle = mediastyles[ i ],
						min = thisstyle.minw,
						max = thisstyle.maxw,
						minnull = min === null,
						maxnull = max === null,
						em = "em";

					if( !!min ){
						min = parseFloat( min ) * ( min.indexOf( em ) > -1 ? ( eminpx || getEmValue() ) : 1 );
					}
					if( !!max ){
						max = parseFloat( max ) * ( max.indexOf( em ) > -1 ? ( eminpx || getEmValue() ) : 1 );
					}

					// if there's no media query at all (the () part), or min or max is not null, and if either is present, they're true
					if( !thisstyle.hasquery || ( !minnull || !maxnull ) && ( minnull || currWidth >= min ) && ( maxnull || currWidth <= max ) ){
						if( !styleBlocks[ thisstyle.media ] ){
							styleBlocks[ thisstyle.media ] = [];
						}
						styleBlocks[ thisstyle.media ].push( rules[ thisstyle.rules ] );
					}
				}
			}

			//remove any existing respond style element(s)
			for( var j in appendedEls ){
				if( appendedEls.hasOwnProperty( j ) ){
					if( appendedEls[ j ] && appendedEls[ j ].parentNode === head ){
						head.removeChild( appendedEls[ j ] );
					}
				}
			}
			appendedEls.length = 0;

			//inject active styles, grouped by media type
			for( var k in styleBlocks ){
				if( styleBlocks.hasOwnProperty( k ) ){
					var ss = doc.createElement( "style" ),
						css = styleBlocks[ k ].join( "\n" );

					ss.type = "text/css";
					ss.media = k;

					//originally, ss was appended to a documentFragment and sheets were appended in bulk.
					//this caused crashes in IE in a number of circumstances, such as when the HTML element had a bg image set, so appending beforehand seems best. Thanks to @dvelyk for the initial research on this one!
					head.insertBefore( ss, lastLink.nextSibling );

					if ( ss.styleSheet ){
						ss.styleSheet.cssText = css;
					}
					else {
						ss.appendChild( doc.createTextNode( css ) );
					}

					//push to appendedEls to track for later removal
					appendedEls.push( ss );
				}
			}
		},
		//find media blocks in css text, convert to style blocks
		translate = function( styles, href, media ){
			var qs = styles.replace( respond.regex.comments, '' )
					.replace( respond.regex.keyframes, '' )
					.match( respond.regex.media ),
				ql = qs && qs.length || 0;

			//try to get CSS path
			href = href.substring( 0, href.lastIndexOf( "/" ) );

			var repUrls = function( css ){
					return css.replace( respond.regex.urls, "$1" + href + "$2$3" );
				},
				useMedia = !ql && media;

			//if path exists, tack on trailing slash
			if( href.length ){ href += "/"; }

			//if no internal queries exist, but media attr does, use that
			//note: this currently lacks support for situations where a media attr is specified on a link AND
				//its associated stylesheet has internal CSS media queries.
				//In those cases, the media attribute will currently be ignored.
			if( useMedia ){
				ql = 1;
			}

			for( var i = 0; i < ql; i++ ){
				var fullq, thisq, eachq, eql;

				//media attr
				if( useMedia ){
					fullq = media;
					rules.push( repUrls( styles ) );
				}
				//parse for styles
				else{
					fullq = qs[ i ].match( respond.regex.findStyles ) && RegExp.$1;
					rules.push( RegExp.$2 && repUrls( RegExp.$2 ) );
				}

				eachq = fullq.split( "," );
				eql = eachq.length;

				for( var j = 0; j < eql; j++ ){
					thisq = eachq[ j ];

					if( isUnsupportedMediaQuery( thisq ) ) {
						continue;
					}

					mediastyles.push( {
						media : thisq.split( "(" )[ 0 ].match( respond.regex.only ) && RegExp.$2 || "all",
						rules : rules.length - 1,
						hasquery : thisq.indexOf("(") > -1,
						minw : thisq.match( respond.regex.minw ) && parseFloat( RegExp.$1 ) + ( RegExp.$2 || "" ),
						maxw : thisq.match( respond.regex.maxw ) && parseFloat( RegExp.$1 ) + ( RegExp.$2 || "" )
					} );
				}
			}

			applyMedia();
		},

		//recurse through request queue, get css text
		makeRequests = function(){
			if( requestQueue.length ){
				var thisRequest = requestQueue.shift();

				ajax( thisRequest.href, function( styles ){
					translate( styles, thisRequest.href, thisRequest.media );
					parsedSheets[ thisRequest.href ] = true;

					// by wrapping recursive function call in setTimeout
					// we prevent "Stack overflow" error in IE7
					w.setTimeout(function(){ makeRequests(); },0);
				} );
			}
		},

		//loop stylesheets, send text content to translate
		ripCSS = function(){

			for( var i = 0; i < links.length; i++ ){
				var sheet = links[ i ],
				href = sheet.href,
				media = sheet.media,
				isCSS = sheet.rel && sheet.rel.toLowerCase() === "stylesheet";

				//only links plz and prevent re-parsing
				if( !!href && isCSS && !parsedSheets[ href ] ){
					// selectivizr exposes css through the rawCssText expando
					if (sheet.styleSheet && sheet.styleSheet.rawCssText) {
						translate( sheet.styleSheet.rawCssText, href, media );
						parsedSheets[ href ] = true;
					} else {
						if( (!/^([a-zA-Z:]*\/\/)/.test( href ) && !base) ||
							href.replace( RegExp.$1, "" ).split( "/" )[0] === w.location.host ){
							// IE7 doesn't handle urls that start with '//' for ajax request
							// manually add in the protocol
							if ( href.substring(0,2) === "//" ) { href = w.location.protocol + href; }
							requestQueue.push( {
								href: href,
								media: media
							} );
						}
					}
				}
			}
			makeRequests();
		};

	//translate CSS
	ripCSS();

	//expose update for re-running respond later on
	respond.update = ripCSS;

	//expose getEmValue
	respond.getEmValue = getEmValue;

	//adjust on resize
	function callMedia(){
		applyMedia( true );
	}

	if( w.addEventListener ){
		w.addEventListener( "resize", callMedia, false );
	}
	else if( w.attachEvent ){
		w.attachEvent( "onresize", callMedia );
	}
})(this);
;
function menuToggle(obj) {
    jQuery(obj).parent().attr("style", "cursor:pointer;");
    var button = jQuery(obj).parent().find("button");
    var ul = jQuery(obj).parent().find("ul");
    jQuery(ul).slideToggle( 400, function() {
        if (jQuery(ul).is(":visible")) {
            jQuery(ul).attr("aria-hidden", "false");
            jQuery(button).attr("aria-expanded", "true");
        } else {
            jQuery(ul).attr("aria-hidden", "true");
            jQuery(button).attr("aria-expanded", "false");
        }; 
    });
}

function mobileMenus() {
    var menuIDs = [
        "block-menu-menu-main-menu",
        "block-menu-menu-tables-mobile",
        "block-menu-menu-prevention-mobile",
        "block-menu-menu-early-detection-mobile",
        "block-menu-menu-diagnosis-mobile",
        "block-menu-menu-treatment-mobile",
        "block-menu-menu-life-after-cancer-mobile",
        "block-menu-menu-end-of-life-mobile",
        "block-menu-menu-about-mobile",
        "block-menu-menu-tools-mobile",
        ];

    var i = 0;
    for (i; i<menuIDs.length; i++) {
        jQuery( "#" + menuIDs[i] + " header").click( function() { menuToggle(this) });
        jQuery( "#" + menuIDs[i] ).attr("style", "cursor:pointer;");

        // move menus to the top except for about and tools
        if ( jQuery.inArray( menuIDs[i], ["block-menu-menu-about-mobile", "block-menu-menu-tools-mobile"] ) < 0 ){
             jQuery( "#" + menuIDs[i] ).insertAfter(jQuery("#block-menu-menu-main-menu"));
        }

        // create buttons for accessibility
        if ( menuIDs[i] == "block-menu-menu-main-menu" ) {
            var button_class = "main-menu-mobile-expand"
        } else {
            var button_class = "menu-mobile-expand"
        }
        var button_id = menuIDs[i] + "-button";
        var h2_id = menuIDs[i] + "-header";
        var ul_id = menuIDs[i] + "-dropdown";
        var html = "<button id='" + button_id + "' class='" + button_class + "' aria-controls='" + ul_id + "' aria-expanded='false' ><i class='fa fa-bars'></i></button>";
        var h2 = jQuery( "#" + menuIDs[i] ).find("h2");
        var h2_text = jQuery( h2 ).html();
        jQuery( h2 ).html( "<span class='header-text'>" + h2_text + "</span>" );
        jQuery( h2 ).attr("id", h2_id).prepend( html );

        jQuery( "#" + menuIDs[i] + " ul").attr("id", ul_id).attr("aria-labeledby", h2_id).attr("style", "display:none").attr("aria-hidden", "true");

    }
}

//add subscript to tables/kidney-lung-ovarian-protate
if (window.location.pathname.indexOf("tables/kidney-lung-ovarian-prostate") >= 0) {
    
}

// pdf generate
function set_pdf_generate_html( data ) {
    jQuery("#pdf_generate").html( data );
}

if (window.location.pathname.indexOf("pdf_generate") >= 0) {

    var pdf_generate_url = 'https://progressreport.cancer.gov/html_to_pdf/website_serialize/1/';
    // For dev
    //var pdf_generate_url = 'https://www26.imsweb.com/html_to_pdf/website_serialize/1/';
    jQuery( document ).ready( function() {
        jQuery.ajax( { type:"GET",
                         url: pdf_generate_url,
                         dataType:"jsonp",
                         jsonp: "set_pdf_generate_html"});

    });

}

jQuery( document ).ready( function() {
    jQuery("#block-superfish-1").attr("role", "navigation");
    jQuery("#block-superfish-1").attr("aria-label", "main");
	
	jQuery("#block-superfish-2").attr("role", "navigation");
    jQuery("#block-superfish-2").attr("aria-label", "about the report");

    jQuery("#block-superfish-3").attr("role", "navigation");
    jQuery("#block-superfish-3").attr("aria-label", "prevention");

    jQuery("#block-superfish-4").attr("role", "navigation");
    jQuery("#block-superfish-4").attr("aria-label", "early detection");
	
	jQuery("#block-superfish-5").attr("role", "navigation");
    jQuery("#block-superfish-5").attr("aria-label", "treatment");
	
	jQuery("#block-superfish-6").attr("role", "navigation");
    jQuery("#block-superfish-6").attr("aria-label", "diagnosis");
	
	jQuery("#block-superfish-7").attr("role", "navigation");
    jQuery("#block-superfish-7").attr("aria-label", "life after cancer");
	
	jQuery("#block-superfish-8").attr("role", "navigation");
    jQuery("#block-superfish-8").attr("aria-label", "end of life");
	
	jQuery("#block-superfish-9").attr("role", "navigation");
    jQuery("#block-superfish-9").attr("aria-label", "summary tables");

    jQuery("#block-superfish-10").attr("role", "navigation");
    jQuery("#block-superfish-10").attr("aria-label", "tools");


    //Turn off focus for top level menu, will work on hover only. This is so screen readers can only access top level of menu
    jQuery(".menuparent").off("focus");

    // Enable click/enter on top menu to go to the link directly instead of doing nothing
    jQuery("a.menuparent").click(function(){
                window.location.href = jQuery(this).attr('href');
    });

});




// left nav dom order
function moveSidebarMenu() {
    if (jQuery(window).width() >=1025) {
            jQuery(".region.region-sidebar-first.sidebar").insertBefore(jQuery("#main-content"));
            for ( var i=3; i<10; i++ ) {
                jQuery("#block-superfish-" + i).insertBefore(jQuery("#block-superfish-2"));
            }
            jQuery(".region.region-sidebar-first.sidebar").attr("style", "margin-left:-33% !important;");
    }
    if ( (jQuery(window).width() < 1025) && (jQuery(window).width() >1008) ) {
            jQuery(".region.region-sidebar-first.sidebar").insertBefore(jQuery("#main-content"));
            for ( var i=3; i<10; i++ ) {
                jQuery("#block-superfish-" + i).insertBefore(jQuery("#block-superfish-2"));
            }
            jQuery(".region.region-sidebar-first.sidebar").attr("style", "margin-left:-25% !important;");
            jQuery("#content-column").attr("style", "width: 75%");
    }
    if ( (jQuery(window).width() < 1008) && (jQuery(window).width() >768) ) {
            jQuery(".region.region-sidebar-first.sidebar").insertBefore(jQuery("#main-content"));
            for ( var i=3; i<10; i++ ) {
                jQuery("#block-superfish-" + i).insertBefore(jQuery("#block-superfish-2"));
            }
            jQuery(".region.region-sidebar-first.sidebar").attr("style", "margin-left:-25% !important;");
    } 
    if ( (jQuery(window).width() <= 768) ) {
            jQuery(".region.region-sidebar-first.sidebar").insertAfter(jQuery("#main-content"));
            for ( var i=3; i<10; i++ ) {
                jQuery("#block-superfish-" + i).insertAfter(jQuery("#block-superfish-1"));
            }
            jQuery(".region.region-sidebar-first.sidebar").attr("style", "margin-left:0 !important;");
    }
}

jQuery( document ).ready( function() { 
    moveSidebarMenu();
});

// create popup links
function createPopups() {
    var popupLinks = ["#header a[href$='/dictionary']", "#header a[href$='/pdf_generate']"];
    for (var i=0; i<popupLinks.length; i++){
        var menu_link = jQuery( popupLinks[i] );
        var old_href = menu_link.attr( "href" );
        var new_href = window.location.protocol + "//" + window.location.hostname+ (window.location.port ? ':'+window.location.port: '') + old_href;
        if (i==1){
            menu_link.attr( "href", "javascript:popupWindow('" + new_href + "', '','width=760, height=500, scrollbars=yes');" );
        } else {
            menu_link.attr( "href", "javascript:popupWindow('" + new_href + "', '','width=400, height=500, scrollbars=yes');" );
        }
    }
}

function popupWindow(target, title, attrs) {
    window.open(target, '', attrs);
}

jQuery( document ).ready( function() {
    createPopups();

    mobileMenus();
});

//external links
jQuery(document).ready(function() {
  jQuery('span.ext').each(function() {
    jQuery(this).wrap('<a href="../external-link-policy"></a>');
    jQuery(this).parent().insertAfter( jQuery(this).parent().parent() );
  });
});

// popup window
if ((window.location.pathname.indexOf("dictionary") >= 0) || (window.location.pathname.indexOf("graph_help") >= 0) || (window.location.pathname.indexOf("pdf_generate") >= 0)) {
  jQuery( document ).ready( function() {
    jQuery( "#block-search-form" ).remove();
    jQuery( ".below-nav" ).first().remove();
    jQuery( "#breadcrumb" ).remove();
    jQuery( ".sidebar" ).first().remove();
    jQuery( "#page-title" ).remove();
    jQuery( "#tasks" ).remove();
    jQuery( "#admin-menu" ).remove();

  });
}

//summary tables
if (window.location.pathname.indexOf("/tables/") >= 0) {
  jQuery( document ).ready( function() {
    jQuery("body").append('<div id="modal-graph" class="modal" style="width: auto; min-height: 93px; height: auto;" scrolltop="0" scrollleft="0"><img alt="" src=""></div>');
  })
}


// window resize - should be last
jQuery( window ).resize(function() {
    moveSidebarMenu();
});

;
/**
 makes all panels in a row the same size
 */
jQuery(document).ready(function(){
for(i=1;i<=5;i++) {
  // keep track of the tallestCol column in each row [i]
  var tallestCol = new Array();
  tallestCol[i] = 0;
  var panelclass = '.panelheight'+i;
  // loop through columns in this row and find the tallestCol
  jQuery(panelclass).each(function(){
    if ( jQuery(this).outerHeight(true) > tallestCol[i] )
      tallestCol[i] = jQuery(this).outerHeight(true);
  });
  // loop through columns in this row and adjust height as necessary
  jQuery(panelclass).each(function(){
    // check if current column needs to be adjusted
    if ( jQuery(this).outerHeight(true) < tallestCol[i] ) {
      // set new height
      jQuery(this).height( tallestCol[i] );
    }
  });
}
});;
