/**
 * Niget - A library to fetch data from Nilde API and to display it using templates. It ships with a set of different widget flavours. i18n dynamic support.
 * @version 0.2
 * @namespace niget
 * @type {object}
 */
var niget = {
	bUrl: null,
	itemsList: null,
	aToken : null,
	locale : null,
	itemDetail: {},
	assetsPath: null,
	/**
	 * Instantiate mandatory data to access API
	 * @memberof niget
	 * @method init
	 * @param {string} baseUrl - The root URL of APIs
	 * @param {string} accessToken - The access token to provide to each API request
	 * @param {string} localeLang - The language of widget interface, default is IT.
	 * @param {string} refreshToken - The refresh token, used to obtain a new access token
	 * @param {string} assets - The relative path for the assets, like css, js and locale
     */
	init : function(baseUrl, accessToken, localeLang, refreshToken, assets){
	    // qui setto accessToken (che sara in una variabile php, quindi sta funzione serve per essere chiamata tipo
	    this.bUrl=baseUrl;
	    this.aToken=accessToken;
		this.locale = niget.checkLang(localeLang);
		this.assetsPath=assets;
		this.updateLang(this.locale);
		/*new Ajax.Request('locales/'+this.locale+'.js',
			{
				method:'GET',
				asynchronous: false,
				requestHeaders: {
					'X-Requested-With': null,
					'X-Prototype-Version': null
				},

				onComplete: function (transport)
				{
					this.localeStrings=JSON.parse(transport.responseText);
				}.bind(this)
			});*/
		},
	/**
	 * Retrieves an array of object from the API of the type defined in the endpoint and set it
	 * @memberof niget
	 * @method list
	 * @param {string} endpoint - The resource type to request to the API
	 * @param [args] - An object that contains the parameters to be passed to filter requests
     */
	list : function(endpoint, args){
		/*var issn = issn;
		var pubyear = pubyear;*/
		var url = this.bUrl + endpoint;
		/*if(issn) {
		    url += sep + 'issn=' + issn;
		    sep = "&";
		}
		if(pubyear) {
			url += sep + 'pubyear=' + pubyear;
		}*/
		//var baseUrl = this.bUrl+endpoint;
		/*if (issn !== null && pubyear == undefined) {
			var url = baseUrl+'?issn='+issn;
		} else if (pubyear !== null && issn == undefined) {
			var url = baseUrl+'?pubyear='+pubyear;
		} else if (issn !== null && pubyear !== null) {
			var url = baseUrl+'?issn='+issn+'&pubyear='+pubyear;
		}*/
		if (this.aToken!== null) {
			new Ajax.Request(url,
		{
				method:'GET',	
				asynchronous: false,			
				parameters: args,
				requestHeaders: {
								'Authorization': 'Bearer '+this.aToken,
 								'X-Requested-With': null,
 								'X-Prototype-Version': null
								},

				onComplete: function (transport)
				{						
						this.itemsList=JSON.parse(transport.responseText);						
				}.bind(this)			
		});
			
		}
	},
	/**
	 * Retrieves an object from the API based on the type defined by the endpoint and the ID provided
	 * @memberof niget
	 * @method single
	 * @param {string} endpoint - The resource type to request to the API
	 * @param {number} ID - The ID number of the resource requested
     */
	single : function(endpoint, ID){
		if (this.aToken!== null) {
			if (this.itemDetail!==null) {
						new Ajax.Request(this.bUrl+'/'+endpoint + '/'+ID,
					{
							method:'GET',	
							asynchronous: false,
							requestHeaders: {
											'Authorization': 'Bearer '+this.aToken,
			 								'X-Requested-With': null,
			 								'X-Prototype-Version': null
											},
			
							onComplete: function (transport)
							{
								//console.log("this.itemDetail['"+endpoint+"']['"+ID+"']=JSON.parse(transport.responseText)");

								//this.itemDetail[id2]=JSON.parse(transport.responseText);
								//x={'endpoint': [1,3,4],'licenses':[34,56]}
								//this.itemDetail[{endpoint}][{ID}]=JSON.parse(transport.responseText);
								//eval("this.itemDetail."+endpoint[''"ID+"']=JSON.parse(transport.responseText)"
								//if(this.itemDetail[endpoint]){this.itemDetail[endpoint] = {};}
								//id2=new String(ID);
								//this.itemDetail[endpoint][ID]=JSON.parse(transport.responseText);
								var v = JSON.parse(transport.responseText);

								// try if endpoint, the resource, exists as a child object of itemDetail, else the error is catched and the creation of the endpoint/resource object is made
								try {
									this.itemDetail[endpoint][ID] = v;
								}
								catch(err) {
									// computed property names inside object initializers are not supported by Internet Explorer so the code commented below is rewritten
									// this.itemDetail[endpoint] = { [ID]: v };
									this.itemDetail[endpoint] = {};
									this.itemDetail[endpoint][ID] = v;
								}
							}.bind(this)			
					});
			}
		}
	},
	/**
	 * Shows a widget based on the template provided, the DOM element target, the data to display and the language of the interface
	 * @memberof niget
	 * @method show
	 * @param template {string} The template file name, contained in `templates` folder and without `.handlebars` expression.
	 * @param targetId {string} The DOM element ID
	 * @param dataContext {object} The data passed as an object to be accessible and rendered inside the template
	 * @param [localeLang] {string} The language to set for the locale
     */
	show: function(template, targetId, dataContext, localeLang){
		var templ = Handlebars.getTemplate(template);
		this.locale = localeLang ? niget.checkLang(localeLang) : niget.checkLang(this.locale);
		if (this.localeStrings[this.locale]==null) {
			this.updateLang(this.locale);
		};
		//var langTmp = localeLang || this.locale;
		var intlData = {
			'locales': this.locale,
			'messages' : this.localeStrings[this.locale]
		};
		console.log(intlData);
		var htmlout = templ(dataContext, {
			data: {intl: intlData}
		});
		document.getElementById(targetId).insertAdjacentHTML('beforeend',htmlout);
	},
	/**
	 * Helper function to check if the language passed is supported and if not returns the default
	 * @memberof niget
	 * @param lang {string} The language to check
	 * @returns {string|*} A valid and supported language
     */
	checkLang : function(lang) {
		lang = ([ 'en', 'it' ].filter(function(x) { return x == lang; }).length > 0 ? lang : 'it');
		console.log("check lang ritorna: "+lang);
		return lang;
	},
	localeStrings: [],
	/**
	 * Set the current Language and translates widget strings accordingly
	 * @memberof niget
	 * @method updateLang
	 * @param lang optionally can change manually the language of the locale
     */
	updateLang : function(lang) {
		console.log(this.locale+ ' il locale');
		console.log(lang+' il parametro lang');
		//if (lang != 'it' || 'en' ) {
		//	lang = 'it';
		//}
		if (this.assetsPath) {

			var path = this.assetsPath + '/locales/' + lang + '.json'
		} else {
			var path = 'locales/' + lang + '.json'
		}
		new Ajax.Request(path,
			{
				method:'GET',
				asynchronous: false,
				requestHeaders: {
					'X-Requested-With': null,
					'X-Prototype-Version': null
				},

				onComplete: function (transport)
				{
					this.localeStrings=JSON.parse(transport.responseText);
				}.bind(this)
			});
	},
	/**
	 * Licenses - widget flavour to display a list of licenses and the detail of the one selected
	 * @memberof niget
	 * @type {object}
	 * @namespace niget.licenses
	 */
	licenses : {
		currentLabel : null,
		currentTab : null,
		name: null,
		cache : {},
		parameters: {'onlypub':1,
					'mineneg':1},
		/**
		 * Create the widget flavour _licenses_
		 * @memberof niget.licenses
		 * @method create
		 * @param target - The DOM element to attach the widget
         * @param name - The name of the widget: it's assigned as an element ID
		 * @param issn - The issn number
		 * @param pubyear - The Publication year of the licenses
		 * @param isbn - The ISBN number
		 * @param [year] - The year of validity of the license
		 * @param callback - A callback function that take the selected license as an object
         */
		create : function(target, name, issn, pubyear, isbn, year, callback) {
			niget.licenses.name = name;
			var today = new Date();
			var curYear = today.getFullYear();
			var containerContext = {
				id: name,
				cyear: curYear,
				cyear1: curYear - 1,
				cyear2: curYear - 2
			};
			if (issn) niget.licenses.parameters.issn = issn;
			if (pubyear) niget.licenses.parameters.pubyear = pubyear;
			if (isbn) niget.licenses.parameters.isbn = isbn;
			if (year) {
				niget.licenses.parameters.year = year;
				containerContext.selyear=parseInt(year);
			} else {containerContext.selyear=parseInt(niget.licenses.parameters.year)}

			var elName = document.getElementById(name);
			if (elName) {
				var elContainer = elName.parentNode;
				elContainer.removeChild(elName);
			}
			niget.show('liccontainer', target, containerContext);
			jQuery('select.dropdown').dropdown();

			var loader = document.createElement('div');
			loader.innerHTML = '<div class="ui very padded segment"><div class="ui active inverted dimmer"><div class="ui text loader">Loading</div></div><p></p></div>';
			document.getElementById(name).appendChild(loader);
			niget.list('licenses', niget.licenses.parameters);
			var context = niget.itemsList;
			//aggiungere show lictab.handlebars e mettere il template parziale che va agganciato a liccontainer, aggiungere anche il template vuoto
			if(typeof niget.itemsList.data != "undefined" && niget.itemsList.data != null && niget.itemsList.data.length > 0) {
				niget.show('lictab','mainlics', context);
				niget.show('lictable','tab-list', context);
				niget.licenses.tab(niget.licenses.name);
				niget.licenses.listdetails("licdetails", "nildeLicId", "tab-detail", "licenses", "licdetail");
				this.currentLabel = document.getElementById("label-list");
				this.currentTab = document.getElementById("tab-list");
				var adoptlic = document.getElementById("adopt-lic");
				var unselectlic = document.getElementById("unselect-lic");
				var withoutlic = document.getElementById("without-lic");
				var nolic = document.getElementById("no-lic");
				var helplic = document.getElementById("help-lic");
				var checkbx = jQuery('.ui.checkbox');
				var tablist = jQuery('#tab-list');
				checkbx.checkbox({onChecked: function() {
					adoptlic.classList.remove("disabled");
					withoutlic.classList.add("disabled");
					nolic.classList.add("disabled");
				}});
				unselectlic.addEventListener('click', function () {
					checkbx.each(function() {
						if (jQuery(this).checkbox('is checked')) {
							jQuery(this).checkbox('set unchecked');
						}
						if (! (adoptlic.classList.contains("disabled"))) {
							adoptlic.classList.add("disabled");
						}
						if (withoutlic.classList.contains("disabled")) {
							withoutlic.classList.remove("disabled")
						};
						if (nolic.classList.contains("disabled")) {
							nolic.classList.remove("disabled")
						};
					});
				});
				adoptlic.addEventListener('click', function () {
					var selid=null;
					checkbx.each(function() {
						if (jQuery(this).checkbox('is checked')) {
							selid = this.parentNode.parentNode.dataset.nildeLicId;
							this.parentNode.parentNode.classList.add("positive");
						} else {this.parentNode.parentNode.classList.add("disabled");}
					});
					jQuery('.dropdown.selection').addClass("disabled");
					adoptlic.classList.add("disabled");
					unselectlic.classList.add("disabled");
					helplic.classList.add("disabled");
					if (selid!=null) {
						niget.single("licenses", selid);
						callback(niget.itemDetail.licenses[selid]);
					} else {
						// Questo non si dovrebbe mai verificare
						alert("Nessuna licenza selezionata. Si prega di selezionare una licenza")
					}
				});
				jQuery('.helppopup').popup();
			} else {
				niget.show('licempty','mainlics', context);
				jQuery('.helppopup').popup();
			}
			document.getElementById(name).removeChild(loader);
			niget.licenses.selectYears(target, name, callback);
			var withoutlic = document.getElementById("without-lic");
			var nolic = document.getElementById("no-lic");
			var helplic = document.getElementById("help-lic");
			withoutlic.addEventListener('click', function () {
				if (tablist) {
					checkbx.each(function() {
						this.parentNode.parentNode.classList.add("disabled");
					});
					unselectlic.classList.add("disabled");
				};
				jQuery('.dropdown.selection').addClass("disabled");
				nolic.classList.add("disabled");
				withoutlic.classList.add("disabled");
				helplic.classList.add("disabled");
				callback();
			});
			nolic.addEventListener('click', function () {
				if (tablist) {
					checkbx.each(function() {
						this.parentNode.parentNode.classList.add("disabled");
					});
					unselectlic.classList.add("disabled");
				};
				jQuery('.dropdown.selection').addClass("disabled");
				withoutlic.classList.add("disabled");
				nolic.classList.add("disabled");
				helplic.classList.add("disabled");
				callback(-1);
			});
		},
		/**
		 * @memberof niget.licenses
		 * @method tab
		 * @param widgetId - The ID of the main DOM element of the widget
		 */
		tab : function(widgetId) {
			var tablabelsname = document.getElementById(widgetId).getElementsByClassName("tabular menu")[0].children;
			for (var i = 0; i < tablabelsname.length; i++) {
				tablabelsname[i].addEventListener('click', function () {
					var tabdataname = this.dataset.tab;
					var clickID = this.id;
					if (clickID != "label-" + niget.licenses.currentLabel.id) {
						niget.licenses.currentLabel.classList.remove("active");
						this.classList.add("active");
						niget.licenses.currentLabel = this;
						niget.licenses.currentTab.classList.remove("active");
						var clickTab = document.getElementById("tab-"+tabdataname);
						clickTab.classList.add("active");
						niget.licenses.currentTab = clickTab;
					}
				});
				/*var tablabelsname = document.getElementsByClassName("tabular menu")[0].children;
				 var tabsname = document.getElementsByClassName("tab");
				 console.log(tablabelsname);
				 for (var i = 0; i < tablabelsname.length; i++) {
				 tablabelsname[i].addEventListener('click', function()
				 {
				 var tabdataname = this.dataset.tab;
				 console.log(tabdataname);
				 console.log(tabsname);
				 for (var ii=0; ii < tabsname.length; ii++ ) {
				 var tabii=tabsname[ii];
				 var tablabelii=tablabelsname[ii];

				 if(tabii.dataset.tab == tabdataname) {
				 tabii.classList.add("active");
				 } else {
				 tabii.classList.remove("active");
				 }

				 if(tablabelii.dataset.tab == tabdataname) {alertId
				 tablabelii.classList.add("active");
				 } else {
				 tablabelii.classList.remove("active");
				 }
				 };
				 });
				 }*/
			}
		},
		/**
		 * Logic for the selected year dropdown menu
		 * @memberof niget.licenses
		 * @method selectYears
		 * @param target - the target of the new create
		 * @param name - the name of the new widget created by the language change
		 */
		selectYears : function(target, name, callback) {
			var licyear = document.getElementById('lic-year');
			licyear.addEventListener('change', function() {
				niget.licenses.parameters.year = this.value;
				if(niget.licenses.parameters.year == "all") {
					delete niget.licenses.parameters.year
				}
				niget.licenses.create(target, name, null, null, null,null,callback);
				/*document.getElementById('tab-list').innerHTML = "";
				niget.list('licenses', niget.licenses.parameters);
				niget.show('lictable','tab-list', niget.itemsList);
				niget.licenses.tab(niget.licenses.name);
				niget.licenses.listdetails("licdetails", "nildeLicId", "tab-detail", "licenses", "licdetail");
				niget.licenses.currentLabel = document.getElementById("label-list");
				niget.licenses.currentTab = document.getElementById("tab-list");*/
			})
		},
		/**
		 * Set the owner of the license in order to display it more easily.
		 * @param id - The ID of the license
         */
		setOwner : function(id) {
			if (niget.itemDetail.licenses[id]) {
				var ownerType = niget.itemDetail.licenses[id].data.relationships.owner.data.type;
				var ownerId = niget.itemDetail.licenses[id].data.relationships.owner.data.id;
				var included = niget.itemDetail.licenses[id].included;
				for (var i = 0; i < included.length; i++) {
					if (included[i].type==ownerType) {
						niget.itemDetail.licenses[id].owner = included[i].attributes;
						console.log("owner: "+niget.itemDetail.licenses[id].owner);
						break;
					}
				}
			} else {
				console.log("Call niget.single() before niget.licenses.setOwner");
			}
		},
		/**
		 * Connect a list of resources with their single representation, making the query for the single resource and displaying the data in the corresponding DOM element
		 * @param {string} triggerEl - The trigger DOM element in which a listener is added
		 * @param {string} dataSet - the data-nilde- name with which we take the single resource id
		 * @param {string} targetEl - The target DOM element where the final output is attached
		 * @param {string} resource - The resource type to request to the API
		 * @param {string} singleTemplate - The template for display the single resource
		 */
		listdetails : function(triggerEl, dataSet, targetEl, resource, singleTemplate) {
			var itemslisthtml = document.getElementsByClassName(triggerEl);
			for (var i = 0; i < itemslisthtml.length; i++) {
				itemslisthtml[i].addEventListener('click', function ()
				{
					var id = this.parentNode.parentNode.dataset[dataSet];
					niget.single(resource, id);
					console.log(niget.itemDetail[resource][id]);
					if(niget.itemDetail[resource][id].data.attributes.contr_tipo==0){niget.licenses.setOwner(id);}
					var contextdet = niget.itemDetail[resource][id];
					var tEl = document.getElementById(targetEl);
					if (tEl.innerHTML !=="") {
						tEl.innerHTML ="";
					}
					var listLabel = document.getElementById("label-list");
					var listTab = document.getElementById("tab-list");
					var detailLabel = document.getElementById("label-detail");
					listLabel.classList.remove("active");
					listTab.classList.remove("active");
					tEl.classList.add("active");
					detailLabel.classList.add("active");
					niget.licenses.currentLabel = detailLabel;
					niget.licenses.currentTab = tEl;
					niget.show(singleTemplate, targetEl, contextdet);
				});
			}
		}
	}
};
Handlebars.getTemplate = function(name) {
    console.log("templates function working");
    if (Handlebars.templates === undefined || Handlebars.templates[name] === undefined) {
        console.log("template undefined");
		if (niget.assetsPath) {
			var path = niget.assetsPath + '/templates/' + name + '.handlebars'
		} else {
			var path = 'templates/' + name + '.handlebars'
		}
				new Ajax.Request(path,
					{
						method:'GET',
						asynchronous: false,
						onComplete: function (data)
						{
							console.log("success compiling template");
							if (Handlebars.templates === undefined) {
								Handlebars.templates = {};
							}
							Handlebars.templates[name] = Handlebars.compile(data.responseText);
							Handlebars.registerHelper("switch", function(value, options) {
								this._switch_value_ = value;
								var html = options.fn(this); // Process the body of the switch block
								delete this._switch_value_;
								return html;
							});
							Handlebars.registerHelper("case", function() {
								// Convert "arguments" to a real array - stackoverflow.com/a/4775938
								var args = Array.prototype.slice.call(arguments);

								var options    = args.pop();
								var caseValues = args;

								if (caseValues.indexOf(this._switch_value_) === -1) {
									return '';
								} else {
									return options.fn(this);
								}
							});
							Handlebars.registerHelper('ifeq', function (a, b, options) {
								// if operator that compares values gist.github.com/tnguyen14/288bc9936d1884596530
								if (a === b) {
									return options.fn(this);
								} else {
									return options.inverse(this);
								}
							});
							Handlebars.registerHelper("x", function (expression, options) {
								var fn = function(){}, result;

								// in a try block in case the expression have invalid javascript
								try {
									// create a new function using Function.apply, notice the capital F in Function
									fn = Function.apply(
										this,
										[
											'window', // or add more '_this, window, a, b' you can add more params if you have references for them when you call fn(window, a, b, c);
											'return ' + expression + ';' // edit that if you know what you're doing
										]
									);
								} catch (e) {
									console.warn('[warning] {{x ' + expression + '}} is invalid javascript', e);
								}

								// then let's execute this new function, and pass it window, like we promised
								// so you can actually use window in your expression
								// i.e expression ==> 'window.config.userLimit + 10 - 5 + 2 - user.count' //
								// or whatever
								try {
									// if you have created the function with more params
									// that would like fn(window, a, b, c)
									result = fn.call(this, window);
								} catch (e) {
									console.warn('[warning] {{x ' + expression + '}} runtime error', e);
								}
								// return the output of that result, or undefined if some error occured
								return result;
							});
							Handlebars.registerHelper("xif", function (expression, options) {
								return Handlebars.helpers["x"].apply(this, [expression, options]) ? options.fn(this) : options.inverse(this);
							});
						}
					});
    }
    return Handlebars.templates[name];
};

/*new Ajax.Request(URL,	
		{
				method:'GET',				
				parameters: { 'operazione': 'fuffa' },
				onComplete: function (transport)
				{						
						$('IDDIV').update(transport.responseJSON);						
				}			
		});*/
