var FeatureChecker = (function(win, doc, nav) {
	var FLASH_MIME_TYPE = 'application/x-shockwave-flash',
		DEFAULT_TIMEOUT = 2000,
		DEFAULT_CHECKER_PATH = 'ppap.swf',
		CHROME_NAVIGATOR_VERSION = '56',
		DEFAULT_APPLET_CALLBACK_NAME = '__appInit',
		MEDIA_SOURCE_TYPES = [
			//[mime type; codecs]
			'video/ogg',
			'video/ogg; codecs="theora, vorbis"',

			'video/webm',
			'video/webm; codecs="vp8"',
			'video/webm; codecs="vorbis"',
			'video/webm; codecs="vp8, vorbis"',
			'video/webm; codecs="vp9, vorbis"',
			'audio/webm; codecs="vorbis"',

			'video/mp4',
			'video/mp4; codecs="avc1.66.13,  mp4a.40.2"',
			'video/mp4; codecs="avc1.42e01e, mp4a.40.2"',
			'video/mp4; codecs="avc1.66.30,  mp4a.40.5"',
			'video/mp4; codecs="avc1.42001e, mp4a.40.5"',
			'video/mp4; codecs="avc1.42001f, mp4a.40.5"',
			'video/mp4; codecs="avc1.77.30,  mp4a.40.5"',
			'video/mp4; codecs="avc1.4d001e, mp4a.40.5"',
			'video/mp4; codecs="avc1.4d001f, mp4a.40.5"',
			'video/mp4; codecs="avc1.640029, mp4a.40.5"',
			'audio/mp4; codecs="mp4a.40.2"',
			'audio/mp4; codecs="mp4a.40.5"',
			'audio/mp4; codecs="mp4a.67"',
			'video/mp4; codecs="mp4a.40.2"',
			'video/mp4; codecs="avc1.4d001e, mp4a.40.2"',

			'video/x-m4v',
			'video/quicktime',
			'video/mp4; codecs="mp4v.20.8, mp4a.40.3"',
			'video/mp4; codecs="mp4v.20.8, samr"',

			'application/x-mpegurl',
			'application/vnd.apple.mpegurl',
			'application/vnd.ms-ss',
			'application/vnd.ms-sstr+xml'
		],

		instance = null;

	function convertVersion(string) {
		var versionArray = string.split(',').map(function(item) {
			return parseInt(item, 10);
		});

		return {
			major   : versionArray[0],
			minor   : versionArray[1],
			release : versionArray[2]
		};
	}

	function FeatureChecker(options) {
		if (instance !== null) {
			return instance;
		}

		instance = this;

		this.timeout = options.timeout || DEFAULT_TIMEOUT;
		this.appletUrl = options.appletUrl || DEFAULT_CHECKER_PATH;
		this.appletCallbackName = options.appletCallbackName || DEFAULT_APPLET_CALLBACK_NAME;

		this.checkerObject = null;
		this.timeoutId = null;
		this.queue = [];
		this.isFlashBlocked = false;
		this.isFlashEnabled = false;
		this.isChecked = false;
	}

	FeatureChecker.prototype.createAppletCallback = function() {
		win[this.appletCallbackName] = function(callback) {

			if (this.timeoutId) {
				win.clearTimeout(this.timeoutId);
			}

			this.isFlashEnabled = true;
			this.isFlashBlocked = false;
			this.finalizeCheck();

			callback();
		}.bind(this);
	};

	FeatureChecker.prototype.getFlashVersion = function() {
		var version = '0,0,0';

		try {
			version = new ActiveXObject('ShockwaveFlash.ShockwaveFlash')
				.GetVariable('$version')
				.replace(/\D+/g, ',').match(/^,?(.+),?$/)[1];
		}
		catch (e) {
			try {
				if (nav.mimeTypes[FLASH_MIME_TYPE].enabledPlugin) {
					version = (nav.plugins['Shockwave Flash 2.0'] ||
					nav.plugins['Shockwave Flash']).description.replace(/\D+/g, ',').match(/^,?(.+),?$/)[1];
				}
			}
			catch (e) {

			}
		}

		return convertVersion(version);
	};

	FeatureChecker.prototype.appendChecker = function() {
		var wrapper = doc.createElement('div'),
			obj = doc.createElement('object'),
			embed = doc.createElement('embed'),
			checkerValues = {
				movie             : this.appletUrl,
				flashvars         : 'jstarget=' + this.appletCallbackName,
				allowScriptAccess : 'always',
				wmode             : 'transparent'
			}, param, key;

		wrapper.setAttribute('style', 'opacity: 0; pointer-events: none;');

		obj.data = checkerValues.movie;
		obj.type = FLASH_MIME_TYPE;
		obj.setAttribute('style', 'opacity: 0; position: absolute; bottom: 0; right: 0;');

		for (key in checkerValues) {
			if (Object.prototype.hasOwnProperty.call(checkerValues, key)) {
				param = doc.createElement('param');
				param.name = key;
				param.value = checkerValues[key];
				obj.appendChild(param);
			}
		}

		embed.setAttribute('flashvars', checkerValues.flashvars);
		embed.setAttribute('allowScriptAccess', checkerValues.allowScriptAccess);
		embed.setAttribute('wmode', 'transparent');
		embed.type = FLASH_MIME_TYPE;
		embed.src = checkerValues.movie;

		obj.appendChild(embed);
		wrapper.appendChild(obj);
		doc.body.appendChild(wrapper);

		this.checkerObject = wrapper;
	};

	FeatureChecker.prototype.getSupportedMediaTypes = function() {
		win.MediaSource = win.MediaSource || win.WebkitMediaSource;

		if (!win.MediaSource) {
			return [];
		}

		return MEDIA_SOURCE_TYPES.filter(function(type) {
			return win.MediaSource.isTypeSupported(type);
		});
	};

	FeatureChecker.prototype.isFlashPluginMissing = function() {
		var flashVersion = this.getFlashVersion();

		return flashVersion.major === 0;
	};

	FeatureChecker.prototype.resultCallback = function(callback) {
		callback({
			mediaSource : {
				supportedTypes : this.getSupportedMediaTypes()
			},
			flash       : {
				version : this.getFlashVersion(),
				enabled : this.isFlashEnabled,
				blocked : this.isFlashBlocked
			}
		});
	};

	FeatureChecker.prototype.chromeNavigatorFlashMissing = function() {
		var ua = window.navigator.userAgent.toLowerCase(),
			ver;
		if (ua.indexOf('chrome/') !== -1) {
			ver = parseInt(ua.split('chrome/')[1].split('.')[0]);
			if (ver > 55) {
				return true;
			}
		}
		return false;
	};

	FeatureChecker.prototype.getFeatures = function(callback) {
		if (this.isChecked) {
			this.resultCallback(callback);
		}
		else if (this.isFlashPluginMissing() && !this.chromeNavigatorFlashMissing()) {
			this.resultCallback(callback);
		}
		else {
			this.addToQueue(callback);

			if (this.queue.length <= 1) {
				this.isFlashBlocked = true;
				this.createAppletCallback();
				this.timeoutId = win.setTimeout(this.finalizeCheck.bind(this), this.timeout);
				this.appendChecker();
			}
		}
	};

	FeatureChecker.prototype.addToQueue = function(callback) {
		this.queue.push(this.resultCallback.bind(this, callback));
	};

	FeatureChecker.prototype.emptyQueue = function() {
		var callback;

		while (this.queue.length) {
			callback = this.queue.shift();
			callback();
		}
	};

	FeatureChecker.prototype.hideCheckerObject = function() {
		if (this.checkerObject) {
			this.checkerObject.setAttribute('style', 'position: absolute; width: 0; height: 0; overflow: hidden;');
		}
	};

	FeatureChecker.prototype.finalizeCheck = function() {
		// If the user manually enables it the applet could set the enabled value from callback later
		if (!this.isFlashBlocked) {
			this.hideCheckerObject();
		}

		this.isChecked = true;
		this.emptyQueue();
	};

	return FeatureChecker;
}(window, document, navigator));