/*global define: false, localStorage: false, UBPMessageAPI: true, UBPPlatformMessageAPI: true, AmazonUBP: true, amznJQ: true  */
(function() {
    "use strict";
    amznJQ.available("UBPPlatformMessageAPI", function() {
        amznJQ.onReady('jQuery', function() {
            var $aaJQ = jQuery;
            var UBPMessageAPI = window.UBPMessageAPI;
            var UBPMessage = UBPMessageAPI.UBPMessage;
            var UBPMessageTypes = UBPMessageAPI.UBPMessageTypes;
            
            if (typeof ($aaJQ) === 'undefined') {
                /** Initialize JQuery in noConflict mode */
                $aaJQ = jQuery.noConflict(true);
                if ($aaJQ.support) {
                    $aaJQ.support.cors = true;
                }
            }
            
            /**
             * Returns a list of all the keys in a JS object, for browsers that don't
             * support Object.keys(). This definition is from
             * https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Object/keys
             */
            if (!Object.keys) {
                Object.keys = function(o) {
                    if ( typeof (o) !== "object") {
                        throw new TypeError('Object.keys called on a non-object');
                    }
                    var ret = [], p;
                    for (p in o) {
                        if (Object.prototype.hasOwnProperty.call(o, p)) {
                            ret.push(p);
                        }
                    }
                    return ret;
                };
            }
        
            /**
             * ECMAScript 5 standard Object.create
             *
             * @param {Object}
             */
            if ( typeof Object.create !== 'function') {
                Object.create = function(object) {
                    function F() {
                    }
        
        
                    F.prototype = object;
                    return new F();
                };
            }
        
            /**
             * Gives us a method that adds methods to a "class"'s prototype
             *
             * @param {String}
             *            name The name of the function
             * @param {Function}
             *            func The function itself
             */
            Function.prototype.method = function(name, func) {
                this.prototype[name] = func;
                return this;
            };
        
            /**
             * Indicates that this "function" inherits from the parent function.
             *
             * @param {Object}
             *            Parent The parent object.
             */
            Function.method('inherits', function(Parent) {
                var d = {}, p = (this.prototype = new Parent());
                this.method('uber', function(name) {
                    if (!( name in d)) {
                        d[name] = 0;
                    }
                    var f, r, t = d[name], v = Parent.prototype;
                    if (t) {
                        while (t) {
                            v = v.constructor.prototype;
                            t -= 1;
                        }
                        f = v[name];
                    } else {
                        f = p[name];
                        if (f === this[name]) {
                            f = v[name];
                        }
                    }
                    d[name] += 1;
                    r = f.apply(this, Array.prototype.slice.apply(arguments, [1]));
                    d[name] -= 1;
                    return r;
                });
                return this;
            });
        
            Function.method('swiss', function(parent) {
                for (var i = 1; i < arguments.length; i += 1) {
                    var name = arguments[i];
                    this.prototype[name] = parent.prototype[name];
                }
                return this;
            });
        
            var AmazonUBPAPI = {};
            AmazonUBPAPI.$aaJQ = $aaJQ;
            AmazonUBPAPI.UBPMessage = UBPMessage;
        
            /**
             * @name AmazonUBP
             * @class Module for "Core" functionality that is used everywhere else.
             */
            AmazonUBPAPI.Core = function() {
                /**
                 * @memberOf AmazonUBP.Core#
                 * @field
                 * @name debugMode
                 * @description Indicates that whether or not logging should occur
                 */
                this.debugMode = true;
                /**
                 * @memberOf AmazonUBP.Core#
                 * @name remoteLoggingURL
                 * @description URL of the remote logging server. If defined, Alexa logs
                 *              are pushed to this endpoint along with the console. See
                 *              BITApplications/scripts/loggingNodeServer.js for server
                 *              code.
                 */
                this.remoteLoggingURL = "";
            };
            AmazonUBPAPI.Core
            /**
             * @function
             * @name getVersion
             * @description Over-ridden by abstraction-layers to return the version of
             *              the native platform.
             * @param {Object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @example { success: function(version){ }, error(message){} }
             * @return {string} The toolbar version returned via callback
             * @memberOf AmazonUBP#
             */.method('getVersion', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Core_getVersion, options);
            })
            /**
             * @function
             * @name getToolbarId
             * @description Returns the unique toolbar-id for the platform.
             * @param {Object} Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @return  {string} Unique ID for the instance of this installation
             * @example { success: function(toolbarid){ }, error(message){ } }
             * @memberOf AmazonUBP#
             */.method('getToolbarId', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Core_getToolbarId, options);
            })
            /**
             * @function
             * @name getTagId
             * @description Returns the tag used by the platform.
             * @param {Object} Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @example { sucess: function(tagId){ }, error(message){} }
             * @return {string} tag ID for the instance of this installation
             * @memberOf AmazonUBP#
             */.method('getTagId', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Core_getTagId, options);
            })
            /**
             * @function
             * @name getRunId
             * @description Returns the runid for the platform passed at install.
             * @param {Object} Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @example { success: function(runid){ }, error(message){ } }
             * @return {string} Unique Tracking ID passed at install for this installation
             * @memberOf AmazonUBP#
             */.method('getRunId', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Core_getRunId, options);
            })
            /**
             * @function
             * @name log
             * @description Logs a message to the debugging console.
             * @memberOf AmazonUBP#
             * @param {string}
             *            text The text to log
             */.method('log', function(text) {
                if (this.debugMode) {
                    UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.DebugLogs_log_message, {log: text});
                }
            });
            /**
             * @name JSON
             * @memberOf AmazonUBP
             * @class Stores the JSON 'stringify' and 'parse' functions.
             */
            AmazonUBPAPI.JSON = function() {
            };
        
            /**
             * @function
             * @name stringify
             * @memberOf AmazonUBP.JSON#
             * @description Converts a JavaScript Object to a string in JSON
             *              format.
             * @returns {string} JavaScript Object converted to string.
             * @param {object}
             *            obj The object to serialize in a String
             */
            AmazonUBPAPI.JSON.method('stringify', window.JSON.stringify);
            /**
             * @function
             * @name parse
             * @memberOf AmazonUBP.JSON#
             * @description Converts a JSON-formatted string to a JavaScript
             *              object.
             * @returns {object} A JavaScript object populated with the contents
             *          of the JSON string
             * @param {string}
             *            string A JSON string that describes a JavaScript
             *            object
             */
            AmazonUBPAPI.JSON.method('parse', window.JSON.parse);
            
            /**
             * @name Storage
             * @memberOf AmazonUBP
             * @class Defines functions for using browser local storage
             */
            AmazonUBPAPI.Storage = function() {};
            AmazonUBPAPI.Storage
            /**
             * @function
             * @name setItem
             * @memberOf AmazonUBP.Storage#
             * @description Stores an item in localStorage (if available) using the
             *              given key
             * @param {string}
             *            key The key by which we can reference the data in localStorage
             * @param {object}
             *            value The item being stored in local storage
             */.method('setItem', function(key, value) {
                try {
                    localStorage.setItem(key, value);
                } catch (err) {
                    AmazonUBP.log(err);
                    if (err.name === 'QUOTA_EXCEEDED_ERR') {
                        AmazonUBP.log('Out of space');
                    }
                }
            })
            /**
             * @function
             * @name getItem
             * @memberOf AmazonUBP.Storage#
             * @description Retrieves an item from localStorage
             * @param {string}
             *            key The key to look up the item
             * @returns {object} The item matching the key in localStorage; undefined if
             *          the object is not found or localStorage is unvailable
             */.method('getItem', function(key) {
                return localStorage.getItem(key);
            })
            /**
             * @function
             * @name numberOfKeys
             * @memberOf AmazonUBP.Storage#
             * @returns The number of keys in browser localStorage, or undefined if
             *          localStorage is unavailable
             */.method('numberOfKeys', function() {
                return localStorage.length;
            })
            /**
             * @function
             * @name key
             * @memberOf AmazonUBP.Storage#
             * @return {string} The nth key in localStorage
             * @param {int}
             *            key The index of the key to look-up.
             * @description Looks up a key in localStorage by index
             */.method('key', function(number) {
                return localStorage.key(number);
            });
        
            /**
             * @name Util
             * @memberOf AmazonUBP
             * @class Utility functions that we find useful. Unfortunately some
             *        functions got placed in here before we had multiple namespaces and
             *        might belong better someplace else.
             */
            AmazonUBPAPI.Util = function() {
            };
            AmazonUBPAPI.Util
            /**
             * @function
             * @name objToQueryString
             * @memberOf AmazonUBP.Util#
             * @description Given a javascript object, produces a Query String for
             *              placing in a URL. Each key/value will be encoded using
             *              encodeURIComponent.
             * @param {object}
             *            obj An associative-array (JavaScript Object) to parameterize
             *            for a URL. The object should be a key-value pair that doesn't
             *            contain arrays or other objects.
             * @returns {string} A query-string beginning with a '?' with the key-value
             *          pairs from the object.
             * @example var myObj = { 'foo': 'bar', 'baz': 'quux' }; var queryString =
             *          AmazonUBP.Util.objToQueryString(myObj); //
             *          '?foo=bar&baz=quux'
             */.method('objToQueryString', function(obj) {
                var str = '', keys = Object.keys(obj), len = keys.length;
                if (len > 0) {
                    str += '?';
                    for (var i = 0; i < len; i++) {
                        var k = keys[i], v = obj[k];
                        str += encodeURIComponent(k) + '=' + encodeURIComponent(v);
                        if (i !== len - 1) {
                            str += '&';
                        }
                    }
                }
                return str;
            })
            /**
             * @function
             * @name objDump
             * @memberOf AmazonUBP.Util#
             * @description Converts a JavaScript object to a string that describes all
             *              the parameters within, including other objects and arrays.
             *              Functions are written simply as the string 'function'.
             * @param {object}
             *            obj The object to dump into a string.
             * @param {int}
             *            [level=1] Used to determine how deeply the function has
             *            recursed; it will exit after 10 levels
             * @returns {string} A string describing all the contents of an object in
             *          JSON-like notation.
             */.method('objDump', function objDump(obj, level) {
                try {
                    if (!AmazonUBP.Core.debugMode) {
                        return;
                    }
                    if (obj == null) {
                        return 'null';
                    }
                    if ( typeof (level) === "undefined") {
                        level = 1;
                    }
                    if (level > 10) {
                        return;
                    }
                    if ( typeof (obj) === 'object') {
                        var str, len, i;
                        if ($aaJQ.isArray(obj)) {
                            str = '[', len = obj.length;
                            for ( i = 0; i < len; i++) {
                                str += objDump(obj[i], level + 1);
                                if (i !== len - 1) {
                                    str += ', ';
                                }
                            }
                            str += ']';
                            return str;
                        } else {
                            var keys;
                            str = '{', keys = Object.keys(obj), len = keys.length;
                            if (len > 0) {
                                for ( i = 0; i < len; i++) {
                                    var k = keys[i], v = obj[k];
                                    str += k + ':' + objDump(v, level + 1);
        
                                    if (i !== len - 1) {
                                        str += ', ';
                                    }
                                }
                            }
                            str += '}';
                            return str;
                        }
                    } else if ( typeof (obj) === 'function') {
                        return '(function)';
                    } else {
                        return '' + obj;
                    }
                } catch (error) {
                    return 'error: ' + error;
                }
            })
            /**
             * @function
             * @name getPageUrl
             * @memberOf AmazonUBP.Util#
             * @description gets the page of the URL in the current tab.
             * @param {Object} Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @example { success: function(url){ }, error(message){ } }
             * @return {string} The URL of the page in the current tab.
             */.method('getPageUrl', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Util_getPageUrl, options);
            })
            /**
             * @function
             * @name getPageTitle
             * @memberOf AmazonUBP.Util#
             * @description Gets the title of the current page.
             * @param {Object} Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @example { success: function(title){ }, error(message){ } }
             * @return {string} The current page's title
             */.method('getPageTitle', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Utils_getPageTitle, options);
            })
            /**
             * @function
             * @name getButtonId
             * @deprecated Alexa Only
             * @memberOf AmazonUBP.Util#
             * @param {Object} Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @example { success: function(buttonid){ }, error(message){ } }
             * @return {string} The ID of the button object. (This might be
             *          Alexa-centric).
             */.method('getButtonId', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Util_getButtonId, options);
            })
            /**
             * @function
             * @name getXPathElements
             * @memberOf AmazonUBP.Util#
             * @description Searches the DOM of the page in the current tab for elements
             *              matching the given xpath
             * @param {Object} Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.xpath The XPath to look up.
             * @example { xpath: "/body", success: function(nodelist){ }, error(message){ } }
             * @return {NodeList} List of all elements on the page matching the XPath.
        
             */.method('getXPathElements', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Util_getXPathElements, options);
            })
            /**
             * @function
             * @name getXPathContent
             * @memberOf AmazonUBP.Util#
             * @description Looks up the element described by the current XPath and
             *              returns the textContent of the first matching node.
             * @param {Object} Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.xpath The XPath to look up.
             * @example { xpath: "/body", success: function(text){ }, error(message){ } }
             * @returns {string} The textContent of the element described by the current
             *          XPath
             */.method('getXPathContent', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Util_getXPathContent, options);
            })
            /**
             * @function
             * @name getXPathContentFromNode
             * @memberOf AmazonUBP.Util#
             * @description Returns the textContent from the provided DOM Node.
             * @param {Object} Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.node The XPath to look up.
             * @example { node: DOMNode, success: function(text){ }, error(message){ } }
             * @return {string} The textContent of the node.
             */.method('getXPathContentFromNode', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Util_getXPathContentFromNode, options);
            })
            /**
             * @function
             * @name updateButtonProperties
             * @deprecated Alexa Only
             * @memberOf AmazonUBP.Util#
             * @description Updates the button properties, such as tooltip, width, etc.
             * @param {object} options An associative-array of properties to update.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @example AmazonUBP.Util.updateButtonProperties({ width: 120, tooltip:
             *          'My New Tooltip', success: function(){ }, error(message){ } });
             */.method('updateButtonProperties', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Util_updateButtonProperties, options);
            })
            /**
             * @function
             * @name updateSearchTerms
             * @memberOf AmazonUBP.Util#
             * @description Updates the search terms displayed in the search input box.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.searchTerm The content to be sent to the search terms input box.
             * @example { searchTerm: "ipod", success: function(){ }, error(message){ } }
             */.method('updateSearchTerms', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Util_updateSearchTerms, options);
            })
            /**
             * @function
             * @name setToolbarRoot
             * @memberOf AmazonUBP.Util#
             * @description Update the toolbar-root so that the content is pulled from
             *              the new root. A 'toolbar-root' is the prefix for all toolbar
             *              resources. E.G. 'http://www.amazon.com/gp/bit/toolbar' is
             *              the toolbar-root for Amazon US.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.root The toolbarRoot to update to.
             * @example
             * AmazonUBP.Util.setToolbarRoot({
             *  root: "http://www.amazon.co.uk/gp/bit/toolbar",
             * success: function(){ },
             * error(message){ }
             * });
             */.method('setToolbarRoot', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Util_setToolbarRoot, options);
            })
            /**
             * @function
             * @name getToolbarRoot
             * @memberOf AmazonUBP.Util#
             * @description Get the toolbar-root that is currently set. A 'toolbar-root'
             *              is the prefix for all toolbar resources. E.G.
             *              'http://www.amazon.com/gp/bit/toolbar' is the toolbar-root
             *              for Amazon US.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @return {string} The toolbar-root.
             * @example
             * AmazonUBP.Util.getToolbarRoot({
             * success: function(root){ },
             * error(message){ }
             * });
             */.method('getToolbarRoot', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Util_getToolbarRoot, options);
            })
            /**
             * @function
             * @name setOEMTag
             * @memberOf AmazonUBP.Util#
             * @description Update the OEM Tag.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.oemid
             *            OEMTag The OEMTag to update to.
             * @example AmazonUBP.Util.setOEMTag({
             * oemid : "abba",
             * success: function(){ },
             * error(message){ }
             * });
             */.method('setOEMTag', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Util_setOEMTag, options);
            })
            /**
             * @function
             * @name getOEMTag
             * @memberOf AmazonUBP.Util#
             * @description Get the OEMTag that is currently set.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @example AmazonUBP.Util.getOEMTag({
             * success: function(oemid){ },
             * error(message){ }
             * });
             * @return {string} The OEMTag.
             */.method('getOEMTag', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Util_getOEMTag, options);
            })
            /**
             * @function
             * @name appendUrlParameter
             * @memberOf AmazonUBP.Util#
             * @description add a parameter name value pair to an existing url
             *              urlencoding the name and value.
             * @param {string}
             *            url the existing url.
             * @param {string}
             *            key the name of the parameter.
             * @param {string}
             *            value the value of the parameter.
             * @example AmazonUBP.Util.appendUrlParameter('http://www.amazon.co.uk/gp/bit/goldbox.html?foo=bar',
             *          "abc", "def ghi");
             */.method('appendUrlParameter', function(url, key, value) {
                var operator = '?';
                if (url.indexOf("?") !== -1) {
                    operator = '&';
                }
                if ( typeof (key) === 'undefined' || typeof (value) === 'undefined') {
                    return url;
                } else {
                    return url + operator + encodeURIComponent(key) + "=" + encodeURIComponent(value);
                }
            })
            /**
             * @function
             * @name replacePlaceholders
             * @deprecated Alexa Only
             * @memberOf AmazonUBP.Util#
             * @description Expand placeholders in a string with real values used for
             *              tabbase and toolbarid.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.stringToExpand
             * The string to update using expansion variables.
             * @return {string} expanded string
             * @example AmazonUBP.Util.replacePlaceholders({ stringToExpand:
             *  '/gp/bit/checkForUpdate.json?tbId=__AID__PLACEHOLDER__&tagbase=__ASSOCIATE__ID__PLACEHOLDER__',
             * success: function(expandedString){ },
             * error(message){ }
             * );
             */.method('replacePlaceholders', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Util_replacePlaceholders, options);
            });

            /**
             * @name Modes
             * @memberOf AmazonUBP
             * @class manages user personalization/branding info for the extension (ie, stuff that goes in
             *        extension storage in Firefox/Chrome, and the Windows Registry in IE)
             */
            AmazonUBPAPI.Modes = function() {
            };
            AmazonUBPAPI.Modes
            /**
             * @function
             * @name enable
             * @memberOf AmazonUBP.Modes#
             * @description Enables smile mode.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.mode  optionId Unique identifiers for the mode
             * @param {string} options.scope
             *            [scope=undefined] The namespace in which to look for the
             *            modes. If undefined, places the option in the "options" scope.
             * @example AmazonUBP.Modes.enable({
             *          mode: "smile",
             *          success: function(value){ },
             *          error: function(err){ }
             * })
             */.method('enable', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Mode_enable, options);
            })
             /**
             * @function
             * @name disable
             * @memberOf AmazonUBP.Modes#
             * @description Disables smile mode.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.mode  optionId Unique identifier for the mode
             * @param {string} options.scope
             *            [scope=undefined] The namespace in which to look for the
             *            option. If undefined, places the option in the "options" scope.
             * @example AmazonUBP.Modes.disable({
             *          mode: "smile",
             *          success: function(value){ },
             *          error: function(err){ }
             * })
             */.method('disable', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Mode_disable, options);
            })
             /**
             * @function
             * @name getModeStatus
             * @memberOf AmazonUBP.Modes#
             * @description Gets mode object from extension storage having branding info eg: {'smile':'true'}.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.scope
             *            [scope=undefined] The namespace in which to look for the
             *            option. If undefined, places the option in the "options" scope.
             * @example AmazonUBP.Modes.getModeStatus({
             *          success: function(value){ },
             *          error: function(err){ }
             * })
             */.method('getModeStatus', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Mode_getModeStatus, options);
            })
             /**
             * @function
             * @name isModeEnabled
             * @memberOf AmazonUBP.Modes#
             * @description Gets mode value from extension storage for input mode
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.mode  optionId Unique identifier for the option
             * @param {string} options.scope
             *            [scope=undefined] The namespace in which to look for the
             *            option. If undefined, places the option in the "options" scope.
             * @example AmazonUBP.Modes.isModeEnabled({
             *          mode: "smile",
             *          success: function(value){ },
             *          error: function(err){ }
             * })
             */ .method('isModeEnabled', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Mode_isModeEnabled, options);
            });

            /**
             * @name Options
             * @memberOf AmazonUBP
             * @class Manages preferences for the extension (ie, stuff that goes in
             *        about:config in Firefox, and the Windows Registry in IE)
             */
            AmazonUBPAPI.Options = function() {
            };
            AmazonUBPAPI.Options
            /**
             * @function
             * @name getOptions
             * @memberOf AmazonUBP.Options#
             * @description Gets all options or a number of options, given the idis and scope. If scope is not
             *              provided, the option is "global", that is, available to all
             *              scopes.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.names  optionId Unique identifiers for the option
             * @param {string} options.scope
             *            [scope=undefined] The namespace in which to look for the
             *            option. If undefined, places the option in the global scope.
             * @returns {object} The value of the options in option value pair.
             * @example AmazonUBP.Options.getOption({
             * names: "appList,alertList,previousAvailableApps",
             * success: function(value){ },
             * error(message){ }
             * })
             */.method('getOptions', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Options_getOptions, options);
            })
            /**
             * @function
             * @name getOption
             * @memberOf AmazonUBP.Options#
             * @description Gets an option given the id and scope. If scope is not
             *              provided, the option is "global", that is, available to all
             *              scopes.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.name  optionId Unique identifier for the option
             * @param {string} options.scope
             *            [scope=undefined] The namespace in which to look for the
             *            option. If undefined, places the option in the global scope.
             * @returns {string} The value of the option. Return 'null' if the option is
             *          not found.
             * @example AmazonUBP.Options.getOption({
             * name: "siaEnabled",
             * scope: "com.amazon.ubp",
             * success: function(value){ },
             * error(message){ }
             * })
             */.method('getOption', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Options_getOption, options);
            })
            /**
             * @function
             * @name setOptions
             * @memberOf AmazonUBP.Options#
             * @description Set a number of options in the browser's option store given ids and correponding values
             *              and scope.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {object}
             *            options.value The key value pairs (options and value
             *            of the option) set.
             * @param {string} options.scope
             *            [scope=undefined] The namespace in which to place the option,
             *            If undefined goes to global scope.
             * @example AmazonUBP.Options.setOption({
             * value: { appList : "sia,notifications,topten", alertList : "sia,deals" },
             * scope: "com.amazon.ubp",
             * success: function(){ },
             * error(message){ }
             * })
             */.method('setOptions', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Options_setOptions, options);
            })
            /**
             * @function
             * @name setOption
             * @memberOf AmazonUBP.Options#
             * @description Set an option in the browser's option store given id, value
             *              and scope.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string}
             *            options.name The key to set the option at.
             * @param {string}
             *            options.value The value of the option to set at the key.
             * @param {string} options.scope
             *            [scope=undefined] The namespace in which to place the option,
             *            If undefined goes to global scope.
             * @example AmazonUBP.Options.setOption({
             * name: "siaEnabled",
             * value: "true",
             * scope: "com.amazon.ubp",
             * success: function(){ },
             * error(message){ }
             * })
             */.method('setOption', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Options_setOption, options);
            })
             /**
             * @function
             * @name resetAlerts
             * @deprecated Alexa Only
             * @memberOf AmazonUBP.Options#
             * @description Resets the notification_count and alerts to zero and empty set respectively.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @example { success: function(){ }, error(message){ } }
             */.method('resetAlerts', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Options_resetAlerts, options);
            })
            /**
             * @function
             * @name isDataCollectionEnabled
             * @memberOf AmazonUBP.Options#
             * @description Check to see if anonymous data collection is enabled.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @returns {boolean} True if anonymous data collection is enabled.
             * @example { success: function(value){ }, error(message){ } }
             */.method('isDataCollectionEnabled', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Options_isDataCollectionEnabled, options);
            })
            /**
             * @function
             * @name setFirstRunOptions
             * @deprecated Alexa Only
             * @memberOf AmazonUBP.Options#
             * @description Sets the options to our defaults if they have not yet been
             *              set
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @example { success: function(){ }, error(message){ } }
             */.method('setFirstRunOptions', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Options_setFirstRunOptions, options);
            })
            /**
             * @function
             * @deprecated Alexa Only
             * @name acceptTermsOfUse
             * @memberOf AmazonUBP.Options#
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @example { success: function(){ }, error(message){ } }
             */.method('acceptTermsOfUse', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Options_acceptTermsOfUse, options);
            })
            /**
             * @function
             * @deprecated Alexa Only
             * @name rejectTermsOfUse
             * @memberOf AmazonUBP.Options#
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @example { success: function(){ }, error(message){ } }
             */.method('rejectTermsOfUse', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Options_rejectTermsOfUse, options);
            });

            AmazonUBPAPI.Notifications = function() {
            };
            AmazonUBPAPI.Notifications
            /*
             * @function
             * @name setAlert
             * @memberOf AmazonUBP.Notifications#
             * @description Set an alert in the browser's option store given id, value
             *              and scope.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string}
             *            options.type The type of alert to set the option at.
             * @param {string}
             *            options.value The value of the alert to set with the key.
             * @param {string} options.scope
             *            [scope=undefined] The namespace in which to place the option,
             *            If undefined goes to global scope.
             * @example AmazonUBP.Notifications.setAlert({
             * type: "deals"
             * value: "{ "DOTD" :{ "title":"Kindle Fire", "description": "10% off" }},
             * scope: "com.amazon.ubp",
             * success: function(){ },
             * error(message){ }});
             */.method('setAlert', function(options) {
                 UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Notifications_setAlert, options);
             })
            /*
             * @function
             * @name getAlerts
             * @memberOf AmazonUBP.Notifications#
             * @description Get all alerts in the browser's option store given id, 
             *              and scope.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.scope
             *            [scope=undefined] The namespace in which to place the option,
             *            If undefined goes to global scope.
             */.method('getAlerts', function(options) {
                 UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Notifications_getAlerts, options);
             })
            /*
             * @function
             * @name getAlert
             * @memberOf AmazonUBP.Notifications#
             * @description Get an alert in the browser's option store given id, 
             *              and scope.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string}
             *            options.type The type of alert to get the value for.
             * @param {string} options.scope
             *            [scope=undefined] The namespace in which to place the option,
             *            If undefined goes to global scope.
             * @example AmazonUBP.Notifications.getAlert({
             * value: "deals",
             * scope: "com.amazon.ubp",
             * success: function(){ },
             * error(message){ }
             */.method('getAlert', function(options) {
                 UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Notifications_getAlert, options);
             })
            /*
             * @function
             * @name clearAllAlerts
             * @memberOf AmazonUBP.Notifications#
             * @description Clear all alerts
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.scope
             *            [scope=undefined] The namespace in which to place the option,
             *            If undefined goes to global scope.
             */.method('clearAllAlerts', function(options) {
                 UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Notifications_clearAllAlerts, options);
             })
            /*
             * @function
             * @name clearAlert
             * @memberOf AmazonUBP.Notifications#
             * @description Clear an alert in the browser's option store given id,
             *              and scope.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string}
             *            options.alertInternalId The internal id of alert to delete.
             * @param {string} options.scope
             *            [scope=undefined] The namespace in which to place the option,
             *            If undefined goes to global scope.
             */.method('clearAlert', function(options) {
                 UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Notifications_clearAlert, options);
             })
            /*
             * @function
             * @name clearSpecificTypeOfAlerts
             * @memberOf AmazonUBP.Notifications#
             * @description Clear an alert in the browser's option store given type
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string}
             *          options.type type of alerts to delete.
             */.method('clearSpecificTypeOfAlerts', function(options) {
                 UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Notifications_clearSpecificTypeOfAlerts, options);
             })
            /*
             * @function
             * @name markAlertAsRead
             * @memberOf AmazonUBP.Notifications#
             * @description Mark a particular alert as read given id
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string}
             *          options.alertInternalId The internal id of alert to be marked read.
             */.method('markAlertAsRead', function(options) {
                 UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Notifications_markAlertAsRead, options);
             })
            /*
             * @function
             * @name markSpecificTypeOfAlertsAsRead
             * @memberOf AmazonUBP.Notifications#
             * @description Mark a particular alert as read given type
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string}
             *          options.type type of alerts to be marked as read.
             */.method('markSpecificTypeOfAlertsAsRead', function(options) {
                 UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Notifications_markSpecificTypeOfAlertsAsRead, options);
             })
            /*
             * @function
             * @name markAllAlertsAsRead
             * @memberOf AmazonUBP.Notifications#
             * @description Mark all alerts as read
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             */.method('markAllAlertsAsRead', function(options) {
                 UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Notifications_markAllAlertsAsRead, options);
             })
            /*
             * @function
             * @name notifications
             * @memberOf AmazonUBP.Configure#
             * @description Sends message to extension to reconfigure notifications(background page)
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string}
             *            options.type The type of alert to delete.
             * @param {string} options.scope
             *            [scope=undefined] The namespace in which to place the option,
             *            If undefined goes to global scope.
             */.method('configure', function(options) {
                 UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Notifications_configure, options);
             });

            /**
             * @name Browser
             * @memberOf AmazonUBP
             * @class Handles browser-level methods like opening gadget windows,
             *        performing cross-domain XML-HTTP Requests, etc.
             */
            AmazonUBPAPI.Browser = function() {
            };
            AmazonUBPAPI.Browser
            /**
             * @function
             * @name showGadgetWindow
             * @memberOf AmazonUBP.Browser#
             * @description Shows a gadget window which sources the specified URL and is
             *              of the given width/height in size.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.url
             *            url The page to load inside the gadget window.
             * @param {int} options.width
             *            width The desired width of the gadget window
             * @param {int} options.height
             *            height The desired height of the gadget window
             * @returns {object} An opaque object that references that gadget window.
             * @example { url: "http://www.amazon.com", width: 640, height: 400, success: function(window){ }, error(message){ } }
             */.method('showGadgetWindow', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Browser_showGadgetWindow, options);
            })
            /**
             * @function
             * @name openWindow
             * @memberOf AmazonUBP.Browser#
             * @description use to display a window/tab with a list of
             *              properties.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.url
             *            The page to load inside the window
             * @param {string} options.name
             *            A name for the gadget window
             * @param {string} options.features
             *            A string of comma-separated key-value pairs
             *            describing the tab/window (e.g.
             *            'width=400,height=200,no-decorate=true') (These might be
             *            browser-specific)
             * @return {object} An opaque object that references the window
             */.method('openWindow', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Browser_openWindow, options);
            })
            /**
             * @function
             * @name injectJavaScriptFromURL
             * @memberOf AmazonUBP.Browser#
             * @description Injects the given URL (which should point to a JavaScript
             *              file) into the page in the current tab, executing it in a
             *              Sandbox.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string}  options.jsUrl
             *            The URL of the JavaScript file to inject into the page
             * @param {boolean} options.includeShim
             *            [includeShim=false] Whether or not to include the "injection
             *            shim" which abstracts the API available in the
             *            native-platform's sandbox (@see
             *            AmazonUBP.Browser#getInjectionShim)
             */.method('injectJavaScriptFromURL', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Browser_injectJavaScriptFromURL, options);
            })
            /**
             * @function
             * @name injectJavaScriptFromString
             * @memberOf AmazonUBP.Browser#
             * @description Injects the given string of JavaScript code onto the page in
             *              the current tab, executing it in a Sandbox
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.jsString
             *            The string of JavaScript code to inject and run
             * @param {boolean} options.includeShim
             *            [includeShim=false] Whether or not to include the "injection
             *            shim" which abstracts the API that is available in the
             *            native-platform's sandbox (@see
             *            AmazonUBP.Browser#getInjectionShim)
             */.method('injectJavaScriptFromString', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Browser_injectJavaScriptFromString, options);
            })
            /**
             * @function
             * @name getInectionShim
             * @memberOf AmazonUBP.Browser#
             * @description Returns a string of JavaScript code that can be injected
             *              into the current tab's page that abstracts the
             *              native-platform's sandbox API to AmazonUBP API's. This
             *              exists for the convenience of having functions like
             *              "AmazonUBP.log" available in the sandbox without having
             *              to do something like "if (typeof Alexa != undefined) {
             *              Alexa.tools.log(....) }". These are the functions defined in
             *              the shim which are therefore available to injected code:
             * @see AmazonUBP#log
             * @see AmazonUBP#JSON
             * @see AmazonUBP.Messaging#postMessage
             * @see AmazonUBP.Browser#isIE
             * @see AmazonUBP.Browser#isFirefox
             * @see AmazonUBP.ClientLogs#log_message
             *      AmazonUBP.Browser.injectJavaScriptFromURL(jsURL, callback) (Note
             *      that this differs from the
             * @see AmazonUBP.Browser#injectJavaScriptFromURL in that it takes a
             *      callback parameter)
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             */.method('getInjectionShim', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Browser_getInjectionShim, options);
            })
            /**
             * @function
             * @name addPageTurnListener
             * @memberOf AmazonUBP.Browser#
             * @description Adds a callback function the list of functions that are
             *              executed when the user navigates to a new page after DOMLoaded.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {function} options.listener
             *            Function to call when the page changes. It should
             *            accept one parameter, which will be the URL of the new page.
             */.method('addPageTurnListener', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Browser_addPageTurnListener, options);
            })
            /**
             * @function
             * @name addUrlChangedListener
             * @memberOf AmazonUBP.Browser#
             * @description Adds a callback function the list of functions that are
             *              executed when the user navigates to a new page before DOMLoaded.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {function} options.listener
             *            Function to call when the page changes. It should
             *            accept one parameter, which will be the URL of the new page.
             */.method('addUrlChangeListener', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Browser_addUrlChangeListener, options);
            })
            /**
             * @function
             * @name addTabChangedListener
             * @memberOf AmazonUBP.Browser#
             * @description Adds a callback function the list of functions that are
             *              executed when the user navigates to a new tab.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {function} options.listener
             *            Function to call when the tab changes. It should
             *            accept one parameter, which will be the URL of the new tab.
             */.method('addTabChangedListener', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Browser_addTabChangedListener, options);
            })
            /**
             * @function
             * @name getBrowser
             * @memberOf AmazonUBP.Browser#
             * @returns {string} user agent string
             */.method('getBrowser', function(options) {
                return navigator.userAgent;
            })
            /**
             * @function
             * @name getBrowserType
             * @memberOf AmazonUBP.Browser#
             * @description Get the browser type.
             * @param {win} window object passed in.
             * @param {doc} document object passed in.
             * @example AmazonUBP.Browser.getBrowserType(window, document);
             */.method('getBrowserType', function(win, doc) {
                var browserType = "unknown";
                var navigator = win.navigator;
                var isUAContain = function(userAgent, keyword) {
                    return (userAgent.toLowerCase().indexOf(keyword) !== -1);
                };
                var hasPlugin = function(navigator, pluginFileName, pluginKeyword) {
                    if (navigator && navigator.plugins) {
                        for (var i in navigator.plugins) {
                            if (navigator.plugins[i].filename === pluginFileName
                                && navigator.plugins[i].name.indexOf(pluginKeyword) !== -1) {
                                return true;
                            }
                        }
                    }
                    return false;
                };

                if (!navigator || !navigator.userAgent) {
                    return "unknown";
                } else if (isUAContain(navigator.userAgent, "1buttontaskbar")) {
                    return "taskbar";
                // this must be put before safari because there is "safari" in UA
                } else if (isUAContain(navigator.userAgent, "opera")
                    || isUAContain(navigator.userAgent, "opr")) {
                    return "opera";
                } else if (isUAContain(navigator.userAgent, "firefox")) {
                    return "firefox";
                } else if (isUAContain(navigator.userAgent, "qqbrowser")) {
                    return "qq";
                } else if (isUAContain(navigator.userAgent, "sogou")
                    || isUAContain(navigator.userAgent, "metasr")) {
                    return "sogou";
                } else if (isUAContain(navigator.userAgent, "maxthon")) {
                    // Known issue: Maxthon IE mode will be recognized as IE - same UA with IE
                    return "maxthon";
                } else if (isUAContain(navigator.userAgent, "lbbrowser")) {
                    return "lb";
                } else if (isUAContain(navigator.userAgent, "bidunbrowser")) {
                    return "baidu";
                // 360 is pretend to be Chrome, we have to distinguish it by checking some special plugins it ships.
                } else if (isUAContain(navigator.userAgent, "chrome")) {
                    if (navigator.plugins
                        && hasPlugin(navigator, CONSTANTS.PLUGIN_FANCY_FILENAME, CONSTANTS.PLUGIN_FANCY_LABEL)
                        && hasPlugin(navigator, CONSTANTS.PLUGIN_FF_MEDIAPLAYER_FILENAME, CONSTANTS.PLUGIN_FF_MEDIAPLAYER_LABEL)) {
                        // Known issue: 360se IE mode will be recognized as IE - same UA with IE
                        return "360se";
                    } else if (navigator.plugins
                        && !hasPlugin(navigator, CONSTANTS.PLUGIN_FANCY_FILENAME, CONSTANTS.PLUGIN_FANCY_LABEL)
                        && hasPlugin(navigator, CONSTANTS.PLUGIN_FF_MEDIAPLAYER_FILENAME, CONSTANTS.PLUGIN_FF_MEDIAPLAYER_LABEL)) {
                        return "360ee";
                    } else {
                        return "chrome";
                    }
                // place safari after chrome because chrome's UA has "safari"
                } else if (isUAContain(navigator.userAgent, "safari")) {
                    return "safari";
                // Put IE check to the last because most China local browsers are based on IE and include "trident" or "msie" in the UA
                } else if ((win && win.ActiveXObject)
                    || (navigator && navigator.userAgent && (isUAContain(navigator.userAgent, "trident") || isUAContain(navigator.userAgent, "msie")))
                    || (doc && doc.documentMode)) {
                    return "ie";
                } else {
                    return "unknown";
                }
            })
            /**
             * @function
             * @name crossDomainXHR
             * @memberOf AmazonUBP.Browser#
             * @description Performs a cross-domain XML HTTP Request from the extension
             *              which does not have to abide by same-origin policy.
             * @param {Object}
             *            options Tuple containing all the data needed for the request.
             * @param {String}
             *            options.method can be 'GET' or 'POST'.
             * @param {String}
             *            options.url The URL to send the request to.
             * @param {Function}
             *            options.success Callback to execute if the request was
             *            successful. It should accept three parameters: repsonseBody,
             *            statusCode, Browser XHR object.
             * @param {Function}
             *            options.error Callback to execute if the request failed. It
             *            should accept three parameters: statusCode, statusText,
             *            Browser XHR object.
             * @param {String}
             *            options.data URLEncoded data to send in the POST body.
             */.method('crossDomainXHR', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Browser_crossDomainXHR, options);
            }).method('showNotification', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Browser_showNotification, options);
            }).method('hideNotification', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Browser_hideNotification, options);
            });
        
            /**
             * @name AmazonUBP.SearchEngines
             * @class Encapsulates methods for setting the browser search engine
             */
            AmazonUBPAPI.SearchEngines = function() {
            };
            AmazonUBPAPI.SearchEngines
            /**
             * @function
             * @name checkStatus
             * @memberOf AmazonUBP.SearchEngines#
             * @param {String}
             *            name The name of the search engine.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {string} options.name name of the search engine
             * @returns {Object} An object containing the status of the search engine in
             *          the browser.
             */.method('checkStatus', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Search_checkStatus, options);
            })
            /**
             * @function
             * @name add
             * @memberOf AmazonUBP.SearchEngines#
             * @description Adds a new search Engine to the Browser
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {String} options.name
             *            The name of the search engine
             * @param {String} options.url
             *            The OSD URL for the search engine
             * @param {boolean} options.setAsDefault [setAsDefault=false] Set as the default search engine.
             */.method('add', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Search_add, options);
            })
            /**
             * @function
             * @name remove
             * @memberOf AmazonUBP.SearchEngines#
             * @description Remove a search engine from the browser's list of search
             *              options.
             * @param {object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {String} options.name
             *            The name of the search engine to remove.
             */.method('remove', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Search_remove, options);
            });
        
            /**
             * @name Messaging
             * @memberOf AmazonUBP
             * @class Handles messaging between different apps and between injected code
             *        and the extension
             */
            AmazonUBPAPI.Messaging = function() {
            };
            AmazonUBPAPI.Messaging
            /**
             * @function
             * @name addMessageListener
             * @memberOf AmazonUBP.Messaging#
             * @description Adds a message listener for the current button to listen for
             *              the given event types
             * @param {object} options
             *            eventMap An object containing a key-value pair of
             *            "eventType":callback. The callback is executed whenever this
             *            handler receives a message with the specified eventType
             *            callbacks accept one parameter: The message itself (a
             *            JavaScript object).
             * @example AmazonUBP.Messaging.addMessageListener({ 'myEvent':
             *          function(message) { if (message.myData === 'foo') { //
             *          do Something } } });
             */.method('addMessageListener', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Messaging_addMessageListener, options);
            })
            /**
             * @function
             * @name postMessage
             * @memberOf AmazonUBP.Messaging#
             * @description Sends a message of the given type to the given target.
             * @param {Object} options The Object containing parameters
             * @param {String} options.eventType
             *            The name of the event to send (which should be
             *            listed in the target's eventMap)
             * @param {Object} options.message
             *            Whatever data you want, though it cannot contain
             *            functions because it gets serialized as JSON.
             */.method('postMessage', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Messaging_postMessage, options);
            });
            
            /**
             * @name Panel
             * @memberOf AmazonUBP
             * @class Manages actions on Panel window, like hiding, resizing, etc
             **/
            AmazonUBPAPI.Panel = function() {
            };
            AmazonUBPAPI.Panel
            /**
             * @function
             * @name hidePanel
             * @memberOf AmazonUBP.Panel#
             * @description Hides a panel window
             **/.method('hidePanel',
                     function() {
                         UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Panel_hidePanel, {});
            })
        
            /**
             * @function
             * @name resizePanel
             * @memberOf AmazonUBP.Panel#
             * @description Resizes a panel window to required size
             * @param {int} options.width
             *              The new width for the panel window
             * @param {int} options.height
             *              The new height for the panel window
             * */.method('resizePanel',
                    function(options) {
                        UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Panel_resizePanel, options);
            });
      
            /**
             * @name Wishlist
             * @memberOf AmazonUBP
             * @class Manages actions on wishlist app
             **/
            AmazonUBPAPI.Wishlist = function() {
            };
            AmazonUBPAPI.Wishlist
            /**
             * @function
             * @name wishlistClicked
             * @memberOf AmazonUBP.Wishlist#
             * @description Notifies that the wishlist app is clicked
             **/.method('wishlistClicked',
                   function() {
                       UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.Wishlist_wishlistClicked, {});
            });

            /**
             * @name ClientLogs
             * @memberOf AmazonUBP
             * @class Handles simple fire-and-forget logging messages.
             */
            AmazonUBPAPI.ClientLogs = function() {
            };
            AmazonUBPAPI.ClientLogs
            /**
             * @function
             * @name log_message
             * @memberOf AmazonUBP.ClientLogs#
             * @description Logs a message in Forester. The message is a simple
             *              key-value pair that can then be parsed out of logs.
             * @param {Object} options Common API Callback Object.
             * @param {function} options.success Success Callback
             * @param {function} options.error Error Callback
             * @param {Object} options.data
             *            A key-value pair of data to be logged on the server
             * @example AmazonUBP.ClientLogs.log_message({
             *  success: function(){},
             *  error: function(message){},
             *  data: { dataType: 'clientLatency', app: 'wishlist', ms: '4000' }
             *  );
             */.method('log_message', function(options) {
                UBPPlatformMessageAPI.sendMessage(UBPMessageTypes.ClientLogs_log_message, options);
            });

            var CONSTANTS = {
                PLUGIN_FANCY_FILENAME: "npfancygame.dll",
                PLUGIN_FANCY_LABEL: "Fancy Game Plugin",
                PLUGIN_FF_MEDIAPLAYER_FILENAME: "np-mswmp.dll",
                PLUGIN_FF_MEDIAPLAYER_LABEL: "Media Player Firefox Plugin",

                CHROME_WEBSTORE_URL: "https://chrome.google.com/webstore"
            };

            /**
             * @name CN
             * @memberOf AmazonUBP
             * @class CN handles CN related checkings.
             */
            AmazonUBPAPI.CN = function() {
            };
            AmazonUBPAPI.CN
            /**
             * @function
             * @name isLocationCN
             * @memberOf AmazonUBP.CN#
             * @description Check if given marketplaceID is CN market.
             * @param {marketplaceID} A marketplaceID.
             * @returns {boolean} Return true if in CN market, otherwise return false.
             * @example AmazonUBP.CN.isLocationCN("abcd");
             */.method('isLocationCN', function(marketplaceID) {
                return 'AAHKV2X7AFYLW' === marketplaceID;
            })
            /**
             * @function
             * @name isChromeWebstoreConnectable
             * @memberOf AmazonUBP.CN#
             * @description Check if chrome web store is connectable.
             * @param {timeout} options.timeout. A timeout value for connect to chrome web store,
             *        default to 2000 mi-seconds.
             * @param {complete} options.complete. A callback function to get the result. It accepts
             *        a boolean parameter, indicates the google is connectable or not.
             * @example AmazonUBP.CN.isChromeWebstoreConnectable({
             *     complete: function(isConnect) {}
             * });
             */.method('isChromeWebstoreConnectable', function(options) {
                jQuery.ajax({
                    url: CONSTANTS.CHROME_WEBSTORE_URL,
                    complete: function(req, status) {
                        if (options && options.complete && typeof options.complete === 'function') {
                            options.complete(status === 'timeout' ? false : true);
                        }
                    },
                    timeout: options && options.timeout ? options.timeout : 2000
                });
            })
            /**
             * @function
             * @name isChromeManualUpdateAvailable
             * @memberOf AmazonUBP.CN#
             * @description Check all conditions to determine if we need to provide manual upgrade for Chrome client.
             * @param {version_url} options.version_url. Version.json's URL on S3.
             * @param {marketplace_id} options.marketplace_id. MarketplaceID passed in.
             * @param {google_timeout} options.google_timeout. A timeout value for checking google connectivity.
             * @param {success} options.success. Callback function recieve the result. The success function accepts
             *        2 arguments: success(status, data). data will be the JS object parsed from version.json. Status
             *        will be one of following 7 values:
             *
             *          - updateRequired          => In chrome, in CN market and google cannot be connected, so we should
             *                                       provide manual upgrade.
             *          - notInChrome             => Not in Chrome.
             *          - notInstalled            => 1BA is not installed.
             *          - notInCN                 => Not in CN market.
             *          - noLatestVersion         => Version object does not include required information.
             *          - errorGetLatestVersion   => Failed to get version object from S3.
             *          - autoUpdateEnabled       => Google is connectable, client can be auto updated.
             *          - upToDate                => 1BA is up to date, no need to upgrade.
             *          - errorGetVersion         => Error get client's version
             *
             * @param {error} options.error. The success function accepts 2 arguments: error(status, msg). Status 
             *        contains error state, msg will contain the error message.
             * @example
             *   AmazonUBP.CN.isChromeManualUpdateAvailable({
             *       version_url: "http://urls",
             *       marketplace_id: "ABCD",
             *       success: function(status, data) {
             *           if (status == "updateRequired") {
             *               ...
             *           }
             *       },
             *       error: function(status, msg) {
             *           ...
             *       }
             *   });
             */.method('isChromeManualUpdateAvailable', function(options) {
                if (!options) {
                    throw new Error("'options' is not supplied!");
                }
                if (!options.version_url || options.version_url === "") {
                    throw new Error("'options.version_url' is not supplied!");
                }
                if (!options.marketplace_id || options.marketplace_id === "") {
                    throw new Error("'options.marketplace_id' is not supplied!");
                }
                if (!options.success || typeof options.success !== "function") {
                    throw new Error("'options.success' is not supplied or it's not a function!");
                }
                if (!options.error || typeof options.error !== "function") {
                    throw new Error("'options.error' is not supplied or it's not a function!");
                }

                if (typeof chrome === "undefined" || AmazonUBP.Browser.getBrowserType(window, document) !== "chrome") {
                    options.success("notInChrome", "Not in Chrome.");
                    return;
                }

                if (!AmazonUBP.CN.isLocationCN(options.marketplace_id)) {
                    options.success("notInCN", "Not in CN marketplace.");
                    return;
                }

                AmazonUBP.CN.isChromeWebstoreConnectable({
                    timeout: options.google_timeout,
                    complete: function(isConnect) {
                        if (isConnect) {
                            options.success("autoUpdateEnabled", "Google is connected.");
                            return;
                        }

                        jQuery.ajax({
                            url: options.version_url,
                            dataType: "json",
                            success: function(data, status, req) {
                                if (!data || !data.version || data.version === "") {
                                    options.success("noLatestVersion", "Version object is empty.");
                                    return;
                                }

                                // error function does not work if no 1ba installed, so we added a timeout function
                                var versionCheckTimer = setTimeout(function() {
                                    options.success("notInstalled", data);
                                }, 1000);

                                AmazonUBP.Core.getVersion({
                                    success: function(ver) {
                                        clearTimeout(versionCheckTimer);

                                        if(data.version === ver) {
                                            options.success("upToDate", data);
                                            return;
                                        }
                                        options.success("updateRequired", data);
                                    },
                                    error: function() {
                                        clearTimeout(versionCheckTimer);
                                        options.success("errorGetVersion", data);
                                    }
                                });
                            },
                            error: function(req, status, err) {
                                options.error("errorGetLatestVersion", "Failed to get the version object: " + status + " - " + err);
                            }
                        });
                    }
                });
            });

            /**
             * @function
             * @name addListener
             * @description Adds event listener to an object.
             * @memberOf AmazonUBP#
             * @param {object}
             *            element to attach listener to
             * @param {string}
             *            name of event
             * @param {function}
             *            listener function
             */
            AmazonUBPAPI.eventListeners = {};
            AmazonUBPAPI.addListener = function(obj, eventName, listener) {
                try {
                    if ( typeof (obj) === "undefined") {
                        return;
                    }
                    var key = obj + "." + eventName;
                    if ( typeof (AmazonUBPAPI.eventListeners[key]) === "undefined") {
                        AmazonUBPAPI.eventListeners[key] = {};
                        AmazonUBPAPI.eventListeners[key].listeners = [];
                        AmazonUBPAPI.eventListeners[key].eventFired = false;
                        var iter = function(e) {
                            try {
                                AmazonUBPAPI.eventListeners[key].eventFired = true;
                                AmazonUBPAPI.eventListeners[key].event = e;
                                var func;
                                do {
                                    func = AmazonUBPAPI.eventListeners[key].listeners.shift();
                                    if ( typeof (func) === "function") {
                                        try {
                                            func(e);
                                        } catch (exception) {
                                            AmazonUBPAPI.Core.log(exception);
                                        }
                                    }
                                } while (typeof (func) !== "undefined" &&
                                AmazonUBPAPI.eventListeners[key].listeners.length !== 0);
                                if ( typeof (obj.removeEventListener) !== "undefined") {
                                    obj.removeEventListener(eventName, iter, false);
                                } else {
                                    if ( typeof (obj.detachEvent) !== "undefined") {
                                        obj.detachEvent(eventName, iter);
                                    }
                                }
                            } catch (except) {
                                AmazonUBPAPI.Core.log(except);
                            }
                        };
                        if ( typeof (obj.addEventListener) !== "undefined") {
                            obj.addEventListener(eventName, iter, false);
                        } else {
                            if ( typeof (obj.attachEvent) !== "undefined") {
                                obj.attachEvent("on" + eventName, iter);
                            }
                        }
                    }
                    if (AmazonUBPAPI.eventListeners[key].eventFired) {
                        if ( typeof (listener) === "function") {
                            listener(AmazonUBPAPI.eventListeners[key].event);
                        }
                    } else {
                        AmazonUBPAPI.eventListeners[key].listeners.push(listener);
                    }
                } catch (e) {
                    AmazonUBPAPI.Core.log(e);
                }
            };
            window.AmazonUBPAPI = AmazonUBPAPI;
            amznJQ.declareAvailable("AmazonUBPAPI");
        });
    });
}());
