/*!
 * jQuery Cookie Plugin v1.3.1
 * https://github.com/carhartl/jquery-cookie
 *
 * Copyright 2013 Klaus Hartl
 * Released under the MIT license
 */
(function (factory) {
	factory(jQuery);
}(function ($) {

	var pluses = /\+/g;

	function raw(s) {
		return s;
	}

	function decoded(s) {
		return decodeURIComponent(s.replace(pluses, ' '));
	}

	function converted(s) {
		if (s.indexOf('"') === 0) {
			// This is a quoted cookie as according to RFC2068, unescape
			s = s.slice(1, -1).replace(/\\"/g, '"').replace(/\\\\/g, '\\');
		}
		try {
			return config.json ? JSON.parse(s) : s;
		} catch(er) {}
	}

	var config = $.cookie = function (key, value, options) {

		// write
		if (value !== undefined) {
			options = $.extend({}, config.defaults, options);

			if (typeof options.expires === 'number') {
				var days = options.expires, t = options.expires = new Date();
				t.setDate(t.getDate() + days);
			}

			value = config.json ? JSON.stringify(value) : String(value);

			return (document.cookie = [
				config.raw ? key : encodeURIComponent(key),
				'=',
				config.raw ? value : encodeURIComponent(value),
				options.expires ? '; expires=' + options.expires.toUTCString() : '', // use expires attribute, max-age is not supported by IE
				options.path    ? '; path=' + options.path : '',
				options.domain  ? '; domain=' + options.domain : '',
				options.secure  ? '; secure' : ''
			].join(''));
		}

		// read
		var decode = config.raw ? raw : decoded;
		var cookies = document.cookie.split('; ');
		var result = key ? undefined : {};
		for (var i = 0, l = cookies.length; i < l; i++) {
			var parts = cookies[i].split('=');
			var name = decode(parts.shift());
			var cookie = decode(parts.join('='));

			if (key && key === name) {
				result = converted(cookie);
				break;
			}

			if (!key) {
				result[name] = converted(cookie);
			}
		}

		return result;
	};

	config.defaults = {};

	$.removeCookie = function (key, options) {
		if ($.cookie(key) !== undefined) {
			$.cookie(key, '', $.extend(options, { expires: -1 }));
			return true;
		}
		return false;
	};

}));

/*!
 * jQuery UI Core 1.9.2
 * http://jqueryui.com
 *
 * Copyright 2012 jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/category/ui-core/
 */
(function( $, undefined ) {

var uuid = 0,
	runiqueId = /^ui-id-\d+$/;

// prevent duplicate loading
// this is only a problem because we proxy existing functions
// and we don't want to double proxy them
$.ui = $.ui || {};
if ( $.ui.version ) {
	return;
}

$.extend( $.ui, {
	version: "1.9.2",

	keyCode: {
		BACKSPACE: 8,
		COMMA: 188,
		DELETE: 46,
		DOWN: 40,
		END: 35,
		ENTER: 13,
		ESCAPE: 27,
		HOME: 36,
		LEFT: 37,
		NUMPAD_ADD: 107,
		NUMPAD_DECIMAL: 110,
		NUMPAD_DIVIDE: 111,
		NUMPAD_ENTER: 108,
		NUMPAD_MULTIPLY: 106,
		NUMPAD_SUBTRACT: 109,
		PAGE_DOWN: 34,
		PAGE_UP: 33,
		PERIOD: 190,
		RIGHT: 39,
		SPACE: 32,
		TAB: 9,
		UP: 38
	}
});

// plugins
$.fn.extend({
	_focus: $.fn.focus,
	focus: function( delay, fn ) {
		return typeof delay === "number" ?
			this.each(function() {
				var elem = this;
				setTimeout(function() {
					$( elem ).focus();
					if ( fn ) {
						fn.call( elem );
					}
				}, delay );
			}) :
			this._focus.apply( this, arguments );
	},

	scrollParent: function() {
		var scrollParent;
		if (($.ui.ie && (/(static|relative)/).test(this.css('position'))) || (/absolute/).test(this.css('position'))) {
			scrollParent = this.parents().filter(function() {
				return (/(relative|absolute|fixed)/).test($.css(this,'position')) && (/(auto|scroll)/).test($.css(this,'overflow')+$.css(this,'overflow-y')+$.css(this,'overflow-x'));
			}).eq(0);
		} else {
			scrollParent = this.parents().filter(function() {
				return (/(auto|scroll)/).test($.css(this,'overflow')+$.css(this,'overflow-y')+$.css(this,'overflow-x'));
			}).eq(0);
		}

		return (/fixed/).test(this.css('position')) || !scrollParent.length ? $(document) : scrollParent;
	},

	zIndex: function( zIndex ) {
		if ( zIndex !== undefined ) {
			return this.css( "zIndex", zIndex );
		}

		if ( this.length ) {
			var elem = $( this[ 0 ] ), position, value;
			while ( elem.length && elem[ 0 ] !== document ) {
				// Ignore z-index if position is set to a value where z-index is ignored by the browser
				// This makes behavior of this function consistent across browsers
				// WebKit always returns auto if the element is positioned
				position = elem.css( "position" );
				if ( position === "absolute" || position === "relative" || position === "fixed" ) {
					// IE returns 0 when zIndex is not specified
					// other browsers return a string
					// we ignore the case of nested elements with an explicit value of 0
					// <div style="z-index: -10;"><div style="z-index: 0;"></div></div>
					value = parseInt( elem.css( "zIndex" ), 10 );
					if ( !isNaN( value ) && value !== 0 ) {
						return value;
					}
				}
				elem = elem.parent();
			}
		}

		return 0;
	},

	uniqueId: function() {
		return this.each(function() {
			if ( !this.id ) {
				this.id = "ui-id-" + (++uuid);
			}
		});
	},

	removeUniqueId: function() {
		return this.each(function() {
			if ( runiqueId.test( this.id ) ) {
				$( this ).removeAttr( "id" );
			}
		});
	}
});

// selectors
function focusable( element, isTabIndexNotNaN ) {
	var map, mapName, img,
		nodeName = element.nodeName.toLowerCase();
	if ( "area" === nodeName ) {
		map = element.parentNode;
		mapName = map.name;
		if ( !element.href || !mapName || map.nodeName.toLowerCase() !== "map" ) {
			return false;
		}
		img = $( "img[usemap=#" + mapName + "]" )[0];
		return !!img && visible( img );
	}
	return ( /input|select|textarea|button|object/.test( nodeName ) ?
		!element.disabled :
		"a" === nodeName ?
			element.href || isTabIndexNotNaN :
			isTabIndexNotNaN) &&
		// the element and all of its ancestors must be visible
		visible( element );
}

function visible( element ) {
	return $.expr.filters.visible( element ) &&
		!$( element ).parents().andSelf().filter(function() {
			return $.css( this, "visibility" ) === "hidden";
		}).length;
}

$.extend( $.expr[ ":" ], {
	data: $.expr.createPseudo ?
		$.expr.createPseudo(function( dataName ) {
			return function( elem ) {
				return !!$.data( elem, dataName );
			};
		}) :
		// support: jQuery <1.8
		function( elem, i, match ) {
			return !!$.data( elem, match[ 3 ] );
		},

	focusable: function( element ) {
		return focusable( element, !isNaN( $.attr( element, "tabindex" ) ) );
	},

	tabbable: function( element ) {
		var tabIndex = $.attr( element, "tabindex" ),
			isTabIndexNaN = isNaN( tabIndex );
		return ( isTabIndexNaN || tabIndex >= 0 ) && focusable( element, !isTabIndexNaN );
	}
});

// support
$(function() {
	var body = document.body,
		div = body.appendChild( div = document.createElement( "div" ) );

	// access offsetHeight before setting the style to prevent a layout bug
	// in IE 9 which causes the element to continue to take up space even
	// after it is removed from the DOM (#8026)
	div.offsetHeight;

	$.extend( div.style, {
		minHeight: "100px",
		height: "auto",
		padding: 0,
		borderWidth: 0
	});

	$.support.minHeight = div.offsetHeight === 100;
	$.support.selectstart = "onselectstart" in div;

	// set display to none to avoid a layout bug in IE
	// http://dev.jquery.com/ticket/4014
	body.removeChild( div ).style.display = "none";
});

// support: jQuery <1.8
if ( !$( "<a>" ).outerWidth( 1 ).jquery ) {
	$.each( [ "Width", "Height" ], function( i, name ) {
		var side = name === "Width" ? [ "Left", "Right" ] : [ "Top", "Bottom" ],
			type = name.toLowerCase(),
			orig = {
				innerWidth: $.fn.innerWidth,
				innerHeight: $.fn.innerHeight,
				outerWidth: $.fn.outerWidth,
				outerHeight: $.fn.outerHeight
			};

		function reduce( elem, size, border, margin ) {
			$.each( side, function() {
				size -= parseFloat( $.css( elem, "padding" + this ) ) || 0;
				if ( border ) {
					size -= parseFloat( $.css( elem, "border" + this + "Width" ) ) || 0;
				}
				if ( margin ) {
					size -= parseFloat( $.css( elem, "margin" + this ) ) || 0;
				}
			});
			return size;
		}

		$.fn[ "inner" + name ] = function( size ) {
			if ( size === undefined ) {
				return orig[ "inner" + name ].call( this );
			}

			return this.each(function() {
				$( this ).css( type, reduce( this, size ) + "px" );
			});
		};

		$.fn[ "outer" + name] = function( size, margin ) {
			if ( typeof size !== "number" ) {
				return orig[ "outer" + name ].call( this, size );
			}

			return this.each(function() {
				$( this).css( type, reduce( this, size, true, margin ) + "px" );
			});
		};
	});
}

// support: jQuery 1.6.1, 1.6.2 (http://bugs.jquery.com/ticket/9413)
if ( $( "<a>" ).data( "a-b", "a" ).removeData( "a-b" ).data( "a-b" ) ) {
	$.fn.removeData = (function( removeData ) {
		return function( key ) {
			if ( arguments.length ) {
				return removeData.call( this, $.camelCase( key ) );
			} else {
				return removeData.call( this );
			}
		};
	})( $.fn.removeData );
}





// deprecated

(function() {
	var uaMatch = /msie ([\w.]+)/.exec( navigator.userAgent.toLowerCase() ) || [];
	$.ui.ie = uaMatch.length ? true : false;
	$.ui.ie6 = parseFloat( uaMatch[ 1 ], 10 ) === 6;
})();

$.fn.extend({
	disableSelection: function() {
		return this.bind( ( $.support.selectstart ? "selectstart" : "mousedown" ) +
			".ui-disableSelection", function( event ) {
				event.preventDefault();
			});
	},

	enableSelection: function() {
		return this.unbind( ".ui-disableSelection" );
	}
});

$.extend( $.ui, {
	// $.ui.plugin is deprecated.  Use the proxy pattern instead.
	plugin: {
		add: function( module, option, set ) {
			var i,
				proto = $.ui[ module ].prototype;
			for ( i in set ) {
				proto.plugins[ i ] = proto.plugins[ i ] || [];
				proto.plugins[ i ].push( [ option, set[ i ] ] );
			}
		},
		call: function( instance, name, args ) {
			var i,
				set = instance.plugins[ name ];
			if ( !set || !instance.element[ 0 ].parentNode || instance.element[ 0 ].parentNode.nodeType === 11 ) {
				return;
			}

			for ( i = 0; i < set.length; i++ ) {
				if ( instance.options[ set[ i ][ 0 ] ] ) {
					set[ i ][ 1 ].apply( instance.element, args );
				}
			}
		}
	},

	contains: $.contains,

	// only used by resizable
	hasScroll: function( el, a ) {

		//If overflow is hidden, the element might have extra content, but the user wants to hide it
		if ( $( el ).css( "overflow" ) === "hidden") {
			return false;
		}

		var scroll = ( a && a === "left" ) ? "scrollLeft" : "scrollTop",
			has = false;

		if ( el[ scroll ] > 0 ) {
			return true;
		}

		// TODO: determine which cases actually cause this to happen
		// if the element doesn't have the scroll set, see if it's possible to
		// set the scroll
		el[ scroll ] = 1;
		has = ( el[ scroll ] > 0 );
		el[ scroll ] = 0;
		return has;
	},

	// these are odd functions, fix the API or move into individual plugins
	isOverAxis: function( x, reference, size ) {
		//Determines when x coordinate is over "b" element axis
		return ( x > reference ) && ( x < ( reference + size ) );
	},
	isOver: function( y, x, top, left, height, width ) {
		//Determines when x, y coordinates is over "b" element
		return $.ui.isOverAxis( y, top, height ) && $.ui.isOverAxis( x, left, width );
	}
});

})( jQuery );

/*!
 * jQuery UI Datepicker 1.9.2
 * http://jqueryui.com
 *
 * Copyright 2012 jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/datepicker/
 *
 * Depends:
 *	jquery.ui.core.js
 */
(function( $, undefined ) {

$.extend($.ui, { datepicker: { version: "1.9.2" } });

var PROP_NAME = 'datepicker';
var dpuuid = new Date().getTime();
var instActive;

/* Date picker manager.
   Use the singleton instance of this class, $.datepicker, to interact with the date picker.
   Settings for (groups of) date pickers are maintained in an instance object,
   allowing multiple different settings on the same page. */

function Datepicker() {
	this.debug = false; // Change this to true to start debugging
	this._curInst = null; // The current instance in use
	this._keyEvent = false; // If the last event was a key event
	this._disabledInputs = []; // List of date picker inputs that have been disabled
	this._datepickerShowing = false; // True if the popup picker is showing , false if not
	this._inDialog = false; // True if showing within a "dialog", false if not
	this._mainDivId = 'ui-datepicker-div'; // The ID of the main datepicker division
	this._inlineClass = 'ui-datepicker-inline'; // The name of the inline marker class
	this._appendClass = 'ui-datepicker-append'; // The name of the append marker class
	this._triggerClass = 'ui-datepicker-trigger'; // The name of the trigger marker class
	this._dialogClass = 'ui-datepicker-dialog'; // The name of the dialog marker class
	this._disableClass = 'ui-datepicker-disabled'; // The name of the disabled covering marker class
	this._unselectableClass = 'ui-datepicker-unselectable'; // The name of the unselectable cell marker class
	this._currentClass = 'ui-datepicker-current-day'; // The name of the current day marker class
	this._dayOverClass = 'ui-datepicker-days-cell-over'; // The name of the day hover marker class
	this.regional = []; // Available regional settings, indexed by language code
	this.regional[''] = { // Default regional settings
		closeText: 'Done', // Display text for close link
		prevText: 'Prev', // Display text for previous month link
		nextText: 'Next', // Display text for next month link
		currentText: 'Today', // Display text for current month link
		monthNames: ['January','February','March','April','May','June',
			'July','August','September','October','November','December'], // Names of months for drop-down and formatting
		monthNamesShort: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'], // For formatting
		dayNames: ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'], // For formatting
		dayNamesShort: ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'], // For formatting
		dayNamesMin: ['Su','Mo','Tu','We','Th','Fr','Sa'], // Column headings for days starting at Sunday
		weekHeader: 'Wk', // Column header for week of the year
		dateFormat: 'mm/dd/yy', // See format options on parseDate
		firstDay: 0, // The first day of the week, Sun = 0, Mon = 1, ...
		isRTL: false, // True if right-to-left language, false if left-to-right
		showMonthAfterYear: false, // True if the year select precedes month, false for month then year
		yearSuffix: '' // Additional text to append to the year in the month headers
	};
	this._defaults = { // Global defaults for all the date picker instances
		showOn: 'focus', // 'focus' for popup on focus,
			// 'button' for trigger button, or 'both' for either
		showAnim: 'fadeIn', // Name of jQuery animation for popup
		showOptions: {}, // Options for enhanced animations
		defaultDate: null, // Used when field is blank: actual date,
			// +/-number for offset from today, null for today
		appendText: '', // Display text following the input box, e.g. showing the format
		buttonText: '...', // Text for trigger button
		buttonImage: '', // URL for trigger button image
		buttonImageOnly: false, // True if the image appears alone, false if it appears on a button
		hideIfNoPrevNext: false, // True to hide next/previous month links
			// if not applicable, false to just disable them
		navigationAsDateFormat: false, // True if date formatting applied to prev/today/next links
		gotoCurrent: false, // True if today link goes back to current selection instead
		changeMonth: false, // True if month can be selected directly, false if only prev/next
		changeYear: false, // True if year can be selected directly, false if only prev/next
		yearRange: 'c-10:c+10', // Range of years to display in drop-down,
			// either relative to today's year (-nn:+nn), relative to currently displayed year
			// (c-nn:c+nn), absolute (nnnn:nnnn), or a combination of the above (nnnn:-n)
		showOtherMonths: false, // True to show dates in other months, false to leave blank
		selectOtherMonths: false, // True to allow selection of dates in other months, false for unselectable
		showWeek: false, // True to show week of the year, false to not show it
		calculateWeek: this.iso8601Week, // How to calculate the week of the year,
			// takes a Date and returns the number of the week for it
		shortYearCutoff: '+10', // Short year values < this are in the current century,
			// > this are in the previous century,
			// string value starting with '+' for current year + value
		minDate: null, // The earliest selectable date, or null for no limit
		maxDate: null, // The latest selectable date, or null for no limit
		duration: 'fast', // Duration of display/closure
		beforeShowDay: null, // Function that takes a date and returns an array with
			// [0] = true if selectable, false if not, [1] = custom CSS class name(s) or '',
			// [2] = cell title (optional), e.g. $.datepicker.noWeekends
		beforeShow: null, // Function that takes an input field and
			// returns a set of custom settings for the date picker
		onSelect: null, // Define a callback function when a date is selected
		onChangeMonthYear: null, // Define a callback function when the month or year is changed
		onClose: null, // Define a callback function when the datepicker is closed
		numberOfMonths: 1, // Number of months to show at a time
		showCurrentAtPos: 0, // The position in multipe months at which to show the current month (starting at 0)
		stepMonths: 1, // Number of months to step back/forward
		stepBigMonths: 12, // Number of months to step back/forward for the big links
		altField: '', // Selector for an alternate field to store selected dates into
		altFormat: '', // The date format to use for the alternate field
		constrainInput: true, // The input is constrained by the current date format
		showButtonPanel: false, // True to show button panel, false to not show it
		autoSize: false, // True to size the input for the date format, false to leave as is
		disabled: false // The initial disabled state
	};
	$.extend(this._defaults, this.regional['']);
	this.dpDiv = bindHover($('<div id="' + this._mainDivId + '" class="ui-datepicker ui-widget ui-widget-content ui-helper-clearfix ui-corner-all"></div>'));
}

$.extend(Datepicker.prototype, {
	/* Class name added to elements to indicate already configured with a date picker. */
	markerClassName: 'hasDatepicker',

	//Keep track of the maximum number of rows displayed (see #7043)
	maxRows: 4,

	/* Debug logging (if enabled). */
	log: function () {
		if (this.debug)
			console.log.apply('', arguments);
	},

	// TODO rename to "widget" when switching to widget factory
	_widgetDatepicker: function() {
		return this.dpDiv;
	},

	/* Override the default settings for all instances of the date picker.
	   @param  settings  object - the new settings to use as defaults (anonymous object)
	   @return the manager object */
	setDefaults: function(settings) {
		extendRemove(this._defaults, settings || {});
		return this;
	},

	/* Attach the date picker to a jQuery selection.
	   @param  target    element - the target input field or division or span
	   @param  settings  object - the new settings to use for this date picker instance (anonymous) */
	_attachDatepicker: function(target, settings) {
		// check for settings on the control itself - in namespace 'date:'
		var inlineSettings = null;
		for (var attrName in this._defaults) {
			var attrValue = target.getAttribute('date:' + attrName);
			if (attrValue) {
				inlineSettings = inlineSettings || {};
				try {
					inlineSettings[attrName] = eval(attrValue);
				} catch (err) {
					inlineSettings[attrName] = attrValue;
				}
			}
		}
		var nodeName = target.nodeName.toLowerCase();
		var inline = (nodeName == 'div' || nodeName == 'span');
		if (!target.id) {
			this.uuid += 1;
			target.id = 'dp' + this.uuid;
		}
		var inst = this._newInst($(target), inline);
		inst.settings = $.extend({}, settings || {}, inlineSettings || {});
		if (nodeName == 'input') {
			this._connectDatepicker(target, inst);
		} else if (inline) {
			this._inlineDatepicker(target, inst);
		}
	},

	/* Create a new instance object. */
	_newInst: function(target, inline) {
		var id = target[0].id.replace(/([^A-Za-z0-9_-])/g, '\\\\$1'); // escape jQuery meta chars
		return {id: id, input: target, // associated target
			selectedDay: 0, selectedMonth: 0, selectedYear: 0, // current selection
			drawMonth: 0, drawYear: 0, // month being drawn
			inline: inline, // is datepicker inline or not
			dpDiv: (!inline ? this.dpDiv : // presentation div
			bindHover($('<div class="' + this._inlineClass + ' ui-datepicker ui-widget ui-widget-content ui-helper-clearfix ui-corner-all"></div>')))};
	},

	/* Attach the date picker to an input field. */
	_connectDatepicker: function(target, inst) {
		var input = $(target);
		inst.append = $([]);
		inst.trigger = $([]);
		if (input.hasClass(this.markerClassName))
			return;
		this._attachments(input, inst);
		input.addClass(this.markerClassName).keydown(this._doKeyDown).
			keypress(this._doKeyPress).keyup(this._doKeyUp).
			bind("setData.datepicker", function(event, key, value) {
				inst.settings[key] = value;
			}).bind("getData.datepicker", function(event, key) {
				return this._get(inst, key);
			});
		this._autoSize(inst);
		$.data(target, PROP_NAME, inst);
		//If disabled option is true, disable the datepicker once it has been attached to the input (see ticket #5665)
		if( inst.settings.disabled ) {
			this._disableDatepicker( target );
		}
	},

	/* Make attachments based on settings. */
	_attachments: function(input, inst) {
		var appendText = this._get(inst, 'appendText');
		var isRTL = this._get(inst, 'isRTL');
		if (inst.append)
			inst.append.remove();
		if (appendText) {
			inst.append = $('<span class="' + this._appendClass + '">' + appendText + '</span>');
			input[isRTL ? 'before' : 'after'](inst.append);
		}
		input.unbind('focus', this._showDatepicker);
		if (inst.trigger)
			inst.trigger.remove();
		var showOn = this._get(inst, 'showOn');
		if (showOn == 'focus' || showOn == 'both') // pop-up date picker when in the marked field
			input.focus(this._showDatepicker);
		if (showOn == 'button' || showOn == 'both') { // pop-up date picker when button clicked
			var buttonText = this._get(inst, 'buttonText');
			var buttonImage = this._get(inst, 'buttonImage');
			inst.trigger = $(this._get(inst, 'buttonImageOnly') ?
				$('<img/>').addClass(this._triggerClass).
					attr({ src: buttonImage, alt: buttonText, title: buttonText }) :
				$('<button type="button"></button>').addClass(this._triggerClass).
					html(buttonImage == '' ? buttonText : $('<img/>').attr(
					{ src:buttonImage, alt:buttonText, title:buttonText })));
			input[isRTL ? 'before' : 'after'](inst.trigger);
			inst.trigger.click(function() {
				if ($.datepicker._datepickerShowing && $.datepicker._lastInput == input[0])
					$.datepicker._hideDatepicker();
				else if ($.datepicker._datepickerShowing && $.datepicker._lastInput != input[0]) {
					$.datepicker._hideDatepicker();
					$.datepicker._showDatepicker(input[0]);
				} else
					$.datepicker._showDatepicker(input[0]);
				return false;
			});
		}
	},

	/* Apply the maximum length for the date format. */
	_autoSize: function(inst) {
		if (this._get(inst, 'autoSize') && !inst.inline) {
			var date = new Date(2009, 12 - 1, 20); // Ensure double digits
			var dateFormat = this._get(inst, 'dateFormat');
			if (dateFormat.match(/[DM]/)) {
				var findMax = function(names) {
					var max = 0;
					var maxI = 0;
					for (var i = 0; i < names.length; i++) {
						if (names[i].length > max) {
							max = names[i].length;
							maxI = i;
						}
					}
					return maxI;
				};
				date.setMonth(findMax(this._get(inst, (dateFormat.match(/MM/) ?
					'monthNames' : 'monthNamesShort'))));
				date.setDate(findMax(this._get(inst, (dateFormat.match(/DD/) ?
					'dayNames' : 'dayNamesShort'))) + 20 - date.getDay());
			}
			inst.input.attr('size', this._formatDate(inst, date).length);
		}
	},

	/* Attach an inline date picker to a div. */
	_inlineDatepicker: function(target, inst) {
		var divSpan = $(target);
		if (divSpan.hasClass(this.markerClassName))
			return;
		divSpan.addClass(this.markerClassName).append(inst.dpDiv).
			bind("setData.datepicker", function(event, key, value){
				inst.settings[key] = value;
			}).bind("getData.datepicker", function(event, key){
				return this._get(inst, key);
			});
		$.data(target, PROP_NAME, inst);
		this._setDate(inst, this._getDefaultDate(inst), true);
		this._updateDatepicker(inst);
		this._updateAlternate(inst);
		//If disabled option is true, disable the datepicker before showing it (see ticket #5665)
		if( inst.settings.disabled ) {
			this._disableDatepicker( target );
		}
		// Set display:block in place of inst.dpDiv.show() which won't work on disconnected elements
		// http://bugs.jqueryui.com/ticket/7552 - A Datepicker created on a detached div has zero height
		inst.dpDiv.css( "display", "block" );
	},

	/* Pop-up the date picker in a "dialog" box.
	   @param  input     element - ignored
	   @param  date      string or Date - the initial date to display
	   @param  onSelect  function - the function to call when a date is selected
	   @param  settings  object - update the dialog date picker instance's settings (anonymous object)
	   @param  pos       int[2] - coordinates for the dialog's position within the screen or
	                     event - with x/y coordinates or
	                     leave empty for default (screen centre)
	   @return the manager object */
	_dialogDatepicker: function(input, date, onSelect, settings, pos) {
		var inst = this._dialogInst; // internal instance
		if (!inst) {
			this.uuid += 1;
			var id = 'dp' + this.uuid;
			this._dialogInput = $('<input type="text" id="' + id +
				'" style="position: absolute; top: -100px; width: 0px;"/>');
			this._dialogInput.keydown(this._doKeyDown);
			$('body').append(this._dialogInput);
			inst = this._dialogInst = this._newInst(this._dialogInput, false);
			inst.settings = {};
			$.data(this._dialogInput[0], PROP_NAME, inst);
		}
		extendRemove(inst.settings, settings || {});
		date = (date && date.constructor == Date ? this._formatDate(inst, date) : date);
		this._dialogInput.val(date);

		this._pos = (pos ? (pos.length ? pos : [pos.pageX, pos.pageY]) : null);
		if (!this._pos) {
			var browserWidth = document.documentElement.clientWidth;
			var browserHeight = document.documentElement.clientHeight;
			var scrollX = document.documentElement.scrollLeft || document.body.scrollLeft;
			var scrollY = document.documentElement.scrollTop || document.body.scrollTop;
			this._pos = // should use actual width/height below
				[(browserWidth / 2) - 100 + scrollX, (browserHeight / 2) - 150 + scrollY];
		}

		// move input on screen for focus, but hidden behind dialog
		this._dialogInput.css('left', (this._pos[0] + 20) + 'px').css('top', this._pos[1] + 'px');
		inst.settings.onSelect = onSelect;
		this._inDialog = true;
		this.dpDiv.addClass(this._dialogClass);
		this._showDatepicker(this._dialogInput[0]);
		if ($.blockUI)
			$.blockUI(this.dpDiv);
		$.data(this._dialogInput[0], PROP_NAME, inst);
		return this;
	},

	/* Detach a datepicker from its control.
	   @param  target    element - the target input field or division or span */
	_destroyDatepicker: function(target) {
		var $target = $(target);
		var inst = $.data(target, PROP_NAME);
		if (!$target.hasClass(this.markerClassName)) {
			return;
		}
		var nodeName = target.nodeName.toLowerCase();
		$.removeData(target, PROP_NAME);
		if (nodeName == 'input') {
			inst.append.remove();
			inst.trigger.remove();
			$target.removeClass(this.markerClassName).
				unbind('focus', this._showDatepicker).
				unbind('keydown', this._doKeyDown).
				unbind('keypress', this._doKeyPress).
				unbind('keyup', this._doKeyUp);
		} else if (nodeName == 'div' || nodeName == 'span')
			$target.removeClass(this.markerClassName).empty();
	},

	/* Enable the date picker to a jQuery selection.
	   @param  target    element - the target input field or division or span */
	_enableDatepicker: function(target) {
		var $target = $(target);
		var inst = $.data(target, PROP_NAME);
		if (!$target.hasClass(this.markerClassName)) {
			return;
		}
		var nodeName = target.nodeName.toLowerCase();
		if (nodeName == 'input') {
			target.disabled = false;
			inst.trigger.filter('button').
				each(function() { this.disabled = false; }).end().
				filter('img').css({opacity: '1.0', cursor: ''});
		}
		else if (nodeName == 'div' || nodeName == 'span') {
			var inline = $target.children('.' + this._inlineClass);
			inline.children().removeClass('ui-state-disabled');
			inline.find("select.ui-datepicker-month, select.ui-datepicker-year").
				prop("disabled", false);
		}
		this._disabledInputs = $.map(this._disabledInputs,
			function(value) { return (value == target ? null : value); }); // delete entry
	},

	/* Disable the date picker to a jQuery selection.
	   @param  target    element - the target input field or division or span */
	_disableDatepicker: function(target) {
		var $target = $(target);
		var inst = $.data(target, PROP_NAME);
		if (!$target.hasClass(this.markerClassName)) {
			return;
		}
		var nodeName = target.nodeName.toLowerCase();
		if (nodeName == 'input') {
			target.disabled = true;
			inst.trigger.filter('button').
				each(function() { this.disabled = true; }).end().
				filter('img').css({opacity: '0.5', cursor: 'default'});
		}
		else if (nodeName == 'div' || nodeName == 'span') {
			var inline = $target.children('.' + this._inlineClass);
			inline.children().addClass('ui-state-disabled');
			inline.find("select.ui-datepicker-month, select.ui-datepicker-year").
				prop("disabled", true);
		}
		this._disabledInputs = $.map(this._disabledInputs,
			function(value) { return (value == target ? null : value); }); // delete entry
		this._disabledInputs[this._disabledInputs.length] = target;
	},

	/* Is the first field in a jQuery collection disabled as a datepicker?
	   @param  target    element - the target input field or division or span
	   @return boolean - true if disabled, false if enabled */
	_isDisabledDatepicker: function(target) {
		if (!target) {
			return false;
		}
		for (var i = 0; i < this._disabledInputs.length; i++) {
			if (this._disabledInputs[i] == target)
				return true;
		}
		return false;
	},

	/* Retrieve the instance data for the target control.
	   @param  target  element - the target input field or division or span
	   @return  object - the associated instance data
	   @throws  error if a jQuery problem getting data */
	_getInst: function(target) {
		try {
			return $.data(target, PROP_NAME);
		}
		catch (err) {
			throw 'Missing instance data for this datepicker';
		}
	},

	/* Update or retrieve the settings for a date picker attached to an input field or division.
	   @param  target  element - the target input field or division or span
	   @param  name    object - the new settings to update or
	                   string - the name of the setting to change or retrieve,
	                   when retrieving also 'all' for all instance settings or
	                   'defaults' for all global defaults
	   @param  value   any - the new value for the setting
	                   (omit if above is an object or to retrieve a value) */
	_optionDatepicker: function(target, name, value) {
		var inst = this._getInst(target);
		if (arguments.length == 2 && typeof name == 'string') {
			return (name == 'defaults' ? $.extend({}, $.datepicker._defaults) :
				(inst ? (name == 'all' ? $.extend({}, inst.settings) :
				this._get(inst, name)) : null));
		}
		var settings = name || {};
		if (typeof name == 'string') {
			settings = {};
			settings[name] = value;
		}
		if (inst) {
			if (this._curInst == inst) {
				this._hideDatepicker();
			}
			var date = this._getDateDatepicker(target, true);
			var minDate = this._getMinMaxDate(inst, 'min');
			var maxDate = this._getMinMaxDate(inst, 'max');
			extendRemove(inst.settings, settings);
			// reformat the old minDate/maxDate values if dateFormat changes and a new minDate/maxDate isn't provided
			if (minDate !== null && settings['dateFormat'] !== undefined && settings['minDate'] === undefined)
				inst.settings.minDate = this._formatDate(inst, minDate);
			if (maxDate !== null && settings['dateFormat'] !== undefined && settings['maxDate'] === undefined)
				inst.settings.maxDate = this._formatDate(inst, maxDate);
			this._attachments($(target), inst);
			this._autoSize(inst);
			this._setDate(inst, date);
			this._updateAlternate(inst);
			this._updateDatepicker(inst);
		}
	},

	// change method deprecated
	_changeDatepicker: function(target, name, value) {
		this._optionDatepicker(target, name, value);
	},

	/* Redraw the date picker attached to an input field or division.
	   @param  target  element - the target input field or division or span */
	_refreshDatepicker: function(target) {
		var inst = this._getInst(target);
		if (inst) {
			this._updateDatepicker(inst);
		}
	},

	/* Set the dates for a jQuery selection.
	   @param  target   element - the target input field or division or span
	   @param  date     Date - the new date */
	_setDateDatepicker: function(target, date) {
		var inst = this._getInst(target);
		if (inst) {
			this._setDate(inst, date);
			this._updateDatepicker(inst);
			this._updateAlternate(inst);
		}
	},

	/* Get the date(s) for the first entry in a jQuery selection.
	   @param  target     element - the target input field or division or span
	   @param  noDefault  boolean - true if no default date is to be used
	   @return Date - the current date */
	_getDateDatepicker: function(target, noDefault) {
		var inst = this._getInst(target);
		if (inst && !inst.inline)
			this._setDateFromField(inst, noDefault);
		return (inst ? this._getDate(inst) : null);
	},

	/* Handle keystrokes. */
	_doKeyDown: function(event) {
		var inst = $.datepicker._getInst(event.target);
		var handled = true;
		var isRTL = inst.dpDiv.is('.ui-datepicker-rtl');
		inst._keyEvent = true;
		if ($.datepicker._datepickerShowing)
			switch (event.keyCode) {
				case 9: $.datepicker._hideDatepicker();
						handled = false;
						break; // hide on tab out
				case 13: var sel = $('td.' + $.datepicker._dayOverClass + ':not(.' +
									$.datepicker._currentClass + ')', inst.dpDiv);
						if (sel[0])
							$.datepicker._selectDay(event.target, inst.selectedMonth, inst.selectedYear, sel[0]);
							var onSelect = $.datepicker._get(inst, 'onSelect');
							if (onSelect) {
								var dateStr = $.datepicker._formatDate(inst);

								// trigger custom callback
								onSelect.apply((inst.input ? inst.input[0] : null), [dateStr, inst]);
							}
						else
							$.datepicker._hideDatepicker();
						return false; // don't submit the form
						break; // select the value on enter
				case 27: $.datepicker._hideDatepicker();
						break; // hide on escape
				case 33: $.datepicker._adjustDate(event.target, (event.ctrlKey ?
							-$.datepicker._get(inst, 'stepBigMonths') :
							-$.datepicker._get(inst, 'stepMonths')), 'M');
						break; // previous month/year on page up/+ ctrl
				case 34: $.datepicker._adjustDate(event.target, (event.ctrlKey ?
							+$.datepicker._get(inst, 'stepBigMonths') :
							+$.datepicker._get(inst, 'stepMonths')), 'M');
						break; // next month/year on page down/+ ctrl
				case 35: if (event.ctrlKey || event.metaKey) $.datepicker._clearDate(event.target);
						handled = event.ctrlKey || event.metaKey;
						break; // clear on ctrl or command +end
				case 36: if (event.ctrlKey || event.metaKey) $.datepicker._gotoToday(event.target);
						handled = event.ctrlKey || event.metaKey;
						break; // current on ctrl or command +home
				case 37: if (event.ctrlKey || event.metaKey) $.datepicker._adjustDate(event.target, (isRTL ? +1 : -1), 'D');
						handled = event.ctrlKey || event.metaKey;
						// -1 day on ctrl or command +left
						if (event.originalEvent.altKey) $.datepicker._adjustDate(event.target, (event.ctrlKey ?
									-$.datepicker._get(inst, 'stepBigMonths') :
									-$.datepicker._get(inst, 'stepMonths')), 'M');
						// next month/year on alt +left on Mac
						break;
				case 38: if (event.ctrlKey || event.metaKey) $.datepicker._adjustDate(event.target, -7, 'D');
						handled = event.ctrlKey || event.metaKey;
						break; // -1 week on ctrl or command +up
				case 39: if (event.ctrlKey || event.metaKey) $.datepicker._adjustDate(event.target, (isRTL ? -1 : +1), 'D');
						handled = event.ctrlKey || event.metaKey;
						// +1 day on ctrl or command +right
						if (event.originalEvent.altKey) $.datepicker._adjustDate(event.target, (event.ctrlKey ?
									+$.datepicker._get(inst, 'stepBigMonths') :
									+$.datepicker._get(inst, 'stepMonths')), 'M');
						// next month/year on alt +right
						break;
				case 40: if (event.ctrlKey || event.metaKey) $.datepicker._adjustDate(event.target, +7, 'D');
						handled = event.ctrlKey || event.metaKey;
						break; // +1 week on ctrl or command +down
				default: handled = false;
			}
		else if (event.keyCode == 36 && event.ctrlKey) // display the date picker on ctrl+home
			$.datepicker._showDatepicker(this);
		else {
			handled = false;
		}
		if (handled) {
			event.preventDefault();
			event.stopPropagation();
		}
	},

	/* Filter entered characters - based on date format. */
	_doKeyPress: function(event) {
		var inst = $.datepicker._getInst(event.target);
		if ($.datepicker._get(inst, 'constrainInput')) {
			var chars = $.datepicker._possibleChars($.datepicker._get(inst, 'dateFormat'));
			var chr = String.fromCharCode(event.charCode == undefined ? event.keyCode : event.charCode);
			return event.ctrlKey || event.metaKey || (chr < ' ' || !chars || chars.indexOf(chr) > -1);
		}
	},

	/* Synchronise manual entry and field/alternate field. */
	_doKeyUp: function(event) {
		var inst = $.datepicker._getInst(event.target);
		if (inst.input.val() != inst.lastVal) {
			try {
				var date = $.datepicker.parseDate($.datepicker._get(inst, 'dateFormat'),
					(inst.input ? inst.input.val() : null),
					$.datepicker._getFormatConfig(inst));
				if (date) { // only if valid
					$.datepicker._setDateFromField(inst);
					$.datepicker._updateAlternate(inst);
					$.datepicker._updateDatepicker(inst);
				}
			}
			catch (err) {
				$.datepicker.log(err);
			}
		}
		return true;
	},

	/* Pop-up the date picker for a given input field.
	   If false returned from beforeShow event handler do not show.
	   @param  input  element - the input field attached to the date picker or
	                  event - if triggered by focus */
	_showDatepicker: function(input) {
		input = input.target || input;
		if (input.nodeName.toLowerCase() != 'input') // find from button/image trigger
			input = $('input', input.parentNode)[0];
		if ($.datepicker._isDisabledDatepicker(input) || $.datepicker._lastInput == input) // already here
			return;
		var inst = $.datepicker._getInst(input);
		if ($.datepicker._curInst && $.datepicker._curInst != inst) {
			$.datepicker._curInst.dpDiv.stop(true, true);
			if ( inst && $.datepicker._datepickerShowing ) {
				$.datepicker._hideDatepicker( $.datepicker._curInst.input[0] );
			}
		}
		var beforeShow = $.datepicker._get(inst, 'beforeShow');
		var beforeShowSettings = beforeShow ? beforeShow.apply(input, [input, inst]) : {};
		if(beforeShowSettings === false){
			//false
			return;
		}
		extendRemove(inst.settings, beforeShowSettings);
		inst.lastVal = null;
		$.datepicker._lastInput = input;
		$.datepicker._setDateFromField(inst);
		if ($.datepicker._inDialog) // hide cursor
			input.value = '';
		if (!$.datepicker._pos) { // position below input
			$.datepicker._pos = $.datepicker._findPos(input);
			$.datepicker._pos[1] += input.offsetHeight; // add the height
		}
		var isFixed = false;
		$(input).parents().each(function() {
			isFixed |= $(this).css('position') == 'fixed';
			return !isFixed;
		});
		var offset = {left: $.datepicker._pos[0], top: $.datepicker._pos[1]};
		$.datepicker._pos = null;
		//to avoid flashes on Firefox
		inst.dpDiv.empty();
		// determine sizing offscreen
		inst.dpDiv.css({position: 'absolute', display: 'block', top: '-1000px'});
		$.datepicker._updateDatepicker(inst);
		// fix width for dynamic number of date pickers
		// and adjust position before showing
		offset = $.datepicker._checkOffset(inst, offset, isFixed);
		inst.dpDiv.css({position: ($.datepicker._inDialog && $.blockUI ?
			'static' : (isFixed ? 'fixed' : 'absolute')), display: 'none',
			left: offset.left + 'px', top: offset.top + 'px'});
		if (!inst.inline) {
			var showAnim = $.datepicker._get(inst, 'showAnim');
			var duration = $.datepicker._get(inst, 'duration');
			var postProcess = function() {
				var cover = inst.dpDiv.find('iframe.ui-datepicker-cover'); // IE6- only
				if( !! cover.length ){
					var borders = $.datepicker._getBorders(inst.dpDiv);
					cover.css({left: -borders[0], top: -borders[1],
						width: inst.dpDiv.outerWidth(), height: inst.dpDiv.outerHeight()});
				}
			};
			inst.dpDiv.zIndex($(input).zIndex()+1);
			$.datepicker._datepickerShowing = true;

			// DEPRECATED: after BC for 1.8.x $.effects[ showAnim ] is not needed
			if ( $.effects && ( $.effects.effect[ showAnim ] || $.effects[ showAnim ] ) )
				inst.dpDiv.show(showAnim, $.datepicker._get(inst, 'showOptions'), duration, postProcess);
			else
				inst.dpDiv[showAnim || 'show']((showAnim ? duration : null), postProcess);
			if (!showAnim || !duration)
				postProcess();
			if (inst.input.is(':visible') && !inst.input.is(':disabled'))
				inst.input.focus();
			$.datepicker._curInst = inst;
		}
	},

	/* Generate the date picker content. */
	_updateDatepicker: function(inst) {
		this.maxRows = 4; //Reset the max number of rows being displayed (see #7043)
		var borders = $.datepicker._getBorders(inst.dpDiv);
		instActive = inst; // for delegate hover events
		inst.dpDiv.empty().append(this._generateHTML(inst));
		this._attachHandlers(inst);
		var cover = inst.dpDiv.find('iframe.ui-datepicker-cover'); // IE6- only
		if( !!cover.length ){ //avoid call to outerXXXX() when not in IE6
			cover.css({left: -borders[0], top: -borders[1], width: inst.dpDiv.outerWidth(), height: inst.dpDiv.outerHeight()})
		}
		inst.dpDiv.find('.' + this._dayOverClass + ' a').mouseover();
		var numMonths = this._getNumberOfMonths(inst);
		var cols = numMonths[1];
		var width = 17;
		inst.dpDiv.removeClass('ui-datepicker-multi-2 ui-datepicker-multi-3 ui-datepicker-multi-4').width('');
		if (cols > 1)
			inst.dpDiv.addClass('ui-datepicker-multi-' + cols).css('width', (width * cols) + 'em');
		inst.dpDiv[(numMonths[0] != 1 || numMonths[1] != 1 ? 'add' : 'remove') +
			'Class']('ui-datepicker-multi');
		inst.dpDiv[(this._get(inst, 'isRTL') ? 'add' : 'remove') +
			'Class']('ui-datepicker-rtl');
		if (inst == $.datepicker._curInst && $.datepicker._datepickerShowing && inst.input &&
				// #6694 - don't focus the input if it's already focused
				// this breaks the change event in IE
				inst.input.is(':visible') && !inst.input.is(':disabled') && inst.input[0] != document.activeElement)
			inst.input.focus();
		// deffered render of the years select (to avoid flashes on Firefox)
		if( inst.yearshtml ){
			var origyearshtml = inst.yearshtml;
			setTimeout(function(){
				//assure that inst.yearshtml didn't change.
				if( origyearshtml === inst.yearshtml && inst.yearshtml ){
					inst.dpDiv.find('select.ui-datepicker-year:first').replaceWith(inst.yearshtml);
				}
				origyearshtml = inst.yearshtml = null;
			}, 0);
		}
	},

	/* Retrieve the size of left and top borders for an element.
	   @param  elem  (jQuery object) the element of interest
	   @return  (number[2]) the left and top borders */
	_getBorders: function(elem) {
		var convert = function(value) {
			return {thin: 1, medium: 2, thick: 3}[value] || value;
		};
		return [parseFloat(convert(elem.css('border-left-width'))),
			parseFloat(convert(elem.css('border-top-width')))];
	},

	/* Check positioning to remain on screen. */
	_checkOffset: function(inst, offset, isFixed) {
		var dpWidth = inst.dpDiv.outerWidth();
		var dpHeight = inst.dpDiv.outerHeight();
		var inputWidth = inst.input ? inst.input.outerWidth() : 0;
		var inputHeight = inst.input ? inst.input.outerHeight() : 0;
		var viewWidth = document.documentElement.clientWidth + (isFixed ? 0 : $(document).scrollLeft());
		var viewHeight = document.documentElement.clientHeight + (isFixed ? 0 : $(document).scrollTop());

		offset.left -= (this._get(inst, 'isRTL') ? (dpWidth - inputWidth) : 0);
		offset.left -= (isFixed && offset.left == inst.input.offset().left) ? $(document).scrollLeft() : 0;
		offset.top -= (isFixed && offset.top == (inst.input.offset().top + inputHeight)) ? $(document).scrollTop() : 0;

		// now check if datepicker is showing outside window viewport - move to a better place if so.
		offset.left -= Math.min(offset.left, (offset.left + dpWidth > viewWidth && viewWidth > dpWidth) ?
			Math.abs(offset.left + dpWidth - viewWidth) : 0);
		offset.top -= Math.min(offset.top, (offset.top + dpHeight > viewHeight && viewHeight > dpHeight) ?
			Math.abs(dpHeight + inputHeight) : 0);

		return offset;
	},

	/* Find an object's position on the screen. */
	_findPos: function(obj) {
		var inst = this._getInst(obj);
		var isRTL = this._get(inst, 'isRTL');
		while (obj && (obj.type == 'hidden' || obj.nodeType != 1 || $.expr.filters.hidden(obj))) {
			obj = obj[isRTL ? 'previousSibling' : 'nextSibling'];
		}
		var position = $(obj).offset();
		return [position.left, position.top];
	},

	/* Hide the date picker from view.
	   @param  input  element - the input field attached to the date picker */
	_hideDatepicker: function(input) {
		var inst = this._curInst;
		if (!inst || (input && inst != $.data(input, PROP_NAME)))
			return;
		if (this._datepickerShowing) {
			var showAnim = this._get(inst, 'showAnim');
			var duration = this._get(inst, 'duration');
			var postProcess = function() {
				$.datepicker._tidyDialog(inst);
			};

			// DEPRECATED: after BC for 1.8.x $.effects[ showAnim ] is not needed
			if ( $.effects && ( $.effects.effect[ showAnim ] || $.effects[ showAnim ] ) )
				inst.dpDiv.hide(showAnim, $.datepicker._get(inst, 'showOptions'), duration, postProcess);
			else
				inst.dpDiv[(showAnim == 'slideDown' ? 'slideUp' :
					(showAnim == 'fadeIn' ? 'fadeOut' : 'hide'))]((showAnim ? duration : null), postProcess);
			if (!showAnim)
				postProcess();
			this._datepickerShowing = false;
			var onClose = this._get(inst, 'onClose');
			if (onClose)
				onClose.apply((inst.input ? inst.input[0] : null),
					[(inst.input ? inst.input.val() : ''), inst]);
			this._lastInput = null;
			if (this._inDialog) {
				this._dialogInput.css({ position: 'absolute', left: '0', top: '-100px' });
				if ($.blockUI) {
					$.unblockUI();
					$('body').append(this.dpDiv);
				}
			}
			this._inDialog = false;
		}
	},

	/* Tidy up after a dialog display. */
	_tidyDialog: function(inst) {
		inst.dpDiv.removeClass(this._dialogClass).unbind('.ui-datepicker-calendar');
	},

	/* Close date picker if clicked elsewhere. */
	_checkExternalClick: function(event) {
		if (!$.datepicker._curInst)
			return;

		var $target = $(event.target),
			inst = $.datepicker._getInst($target[0]);

		if ( ( ( $target[0].id != $.datepicker._mainDivId &&
				$target.parents('#' + $.datepicker._mainDivId).length == 0 &&
				!$target.hasClass($.datepicker.markerClassName) &&
				!$target.closest("." + $.datepicker._triggerClass).length &&
				$.datepicker._datepickerShowing && !($.datepicker._inDialog && $.blockUI) ) ) ||
			( $target.hasClass($.datepicker.markerClassName) && $.datepicker._curInst != inst ) )
			$.datepicker._hideDatepicker();
	},

	/* Adjust one of the date sub-fields. */
	_adjustDate: function(id, offset, period) {
		var target = $(id);
		var inst = this._getInst(target[0]);
		if (this._isDisabledDatepicker(target[0])) {
			return;
		}
		this._adjustInstDate(inst, offset +
			(period == 'M' ? this._get(inst, 'showCurrentAtPos') : 0), // undo positioning
			period);
		this._updateDatepicker(inst);
	},

	/* Action for current link. */
	_gotoToday: function(id) {
		var target = $(id);
		var inst = this._getInst(target[0]);
		if (this._get(inst, 'gotoCurrent') && inst.currentDay) {
			inst.selectedDay = inst.currentDay;
			inst.drawMonth = inst.selectedMonth = inst.currentMonth;
			inst.drawYear = inst.selectedYear = inst.currentYear;
		}
		else {
			var date = new Date();
			inst.selectedDay = date.getDate();
			inst.drawMonth = inst.selectedMonth = date.getMonth();
			inst.drawYear = inst.selectedYear = date.getFullYear();
		}
		this._notifyChange(inst);
		this._adjustDate(target);
	},

	/* Action for selecting a new month/year. */
	_selectMonthYear: function(id, select, period) {
		var target = $(id);
		var inst = this._getInst(target[0]);
		inst['selected' + (period == 'M' ? 'Month' : 'Year')] =
		inst['draw' + (period == 'M' ? 'Month' : 'Year')] =
			parseInt(select.options[select.selectedIndex].value,10);
		this._notifyChange(inst);
		this._adjustDate(target);
	},

	/* Action for selecting a day. */
	_selectDay: function(id, month, year, td) {
		var target = $(id);
		if ($(td).hasClass(this._unselectableClass) || this._isDisabledDatepicker(target[0])) {
			return;
		}
		var inst = this._getInst(target[0]);
		inst.selectedDay = inst.currentDay = $('a', td).html();
		inst.selectedMonth = inst.currentMonth = month;
		inst.selectedYear = inst.currentYear = year;
		this._selectDate(id, this._formatDate(inst,
			inst.currentDay, inst.currentMonth, inst.currentYear));
	},

	/* Erase the input field and hide the date picker. */
	_clearDate: function(id) {
		var target = $(id);
		var inst = this._getInst(target[0]);
		this._selectDate(target, '');
	},

	/* Update the input field with the selected date. */
	_selectDate: function(id, dateStr) {
		var target = $(id);
		var inst = this._getInst(target[0]);
		dateStr = (dateStr != null ? dateStr : this._formatDate(inst));
		if (inst.input)
			inst.input.val(dateStr);
		this._updateAlternate(inst);
		var onSelect = this._get(inst, 'onSelect');
		if (onSelect)
			onSelect.apply((inst.input ? inst.input[0] : null), [dateStr, inst]);  // trigger custom callback
		else if (inst.input)
			inst.input.trigger('change'); // fire the change event
		if (inst.inline)
			this._updateDatepicker(inst);
		else {
			this._hideDatepicker();
			this._lastInput = inst.input[0];
			if (typeof(inst.input[0]) != 'object')
				inst.input.focus(); // restore focus
			this._lastInput = null;
		}
	},

	/* Update any alternate field to synchronise with the main field. */
	_updateAlternate: function(inst) {
		var altField = this._get(inst, 'altField');
		if (altField) { // update alternate field too
			var altFormat = this._get(inst, 'altFormat') || this._get(inst, 'dateFormat');
			var date = this._getDate(inst);
			var dateStr = this.formatDate(altFormat, date, this._getFormatConfig(inst));
			$(altField).each(function() { $(this).val(dateStr); });
		}
	},

	/* Set as beforeShowDay function to prevent selection of weekends.
	   @param  date  Date - the date to customise
	   @return [boolean, string] - is this date selectable?, what is its CSS class? */
	noWeekends: function(date) {
		var day = date.getDay();
		return [(day > 0 && day < 6), ''];
	},

	/* Set as calculateWeek to determine the week of the year based on the ISO 8601 definition.
	   @param  date  Date - the date to get the week for
	   @return  number - the number of the week within the year that contains this date */
	iso8601Week: function(date) {
		var checkDate = new Date(date.getTime());
		// Find Thursday of this week starting on Monday
		checkDate.setDate(checkDate.getDate() + 4 - (checkDate.getDay() || 7));
		var time = checkDate.getTime();
		checkDate.setMonth(0); // Compare with Jan 1
		checkDate.setDate(1);
		return Math.floor(Math.round((time - checkDate) / 86400000) / 7) + 1;
	},

	/* Parse a string value into a date object.
	   See formatDate below for the possible formats.

	   @param  format    string - the expected format of the date
	   @param  value     string - the date in the above format
	   @param  settings  Object - attributes include:
	                     shortYearCutoff  number - the cutoff year for determining the century (optional)
	                     dayNamesShort    string[7] - abbreviated names of the days from Sunday (optional)
	                     dayNames         string[7] - names of the days from Sunday (optional)
	                     monthNamesShort  string[12] - abbreviated names of the months (optional)
	                     monthNames       string[12] - names of the months (optional)
	   @return  Date - the extracted date value or null if value is blank */
	parseDate: function (format, value, settings) {
		if (format == null || value == null)
			throw 'Invalid arguments';
		value = (typeof value == 'object' ? value.toString() : value + '');
		if (value == '')
			return null;
		var shortYearCutoff = (settings ? settings.shortYearCutoff : null) || this._defaults.shortYearCutoff;
		shortYearCutoff = (typeof shortYearCutoff != 'string' ? shortYearCutoff :
				new Date().getFullYear() % 100 + parseInt(shortYearCutoff, 10));
		var dayNamesShort = (settings ? settings.dayNamesShort : null) || this._defaults.dayNamesShort;
		var dayNames = (settings ? settings.dayNames : null) || this._defaults.dayNames;
		var monthNamesShort = (settings ? settings.monthNamesShort : null) || this._defaults.monthNamesShort;
		var monthNames = (settings ? settings.monthNames : null) || this._defaults.monthNames;
		var year = -1;
		var month = -1;
		var day = -1;
		var doy = -1;
		var literal = false;
		// Check whether a format character is doubled
		var lookAhead = function(match) {
			var matches = (iFormat + 1 < format.length && format.charAt(iFormat + 1) == match);
			if (matches)
				iFormat++;
			return matches;
		};
		// Extract a number from the string value
		var getNumber = function(match) {
			var isDoubled = lookAhead(match);
			var size = (match == '@' ? 14 : (match == '!' ? 20 :
				(match == 'y' && isDoubled ? 4 : (match == 'o' ? 3 : 2))));
			var digits = new RegExp('^\\d{1,' + size + '}');
			var num = value.substring(iValue).match(digits);
			if (!num)
				throw 'Missing number at position ' + iValue;
			iValue += num[0].length;
			return parseInt(num[0], 10);
		};
		// Extract a name from the string value and convert to an index
		var getName = function(match, shortNames, longNames) {
			var names = $.map(lookAhead(match) ? longNames : shortNames, function (v, k) {
				return [ [k, v] ];
			}).sort(function (a, b) {
				return -(a[1].length - b[1].length);
			});
			var index = -1;
			$.each(names, function (i, pair) {
				var name = pair[1];
				if (value.substr(iValue, name.length).toLowerCase() == name.toLowerCase()) {
					index = pair[0];
					iValue += name.length;
					return false;
				}
			});
			if (index != -1)
				return index + 1;
			else
				throw 'Unknown name at position ' + iValue;
		};
		// Confirm that a literal character matches the string value
		var checkLiteral = function() {
			if (value.charAt(iValue) != format.charAt(iFormat))
				throw 'Unexpected literal at position ' + iValue;
			iValue++;
		};
		var iValue = 0;
		for (var iFormat = 0; iFormat < format.length; iFormat++) {
			if (literal)
				if (format.charAt(iFormat) == "'" && !lookAhead("'"))
					literal = false;
				else
					checkLiteral();
			else
				switch (format.charAt(iFormat)) {
					case 'd':
						day = getNumber('d');
						break;
					case 'D':
						getName('D', dayNamesShort, dayNames);
						break;
					case 'o':
						doy = getNumber('o');
						break;
					case 'm':
						month = getNumber('m');
						break;
					case 'M':
						month = getName('M', monthNamesShort, monthNames);
						break;
					case 'y':
						year = getNumber('y');
						break;
					case '@':
						var date = new Date(getNumber('@'));
						year = date.getFullYear();
						month = date.getMonth() + 1;
						day = date.getDate();
						break;
					case '!':
						var date = new Date((getNumber('!') - this._ticksTo1970) / 10000);
						year = date.getFullYear();
						month = date.getMonth() + 1;
						day = date.getDate();
						break;
					case "'":
						if (lookAhead("'"))
							checkLiteral();
						else
							literal = true;
						break;
					default:
						checkLiteral();
				}
		}
		if (iValue < value.length){
			var extra = value.substr(iValue);
			if (!/^\s+/.test(extra)) {
				throw "Extra/unparsed characters found in date: " + extra;
			}
		}
		if (year == -1)
			year = new Date().getFullYear();
		else if (year < 100)
			year += new Date().getFullYear() - new Date().getFullYear() % 100 +
				(year <= shortYearCutoff ? 0 : -100);
		if (doy > -1) {
			month = 1;
			day = doy;
			do {
				var dim = this._getDaysInMonth(year, month - 1);
				if (day <= dim)
					break;
				month++;
				day -= dim;
			} while (true);
		}
		var date = this._daylightSavingAdjust(new Date(year, month - 1, day));
		if (date.getFullYear() != year || date.getMonth() + 1 != month || date.getDate() != day)
			throw 'Invalid date'; // E.g. 31/02/00
		return date;
	},

	/* Standard date formats. */
	ATOM: 'yy-mm-dd', // RFC 3339 (ISO 8601)
	COOKIE: 'D, dd M yy',
	ISO_8601: 'yy-mm-dd',
	RFC_822: 'D, d M y',
	RFC_850: 'DD, dd-M-y',
	RFC_1036: 'D, d M y',
	RFC_1123: 'D, d M yy',
	RFC_2822: 'D, d M yy',
	RSS: 'D, d M y', // RFC 822
	TICKS: '!',
	TIMESTAMP: '@',
	W3C: 'yy-mm-dd', // ISO 8601

	_ticksTo1970: (((1970 - 1) * 365 + Math.floor(1970 / 4) - Math.floor(1970 / 100) +
		Math.floor(1970 / 400)) * 24 * 60 * 60 * 10000000),

	/* Format a date object into a string value.
	   The format can be combinations of the following:
	   d  - day of month (no leading zero)
	   dd - day of month (two digit)
	   o  - day of year (no leading zeros)
	   oo - day of year (three digit)
	   D  - day name short
	   DD - day name long
	   m  - month of year (no leading zero)
	   mm - month of year (two digit)
	   M  - month name short
	   MM - month name long
	   y  - year (two digit)
	   yy - year (four digit)
	   @ - Unix timestamp (ms since 01/01/1970)
	   ! - Windows ticks (100ns since 01/01/0001)
	   '...' - literal text
	   '' - single quote

	   @param  format    string - the desired format of the date
	   @param  date      Date - the date value to format
	   @param  settings  Object - attributes include:
	                     dayNamesShort    string[7] - abbreviated names of the days from Sunday (optional)
	                     dayNames         string[7] - names of the days from Sunday (optional)
	                     monthNamesShort  string[12] - abbreviated names of the months (optional)
	                     monthNames       string[12] - names of the months (optional)
	   @return  string - the date in the above format */
	formatDate: function (format, date, settings) {
		if (!date)
			return '';
		var dayNamesShort = (settings ? settings.dayNamesShort : null) || this._defaults.dayNamesShort;
		var dayNames = (settings ? settings.dayNames : null) || this._defaults.dayNames;
		var monthNamesShort = (settings ? settings.monthNamesShort : null) || this._defaults.monthNamesShort;
		var monthNames = (settings ? settings.monthNames : null) || this._defaults.monthNames;
		// Check whether a format character is doubled
		var lookAhead = function(match) {
			var matches = (iFormat + 1 < format.length && format.charAt(iFormat + 1) == match);
			if (matches)
				iFormat++;
			return matches;
		};
		// Format a number, with leading zero if necessary
		var formatNumber = function(match, value, len) {
			var num = '' + value;
			if (lookAhead(match))
				while (num.length < len)
					num = '0' + num;
			return num;
		};
		// Format a name, short or long as requested
		var formatName = function(match, value, shortNames, longNames) {
			return (lookAhead(match) ? longNames[value] : shortNames[value]);
		};
		var output = '';
		var literal = false;
		if (date)
			for (var iFormat = 0; iFormat < format.length; iFormat++) {
				if (literal)
					if (format.charAt(iFormat) == "'" && !lookAhead("'"))
						literal = false;
					else
						output += format.charAt(iFormat);
				else
					switch (format.charAt(iFormat)) {
						case 'd':
							output += formatNumber('d', date.getDate(), 2);
							break;
						case 'D':
							output += formatName('D', date.getDay(), dayNamesShort, dayNames);
							break;
						case 'o':
							output += formatNumber('o',
								Math.round((new Date(date.getFullYear(), date.getMonth(), date.getDate()).getTime() - new Date(date.getFullYear(), 0, 0).getTime()) / 86400000), 3);
							break;
						case 'm':
							output += formatNumber('m', date.getMonth() + 1, 2);
							break;
						case 'M':
							output += formatName('M', date.getMonth(), monthNamesShort, monthNames);
							break;
						case 'y':
							output += (lookAhead('y') ? date.getFullYear() :
								(date.getYear() % 100 < 10 ? '0' : '') + date.getYear() % 100);
							break;
						case '@':
							output += date.getTime();
							break;
						case '!':
							output += date.getTime() * 10000 + this._ticksTo1970;
							break;
						case "'":
							if (lookAhead("'"))
								output += "'";
							else
								literal = true;
							break;
						default:
							output += format.charAt(iFormat);
					}
			}
		return output;
	},

	/* Extract all possible characters from the date format. */
	_possibleChars: function (format) {
		var chars = '';
		var literal = false;
		// Check whether a format character is doubled
		var lookAhead = function(match) {
			var matches = (iFormat + 1 < format.length && format.charAt(iFormat + 1) == match);
			if (matches)
				iFormat++;
			return matches;
		};
		for (var iFormat = 0; iFormat < format.length; iFormat++)
			if (literal)
				if (format.charAt(iFormat) == "'" && !lookAhead("'"))
					literal = false;
				else
					chars += format.charAt(iFormat);
			else
				switch (format.charAt(iFormat)) {
					case 'd': case 'm': case 'y': case '@':
						chars += '0123456789';
						break;
					case 'D': case 'M':
						return null; // Accept anything
					case "'":
						if (lookAhead("'"))
							chars += "'";
						else
							literal = true;
						break;
					default:
						chars += format.charAt(iFormat);
				}
		return chars;
	},

	/* Get a setting value, defaulting if necessary. */
	_get: function(inst, name) {
		return inst.settings[name] !== undefined ?
			inst.settings[name] : this._defaults[name];
	},

	/* Parse existing date and initialise date picker. */
	_setDateFromField: function(inst, noDefault) {
		if (inst.input.val() == inst.lastVal) {
			return;
		}
		var dateFormat = this._get(inst, 'dateFormat');
		var dates = inst.lastVal = inst.input ? inst.input.val() : null;
		var date, defaultDate;
		date = defaultDate = this._getDefaultDate(inst);
		var settings = this._getFormatConfig(inst);
		try {
			date = this.parseDate(dateFormat, dates, settings) || defaultDate;
		} catch (event) {
			this.log(event);
			dates = (noDefault ? '' : dates);
		}
		inst.selectedDay = date.getDate();
		inst.drawMonth = inst.selectedMonth = date.getMonth();
		inst.drawYear = inst.selectedYear = date.getFullYear();
		inst.currentDay = (dates ? date.getDate() : 0);
		inst.currentMonth = (dates ? date.getMonth() : 0);
		inst.currentYear = (dates ? date.getFullYear() : 0);
		this._adjustInstDate(inst);
	},

	/* Retrieve the default date shown on opening. */
	_getDefaultDate: function(inst) {
		return this._restrictMinMax(inst,
			this._determineDate(inst, this._get(inst, 'defaultDate'), new Date()));
	},

	/* A date may be specified as an exact value or a relative one. */
	_determineDate: function(inst, date, defaultDate) {
		var offsetNumeric = function(offset) {
			var date = new Date();
			date.setDate(date.getDate() + offset);
			return date;
		};
		var offsetString = function(offset) {
			try {
				return $.datepicker.parseDate($.datepicker._get(inst, 'dateFormat'),
					offset, $.datepicker._getFormatConfig(inst));
			}
			catch (e) {
				// Ignore
			}
			var date = (offset.toLowerCase().match(/^c/) ?
				$.datepicker._getDate(inst) : null) || new Date();
			var year = date.getFullYear();
			var month = date.getMonth();
			var day = date.getDate();
			var pattern = /([+-]?[0-9]+)\s*(d|D|w|W|m|M|y|Y)?/g;
			var matches = pattern.exec(offset);
			while (matches) {
				switch (matches[2] || 'd') {
					case 'd' : case 'D' :
						day += parseInt(matches[1],10); break;
					case 'w' : case 'W' :
						day += parseInt(matches[1],10) * 7; break;
					case 'm' : case 'M' :
						month += parseInt(matches[1],10);
						day = Math.min(day, $.datepicker._getDaysInMonth(year, month));
						break;
					case 'y': case 'Y' :
						year += parseInt(matches[1],10);
						day = Math.min(day, $.datepicker._getDaysInMonth(year, month));
						break;
				}
				matches = pattern.exec(offset);
			}
			return new Date(year, month, day);
		};
		var newDate = (date == null || date === '' ? defaultDate : (typeof date == 'string' ? offsetString(date) :
			(typeof date == 'number' ? (isNaN(date) ? defaultDate : offsetNumeric(date)) : new Date(date.getTime()))));
		newDate = (newDate && newDate.toString() == 'Invalid Date' ? defaultDate : newDate);
		if (newDate) {
			newDate.setHours(0);
			newDate.setMinutes(0);
			newDate.setSeconds(0);
			newDate.setMilliseconds(0);
		}
		return this._daylightSavingAdjust(newDate);
	},

	/* Handle switch to/from daylight saving.
	   Hours may be non-zero on daylight saving cut-over:
	   > 12 when midnight changeover, but then cannot generate
	   midnight datetime, so jump to 1AM, otherwise reset.
	   @param  date  (Date) the date to check
	   @return  (Date) the corrected date */
	_daylightSavingAdjust: function(date) {
		if (!date) return null;
		date.setHours(date.getHours() > 12 ? date.getHours() + 2 : 0);
		return date;
	},

	/* Set the date(s) directly. */
	_setDate: function(inst, date, noChange) {
		var clear = !date;
		var origMonth = inst.selectedMonth;
		var origYear = inst.selectedYear;
		var newDate = this._restrictMinMax(inst, this._determineDate(inst, date, new Date()));
		inst.selectedDay = inst.currentDay = newDate.getDate();
		inst.drawMonth = inst.selectedMonth = inst.currentMonth = newDate.getMonth();
		inst.drawYear = inst.selectedYear = inst.currentYear = newDate.getFullYear();
		if ((origMonth != inst.selectedMonth || origYear != inst.selectedYear) && !noChange)
			this._notifyChange(inst);
		this._adjustInstDate(inst);
		if (inst.input) {
			inst.input.val(clear ? '' : this._formatDate(inst));
		}
	},

	/* Retrieve the date(s) directly. */
	_getDate: function(inst) {
		var startDate = (!inst.currentYear || (inst.input && inst.input.val() == '') ? null :
			this._daylightSavingAdjust(new Date(
			inst.currentYear, inst.currentMonth, inst.currentDay)));
			return startDate;
	},

	/* Attach the onxxx handlers.  These are declared statically so
	 * they work with static code transformers like Caja.
	 */
	_attachHandlers: function(inst) {
		var stepMonths = this._get(inst, 'stepMonths');
		var id = '#' + inst.id.replace( /\\\\/g, "\\" );
		inst.dpDiv.find('[data-handler]').map(function () {
			var handler = {
				prev: function () {
					window['DP_jQuery_' + dpuuid].datepicker._adjustDate(id, -stepMonths, 'M');
				},
				next: function () {
					window['DP_jQuery_' + dpuuid].datepicker._adjustDate(id, +stepMonths, 'M');
				},
				hide: function () {
					window['DP_jQuery_' + dpuuid].datepicker._hideDatepicker();
				},
				today: function () {
					window['DP_jQuery_' + dpuuid].datepicker._gotoToday(id);
				},
				selectDay: function () {
					window['DP_jQuery_' + dpuuid].datepicker._selectDay(id, +this.getAttribute('data-month'), +this.getAttribute('data-year'), this);
					return false;
				},
				selectMonth: function () {
					window['DP_jQuery_' + dpuuid].datepicker._selectMonthYear(id, this, 'M');
					return false;
				},
				selectYear: function () {
					window['DP_jQuery_' + dpuuid].datepicker._selectMonthYear(id, this, 'Y');
					return false;
				}
			};
			$(this).bind(this.getAttribute('data-event'), handler[this.getAttribute('data-handler')]);
		});
	},

	/* Generate the HTML for the current state of the date picker. */
	_generateHTML: function(inst) {
		var today = new Date();
		today = this._daylightSavingAdjust(
			new Date(today.getFullYear(), today.getMonth(), today.getDate())); // clear time
		var isRTL = this._get(inst, 'isRTL');
		var showButtonPanel = this._get(inst, 'showButtonPanel');
		var hideIfNoPrevNext = this._get(inst, 'hideIfNoPrevNext');
		var navigationAsDateFormat = this._get(inst, 'navigationAsDateFormat');
		var numMonths = this._getNumberOfMonths(inst);
		var showCurrentAtPos = this._get(inst, 'showCurrentAtPos');
		var stepMonths = this._get(inst, 'stepMonths');
		var isMultiMonth = (numMonths[0] != 1 || numMonths[1] != 1);
		var currentDate = this._daylightSavingAdjust((!inst.currentDay ? new Date(9999, 9, 9) :
			new Date(inst.currentYear, inst.currentMonth, inst.currentDay)));
		var minDate = this._getMinMaxDate(inst, 'min');
		var maxDate = this._getMinMaxDate(inst, 'max');
		var drawMonth = inst.drawMonth - showCurrentAtPos;
		var drawYear = inst.drawYear;
		if (drawMonth < 0) {
			drawMonth += 12;
			drawYear--;
		}
		if (maxDate) {
			var maxDraw = this._daylightSavingAdjust(new Date(maxDate.getFullYear(),
				maxDate.getMonth() - (numMonths[0] * numMonths[1]) + 1, maxDate.getDate()));
			maxDraw = (minDate && maxDraw < minDate ? minDate : maxDraw);
			while (this._daylightSavingAdjust(new Date(drawYear, drawMonth, 1)) > maxDraw) {
				drawMonth--;
				if (drawMonth < 0) {
					drawMonth = 11;
					drawYear--;
				}
			}
		}
		inst.drawMonth = drawMonth;
		inst.drawYear = drawYear;
		var prevText = this._get(inst, 'prevText');
		prevText = (!navigationAsDateFormat ? prevText : this.formatDate(prevText,
			this._daylightSavingAdjust(new Date(drawYear, drawMonth - stepMonths, 1)),
			this._getFormatConfig(inst)));
		var prev = (this._canAdjustMonth(inst, -1, drawYear, drawMonth) ?
			'<a class="ui-datepicker-prev ui-corner-all" data-handler="prev" data-event="click"' +
			' title="' + prevText + '"><span class="ui-icon ui-icon-circle-triangle-' + ( isRTL ? 'e' : 'w') + '">' + prevText + '</span></a>' :
			(hideIfNoPrevNext ? '' : '<a class="ui-datepicker-prev ui-corner-all ui-state-disabled" title="'+ prevText +'"><span class="ui-icon ui-icon-circle-triangle-' + ( isRTL ? 'e' : 'w') + '">' + prevText + '</span></a>'));
		var nextText = this._get(inst, 'nextText');
		nextText = (!navigationAsDateFormat ? nextText : this.formatDate(nextText,
			this._daylightSavingAdjust(new Date(drawYear, drawMonth + stepMonths, 1)),
			this._getFormatConfig(inst)));
		var next = (this._canAdjustMonth(inst, +1, drawYear, drawMonth) ?
			'<a class="ui-datepicker-next ui-corner-all" data-handler="next" data-event="click"' +
			' title="' + nextText + '"><span class="ui-icon ui-icon-circle-triangle-' + ( isRTL ? 'w' : 'e') + '">' + nextText + '</span></a>' :
			(hideIfNoPrevNext ? '' : '<a class="ui-datepicker-next ui-corner-all ui-state-disabled" title="'+ nextText + '"><span class="ui-icon ui-icon-circle-triangle-' + ( isRTL ? 'w' : 'e') + '">' + nextText + '</span></a>'));
		var currentText = this._get(inst, 'currentText');
		var gotoDate = (this._get(inst, 'gotoCurrent') && inst.currentDay ? currentDate : today);
		currentText = (!navigationAsDateFormat ? currentText :
			this.formatDate(currentText, gotoDate, this._getFormatConfig(inst)));
		var controls = (!inst.inline ? '<button type="button" class="ui-datepicker-close ui-state-default ui-priority-primary ui-corner-all" data-handler="hide" data-event="click">' +
			this._get(inst, 'closeText') + '</button>' : '');
		var buttonPanel = (showButtonPanel) ? '<div class="ui-datepicker-buttonpane ui-widget-content">' + (isRTL ? controls : '') +
			(this._isInRange(inst, gotoDate) ? '<button type="button" class="ui-datepicker-current ui-state-default ui-priority-secondary ui-corner-all" data-handler="today" data-event="click"' +
			'>' + currentText + '</button>' : '') + (isRTL ? '' : controls) + '</div>' : '';
		var firstDay = parseInt(this._get(inst, 'firstDay'),10);
		firstDay = (isNaN(firstDay) ? 0 : firstDay);
		var showWeek = this._get(inst, 'showWeek');
		var dayNames = this._get(inst, 'dayNames');
		var dayNamesShort = this._get(inst, 'dayNamesShort');
		var dayNamesMin = this._get(inst, 'dayNamesMin');
		var monthNames = this._get(inst, 'monthNames');
		var monthNamesShort = this._get(inst, 'monthNamesShort');
		var beforeShowDay = this._get(inst, 'beforeShowDay');
		var showOtherMonths = this._get(inst, 'showOtherMonths');
		var selectOtherMonths = this._get(inst, 'selectOtherMonths');
		var calculateWeek = this._get(inst, 'calculateWeek') || this.iso8601Week;
		var defaultDate = this._getDefaultDate(inst);
		var html = '';
		for (var row = 0; row < numMonths[0]; row++) {
			var group = '';
			this.maxRows = 4;
			for (var col = 0; col < numMonths[1]; col++) {
				var selectedDate = this._daylightSavingAdjust(new Date(drawYear, drawMonth, inst.selectedDay));
				var cornerClass = ' ui-corner-all';
				var calender = '';
				if (isMultiMonth) {
					calender += '<div class="ui-datepicker-group';
					if (numMonths[1] > 1)
						switch (col) {
							case 0: calender += ' ui-datepicker-group-first';
								cornerClass = ' ui-corner-' + (isRTL ? 'right' : 'left'); break;
							case numMonths[1]-1: calender += ' ui-datepicker-group-last';
								cornerClass = ' ui-corner-' + (isRTL ? 'left' : 'right'); break;
							default: calender += ' ui-datepicker-group-middle'; cornerClass = ''; break;
						}
					calender += '">';
				}
				calender += '<div class="ui-datepicker-header ui-widget-header ui-helper-clearfix' + cornerClass + '">' +
					(/all|left/.test(cornerClass) && row == 0 ? (isRTL ? next : prev) : '') +
					(/all|right/.test(cornerClass) && row == 0 ? (isRTL ? prev : next) : '') +
					this._generateMonthYearHeader(inst, drawMonth, drawYear, minDate, maxDate,
					row > 0 || col > 0, monthNames, monthNamesShort) + // draw month headers
					'</div><table class="ui-datepicker-calendar"><thead>' +
					'<tr>';
				var thead = (showWeek ? '<th class="ui-datepicker-week-col">' + this._get(inst, 'weekHeader') + '</th>' : '');
				for (var dow = 0; dow < 7; dow++) { // days of the week
					var day = (dow + firstDay) % 7;
					thead += '<th' + ((dow + firstDay + 6) % 7 >= 5 ? ' class="ui-datepicker-week-end"' : '') + '>' +
						'<span title="' + dayNames[day] + '">' + dayNamesMin[day] + '</span></th>';
				}
				calender += thead + '</tr></thead><tbody>';
				var daysInMonth = this._getDaysInMonth(drawYear, drawMonth);
				if (drawYear == inst.selectedYear && drawMonth == inst.selectedMonth)
					inst.selectedDay = Math.min(inst.selectedDay, daysInMonth);
				var leadDays = (this._getFirstDayOfMonth(drawYear, drawMonth) - firstDay + 7) % 7;
				var curRows = Math.ceil((leadDays + daysInMonth) / 7); // calculate the number of rows to generate
				var numRows = (isMultiMonth ? this.maxRows > curRows ? this.maxRows : curRows : curRows); //If multiple months, use the higher number of rows (see #7043)
				this.maxRows = numRows;
				var printDate = this._daylightSavingAdjust(new Date(drawYear, drawMonth, 1 - leadDays));
				for (var dRow = 0; dRow < numRows; dRow++) { // create date picker rows
					calender += '<tr>';
					var tbody = (!showWeek ? '' : '<td class="ui-datepicker-week-col">' +
						this._get(inst, 'calculateWeek')(printDate) + '</td>');
					for (var dow = 0; dow < 7; dow++) { // create date picker days
						var daySettings = (beforeShowDay ?
							beforeShowDay.apply((inst.input ? inst.input[0] : null), [printDate]) : [true, '']);
						var otherMonth = (printDate.getMonth() != drawMonth);
						var unselectable = (otherMonth && !selectOtherMonths) || !daySettings[0] ||
							(minDate && printDate < minDate) || (maxDate && printDate > maxDate);
						tbody += '<td class="' +
							((dow + firstDay + 6) % 7 >= 5 ? ' ui-datepicker-week-end' : '') + // highlight weekends
							(otherMonth ? ' ui-datepicker-other-month' : '') + // highlight days from other months
							((printDate.getTime() == selectedDate.getTime() && drawMonth == inst.selectedMonth && inst._keyEvent) || // user pressed key
							(defaultDate.getTime() == printDate.getTime() && defaultDate.getTime() == selectedDate.getTime()) ?
							// or defaultDate is current printedDate and defaultDate is selectedDate
							' ' + this._dayOverClass : '') + // highlight selected day
							(unselectable ? ' ' + this._unselectableClass + ' ui-state-disabled': '') +  // highlight unselectable days
							(otherMonth && !showOtherMonths ? '' : ' ' + daySettings[1] + // highlight custom dates
							(printDate.getTime() == currentDate.getTime() ? ' ' + this._currentClass : '') + // highlight selected day
							(printDate.getTime() == today.getTime() ? ' ui-datepicker-today' : '')) + '"' + // highlight today (if different)
							((!otherMonth || showOtherMonths) && daySettings[2] ? ' title="' + daySettings[2] + '"' : '') + // cell title
							(unselectable ? '' : ' data-handler="selectDay" data-event="click" data-month="' + printDate.getMonth() + '" data-year="' + printDate.getFullYear() + '"') + '>' + // actions
							(otherMonth && !showOtherMonths ? '&#xa0;' : // display for other months
							(unselectable ? '<span class="ui-state-default">' + printDate.getDate() + '</span>' : '<a class="ui-state-default' +
							(printDate.getTime() == today.getTime() ? ' ui-state-highlight' : '') +
							(printDate.getTime() == currentDate.getTime() ? ' ui-state-active' : '') + // highlight selected day
							(otherMonth ? ' ui-priority-secondary' : '') + // distinguish dates from other months
							'" href="#">' + printDate.getDate() + '</a>')) + '</td>'; // display selectable date
						printDate.setDate(printDate.getDate() + 1);
						printDate = this._daylightSavingAdjust(printDate);
					}
					calender += tbody + '</tr>';
				}
				drawMonth++;
				if (drawMonth > 11) {
					drawMonth = 0;
					drawYear++;
				}
				calender += '</tbody></table>' + (isMultiMonth ? '</div>' +
							((numMonths[0] > 0 && col == numMonths[1]-1) ? '<div class="ui-datepicker-row-break"></div>' : '') : '');
				group += calender;
			}
			html += group;
		}
		html += buttonPanel + ($.ui.ie6 && !inst.inline ?
			'<iframe src="javascript:false;" class="ui-datepicker-cover" frameborder="0"></iframe>' : '');
		inst._keyEvent = false;
		return html;
	},

	/* Generate the month and year header. */
	_generateMonthYearHeader: function(inst, drawMonth, drawYear, minDate, maxDate,
			secondary, monthNames, monthNamesShort) {
		var changeMonth = this._get(inst, 'changeMonth');
		var changeYear = this._get(inst, 'changeYear');
		var showMonthAfterYear = this._get(inst, 'showMonthAfterYear');
		var html = '<div class="ui-datepicker-title">';
		var monthHtml = '';
		// month selection
		if (secondary || !changeMonth)
			monthHtml += '<span class="ui-datepicker-month">' + monthNames[drawMonth] + '</span>';
		else {
			var inMinYear = (minDate && minDate.getFullYear() == drawYear);
			var inMaxYear = (maxDate && maxDate.getFullYear() == drawYear);
			monthHtml += '<select class="ui-datepicker-month" data-handler="selectMonth" data-event="change">';
			for (var month = 0; month < 12; month++) {
				if ((!inMinYear || month >= minDate.getMonth()) &&
						(!inMaxYear || month <= maxDate.getMonth()))
					monthHtml += '<option value="' + month + '"' +
						(month == drawMonth ? ' selected="selected"' : '') +
						'>' + monthNamesShort[month] + '</option>';
			}
			monthHtml += '</select>';
		}
		if (!showMonthAfterYear)
			html += monthHtml + (secondary || !(changeMonth && changeYear) ? '&#xa0;' : '');
		// year selection
		if ( !inst.yearshtml ) {
			inst.yearshtml = '';
			if (secondary || !changeYear)
				html += '<span class="ui-datepicker-year">' + drawYear + '</span>';
			else {
				// determine range of years to display
				var years = this._get(inst, 'yearRange').split(':');
				var thisYear = new Date().getFullYear();
				var determineYear = function(value) {
					var year = (value.match(/c[+-].*/) ? drawYear + parseInt(value.substring(1), 10) :
						(value.match(/[+-].*/) ? thisYear + parseInt(value, 10) :
						parseInt(value, 10)));
					return (isNaN(year) ? thisYear : year);
				};
				var year = determineYear(years[0]);
				var endYear = Math.max(year, determineYear(years[1] || ''));
				year = (minDate ? Math.max(year, minDate.getFullYear()) : year);
				endYear = (maxDate ? Math.min(endYear, maxDate.getFullYear()) : endYear);
				inst.yearshtml += '<select class="ui-datepicker-year" data-handler="selectYear" data-event="change">';
				for (; year <= endYear; year++) {
					inst.yearshtml += '<option value="' + year + '"' +
						(year == drawYear ? ' selected="selected"' : '') +
						'>' + year + '</option>';
				}
				inst.yearshtml += '</select>';

				html += inst.yearshtml;
				inst.yearshtml = null;
			}
		}
		html += this._get(inst, 'yearSuffix');
		if (showMonthAfterYear)
			html += (secondary || !(changeMonth && changeYear) ? '&#xa0;' : '') + monthHtml;
		html += '</div>'; // Close datepicker_header
		return html;
	},

	/* Adjust one of the date sub-fields. */
	_adjustInstDate: function(inst, offset, period) {
		var year = inst.drawYear + (period == 'Y' ? offset : 0);
		var month = inst.drawMonth + (period == 'M' ? offset : 0);
		var day = Math.min(inst.selectedDay, this._getDaysInMonth(year, month)) +
			(period == 'D' ? offset : 0);
		var date = this._restrictMinMax(inst,
			this._daylightSavingAdjust(new Date(year, month, day)));
		inst.selectedDay = date.getDate();
		inst.drawMonth = inst.selectedMonth = date.getMonth();
		inst.drawYear = inst.selectedYear = date.getFullYear();
		if (period == 'M' || period == 'Y')
			this._notifyChange(inst);
	},

	/* Ensure a date is within any min/max bounds. */
	_restrictMinMax: function(inst, date) {
		var minDate = this._getMinMaxDate(inst, 'min');
		var maxDate = this._getMinMaxDate(inst, 'max');
		var newDate = (minDate && date < minDate ? minDate : date);
		newDate = (maxDate && newDate > maxDate ? maxDate : newDate);
		return newDate;
	},

	/* Notify change of month/year. */
	_notifyChange: function(inst) {
		var onChange = this._get(inst, 'onChangeMonthYear');
		if (onChange)
			onChange.apply((inst.input ? inst.input[0] : null),
				[inst.selectedYear, inst.selectedMonth + 1, inst]);
	},

	/* Determine the number of months to show. */
	_getNumberOfMonths: function(inst) {
		var numMonths = this._get(inst, 'numberOfMonths');
		return (numMonths == null ? [1, 1] : (typeof numMonths == 'number' ? [1, numMonths] : numMonths));
	},

	/* Determine the current maximum date - ensure no time components are set. */
	_getMinMaxDate: function(inst, minMax) {
		return this._determineDate(inst, this._get(inst, minMax + 'Date'), null);
	},

	/* Find the number of days in a given month. */
	_getDaysInMonth: function(year, month) {
		return 32 - this._daylightSavingAdjust(new Date(year, month, 32)).getDate();
	},

	/* Find the day of the week of the first of a month. */
	_getFirstDayOfMonth: function(year, month) {
		return new Date(year, month, 1).getDay();
	},

	/* Determines if we should allow a "next/prev" month display change. */
	_canAdjustMonth: function(inst, offset, curYear, curMonth) {
		var numMonths = this._getNumberOfMonths(inst);
		var date = this._daylightSavingAdjust(new Date(curYear,
			curMonth + (offset < 0 ? offset : numMonths[0] * numMonths[1]), 1));
		if (offset < 0)
			date.setDate(this._getDaysInMonth(date.getFullYear(), date.getMonth()));
		return this._isInRange(inst, date);
	},

	/* Is the given date in the accepted range? */
	_isInRange: function(inst, date) {
		var minDate = this._getMinMaxDate(inst, 'min');
		var maxDate = this._getMinMaxDate(inst, 'max');
		return ((!minDate || date.getTime() >= minDate.getTime()) &&
			(!maxDate || date.getTime() <= maxDate.getTime()));
	},

	/* Provide the configuration settings for formatting/parsing. */
	_getFormatConfig: function(inst) {
		var shortYearCutoff = this._get(inst, 'shortYearCutoff');
		shortYearCutoff = (typeof shortYearCutoff != 'string' ? shortYearCutoff :
			new Date().getFullYear() % 100 + parseInt(shortYearCutoff, 10));
		return {shortYearCutoff: shortYearCutoff,
			dayNamesShort: this._get(inst, 'dayNamesShort'), dayNames: this._get(inst, 'dayNames'),
			monthNamesShort: this._get(inst, 'monthNamesShort'), monthNames: this._get(inst, 'monthNames')};
	},

	/* Format the given date for display. */
	_formatDate: function(inst, day, month, year) {
		if (!day) {
			inst.currentDay = inst.selectedDay;
			inst.currentMonth = inst.selectedMonth;
			inst.currentYear = inst.selectedYear;
		}
		var date = (day ? (typeof day == 'object' ? day :
			this._daylightSavingAdjust(new Date(year, month, day))) :
			this._daylightSavingAdjust(new Date(inst.currentYear, inst.currentMonth, inst.currentDay)));
		return this.formatDate(this._get(inst, 'dateFormat'), date, this._getFormatConfig(inst));
	}
});

/*
 * Bind hover events for datepicker elements.
 * Done via delegate so the binding only occurs once in the lifetime of the parent div.
 * Global instActive, set by _updateDatepicker allows the handlers to find their way back to the active picker.
 */
function bindHover(dpDiv) {
	var selector = 'button, .ui-datepicker-prev, .ui-datepicker-next, .ui-datepicker-calendar td a';
	return dpDiv.delegate(selector, 'mouseout', function() {
			$(this).removeClass('ui-state-hover');
			if (this.className.indexOf('ui-datepicker-prev') != -1) $(this).removeClass('ui-datepicker-prev-hover');
			if (this.className.indexOf('ui-datepicker-next') != -1) $(this).removeClass('ui-datepicker-next-hover');
		})
		.delegate(selector, 'mouseover', function(){
			if (!$.datepicker._isDisabledDatepicker( instActive.inline ? dpDiv.parent()[0] : instActive.input[0])) {
				$(this).parents('.ui-datepicker-calendar').find('a').removeClass('ui-state-hover');
				$(this).addClass('ui-state-hover');
				if (this.className.indexOf('ui-datepicker-prev') != -1) $(this).addClass('ui-datepicker-prev-hover');
				if (this.className.indexOf('ui-datepicker-next') != -1) $(this).addClass('ui-datepicker-next-hover');
			}
		});
}

/* jQuery extend now ignores nulls! */
function extendRemove(target, props) {
	$.extend(target, props);
	for (var name in props)
		if (props[name] == null || props[name] == undefined)
			target[name] = props[name];
	return target;
}
	/* Invoke the datepicker functionality.
   @param  options  string - a command, optionally followed by additional parameters or
	                Object - settings for attaching new datepicker functionality
   @return  jQuery object */
$.fn.datepicker = function(options){

	/* Verify an empty collection wasn't passed - Fixes #6976 */
	if ( !this.length ) {
		return this;
	}

	/* Initialise the date picker. */
	if (!$.datepicker.initialized) {
		$(document).mousedown($.datepicker._checkExternalClick).
			find(document.body).append($.datepicker.dpDiv);
		$.datepicker.initialized = true;
	}

	var otherArgs = Array.prototype.slice.call(arguments, 1);
	if (typeof options == 'string' && (options == 'isDisabled' || options == 'getDate' || options == 'widget'))
		return $.datepicker['_' + options + 'Datepicker'].
			apply($.datepicker, [this[0]].concat(otherArgs));
	if (options == 'option' && arguments.length == 2 && typeof arguments[1] == 'string')
		return $.datepicker['_' + options + 'Datepicker'].
			apply($.datepicker, [this[0]].concat(otherArgs));
	return this.each(function() {
		typeof options == 'string' ?
			$.datepicker['_' + options + 'Datepicker'].
				apply($.datepicker, [this].concat(otherArgs)) :
			$.datepicker._attachDatepicker(this, options);
	});
};

$.datepicker = new Datepicker(); // singleton instance
$.datepicker.initialized = false;
$.datepicker.uuid = new Date().getTime();
$.datepicker.version = "1.9.2";

// Workaround for #4055
// Add another global to avoid noConflict issues with inline event handlers
window['DP_jQuery_' + dpuuid] = $;

})(jQuery);

/**
 * @license
 * lodash 3.3.1 (Custom Build) lodash.com/license | Underscore.js 1.8.2 underscorejs.org/LICENSE
 * Build: `lodash modern -o ./lodash.js`
 */
;(function(){function n(n,t){if(n!==t){var r=n===n,e=t===t;if(n>t||!r||typeof n=="undefined"&&e)return 1;if(n<t||!e||typeof t=="undefined"&&r)return-1}return 0}function t(n,t,r){if(t!==t)return h(n,r);r=(r||0)-1;for(var e=n.length;++r<e;)if(n[r]===t)return r;return-1}function r(n){return typeof n=="function"||false}function e(n,t){var r=n.length;for(n.sort(t);r--;)n[r]=n[r].c;return n}function u(n){return typeof n=="string"?n:null==n?"":n+""}function o(n){return n.charCodeAt(0)}function i(n,t){for(var r=-1,e=n.length;++r<e&&-1<t.indexOf(n.charAt(r)););return r
}function f(n,t){for(var r=n.length;r--&&-1<t.indexOf(n.charAt(r)););return r}function a(t,r){return n(t.a,r.a)||t.b-r.b}function c(t,r){for(var e=-1,u=t.a,o=r.a,i=u.length;++e<i;){var f=n(u[e],o[e]);if(f)return f}return t.b-r.b}function l(n){return Nt[n]}function s(n){return Ut[n]}function p(n){return"\\"+$t[n]}function h(n,t,r){var e=n.length;for(t=r?t||e:(t||0)-1;r?t--:++t<e;){var u=n[t];if(u!==u)return t}return-1}function _(n){return n&&typeof n=="object"||false}function g(n){return 160>=n&&9<=n&&13>=n||32==n||160==n||5760==n||6158==n||8192<=n&&(8202>=n||8232==n||8233==n||8239==n||8287==n||12288==n||65279==n)
}function v(n,t){for(var r=-1,e=n.length,u=-1,o=[];++r<e;)n[r]===t&&(n[r]=z,o[++u]=r);return o}function y(n){for(var t=-1,r=n.length;++t<r&&g(n.charCodeAt(t)););return t}function d(n){for(var t=n.length;t--&&g(n.charCodeAt(t)););return t}function m(n){return Ft[n]}function w(g){function Nt(n){if(_(n)&&!(Wo(n)||n instanceof Lt)){if(n instanceof Ft)return n;if(Fu.call(n,"__chain__")&&Fu.call(n,"__wrapped__"))return ge(n)}return new Ft(n)}function Ut(){}function Ft(n,t,r){this.__wrapped__=n,this.__actions__=r||[],this.__chain__=!!t
}function Lt(n){this.__wrapped__=n,this.__actions__=null,this.__dir__=1,this.__dropCount__=0,this.__filtered__=false,this.__iteratees__=null,this.__takeCount__=po,this.__views__=null}function $t(){this.__data__={}}function zt(n){var t=n?n.length:0;for(this.data={hash:ro(null),set:new Gu};t--;)this.push(n[t])}function Dt(n,t){var r=n.data;return(typeof t=="string"||He(t)?r.set.has(t):r.hash[t])?0:-1}function qt(n,t){var r=-1,e=n.length;for(t||(t=bu(e));++r<e;)t[r]=n[r];return t}function Pt(n,t){for(var r=-1,e=n.length;++r<e&&false!==t(n[r],r,n););return n
}function Kt(n,t){for(var r=-1,e=n.length;++r<e;)if(!t(n[r],r,n))return false;return true}function Vt(n,t){for(var r=-1,e=n.length,u=-1,o=[];++r<e;){var i=n[r];t(i,r,n)&&(o[++u]=i)}return o}function Yt(n,t){for(var r=-1,e=n.length,u=bu(e);++r<e;)u[r]=t(n[r],r,n);return u}function Zt(n){for(var t=-1,r=n.length,e=so;++t<r;){var u=n[t];u>e&&(e=u)}return e}function Gt(n,t,r,e){var u=-1,o=n.length;for(e&&o&&(r=n[++u]);++u<o;)r=t(r,n[u],u,n);return r}function Jt(n,t,r,e){var u=n.length;for(e&&u&&(r=n[--u]);u--;)r=t(r,n[u],u,n);
return r}function Xt(n,t){for(var r=-1,e=n.length;++r<e;)if(t(n[r],r,n))return true;return false}function Ht(n,t){return typeof n=="undefined"?t:n}function Qt(n,t,r,e){return typeof n!="undefined"&&Fu.call(e,r)?n:t}function nr(n,t,r){var e=$o(t);if(!r)return rr(t,n,e);for(var u=-1,o=e.length;++u<o;){var i=e[u],f=n[i],a=r(f,t[i],i,n,t);(a===a?a===f:f!==f)&&(typeof f!="undefined"||i in n)||(n[i]=a)}return n}function tr(n,t){for(var r=-1,e=n.length,u=fe(e),o=t.length,i=bu(o);++r<o;){var f=t[r];u?(f=parseFloat(f),i[r]=oe(f,e)?n[f]:b):i[r]=n[f]
}return i}function rr(n,t,r){r||(r=t,t={});for(var e=-1,u=r.length;++e<u;){var o=r[e];t[o]=n[o]}return t}function er(n,t,r){var e=typeof n;if("function"==e){if(e=typeof t!="undefined"){var e=Nt.support,u=!(e.funcNames?n.name:e.funcDecomp);if(!u){var o=Nu.call(n);e.funcNames||(u=!mt.test(o)),u||(u=Et.test(o)||Qe(n),xo(n,u))}e=u}n=e?Fr(n,t,r):n}else n=null==n?yu:"object"==e?Ar(n):typeof t=="undefined"?Er(n+""):jr(n+"",t);return n}function ur(n,t,r,e,u,o,i){var f;if(r&&(f=u?r(n,e,u):r(n)),typeof f!="undefined")return f;
if(!He(n))return n;if(e=Wo(n)){if(f=re(n),!t)return qt(n,f)}else{var a=$u.call(n),c=a==V;if(a!=Z&&a!=D&&(!c||u))return St[a]?ue(n,a,t):u?n:{};if(f=ee(c?{}:n),!t)return rr(n,f,$o(n))}for(o||(o=[]),i||(i=[]),u=o.length;u--;)if(o[u]==n)return i[u];return o.push(n),i.push(f),(e?Pt:vr)(n,function(e,u){f[u]=ur(e,t,r,u,n,o,i)}),f}function or(n,t,r,e){if(typeof n!="function")throw new Cu(B);return Ju(function(){n.apply(b,Or(r,e))},t)}function ir(n,r){var e=n?n.length:0,u=[];if(!e)return u;var o=-1,i=te(),f=i==t,a=f&&200<=r.length?Ao(r):null,c=r.length;
a&&(i=Dt,f=false,r=a);n:for(;++o<e;)if(a=n[o],f&&a===a){for(var l=c;l--;)if(r[l]===a)continue n;u.push(a)}else 0>i(r,a)&&u.push(a);return u}function fr(n,t){var r=n?n.length:0;if(!fe(r))return vr(n,t);for(var e=-1,u=_e(n);++e<r&&false!==t(u[e],e,u););return n}function ar(n,t){var r=n?n.length:0;if(!fe(r))return yr(n,t);for(var e=_e(n);r--&&false!==t(e[r],r,e););return n}function cr(n,t){var r=true;return fr(n,function(n,e,u){return r=!!t(n,e,u)}),r}function lr(n,t){var r=[];return fr(n,function(n,e,u){t(n,e,u)&&r.push(n)
}),r}function sr(n,t,r,e){var u;return r(n,function(n,r,o){return t(n,r,o)?(u=e?r:n,false):void 0}),u}function pr(n,t,r,e){e=(e||0)-1;for(var u=n.length,o=-1,i=[];++e<u;){var f=n[e];if(_(f)&&fe(f.length)&&(Wo(f)||Ge(f))){t&&(f=pr(f,t,r));var a=-1,c=f.length;for(i.length+=c;++a<c;)i[++o]=f[a]}else r||(i[++o]=f)}return i}function hr(n,t,r){var e=-1,u=_e(n);r=r(n);for(var o=r.length;++e<o;){var i=r[e];if(false===t(u[i],i,u))break}return n}function _r(n,t,r){var e=_e(n);r=r(n);for(var u=r.length;u--;){var o=r[u];
if(false===t(e[o],o,e))break}return n}function gr(n,t){hr(n,t,iu)}function vr(n,t){return hr(n,t,$o)}function yr(n,t){return _r(n,t,$o)}function dr(n,t){for(var r=-1,e=t.length,u=-1,o=[];++r<e;){var i=t[r];Uo(n[i])&&(o[++u]=i)}return o}function mr(n,t,r){var e=-1,u=typeof t=="function",o=n?n.length:0,i=fe(o)?bu(o):[];return fr(n,function(n){var o=u?t:null!=n&&n[t];i[++e]=o?o.apply(n,r):b}),i}function wr(n,t,r,e,u,o){if(n===t)return 0!==n||1/n==1/t;var i=typeof n,f=typeof t;if("function"!=i&&"object"!=i&&"function"!=f&&"object"!=f||null==n||null==t)n=n!==n&&t!==t;
else n:{var i=wr,f=Wo(n),a=Wo(t),c=M,l=M;f||(c=$u.call(n),c==D?c=Z:c!=Z&&(f=eu(n))),a||(l=$u.call(t),l==D?l=Z:l!=Z&&eu(t));var s=c==Z,a=l==Z,l=c==l;if(!l||f||s)if(c=s&&Fu.call(n,"__wrapped__"),a=a&&Fu.call(t,"__wrapped__"),c||a)n=i(c?n.value():n,a?t.value():t,r,e,u,o);else if(l){for(u||(u=[]),o||(o=[]),c=u.length;c--;)if(u[c]==n){n=o[c]==t;break n}u.push(n),o.push(t),n=(f?Jr:Hr)(n,t,i,r,e,u,o),u.pop(),o.pop()}else n=false;else n=Xr(n,t,c)}return n}function br(n,t,r,e,u){var o=t.length;if(null==n)return!o;
for(var i=-1,f=!u;++i<o;)if(f&&e[i]?r[i]!==n[t[i]]:!Fu.call(n,t[i]))return false;for(i=-1;++i<o;){var a=t[i];if(f&&e[i])a=Fu.call(n,a);else{var c=n[a],l=r[i],a=u?u(c,l,a):b;typeof a=="undefined"&&(a=wr(l,c,u,true))}if(!a)return false}return true}function xr(n,t){var r=[];return fr(n,function(n,e,u){r.push(t(n,e,u))}),r}function Ar(n){var t=$o(n),r=t.length;if(1==r){var e=t[0],u=n[e];if(ae(u))return function(n){return null!=n&&n[e]===u&&Fu.call(n,e)}}for(var o=bu(r),i=bu(r);r--;)u=n[t[r]],o[r]=u,i[r]=ae(u);return function(n){return br(n,t,o,i)
}}function jr(n,t){return ae(t)?function(r){return null!=r&&r[n]===t}:function(r){return null!=r&&wr(t,r[n],null,true)}}function kr(n,t,r,e,u){if(!He(n))return n;var o=fe(t.length)&&(Wo(t)||eu(t));return(o?Pt:vr)(t,function(t,i,f){if(_(t)){e||(e=[]),u||(u=[]);n:{t=e;for(var a=u,c=t.length,l=f[i];c--;)if(t[c]==l){n[i]=a[c],i=void 0;break n}c=n[i],f=r?r(c,l,i,n,f):b;var s=typeof f=="undefined";s&&(f=l,fe(l.length)&&(Wo(l)||eu(l))?f=Wo(c)?c:c?qt(c):[]:Fo(l)||Ge(l)?f=Ge(c)?uu(c):Fo(c)?c:{}:s=false),t.push(l),a.push(f),s?n[i]=kr(f,l,r,t,a):(f===f?f!==c:c===c)&&(n[i]=f),i=void 0
}return i}a=n[i],f=r?r(a,t,i,n,f):b,(l=typeof f=="undefined")&&(f=t),!o&&typeof f=="undefined"||!l&&(f===f?f===a:a!==a)||(n[i]=f)}),n}function Er(n){return function(t){return null==t?b:t[n]}}function Rr(n,t){return n+Ku(lo()*(t-n+1))}function Ir(n,t,r,e,u){return u(n,function(n,u,o){r=e?(e=false,n):t(r,n,u,o)}),r}function Or(n,t,r){var e=-1,u=n.length;for(t=null==t?0:+t||0,0>t&&(t=-t>u?0:u+t),r=typeof r=="undefined"||r>u?u:+r||0,0>r&&(r+=u),u=t>r?0:r-t>>>0,t>>>=0,r=bu(u);++e<u;)r[e]=n[e+t];return r}function Cr(n,t){var r;
return fr(n,function(n,e,u){return r=t(n,e,u),!r}),!!r}function Tr(n,r){var e=-1,u=te(),o=n.length,i=u==t,f=i&&200<=o,a=f?Ao():null,c=[];a?(u=Dt,i=false):(f=false,a=r?[]:c);n:for(;++e<o;){var l=n[e],s=r?r(l,e,n):l;if(i&&l===l){for(var p=a.length;p--;)if(a[p]===s)continue n;r&&a.push(s),c.push(l)}else 0>u(a,s)&&((r||f)&&a.push(s),c.push(l))}return c}function Sr(n,t){for(var r=-1,e=t.length,u=bu(e);++r<e;)u[r]=n[t[r]];return u}function Wr(n,t){var r=n;r instanceof Lt&&(r=r.value());for(var e=-1,u=t.length;++e<u;){var r=[r],o=t[e];
Yu.apply(r,o.args),r=o.func.apply(o.thisArg,r)}return r}function Nr(n,t,r){var e=0,u=n?n.length:e;if(typeof t=="number"&&t===t&&u<=go){for(;e<u;){var o=e+u>>>1,i=n[o];(r?i<=t:i<t)?e=o+1:u=o}return u}return Ur(n,t,yu,r)}function Ur(n,t,r,e){t=r(t);for(var u=0,o=n?n.length:0,i=t!==t,f=typeof t=="undefined";u<o;){var a=Ku((u+o)/2),c=r(n[a]),l=c===c;(i?l||e:f?l&&(e||typeof c!="undefined"):e?c<=t:c<t)?u=a+1:o=a}return io(o,_o)}function Fr(n,t,r){if(typeof n!="function")return yu;if(typeof t=="undefined")return n;
switch(r){case 1:return function(r){return n.call(t,r)};case 3:return function(r,e,u){return n.call(t,r,e,u)};case 4:return function(r,e,u,o){return n.call(t,r,e,u,o)};case 5:return function(r,e,u,o,i){return n.call(t,r,e,u,o,i)}}return function(){return n.apply(t,arguments)}}function Lr(n){return Mu.call(n,0)}function $r(n,t,r){for(var e=r.length,u=-1,o=oo(n.length-e,0),i=-1,f=t.length,a=bu(o+f);++i<f;)a[i]=t[i];for(;++u<e;)a[r[u]]=n[u];for(;o--;)a[i++]=n[u++];return a}function Br(n,t,r){for(var e=-1,u=r.length,o=-1,i=oo(n.length-u,0),f=-1,a=t.length,c=bu(i+a);++o<i;)c[o]=n[o];
for(i=o;++f<a;)c[i+f]=t[f];for(;++e<u;)c[i+r[e]]=n[o++];return c}function zr(n,t){return function(r,e,u){var o=t?t():{};if(e=ne(e,u,3),Wo(r)){u=-1;for(var i=r.length;++u<i;){var f=r[u];n(o,f,e(f,u,r),r)}}else fr(r,function(t,r,u){n(o,t,e(t,r,u),u)});return o}}function Dr(n){return function(){var t=arguments.length,r=arguments[0];if(2>t||null==r)return r;if(3<t&&ie(arguments[1],arguments[2],arguments[3])&&(t=2),3<t&&"function"==typeof arguments[t-2])var e=Fr(arguments[--t-1],arguments[t--],5);else 2<t&&"function"==typeof arguments[t-1]&&(e=arguments[--t]);
for(var u=0;++u<t;){var o=arguments[u];o&&n(r,o,e)}return r}}function Mr(n,t){function r(){return(this instanceof r?e:n).apply(t,arguments)}var e=Pr(n);return r}function qr(n){return function(t){var r=-1;t=hu(au(t));for(var e=t.length,u="";++r<e;)u=n(u,t[r],r);return u}}function Pr(n){return function(){var t=bo(n.prototype),r=n.apply(t,arguments);return He(r)?r:t}}function Kr(n,t){return function(r,e,u){u&&ie(r,e,u)&&(e=null);var i=ne(),f=null==e;if(i===er&&f||(f=false,e=i(e,u,3)),f){if(e=Wo(r),e||!ru(r))return n(e?r:he(r));
e=o}return Qr(r,e,t)}}function Vr(n,t,r,e,u,o,i,f,a,c){function l(){for(var w=arguments.length,x=w,k=bu(w);x--;)k[x]=arguments[x];if(e&&(k=$r(k,e,u)),o&&(k=Br(k,o,i)),_||y){var x=l.placeholder,E=v(k,x),w=w-E.length;if(w<c){var R=f?qt(f):null,w=oo(c-w,0),C=_?E:null,E=_?null:E,T=_?k:null,k=_?null:k;return t|=_?I:O,t&=~(_?O:I),g||(t&=~(A|j)),k=Vr(n,t,r,T,C,k,E,R,a,w),k.placeholder=x,k}}if(x=p?r:this,h&&(n=x[m]),f)for(R=k.length,w=io(f.length,R),C=qt(k);w--;)E=f[w],k[w]=oe(E,R)?C[E]:b;return s&&a<k.length&&(k.length=a),(this instanceof l?d||Pr(n):n).apply(x,k)
}var s=t&T,p=t&A,h=t&j,_=t&E,g=t&k,y=t&R,d=!h&&Pr(n),m=n;return l}function Yr(n,t,r){return n=n.length,t=+t,n<t&&eo(t)?(t-=n,r=null==r?" ":r+"",su(r,qu(t/r.length)).slice(0,t)):""}function Zr(n,t,r,e){function u(){for(var t=-1,f=arguments.length,a=-1,c=e.length,l=bu(f+c);++a<c;)l[a]=e[a];for(;f--;)l[a++]=arguments[++t];return(this instanceof u?i:n).apply(o?r:this,l)}var o=t&A,i=Pr(n);return u}function Gr(n,t,r,e,u,o,i,f){var a=t&j;if(!a&&typeof n!="function")throw new Cu(B);var c=e?e.length:0;if(c||(t&=~(I|O),e=u=null),c-=u?u.length:0,t&O){var l=e,s=u;
e=u=null}var p=!a&&jo(n);if(r=[n,t,r,e,u,l,s,o,i,f],p&&true!==p){e=r[1],t=p[1],f=e|t,o=T|C,u=A|j,i=o|u|k|R;var l=e&T&&!(t&T),s=e&C&&!(t&C),h=(s?r:p)[7],_=(l?r:p)[8];o=f>=o&&f<=i&&(e<C||(s||l)&&h.length<=_),(!(e>=C&&t>u||e>u&&t>=C)||o)&&(t&A&&(r[2]=p[2],f|=e&A?0:k),(e=p[3])&&(u=r[3],r[3]=u?$r(u,e,p[4]):qt(e),r[4]=u?v(r[3],z):qt(p[4])),(e=p[5])&&(u=r[5],r[5]=u?Br(u,e,p[6]):qt(e),r[6]=u?v(r[5],z):qt(p[6])),(e=p[7])&&(r[7]=qt(e)),t&T&&(r[8]=null==r[8]?p[8]:io(r[8],p[8])),null==r[9]&&(r[9]=p[9]),r[0]=p[0],r[1]=f),t=r[1],f=r[9]
}return r[9]=null==f?a?0:n.length:oo(f-c,0)||0,(p?xo:ko)(t==A?Mr(r[0],r[2]):t!=I&&t!=(A|I)||r[4].length?Vr.apply(b,r):Zr.apply(b,r),r)}function Jr(n,t,r,e,u,o,i){var f=-1,a=n.length,c=t.length,l=true;if(a!=c&&(!u||c<=a))return false;for(;l&&++f<a;){var s=n[f],p=t[f],l=b;if(e&&(l=u?e(p,s,f):e(s,p,f)),typeof l=="undefined")if(u)for(var h=c;h--&&(p=t[h],!(l=s&&s===p||r(s,p,e,u,o,i))););else l=s&&s===p||r(s,p,e,u,o,i)}return!!l}function Xr(n,t,r){switch(r){case q:case P:return+n==+t;case K:return n.name==t.name&&n.message==t.message;
case Y:return n!=+n?t!=+t:0==n?1/n==1/t:n==+t;case G:case J:return n==t+""}return false}function Hr(n,t,r,e,u,o,i){var f=$o(n),a=f.length,c=$o(t).length;if(a!=c&&!u)return false;for(var l,c=-1;++c<a;){var s=f[c],p=Fu.call(t,s);if(p){var h=n[s],_=t[s],p=b;e&&(p=u?e(_,h,s):e(h,_,s)),typeof p=="undefined"&&(p=h&&h===_||r(h,_,e,u,o,i))}if(!p)return false;l||(l="constructor"==s)}return l||(r=n.constructor,e=t.constructor,!(r!=e&&"constructor"in n&&"constructor"in t)||typeof r=="function"&&r instanceof r&&typeof e=="function"&&e instanceof e)?true:false
}function Qr(n,t,r){var e=r?po:so,u=e,o=u;return fr(n,function(n,i,f){i=t(n,i,f),((r?i<u:i>u)||i===e&&i===o)&&(u=i,o=n)}),o}function ne(n,t,r){var e=Nt.callback||gu,e=e===gu?er:e;return r?e(n,t,r):e}function te(n,r,e){var u=Nt.indexOf||we,u=u===we?t:u;return n?u(n,r,e):u}function re(n){var t=n.length,r=new n.constructor(t);return t&&"string"==typeof n[0]&&Fu.call(n,"index")&&(r.index=n.index,r.input=n.input),r}function ee(n){return n=n.constructor,typeof n=="function"&&n instanceof n||(n=Ru),new n
}function ue(n,t,r){var e=n.constructor;switch(t){case X:return Lr(n);case q:case P:return new e(+n);case H:case Q:case nt:case tt:case rt:case et:case ut:case ot:case it:return t=n.buffer,new e(r?Lr(t):t,n.byteOffset,n.length);case Y:case J:return new e(n);case G:var u=new e(n.source,dt.exec(n));u.lastIndex=n.lastIndex}return u}function oe(n,t){return n=+n,t=null==t?yo:t,-1<n&&0==n%1&&n<t}function ie(n,t,r){if(!He(r))return false;var e=typeof t;return"number"==e?(e=r.length,e=fe(e)&&oe(t,e)):e="string"==e&&t in r,e?(t=r[t],n===n?n===t:t!==t):false
}function fe(n){return typeof n=="number"&&-1<n&&0==n%1&&n<=yo}function ae(n){return n===n&&(0===n?0<1/n:!He(n))}function ce(n,t){n=_e(n);for(var r=-1,e=t.length,u={};++r<e;){var o=t[r];o in n&&(u[o]=n[o])}return u}function le(n,t){var r={};return gr(n,function(n,e,u){t(n,e,u)&&(r[e]=n)}),r}function se(n){var t;if(!_(n)||$u.call(n)!=Z||!(Fu.call(n,"constructor")||(t=n.constructor,typeof t!="function"||t instanceof t)))return false;var r;return gr(n,function(n,t){r=t}),typeof r=="undefined"||Fu.call(n,r)
}function pe(n){for(var t=iu(n),r=t.length,e=r&&n.length,u=Nt.support,u=e&&fe(e)&&(Wo(n)||u.nonEnumArgs&&Ge(n)),o=-1,i=[];++o<r;){var f=t[o];(u&&oe(f,e)||Fu.call(n,f))&&i.push(f)}return i}function he(n){return null==n?[]:fe(n.length)?He(n)?n:Ru(n):fu(n)}function _e(n){return He(n)?n:Ru(n)}function ge(n){return n instanceof Lt?n.clone():new Ft(n.__wrapped__,n.__chain__,qt(n.__actions__))}function ve(n,t,r){return n&&n.length?((r?ie(n,t,r):null==t)&&(t=1),Or(n,0>t?0:t)):[]}function ye(n,t,r){var e=n?n.length:0;
return e?((r?ie(n,t,r):null==t)&&(t=1),t=e-(+t||0),Or(n,0,0>t?0:t)):[]}function de(n,t,r){var e=-1,u=n?n.length:0;for(t=ne(t,r,3);++e<u;)if(t(n[e],e,n))return e;return-1}function me(n){return n?n[0]:b}function we(n,r,e){var u=n?n.length:0;if(!u)return-1;if(typeof e=="number")e=0>e?oo(u+e,0):e||0;else if(e)return e=Nr(n,r),n=n[e],(r===r?r===n:n!==n)?e:-1;return t(n,r,e)}function be(n){return ve(n,1)}function xe(n,r,e,u){if(!n||!n.length)return[];null!=r&&typeof r!="boolean"&&(u=e,e=ie(n,r,u)?null:r,r=false);
var o=ne();if((o!==er||null!=e)&&(e=o(e,u,3)),r&&te()==t){r=e;var i;e=-1,u=n.length;for(var o=-1,f=[];++e<u;){var a=n[e],c=r?r(a,e,n):a;e&&i===c||(i=c,f[++o]=a)}n=f}else n=Tr(n,e);return n}function Ae(n){for(var t=-1,r=(n&&n.length&&Zt(Yt(n,Uu)))>>>0,e=bu(r);++t<r;)e[t]=Yt(n,Er(t));return e}function je(n,t){var r=-1,e=n?n.length:0,u={};for(!e||t||Wo(n[0])||(t=[]);++r<e;){var o=n[r];t?u[o]=t[r]:o&&(u[o[0]]=o[1])}return u}function ke(n){return n=Nt(n),n.__chain__=true,n}function Ee(n,t,r){return t.call(r,n)
}function Re(n,t,r){var e=Wo(n)?Kt:cr;return(typeof t!="function"||typeof r!="undefined")&&(t=ne(t,r,3)),e(n,t)}function Ie(n,t,r){var e=Wo(n)?Vt:lr;return t=ne(t,r,3),e(n,t)}function Oe(n,t,r){return Wo(n)?(t=de(n,t,r),-1<t?n[t]:b):(t=ne(t,r,3),sr(n,t,fr))}function Ce(n,t,r){return typeof t=="function"&&typeof r=="undefined"&&Wo(n)?Pt(n,t):fr(n,Fr(t,r,3))}function Te(n,t,r){if(typeof t=="function"&&typeof r=="undefined"&&Wo(n))for(r=n.length;r--&&false!==t(n[r],r,n););else n=ar(n,Fr(t,r,3));return n
}function Se(n,t,r){var e=n?n.length:0;return fe(e)||(n=fu(n),e=n.length),e?(r=typeof r=="number"?0>r?oo(e+r,0):r||0:0,typeof n=="string"||!Wo(n)&&ru(n)?r<e&&-1<n.indexOf(t,r):-1<te(n,t,r)):false}function We(n,t,r){var e=Wo(n)?Yt:xr;return t=ne(t,r,3),e(n,t)}function Ne(n,t,r,e){return(Wo(n)?Gt:Ir)(n,ne(t,e,4),r,3>arguments.length,fr)}function Ue(n,t,r,e){return(Wo(n)?Jt:Ir)(n,ne(t,e,4),r,3>arguments.length,ar)}function Fe(n,t,r){return(r?ie(n,t,r):null==t)?(n=he(n),t=n.length,0<t?n[Rr(0,t-1)]:b):(n=Le(n),n.length=io(0>t?0:+t||0,n.length),n)
}function Le(n){n=he(n);for(var t=-1,r=n.length,e=bu(r);++t<r;){var u=Rr(0,t);t!=u&&(e[t]=e[u]),e[u]=n[t]}return e}function $e(n,t,r){var e=Wo(n)?Xt:Cr;return(typeof t!="function"||typeof r!="undefined")&&(t=ne(t,r,3)),e(n,t)}function Be(n,t){var r;if(typeof t!="function"){if(typeof n!="function")throw new Cu(B);var e=n;n=t,t=e}return function(){return 0<--n?r=t.apply(this,arguments):t=null,r}}function ze(n,t){var r=A;if(2<arguments.length)var e=Or(arguments,2),u=v(e,ze.placeholder),r=r|I;return Gr(n,r,t,e,u)
}function De(n,t){var r=A|j;if(2<arguments.length)var e=Or(arguments,2),u=v(e,De.placeholder),r=r|I;return Gr(t,r,n,e,u)}function Me(n,t,r){return r&&ie(n,t,r)&&(t=null),n=Gr(n,E,null,null,null,null,null,t),n.placeholder=Me.placeholder,n}function qe(n,t,r){return r&&ie(n,t,r)&&(t=null),n=Gr(n,R,null,null,null,null,null,t),n.placeholder=qe.placeholder,n}function Pe(n,t,r){function e(){var r=t-(So()-c);0>=r||r>t?(f&&Pu(f),r=p,f=s=p=b,r&&(h=So(),a=n.apply(l,i),s||f||(i=l=null))):s=Ju(e,r)}function u(){s&&Pu(s),f=s=p=b,(g||_!==t)&&(h=So(),a=n.apply(l,i),s||f||(i=l=null))
}function o(){if(i=arguments,c=So(),l=this,p=g&&(s||!v),false===_)var r=v&&!s;else{f||v||(h=c);var o=_-(c-h),y=0>=o||o>_;y?(f&&(f=Pu(f)),h=c,a=n.apply(l,i)):f||(f=Ju(u,o))}return y&&s?s=Pu(s):s||t===_||(s=Ju(e,t)),r&&(y=true,a=n.apply(l,i)),!y||s||f||(i=l=null),a}var i,f,a,c,l,s,p,h=0,_=false,g=true;if(typeof n!="function")throw new Cu(B);if(t=0>t?0:+t||0,true===r)var v=true,g=false;else He(r)&&(v=r.leading,_="maxWait"in r&&oo(+r.maxWait||0,t),g="trailing"in r?r.trailing:g);return o.cancel=function(){s&&Pu(s),f&&Pu(f),f=s=p=b
},o}function Ke(){var n=arguments,t=n.length-1;if(0>t)return function(n){return n};if(!Kt(n,r))throw new Cu(B);return function(){for(var r=t,e=n[r].apply(this,arguments);r--;)e=n[r].call(this,e);return e}}function Ve(n,t){function r(){var e=r.cache,u=t?t.apply(this,arguments):arguments[0];if(e.has(u))return e.get(u);var o=n.apply(this,arguments);return e.set(u,o),o}if(typeof n!="function"||t&&typeof t!="function")throw new Cu(B);return r.cache=new Ve.Cache,r}function Ye(n){var t=Or(arguments,1),r=v(t,Ye.placeholder);
return Gr(n,I,null,t,r)}function Ze(n){var t=Or(arguments,1),r=v(t,Ze.placeholder);return Gr(n,O,null,t,r)}function Ge(n){return fe(_(n)?n.length:b)&&$u.call(n)==D||false}function Je(n){return n&&1===n.nodeType&&_(n)&&-1<$u.call(n).indexOf("Element")||false}function Xe(n){return _(n)&&typeof n.message=="string"&&$u.call(n)==K||false}function He(n){var t=typeof n;return"function"==t||n&&"object"==t||false}function Qe(n){return null==n?false:$u.call(n)==V?zu.test(Nu.call(n)):_(n)&&bt.test(n)||false}function nu(n){return typeof n=="number"||_(n)&&$u.call(n)==Y||false
}function tu(n){return _(n)&&$u.call(n)==G||false}function ru(n){return typeof n=="string"||_(n)&&$u.call(n)==J||false}function eu(n){return _(n)&&fe(n.length)&&Tt[$u.call(n)]||false}function uu(n){return rr(n,iu(n))}function ou(n){return dr(n,iu(n))}function iu(n){if(null==n)return[];He(n)||(n=Ru(n));for(var t=n.length,t=t&&fe(t)&&(Wo(n)||wo.nonEnumArgs&&Ge(n))&&t||0,r=n.constructor,e=-1,r=typeof r=="function"&&r.prototype===n,u=bu(t),o=0<t;++e<t;)u[e]=e+"";for(var i in n)o&&oe(i,t)||"constructor"==i&&(r||!Fu.call(n,i))||u.push(i);
return u}function fu(n){return Sr(n,$o(n))}function au(n){return(n=u(n))&&n.replace(xt,l)}function cu(n){return(n=u(n))&&kt.test(n)?n.replace(jt,"\\$&"):n}function lu(n,t,r){return r&&ie(n,t,r)&&(t=0),co(n,t)}function su(n,t){var r="";if(n=u(n),t=+t,1>t||!n||!eo(t))return r;do t%2&&(r+=n),t=Ku(t/2),n+=n;while(t);return r}function pu(n,t,r){var e=n;return(n=u(n))?(r?ie(e,t,r):null==t)?n.slice(y(n),d(n)+1):(t+="",n.slice(i(n,t),f(n,t)+1)):n}function hu(n,t,r){return r&&ie(n,t,r)&&(t=null),n=u(n),n.match(t||It)||[]
}function _u(){var n=arguments.length,t=arguments[0];try{for(var r=bu(n?n-1:0);0<--n;)r[n-1]=arguments[n];return t.apply(b,r)}catch(e){return Xe(e)?e:new Au(e)}}function gu(n,t,r){return r&&ie(n,t,r)&&(t=null),_(n)?du(n):er(n,t)}function vu(n){return function(){return n}}function yu(n){return n}function du(n){return Ar(ur(n,true))}function mu(n,t,r){if(null==r){var e=He(t),u=e&&$o(t);((u=u&&u.length&&dr(t,u))?u.length:e)||(u=false,r=t,t=n,n=this)}u||(u=dr(t,$o(t)));var o=true,e=-1,i=Uo(n),f=u.length;false===r?o=false:He(r)&&"chain"in r&&(o=r.chain);
for(;++e<f;){r=u[e];var a=t[r];n[r]=a,i&&(n.prototype[r]=function(t){return function(){var r=this.__chain__;if(o||r){var e=n(this.__wrapped__);return(e.__actions__=qt(this.__actions__)).push({func:t,args:arguments,thisArg:n}),e.__chain__=r,e}return r=[this.value()],Yu.apply(r,arguments),t.apply(n,r)}}(a))}return n}function wu(){}g=g?Mt.defaults(Bt.Object(),g,Mt.pick(Bt,Ct)):Bt;var bu=g.Array,xu=g.Date,Au=g.Error,ju=g.Function,ku=g.Math,Eu=g.Number,Ru=g.Object,Iu=g.RegExp,Ou=g.String,Cu=g.TypeError,Tu=bu.prototype,Su=Ru.prototype,Wu=(Wu=g.window)&&Wu.document,Nu=ju.prototype.toString,Uu=Er("length"),Fu=Su.hasOwnProperty,Lu=0,$u=Su.toString,Bu=g._,zu=Iu("^"+cu($u).replace(/toString|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$"),Du=Qe(Du=g.ArrayBuffer)&&Du,Mu=Qe(Mu=Du&&new Du(0).slice)&&Mu,qu=ku.ceil,Pu=g.clearTimeout,Ku=ku.floor,Vu=Qe(Vu=Ru.getPrototypeOf)&&Vu,Yu=Tu.push,Zu=Su.propertyIsEnumerable,Gu=Qe(Gu=g.Set)&&Gu,Ju=g.setTimeout,Xu=Tu.splice,Hu=Qe(Hu=g.Uint8Array)&&Hu,Qu=Qe(Qu=g.WeakMap)&&Qu,no=function(){try{var n=Qe(n=g.Float64Array)&&n,t=new n(new Du(10),0,1)&&n
}catch(r){}return t}(),to=Qe(to=bu.isArray)&&to,ro=Qe(ro=Ru.create)&&ro,eo=g.isFinite,uo=Qe(uo=Ru.keys)&&uo,oo=ku.max,io=ku.min,fo=Qe(fo=xu.now)&&fo,ao=Qe(ao=Eu.isFinite)&&ao,co=g.parseInt,lo=ku.random,so=Eu.NEGATIVE_INFINITY,po=Eu.POSITIVE_INFINITY,ho=ku.pow(2,32)-1,_o=ho-1,go=ho>>>1,vo=no?no.BYTES_PER_ELEMENT:0,yo=ku.pow(2,53)-1,mo=Qu&&new Qu,wo=Nt.support={};!function(n){wo.funcDecomp=!Qe(g.WinRTError)&&Et.test(w),wo.funcNames=typeof ju.name=="string";try{wo.dom=11===Wu.createDocumentFragment().nodeType
}catch(t){wo.dom=false}try{wo.nonEnumArgs=!Zu.call(arguments,1)}catch(r){wo.nonEnumArgs=true}}(0,0),Nt.templateSettings={escape:_t,evaluate:gt,interpolate:vt,variable:"",imports:{_:Nt}};var bo=function(){function n(){}return function(t){if(He(t)){n.prototype=t;var r=new n;n.prototype=null}return r||g.Object()}}(),xo=mo?function(n,t){return mo.set(n,t),n}:yu;Mu||(Lr=Du&&Hu?function(n){var t=n.byteLength,r=no?Ku(t/vo):0,e=r*vo,u=new Du(t);if(r){var o=new no(u,0,r);o.set(new no(n,0,r))}return t!=e&&(o=new Hu(u,e),o.set(new Hu(n,e))),u
}:vu(null));var Ao=ro&&Gu?function(n){return new zt(n)}:vu(null),jo=mo?function(n){return mo.get(n)}:wu,ko=function(){var n=0,t=0;return function(r,e){var u=So(),o=U-(u-t);if(t=u,0<o){if(++n>=N)return r}else n=0;return xo(r,e)}}(),Eo=zr(function(n,t,r){Fu.call(n,r)?++n[r]:n[r]=1}),Ro=zr(function(n,t,r){Fu.call(n,r)?n[r].push(t):n[r]=[t]}),Io=zr(function(n,t,r){n[r]=t}),Oo=Kr(Zt),Co=Kr(function(n){for(var t=-1,r=n.length,e=po;++t<r;){var u=n[t];u<e&&(e=u)}return e},true),To=zr(function(n,t,r){n[r?0:1].push(t)
},function(){return[[],[]]}),So=fo||function(){return(new xu).getTime()},Wo=to||function(n){return _(n)&&fe(n.length)&&$u.call(n)==M||false};wo.dom||(Je=function(n){return n&&1===n.nodeType&&_(n)&&!Fo(n)||false});var No=ao||function(n){return typeof n=="number"&&eo(n)},Uo=r(/x/)||Hu&&!r(Hu)?function(n){return $u.call(n)==V}:r,Fo=Vu?function(n){if(!n||$u.call(n)!=Z)return false;var t=n.valueOf,r=Qe(t)&&(r=Vu(t))&&Vu(r);return r?n==r||Vu(n)==r:se(n)}:se,Lo=Dr(nr),$o=uo?function(n){if(n)var t=n.constructor,r=n.length;
return typeof t=="function"&&t.prototype===n||typeof n!="function"&&r&&fe(r)?pe(n):He(n)?uo(n):[]}:pe,Bo=Dr(kr),zo=qr(function(n,t,r){return t=t.toLowerCase(),n+(r?t.charAt(0).toUpperCase()+t.slice(1):t)}),Do=qr(function(n,t,r){return n+(r?"-":"")+t.toLowerCase()});8!=co(Ot+"08")&&(lu=function(n,t,r){return(r?ie(n,t,r):null==t)?t=0:t&&(t=+t),n=pu(n),co(n,t||(wt.test(n)?16:10))});var Mo=qr(function(n,t,r){return n+(r?"_":"")+t.toLowerCase()}),qo=qr(function(n,t,r){return n+(r?" ":"")+(t.charAt(0).toUpperCase()+t.slice(1))
});return Nt.prototype=Ut.prototype,Ft.prototype=bo(Ut.prototype),Ft.prototype.constructor=Ft,Lt.prototype=bo(Ut.prototype),Lt.prototype.constructor=Lt,$t.prototype["delete"]=function(n){return this.has(n)&&delete this.__data__[n]},$t.prototype.get=function(n){return"__proto__"==n?b:this.__data__[n]},$t.prototype.has=function(n){return"__proto__"!=n&&Fu.call(this.__data__,n)},$t.prototype.set=function(n,t){return"__proto__"!=n&&(this.__data__[n]=t),this},zt.prototype.push=function(n){var t=this.data;
typeof n=="string"||He(n)?t.set.add(n):t.hash[n]=true},Ve.Cache=$t,Nt.after=function(n,t){if(typeof t!="function"){if(typeof n!="function")throw new Cu(B);var r=n;n=t,t=r}return n=eo(n=+n)?n:0,function(){return 1>--n?t.apply(this,arguments):void 0}},Nt.ary=function(n,t,r){return r&&ie(n,t,r)&&(t=null),t=n&&null==t?n.length:oo(+t||0,0),Gr(n,T,null,null,null,null,t)},Nt.assign=Lo,Nt.at=function(n){return fe(n?n.length:0)&&(n=he(n)),tr(n,pr(arguments,false,false,1))},Nt.before=Be,Nt.bind=ze,Nt.bindAll=function(n){for(var t=n,r=1<arguments.length?pr(arguments,false,false,1):ou(n),e=-1,u=r.length;++e<u;){var o=r[e];
t[o]=Gr(t[o],A,t)}return t},Nt.bindKey=De,Nt.callback=gu,Nt.chain=ke,Nt.chunk=function(n,t,r){t=(r?ie(n,t,r):null==t)?1:oo(+t||1,1),r=0;for(var e=n?n.length:0,u=-1,o=bu(qu(e/t));r<e;)o[++u]=Or(n,r,r+=t);return o},Nt.compact=function(n){for(var t=-1,r=n?n.length:0,e=-1,u=[];++t<r;){var o=n[t];o&&(u[++e]=o)}return u},Nt.constant=vu,Nt.countBy=Eo,Nt.create=function(n,t,r){var e=bo(n);return r&&ie(n,t,r)&&(t=null),t?rr(t,e,$o(t)):e},Nt.curry=Me,Nt.curryRight=qe,Nt.debounce=Pe,Nt.defaults=function(n){if(null==n)return n;
var t=qt(arguments);return t.push(Ht),Lo.apply(b,t)},Nt.defer=function(n){return or(n,1,arguments,1)},Nt.delay=function(n,t){return or(n,t,arguments,2)},Nt.difference=function(){for(var n=-1,t=arguments.length;++n<t;){var r=arguments[n];if(Wo(r)||Ge(r))break}return ir(r,pr(arguments,false,true,++n))},Nt.drop=ve,Nt.dropRight=ye,Nt.dropRightWhile=function(n,t,r){var e=n?n.length:0;if(!e)return[];for(t=ne(t,r,3);e--&&t(n[e],e,n););return Or(n,0,e+1)},Nt.dropWhile=function(n,t,r){var e=n?n.length:0;if(!e)return[];
var u=-1;for(t=ne(t,r,3);++u<e&&t(n[u],u,n););return Or(n,u)},Nt.fill=function(n,t,r,e){var u=n?n.length:0;if(!u)return[];for(r&&typeof r!="number"&&ie(n,t,r)&&(r=0,e=u),u=n.length,r=null==r?0:+r||0,0>r&&(r=-r>u?0:u+r),e=typeof e=="undefined"||e>u?u:+e||0,0>e&&(e+=u),u=r>e?0:e>>>0,r>>>=0;r<u;)n[r++]=t;return n},Nt.filter=Ie,Nt.flatten=function(n,t,r){var e=n?n.length:0;return r&&ie(n,t,r)&&(t=false),e?pr(n,t):[]},Nt.flattenDeep=function(n){return n&&n.length?pr(n,true):[]},Nt.flow=function(){var n=arguments,t=n.length;
if(!t)return function(n){return n};if(!Kt(n,r))throw new Cu(B);return function(){for(var r=0,e=n[r].apply(this,arguments);++r<t;)e=n[r].call(this,e);return e}},Nt.flowRight=Ke,Nt.forEach=Ce,Nt.forEachRight=Te,Nt.forIn=function(n,t,r){return(typeof t!="function"||typeof r!="undefined")&&(t=Fr(t,r,3)),hr(n,t,iu)},Nt.forInRight=function(n,t,r){return t=Fr(t,r,3),_r(n,t,iu)},Nt.forOwn=function(n,t,r){return(typeof t!="function"||typeof r!="undefined")&&(t=Fr(t,r,3)),vr(n,t)},Nt.forOwnRight=function(n,t,r){return t=Fr(t,r,3),_r(n,t,$o)
},Nt.functions=ou,Nt.groupBy=Ro,Nt.indexBy=Io,Nt.initial=function(n){return ye(n,1)},Nt.intersection=function(){for(var n=[],r=-1,e=arguments.length,u=[],o=te(),i=o==t;++r<e;){var f=arguments[r];(Wo(f)||Ge(f))&&(n.push(f),u.push(i&&120<=f.length?Ao(r&&f):null))}var e=n.length,i=n[0],a=-1,c=i?i.length:0,l=[],s=u[0];n:for(;++a<c;)if(f=i[a],0>(s?Dt(s,f):o(l,f))){for(r=e;--r;){var p=u[r];if(0>(p?Dt(p,f):o(n[r],f)))continue n}s&&s.push(f),l.push(f)}return l},Nt.invert=function(n,t,r){r&&ie(n,t,r)&&(t=null),r=-1;
for(var e=$o(n),u=e.length,o={};++r<u;){var i=e[r],f=n[i];t?Fu.call(o,f)?o[f].push(i):o[f]=[i]:o[f]=i}return o},Nt.invoke=function(n,t){return mr(n,t,Or(arguments,2))},Nt.keys=$o,Nt.keysIn=iu,Nt.map=We,Nt.mapValues=function(n,t,r){var e={};return t=ne(t,r,3),vr(n,function(n,r,u){e[r]=t(n,r,u)}),e},Nt.matches=du,Nt.matchesProperty=function(n,t){return jr(n+"",ur(t,true))},Nt.memoize=Ve,Nt.merge=Bo,Nt.mixin=mu,Nt.negate=function(n){if(typeof n!="function")throw new Cu(B);return function(){return!n.apply(this,arguments)
}},Nt.omit=function(n,t,r){if(null==n)return{};if(typeof t!="function"){var e=Yt(pr(arguments,false,false,1),Ou);return ce(n,ir(iu(n),e))}return t=Fr(t,r,3),le(n,function(n,r,e){return!t(n,r,e)})},Nt.once=function(n){return Be(n,2)},Nt.pairs=function(n){for(var t=-1,r=$o(n),e=r.length,u=bu(e);++t<e;){var o=r[t];u[t]=[o,n[o]]}return u},Nt.partial=Ye,Nt.partialRight=Ze,Nt.partition=To,Nt.pick=function(n,t,r){return null==n?{}:typeof t=="function"?le(n,Fr(t,r,3)):ce(n,pr(arguments,false,false,1))},Nt.pluck=function(n,t){return We(n,Er(t))
},Nt.property=function(n){return Er(n+"")},Nt.propertyOf=function(n){return function(t){return null==n?b:n[t]}},Nt.pull=function(){var n=arguments[0];if(!n||!n.length)return n;for(var t=0,r=te(),e=arguments.length;++t<e;)for(var u=0,o=arguments[t];-1<(u=r(n,o,u));)Xu.call(n,u,1);return n},Nt.pullAt=function(t){var r=t||[],e=pr(arguments,false,false,1),u=e.length,o=tr(r,e);for(e.sort(n);u--;){var i=parseFloat(e[u]);if(i!=f&&oe(i)){var f=i;Xu.call(r,i,1)}}return o},Nt.range=function(n,t,r){r&&ie(n,t,r)&&(t=r=null),n=+n||0,r=null==r?1:+r||0,null==t?(t=n,n=0):t=+t||0;
var e=-1;t=oo(qu((t-n)/(r||1)),0);for(var u=bu(t);++e<t;)u[e]=n,n+=r;return u},Nt.rearg=function(n){var t=pr(arguments,false,false,1);return Gr(n,C,null,null,null,t)},Nt.reject=function(n,t,r){var e=Wo(n)?Vt:lr;return t=ne(t,r,3),e(n,function(n,r,e){return!t(n,r,e)})},Nt.remove=function(n,t,r){var e=-1,u=n?n.length:0,o=[];for(t=ne(t,r,3);++e<u;)r=n[e],t(r,e,n)&&(o.push(r),Xu.call(n,e--,1),u--);return o},Nt.rest=be,Nt.shuffle=Le,Nt.slice=function(n,t,r){var e=n?n.length:0;return e?(r&&typeof r!="number"&&ie(n,t,r)&&(t=0,r=e),Or(n,t,r)):[]
},Nt.sortBy=function(n,t,r){var u=-1,o=n?n.length:0,i=fe(o)?bu(o):[];return r&&ie(n,t,r)&&(t=null),t=ne(t,r,3),fr(n,function(n,r,e){i[++u]={a:t(n,r,e),b:u,c:n}}),e(i,a)},Nt.sortByAll=function(n){var t=arguments;3<t.length&&ie(t[1],t[2],t[3])&&(t=[n,t[1]]);var r=-1,u=n?n.length:0,o=pr(t,false,false,1),i=fe(u)?bu(u):[];return fr(n,function(n){for(var t=o.length,e=bu(t);t--;)e[t]=null==n?b:n[o[t]];i[++r]={a:e,b:r,c:n}}),e(i,c)},Nt.spread=function(n){if(typeof n!="function")throw new Cu(B);return function(t){return n.apply(this,t)
}},Nt.take=function(n,t,r){return n&&n.length?((r?ie(n,t,r):null==t)&&(t=1),Or(n,0,0>t?0:t)):[]},Nt.takeRight=function(n,t,r){var e=n?n.length:0;return e?((r?ie(n,t,r):null==t)&&(t=1),t=e-(+t||0),Or(n,0>t?0:t)):[]},Nt.takeRightWhile=function(n,t,r){var e=n?n.length:0;if(!e)return[];for(t=ne(t,r,3);e--&&t(n[e],e,n););return Or(n,e+1)},Nt.takeWhile=function(n,t,r){var e=n?n.length:0;if(!e)return[];var u=-1;for(t=ne(t,r,3);++u<e&&t(n[u],u,n););return Or(n,0,u)},Nt.tap=function(n,t,r){return t.call(r,n),n
},Nt.throttle=function(n,t,r){var e=true,u=true;if(typeof n!="function")throw new Cu(B);return false===r?e=false:He(r)&&(e="leading"in r?!!r.leading:e,u="trailing"in r?!!r.trailing:u),Wt.leading=e,Wt.maxWait=+t,Wt.trailing=u,Pe(n,t,Wt)},Nt.thru=Ee,Nt.times=function(n,t,r){if(n=+n,1>n||!eo(n))return[];var e=-1,u=bu(io(n,ho));for(t=Fr(t,r,1);++e<n;)e<ho?u[e]=t(e):t(e);return u},Nt.toArray=function(n){var t=n?n.length:0;return fe(t)?t?qt(n):[]:fu(n)},Nt.toPlainObject=uu,Nt.transform=function(n,t,r,e){var u=Wo(n)||eu(n);
return t=ne(t,e,4),null==r&&(u||He(n)?(e=n.constructor,r=u?Wo(n)?new e:[]:bo(Uo(e)&&e.prototype)):r={}),(u?Pt:vr)(n,function(n,e,u){return t(r,n,e,u)}),r},Nt.union=function(){return Tr(pr(arguments,false,true))},Nt.uniq=xe,Nt.unzip=Ae,Nt.values=fu,Nt.valuesIn=function(n){return Sr(n,iu(n))},Nt.where=function(n,t){return Ie(n,Ar(t))},Nt.without=function(n){return ir(n,Or(arguments,1))},Nt.wrap=function(n,t){return t=null==t?yu:t,Gr(t,I,null,[n],[])},Nt.xor=function(){for(var n=-1,t=arguments.length;++n<t;){var r=arguments[n];
if(Wo(r)||Ge(r))var e=e?ir(e,r).concat(ir(r,e)):r}return e?Tr(e):[]},Nt.zip=function(){for(var n=arguments.length,t=bu(n);n--;)t[n]=arguments[n];return Ae(t)},Nt.zipObject=je,Nt.backflow=Ke,Nt.collect=We,Nt.compose=Ke,Nt.each=Ce,Nt.eachRight=Te,Nt.extend=Lo,Nt.iteratee=gu,Nt.methods=ou,Nt.object=je,Nt.select=Ie,Nt.tail=be,Nt.unique=xe,mu(Nt,Nt),Nt.attempt=_u,Nt.camelCase=zo,Nt.capitalize=function(n){return(n=u(n))&&n.charAt(0).toUpperCase()+n.slice(1)},Nt.clone=function(n,t,r,e){return t&&typeof t!="boolean"&&ie(n,t,r)?t=false:typeof t=="function"&&(e=r,r=t,t=false),r=typeof r=="function"&&Fr(r,e,1),ur(n,t,r)
},Nt.cloneDeep=function(n,t,r){return t=typeof t=="function"&&Fr(t,r,1),ur(n,true,t)},Nt.deburr=au,Nt.endsWith=function(n,t,r){n=u(n),t+="";var e=n.length;return r=(typeof r=="undefined"?e:io(0>r?0:+r||0,e))-t.length,0<=r&&n.indexOf(t,r)==r},Nt.escape=function(n){return(n=u(n))&&ht.test(n)?n.replace(st,s):n},Nt.escapeRegExp=cu,Nt.every=Re,Nt.find=Oe,Nt.findIndex=de,Nt.findKey=function(n,t,r){return t=ne(t,r,3),sr(n,t,vr,true)},Nt.findLast=function(n,t,r){return t=ne(t,r,3),sr(n,t,ar)},Nt.findLastIndex=function(n,t,r){var e=n?n.length:0;
for(t=ne(t,r,3);e--;)if(t(n[e],e,n))return e;return-1},Nt.findLastKey=function(n,t,r){return t=ne(t,r,3),sr(n,t,yr,true)},Nt.findWhere=function(n,t){return Oe(n,Ar(t))},Nt.first=me,Nt.has=function(n,t){return n?Fu.call(n,t):false},Nt.identity=yu,Nt.includes=Se,Nt.indexOf=we,Nt.inRange=function(n,t,r){return t=+t||0,"undefined"===typeof r?(r=t,t=0):r=+r||0,n>=t&&n<r},Nt.isArguments=Ge,Nt.isArray=Wo,Nt.isBoolean=function(n){return true===n||false===n||_(n)&&$u.call(n)==q||false},Nt.isDate=function(n){return _(n)&&$u.call(n)==P||false
},Nt.isElement=Je,Nt.isEmpty=function(n){if(null==n)return true;var t=n.length;return fe(t)&&(Wo(n)||ru(n)||Ge(n)||_(n)&&Uo(n.splice))?!t:!$o(n).length},Nt.isEqual=function(n,t,r,e){return r=typeof r=="function"&&Fr(r,e,3),!r&&ae(n)&&ae(t)?n===t:(e=r?r(n,t):b,typeof e=="undefined"?wr(n,t,r):!!e)},Nt.isError=Xe,Nt.isFinite=No,Nt.isFunction=Uo,Nt.isMatch=function(n,t,r,e){var u=$o(t),o=u.length;if(r=typeof r=="function"&&Fr(r,e,3),!r&&1==o){var i=u[0];if(e=t[i],ae(e))return null!=n&&e===n[i]&&Fu.call(n,i)
}for(var i=bu(o),f=bu(o);o--;)e=i[o]=t[u[o]],f[o]=ae(e);return br(n,u,i,f,r)},Nt.isNaN=function(n){return nu(n)&&n!=+n},Nt.isNative=Qe,Nt.isNull=function(n){return null===n},Nt.isNumber=nu,Nt.isObject=He,Nt.isPlainObject=Fo,Nt.isRegExp=tu,Nt.isString=ru,Nt.isTypedArray=eu,Nt.isUndefined=function(n){return typeof n=="undefined"},Nt.kebabCase=Do,Nt.last=function(n){var t=n?n.length:0;return t?n[t-1]:b},Nt.lastIndexOf=function(n,t,r){var e=n?n.length:0;if(!e)return-1;var u=e;if(typeof r=="number")u=(0>r?oo(e+r,0):io(r||0,e-1))+1;
else if(r)return u=Nr(n,t,true)-1,n=n[u],(t===t?t===n:n!==n)?u:-1;if(t!==t)return h(n,u,true);for(;u--;)if(n[u]===t)return u;return-1},Nt.max=Oo,Nt.min=Co,Nt.noConflict=function(){return g._=Bu,this},Nt.noop=wu,Nt.now=So,Nt.pad=function(n,t,r){n=u(n),t=+t;var e=n.length;return e<t&&eo(t)?(e=(t-e)/2,t=Ku(e),e=qu(e),r=Yr("",e,r),r.slice(0,t)+n+r):n},Nt.padLeft=function(n,t,r){return(n=u(n))&&Yr(n,t,r)+n},Nt.padRight=function(n,t,r){return(n=u(n))&&n+Yr(n,t,r)},Nt.parseInt=lu,Nt.random=function(n,t,r){r&&ie(n,t,r)&&(t=r=null);
var e=null==n,u=null==t;return null==r&&(u&&typeof n=="boolean"?(r=n,n=1):typeof t=="boolean"&&(r=t,u=true)),e&&u&&(t=1,u=false),n=+n||0,u?(t=n,n=0):t=+t||0,r||n%1||t%1?(r=lo(),io(n+r*(t-n+parseFloat("1e-"+((r+"").length-1))),t)):Rr(n,t)},Nt.reduce=Ne,Nt.reduceRight=Ue,Nt.repeat=su,Nt.result=function(n,t,r){return t=null==n?b:n[t],typeof t=="undefined"&&(t=r),Uo(t)?t.call(n):t},Nt.runInContext=w,Nt.size=function(n){var t=n?n.length:0;return fe(t)?t:$o(n).length},Nt.snakeCase=Mo,Nt.some=$e,Nt.sortedIndex=function(n,t,r,e){var u=ne(r);
return u===er&&null==r?Nr(n,t):Ur(n,t,u(r,e,1))},Nt.sortedLastIndex=function(n,t,r,e){var u=ne(r);return u===er&&null==r?Nr(n,t,true):Ur(n,t,u(r,e,1),true)},Nt.startCase=qo,Nt.startsWith=function(n,t,r){return n=u(n),r=null==r?0:io(0>r?0:+r||0,n.length),n.lastIndexOf(t,r)==r},Nt.template=function(n,t,r){var e=Nt.templateSettings;r&&ie(n,t,r)&&(t=r=null),n=u(n),t=nr(nr({},r||t),e,Qt),r=nr(nr({},t.imports),e.imports,Qt);var o,i,f=$o(r),a=Sr(r,f),c=0;r=t.interpolate||At;var l="__p+='";r=Iu((t.escape||At).source+"|"+r.source+"|"+(r===vt?yt:At).source+"|"+(t.evaluate||At).source+"|$","g");
var s="sourceURL"in t?"//# sourceURL="+t.sourceURL+"\n":"";if(n.replace(r,function(t,r,e,u,f,a){return e||(e=u),l+=n.slice(c,a).replace(Rt,p),r&&(o=true,l+="'+__e("+r+")+'"),f&&(i=true,l+="';"+f+";\n__p+='"),e&&(l+="'+((__t=("+e+"))==null?'':__t)+'"),c=a+t.length,t}),l+="';",(t=t.variable)||(l="with(obj){"+l+"}"),l=(i?l.replace(ft,""):l).replace(at,"$1").replace(ct,"$1;"),l="function("+(t||"obj")+"){"+(t?"":"obj||(obj={});")+"var __t,__p=''"+(o?",__e=_.escape":"")+(i?",__j=Array.prototype.join;function print(){__p+=__j.call(arguments,'')}":";")+l+"return __p}",t=_u(function(){return ju(f,s+"return "+l).apply(b,a)
}),t.source=l,Xe(t))throw t;return t},Nt.trim=pu,Nt.trimLeft=function(n,t,r){var e=n;return(n=u(n))?n.slice((r?ie(e,t,r):null==t)?y(n):i(n,t+"")):n},Nt.trimRight=function(n,t,r){var e=n;return(n=u(n))?(r?ie(e,t,r):null==t)?n.slice(0,d(n)+1):n.slice(0,f(n,t+"")+1):n},Nt.trunc=function(n,t,r){r&&ie(n,t,r)&&(t=null);var e=S;if(r=W,null!=t)if(He(t)){var o="separator"in t?t.separator:o,e="length"in t?+t.length||0:e;r="omission"in t?u(t.omission):r}else e=+t||0;if(n=u(n),e>=n.length)return n;if(e-=r.length,1>e)return r;
if(t=n.slice(0,e),null==o)return t+r;if(tu(o)){if(n.slice(e).search(o)){var i,f=n.slice(0,e);for(o.global||(o=Iu(o.source,(dt.exec(o)||"")+"g")),o.lastIndex=0;n=o.exec(f);)i=n.index;t=t.slice(0,null==i?e:i)}}else n.indexOf(o,e)!=e&&(o=t.lastIndexOf(o),-1<o&&(t=t.slice(0,o)));return t+r},Nt.unescape=function(n){return(n=u(n))&&pt.test(n)?n.replace(lt,m):n},Nt.uniqueId=function(n){var t=++Lu;return u(n)+t},Nt.words=hu,Nt.all=Re,Nt.any=$e,Nt.contains=Se,Nt.detect=Oe,Nt.foldl=Ne,Nt.foldr=Ue,Nt.head=me,Nt.include=Se,Nt.inject=Ne,mu(Nt,function(){var n={};
return vr(Nt,function(t,r){Nt.prototype[r]||(n[r]=t)}),n}(),false),Nt.sample=Fe,Nt.prototype.sample=function(n){return this.__chain__||null!=n?this.thru(function(t){return Fe(t,n)}):Fe(this.value())},Nt.VERSION=x,Pt("bind bindKey curry curryRight partial partialRight".split(" "),function(n){Nt[n].placeholder=Nt}),Pt(["filter","map","takeWhile"],function(n,t){var r=t==F||t==$;Lt.prototype[n]=function(n,e){var u=this.clone(),o=u.__iteratees__||(u.__iteratees__=[]);return u.__filtered__=u.__filtered__||r,o.push({iteratee:ne(n,e,3),type:t}),u
}}),Pt(["drop","take"],function(n,t){var r="__"+n+"Count__",e=n+"While";Lt.prototype[n]=function(e){e=null==e?1:oo(Ku(e)||0,0);var u=this.clone();if(u.__filtered__){var o=u[r];u[r]=t?io(o,e):o+e}else(u.__views__||(u.__views__=[])).push({size:e,type:n+(0>u.__dir__?"Right":"")});return u},Lt.prototype[n+"Right"]=function(t){return this.reverse()[n](t).reverse()},Lt.prototype[n+"RightWhile"]=function(n,t){return this.reverse()[e](n,t).reverse()}}),Pt(["first","last"],function(n,t){var r="take"+(t?"Right":"");
Lt.prototype[n]=function(){return this[r](1).value()[0]}}),Pt(["initial","rest"],function(n,t){var r="drop"+(t?"":"Right");Lt.prototype[n]=function(){return this[r](1)}}),Pt(["pluck","where"],function(n,t){var r=t?"filter":"map",e=t?Ar:Er;Lt.prototype[n]=function(n){return this[r](e(n))}}),Lt.prototype.compact=function(){return this.filter(yu)},Lt.prototype.dropWhile=function(n,t){var r,e,u=0>this.__dir__;return n=ne(n,t,3),this.filter(function(t,o,i){return r=r&&(u?o<e:o>e),e=o,r||(r=!n(t,o,i))})
},Lt.prototype.reject=function(n,t){return n=ne(n,t,3),this.filter(function(t,r,e){return!n(t,r,e)})},Lt.prototype.slice=function(n,t){n=null==n?0:+n||0;var r=0>n?this.takeRight(-n):this.drop(n);return typeof t!="undefined"&&(t=+t||0,r=0>t?r.dropRight(-t):r.take(t-n)),r},Lt.prototype.toArray=function(){return this.drop(0)},vr(Lt.prototype,function(n,t){var r=Nt[t],e=/^(?:first|last)$/.test(t);Nt.prototype[t]=function(){function t(n){return n=[n],Yu.apply(n,o),r.apply(Nt,n)}var u=this.__wrapped__,o=arguments,i=this.__chain__,f=!!this.__actions__.length,a=u instanceof Lt,c=a&&!f;
return e&&!i?c?n.call(u):r.call(Nt,this.value()):a||Wo(u)?(u=n.apply(c?u:new Lt(this),o),e||!f&&!u.__actions__||(u.__actions__||(u.__actions__=[])).push({func:Ee,args:[t],thisArg:Nt}),new Ft(u,i)):this.thru(t)}}),Pt("concat join pop push shift sort splice unshift".split(" "),function(n){var t=Tu[n],r=/^(?:push|sort|unshift)$/.test(n)?"tap":"thru",e=/^(?:join|pop|shift)$/.test(n);Nt.prototype[n]=function(){var n=arguments;return e&&!this.__chain__?t.apply(this.value(),n):this[r](function(r){return t.apply(r,n)
})}}),Lt.prototype.clone=function(){var n=this.__actions__,t=this.__iteratees__,r=this.__views__,e=new Lt(this.__wrapped__);return e.__actions__=n?qt(n):null,e.__dir__=this.__dir__,e.__dropCount__=this.__dropCount__,e.__filtered__=this.__filtered__,e.__iteratees__=t?qt(t):null,e.__takeCount__=this.__takeCount__,e.__views__=r?qt(r):null,e},Lt.prototype.reverse=function(){if(this.__filtered__){var n=new Lt(this);n.__dir__=-1,n.__filtered__=true}else n=this.clone(),n.__dir__*=-1;return n},Lt.prototype.value=function(){var n=this.__wrapped__.value();
if(!Wo(n))return Wr(n,this.__actions__);var t,r=this.__dir__,e=0>r;t=n.length;for(var u=this.__views__,o=0,i=-1,f=u?u.length:0;++i<f;){var a=u[i],c=a.size;switch(a.type){case"drop":o+=c;break;case"dropRight":t-=c;break;case"take":t=io(t,o+c);break;case"takeRight":o=oo(o,t-c)}}t={start:o,end:t},i=t.start,f=t.end,t=f-i,u=this.__dropCount__,o=io(t,this.__takeCount__),e=e?f:i-1,f=(i=this.__iteratees__)?i.length:0,a=0,c=[];n:for(;t--&&a<o;){for(var e=e+r,l=-1,s=n[e];++l<f;){var p=i[l],h=p.iteratee(s,e,n),p=p.type;
if(p==L)s=h;else if(!h){if(p==F)continue n;break n}}u?u--:c[a++]=s}return c},Nt.prototype.chain=function(){return ke(this)},Nt.prototype.commit=function(){return new Ft(this.value(),this.__chain__)},Nt.prototype.plant=function(n){for(var t,r=this;r instanceof Ut;){var e=ge(r);t?u.__wrapped__=e:t=e;var u=e,r=r.__wrapped__}return u.__wrapped__=n,t},Nt.prototype.reverse=function(){var n=this.__wrapped__;return n instanceof Lt?(this.__actions__.length&&(n=new Lt(this)),new Ft(n.reverse(),this.__chain__)):this.thru(function(n){return n.reverse()
})},Nt.prototype.toString=function(){return this.value()+""},Nt.prototype.run=Nt.prototype.toJSON=Nt.prototype.valueOf=Nt.prototype.value=function(){return Wr(this.__wrapped__,this.__actions__)},Nt.prototype.collect=Nt.prototype.map,Nt.prototype.head=Nt.prototype.first,Nt.prototype.select=Nt.prototype.filter,Nt.prototype.tail=Nt.prototype.rest,Nt}var b,x="3.3.1",A=1,j=2,k=4,E=8,R=16,I=32,O=64,C=128,T=256,S=30,W="...",N=150,U=16,F=0,L=1,$=2,B="Expected a function",z="__lodash_placeholder__",D="[object Arguments]",M="[object Array]",q="[object Boolean]",P="[object Date]",K="[object Error]",V="[object Function]",Y="[object Number]",Z="[object Object]",G="[object RegExp]",J="[object String]",X="[object ArrayBuffer]",H="[object Float32Array]",Q="[object Float64Array]",nt="[object Int8Array]",tt="[object Int16Array]",rt="[object Int32Array]",et="[object Uint8Array]",ut="[object Uint8ClampedArray]",ot="[object Uint16Array]",it="[object Uint32Array]",ft=/\b__p\+='';/g,at=/\b(__p\+=)''\+/g,ct=/(__e\(.*?\)|\b__t\))\+'';/g,lt=/&(?:amp|lt|gt|quot|#39|#96);/g,st=/[&<>"'`]/g,pt=RegExp(lt.source),ht=RegExp(st.source),_t=/<%-([\s\S]+?)%>/g,gt=/<%([\s\S]+?)%>/g,vt=/<%=([\s\S]+?)%>/g,yt=/\$\{([^\\}]*(?:\\.[^\\}]*)*)\}/g,dt=/\w*$/,mt=/^\s*function[ \n\r\t]+\w/,wt=/^0[xX]/,bt=/^\[object .+?Constructor\]$/,xt=/[\xc0-\xd6\xd8-\xde\xdf-\xf6\xf8-\xff]/g,At=/($^)/,jt=/[.*+?^${}()|[\]\/\\]/g,kt=RegExp(jt.source),Et=/\bthis\b/,Rt=/['\n\r\u2028\u2029\\]/g,It=RegExp("[A-Z\\xc0-\\xd6\\xd8-\\xde]{2,}(?=[A-Z\\xc0-\\xd6\\xd8-\\xde][a-z\\xdf-\\xf6\\xf8-\\xff]+)|[A-Z\\xc0-\\xd6\\xd8-\\xde]?[a-z\\xdf-\\xf6\\xf8-\\xff]+|[A-Z\\xc0-\\xd6\\xd8-\\xde]+|[0-9]+","g"),Ot=" \t\x0b\f\xa0\ufeff\n\r\u2028\u2029\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u202f\u205f\u3000",Ct="Array ArrayBuffer Date Error Float32Array Float64Array Function Int8Array Int16Array Int32Array Math Number Object RegExp Set String _ clearTimeout document isFinite parseInt setTimeout TypeError Uint8Array Uint8ClampedArray Uint16Array Uint32Array WeakMap window WinRTError".split(" "),Tt={};
Tt[H]=Tt[Q]=Tt[nt]=Tt[tt]=Tt[rt]=Tt[et]=Tt[ut]=Tt[ot]=Tt[it]=true,Tt[D]=Tt[M]=Tt[X]=Tt[q]=Tt[P]=Tt[K]=Tt[V]=Tt["[object Map]"]=Tt[Y]=Tt[Z]=Tt[G]=Tt["[object Set]"]=Tt[J]=Tt["[object WeakMap]"]=false;var St={};St[D]=St[M]=St[X]=St[q]=St[P]=St[H]=St[Q]=St[nt]=St[tt]=St[rt]=St[Y]=St[Z]=St[G]=St[J]=St[et]=St[ut]=St[ot]=St[it]=true,St[K]=St[V]=St["[object Map]"]=St["[object Set]"]=St["[object WeakMap]"]=false;var Wt={leading:false,maxWait:0,trailing:false},Nt={"\xc0":"A","\xc1":"A","\xc2":"A","\xc3":"A","\xc4":"A","\xc5":"A","\xe0":"a","\xe1":"a","\xe2":"a","\xe3":"a","\xe4":"a","\xe5":"a","\xc7":"C","\xe7":"c","\xd0":"D","\xf0":"d","\xc8":"E","\xc9":"E","\xca":"E","\xcb":"E","\xe8":"e","\xe9":"e","\xea":"e","\xeb":"e","\xcc":"I","\xcd":"I","\xce":"I","\xcf":"I","\xec":"i","\xed":"i","\xee":"i","\xef":"i","\xd1":"N","\xf1":"n","\xd2":"O","\xd3":"O","\xd4":"O","\xd5":"O","\xd6":"O","\xd8":"O","\xf2":"o","\xf3":"o","\xf4":"o","\xf5":"o","\xf6":"o","\xf8":"o","\xd9":"U","\xda":"U","\xdb":"U","\xdc":"U","\xf9":"u","\xfa":"u","\xfb":"u","\xfc":"u","\xdd":"Y","\xfd":"y","\xff":"y","\xc6":"Ae","\xe6":"ae","\xde":"Th","\xfe":"th","\xdf":"ss"},Ut={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;","`":"&#96;"},Ft={"&amp;":"&","&lt;":"<","&gt;":">","&quot;":'"',"&#39;":"'","&#96;":"`"},Lt={"function":true,object:true},$t={"\\":"\\","'":"'","\n":"n","\r":"r","\u2028":"u2028","\u2029":"u2029"},Bt=Lt[typeof window]&&window!==(this&&this.window)?window:this,zt=Lt[typeof exports]&&exports&&!exports.nodeType&&exports,Lt=Lt[typeof module]&&module&&!module.nodeType&&module,Dt=zt&&Lt&&typeof global=="object"&&global;
!Dt||Dt.global!==Dt&&Dt.window!==Dt&&Dt.self!==Dt||(Bt=Dt);var Dt=Lt&&Lt.exports===zt&&zt,Mt=w();typeof define=="function"&&typeof define.amd=="object"&&define.amd?(Bt._=Mt, define('lodash', function(){return Mt})):zt&&Lt?Dt?(Lt.exports=Mt)._=Mt:zt._=Mt:Bt._=Mt}).call(this);
/*!
 * jQuery Tools v1.2.7 - The missing UI library for the Web
 * 
 * overlay/overlay.js
 * scrollable/scrollable.js
 * tabs/tabs.js
 * tooltip/tooltip.js
 * 
 * NO COPYRIGHTS OR LICENSES. DO WHAT YOU LIKE.
 * 
 * http://flowplayer.org/tools/
 * 
 */
(function (a) {
    a.tools = a.tools || {version: "v1.2.7"}, a.tools.overlay = {
        addEffect: function (a, b, d) {
            c[a] = [b, d]
        },
        conf: {
            close: null,
            closeOnClick: !0,
            closeOnEsc: !0,
            closeSpeed: "fast",
            effect: "default",
            fixed: !a.browser.msie || a.browser.version > 6,
            left: "center",
            load: !1,
            mask: null,
            oneInstance: !0,
            speed: "normal",
            target: null,
            top: "10%"
        }
    };
    var b = [], c = {};
    a.tools.overlay.addEffect("default", function (b, c) {
        var d = this.getConf(), e = a(window);
        d.fixed || (b.top += e.scrollTop(), b.left += e.scrollLeft()), b.position = d.fixed ? "fixed" : "absolute", this.getOverlay().css(b).fadeIn(d.speed, c)
    }, function (a) {
        this.getOverlay().fadeOut(this.getConf().closeSpeed, a)
    });
    function d(d, e) {
        var f = this, g = d.add(f), h = a(window), i, j, k, l = a.tools.expose && (e.mask || e.expose), m = Math.random().toString().slice(10);
        l && (typeof l == "string" && (l = {color: l}), l.closeOnClick = l.closeOnEsc = !1);
        var n = e.target || d.attr("rel");
        j = n ? a(n) : null || d;
        if (!j.length)throw"Could not find Overlay: " + n;
        d && d.index(j) == -1 && d.click(function (a) {
            f.load(a);
            return a.preventDefault()
        }), a.extend(f, {
            load: function (d) {
                if (f.isOpened())return f;
                var i = c[e.effect];
                if (!i)throw"Overlay: cannot find effect : \"" + e.effect + "\"";
                e.oneInstance && a.each(b, function () {
                    this.close(d)
                }), d = d || a.Event(), d.type = "onBeforeLoad", g.trigger(d);
                if (d.isDefaultPrevented())return f;
                k = !0, l && a(j).expose(l);
                var n = e.top, o = e.left, p = j.outerWidth({margin: !0}), q = j.outerHeight({margin: !0});
                typeof n == "string" && (n = n == "center" ? Math.max((h.height() - q) / 2, 0) : parseInt(n, 10) / 100 * h.height()), o == "center" && (o = Math.max((h.width() - p) / 2, 0)), i[0].call(f, {
                    top: n,
                    left: o
                }, function () {
                    k && (d.type = "onLoad", g.trigger(d))
                }), l && e.closeOnClick && a.mask.getMask().one("click", f.close), e.closeOnClick && a(document).on("click." + m, function (b) {
                    a(b.target).parents(j).length || f.close(b)
                }), e.closeOnEsc && a(document).on("keydown." + m, function (a) {
                    a.keyCode == 27 && f.close(a)
                });
                return f
            }, close: function (b) {
                if (!f.isOpened())return f;
                b = b || a.Event(), b.type = "onBeforeClose", g.trigger(b);
                if (!b.isDefaultPrevented()) {
                    k = !1, c[e.effect][1].call(f, function () {
                        b.type = "onClose", g.trigger(b)
                    }), a(document).off("click." + m + " keydown." + m), l && a.mask.close();
                    return f
                }
            }, getOverlay: function () {
                return j
            }, getTrigger: function () {
                return d
            }, getClosers: function () {
                return i
            }, isOpened: function () {
                return k
            }, getConf: function () {
                return e
            }
        }), a.each("onBeforeLoad,onStart,onLoad,onBeforeClose,onClose".split(","), function (b, c) {
            a.isFunction(e[c]) && a(f).on(c, e[c]), f[c] = function (b) {
                b && a(f).on(c, b);
                return f
            }
        }), i = j.find(e.close || ".close"), !i.length && !e.close && (i = a("<a class=\"close\"></a>"), j.prepend(i)), i.click(function (a) {
            f.close(a)
        }), e.load && f.load()
    }

    a.fn.overlay = function (c) {
        var e = this.data("overlay");
        if (e)return e;
        a.isFunction(c) && (c = {onBeforeLoad: c}), c = a.extend(!0, {}, a.tools.overlay.conf, c), this.each(function () {
            e = new d(a(this), c), b.push(e), a(this).data("overlay", e)
        });
        return c.api ? e : this
    }
})(jQuery);
(function (a) {
    a.tools = a.tools || {version: "v1.2.7"}, a.tools.scrollable = {
        conf: {
            activeClass: "active",
            circular: !1,
            clonedClass: "cloned",
            disabledClass: "disabled",
            easing: "swing",
            initialIndex: 0,
            item: "> *",
            items: ".items",
            keyboard: !0,
            mousewheel: !1,
            next: ".next",
            prev: ".prev",
            size: 1,
            speed: 400,
            vertical: !1,
            touch: !0,
            wheelSpeed: 0
        }
    };
    function b(a, b) {
        var c = parseInt(a.css(b), 10);
        if (c)return c;
        var d = a[0].currentStyle;
        return d && d.width && parseInt(d.width, 10)
    }

    function c(b, c) {
        var d = a(c);
        return d.length < 2 ? d : b.parent().find(c)
    }

    var d;

    function e(b, e) {
        var f = this, g = b.add(f), h = b.children(), i = 0, j = e.vertical;
        d || (d = f), h.length > 1 && (h = a(e.items, b)), e.size > 1 && (e.circular = !1), a.extend(f, {
            getConf: function () {
                return e
            }, getIndex: function () {
                return i
            }, getSize: function () {
                return f.getItems().size()
            }, getNaviButtons: function () {
                return n.add(o)
            }, getRoot: function () {
                return b
            }, getItemWrap: function () {
                return h
            }, getItems: function () {
                return h.find(e.item).not("." + e.clonedClass)
            }, move: function (a, b) {
                return f.seekTo(i + a, b)
            }, next: function (a) {
                return f.move(e.size, a)
            }, prev: function (a) {
                return f.move(-e.size, a)
            }, begin: function (a) {
                return f.seekTo(0, a)
            }, end: function (a) {
                return f.seekTo(f.getSize() - 1, a)
            }, focus: function () {
                d = f;
                return f
            }, addItem: function (b) {
                b = a(b), e.circular ? (h.children().last().before(b), h.children().first().replaceWith(b.clone().addClass(e.clonedClass))) : (h.append(b), o.removeClass("disabled")), g.trigger("onAddItem", [b]);
                return f
            }, seekTo: function (b, c, k) {
                b.jquery || (b *= 1);
                if (e.circular && b === 0 && i == -1 && c !== 0)return f;
                if (!e.circular && b < 0 || b > f.getSize() || b < -1)return f;
                var l = b;
                b.jquery ? b = f.getItems().index(b) : l = f.getItems().eq(b);
                var m = a.Event("onBeforeSeek");
                if (!k) {
                    g.trigger(m, [b, c]);
                    if (m.isDefaultPrevented() || !l.length)return f
                }
                var n = j ? {top: -l.position().top} : {left: -l.position().left};
                i = b, d = f, c === undefined && (c = e.speed), h.animate(n, c, e.easing, k || function () {
                    g.trigger("onSeek", [b])
                });
                return f
            }
        }), a.each(["onBeforeSeek", "onSeek", "onAddItem"], function (b, c) {
            a.isFunction(e[c]) && a(f).on(c, e[c]), f[c] = function (b) {
                b && a(f).on(c, b);
                return f
            }
        });
        if (e.circular) {
            var k = f.getItems().slice(-1).clone().prependTo(h), l = f.getItems().eq(1).clone().appendTo(h);
            k.add(l).addClass(e.clonedClass), f.onBeforeSeek(function (a, b, c) {
                if (!a.isDefaultPrevented()) {
                    if (b == -1) {
                        f.seekTo(k, c, function () {
                            f.end(0)
                        });
                        return a.preventDefault()
                    }
                    b == f.getSize() && f.seekTo(l, c, function () {
                        f.begin(0)
                    })
                }
            });
            var m = b.parents().add(b).filter(function () {
                if (a(this).css("display") === "none")return !0
            });
            m.length ? (m.show(), f.seekTo(0, 0, function () {
            }), m.hide()) : f.seekTo(0, 0, function () {
            })
        }
        var n = c(b, e.prev).click(function (a) {
            a.stopPropagation(), f.prev()
        }), o = c(b, e.next).click(function (a) {
            a.stopPropagation(), f.next()
        });
        e.circular || (f.onBeforeSeek(function (a, b) {
            setTimeout(function () {
                a.isDefaultPrevented() || (n.toggleClass(e.disabledClass, b <= 0), o.toggleClass(e.disabledClass, b >= f.getSize() - 1))
            }, 1)
        }), e.initialIndex || n.addClass(e.disabledClass)), f.getSize() < 2 && n.add(o).addClass(e.disabledClass), e.mousewheel && a.fn.mousewheel && b.mousewheel(function (a, b) {
            if (e.mousewheel) {
                f.move(b < 0 ? 1 : -1, e.wheelSpeed || 50);
                return !1
            }
        });
        if (e.touch) {
            var p = {};
            h[0].ontouchstart = function (a) {
                var b = a.touches[0];
                p.x = b.clientX, p.y = b.clientY
            }, h[0].ontouchmove = function (a) {
                if (a.touches.length == 1 && !h.is(":animated")) {
                    var b = a.touches[0], c = p.x - b.clientX, d = p.y - b.clientY;
                    f[j && d > 0 || !j && c > 0 ? "next" : "prev"](), a.preventDefault()
                }
            }
        }
        e.keyboard && a(document).on("keydown.scrollable", function (b) {
            if (!(!e.keyboard || b.altKey || b.ctrlKey || b.metaKey || a(b.target).is(":input"))) {
                if (e.keyboard != "static" && d != f)return;
                var c = b.keyCode;
                if (j && (c == 38 || c == 40)) {
                    f.move(c == 38 ? -1 : 1);
                    return b.preventDefault()
                }
                if (!j && (c == 37 || c == 39)) {
                    f.move(c == 37 ? -1 : 1);
                    return b.preventDefault()
                }
            }
        }), e.initialIndex && f.seekTo(e.initialIndex, 0, function () {
        })
    }

    a.fn.scrollable = function (b) {
        var c = this.data("scrollable");
        if (c)return c;
        b = a.extend({}, a.tools.scrollable.conf, b), this.each(function () {
            c = new e(a(this), b), a(this).data("scrollable", c)
        });
        return b.api ? c : this
    }
})(jQuery);
(function (a) {
    a.tools = a.tools || {version: "v1.2.7"}, a.tools.tabs = {
        conf: {
            tabs: "a",
            current: "current",
            onBeforeClick: null,
            onClick: null,
            effect: "default",
            initialEffect: !1,
            initialIndex: 0,
            event: "click",
            rotate: !1,
            slideUpSpeed: 400,
            slideDownSpeed: 400,
            history: !1
        }, addEffect: function (a, c) {
            b[a] = c
        }
    };
    var b = {
        "default": function (a, b) {
            this.getPanes().hide().eq(a).show(), b.call()
        }, fade: function (a, b) {
            var c = this.getConf(), d = c.fadeOutSpeed, e = this.getPanes();
            d ? e.fadeOut(d) : e.hide(), e.eq(a).fadeIn(c.fadeInSpeed, b)
        }, slide: function (a, b) {
            var c = this.getConf();
            this.getPanes().slideUp(c.slideUpSpeed), this.getPanes().eq(a).slideDown(c.slideDownSpeed, b)
        }, ajax: function (a, b) {
            this.getPanes().eq(0).load(this.getTabs().eq(a).attr("href"), b)
        }
    }, c, d;
    a.tools.tabs.addEffect("horizontal", function (b, e) {
        if (!c) {
            var f = this.getPanes().eq(b), g = this.getCurrentPane();
            d || (d = this.getPanes().eq(0).width()), c = !0, f.show(), g.animate({width: 0}, {
                step: function (a) {
                    f.css("width", d - a)
                }, complete: function () {
                    a(this).hide(), e.call(), c = !1
                }
            }), g.length || (e.call(), c = !1)
        }
    });
    function e(c, d, e) {
        var f = this, g = c.add(this), h = c.find(e.tabs), i = d.jquery ? d : c.children(d), j;
        h.length || (h = c.children()), i.length || (i = c.parent().find(d)), i.length || (i = a(d)), a.extend(this, {
            click: function (d, i) {
                var k = h.eq(d), l = !c.data("tabs");
                typeof d == "string" && d.replace("#", "") && (k = h.filter("[href*=\"" + d.replace("#", "") + "\"]"), d = Math.max(h.index(k), 0));
                if (e.rotate) {
                    var m = h.length - 1;
                    if (d < 0)return f.click(m, i);
                    if (d > m)return f.click(0, i)
                }
                if (!k.length) {
                    if (j >= 0)return f;
                    d = e.initialIndex, k = h.eq(d)
                }
                if (d === j)return f;
                i = i || a.Event(), i.type = "onBeforeClick", g.trigger(i, [d]);
                if (!i.isDefaultPrevented()) {
                    var n = l ? e.initialEffect && e.effect || "default" : e.effect;
                    b[n].call(f, d, function () {
                        j = d, i.type = "onClick", g.trigger(i, [d])
                    }), h.removeClass(e.current), k.addClass(e.current);
                    return f
                }
            }, getConf: function () {
                return e
            }, getTabs: function () {
                return h
            }, getPanes: function () {
                return i
            }, getCurrentPane: function () {
                return i.eq(j)
            }, getCurrentTab: function () {
                return h.eq(j)
            }, getIndex: function () {
                return j
            }, next: function () {
                return f.click(j + 1)
            }, prev: function () {
                return f.click(j - 1)
            }, destroy: function () {
                h.off(e.event).removeClass(e.current), i.find("a[href^=\"#\"]").off("click.T");
                return f
            }
        }), a.each("onBeforeClick,onClick".split(","), function (b, c) {
            a.isFunction(e[c]) && a(f).on(c, e[c]), f[c] = function (b) {
                b && a(f).on(c, b);
                return f
            }
        }), e.history && a.fn.history && (a.tools.history.init(h), e.event = "history"), h.each(function (b) {
            a(this).on(e.event, function (a) {
                f.click(b, a);
                return a.preventDefault()
            })
        }), i.find("a[href^=\"#\"]").on("click.T", function (b) {
            f.click(a(this).attr("href"), b)
        }), location.hash && e.tabs == "a" && c.find("[href=\"" + location.hash + "\"]").length ? f.click(location.hash) : (e.initialIndex === 0 || e.initialIndex > 0) && f.click(e.initialIndex)
    }

    a.fn.tabs = function (b, c) {
        var d = this.data("tabs");
        d && (d.destroy(), this.removeData("tabs")), a.isFunction(c) && (c = {onBeforeClick: c}), c = a.extend({}, a.tools.tabs.conf, c), this.each(function () {
            d = new e(a(this), b, c), a(this).data("tabs", d)
        });
        return c.api ? d : this
    }
})(jQuery);
(function (a) {
    a.tools = a.tools || {version: "v1.2.7"}, a.tools.tooltip = {
        conf: {
            effect: "toggle",
            fadeOutSpeed: "fast",
            predelay: 0,
            delay: 30,
            opacity: 1,
            tip: 0,
            fadeIE: !1,
            position: ["top", "center"],
            offset: [0, 0],
            relative: !1,
            cancelDefault: !0,
            events: {
                def: "mouseenter,mouseleave",
                input: "focus,blur",
                widget: "focus mouseenter,blur mouseleave",
                tooltip: "mouseenter,mouseleave"
            },
            layout: "<div/>",
            tipClass: "tooltip"
        }, addEffect: function (a, c, d) {
            b[a] = [c, d]
        }
    };
    var b = {
        toggle: [function (a) {
            var b = this.getConf(), c = this.getTip(), d = b.opacity;
            d < 1 && c.css({opacity: d}), c.show(), a.call()
        }, function (a) {
            this.getTip().hide(), a.call()
        }], fade: [function (b) {
            var c = this.getConf();
            !a.browser.msie || c.fad
            eIE ? this.getTip().fadeTo(c.fadeInSpeed, c.opacity, b) : (this.getTip().show(), b())
        }, function (b) {
            var c = this.getConf();
            !a.browser.msie || c.fadeIE ? this.getTip().fadeOut(c.fadeOutSpeed, b) : (this.getTip().hide(), b())
        }]
    };

    function c(b, c, d) {
        var e = d.relative ? b.position().top : b.offset().top, f = d.relative ? b.position().left : b.offset().left, g = d.position[0];
        e -= c.outerHeight() - d.offset[0], f += b.outerWidth() + d.offset[1], /iPad/i.test(navigator.userAgent) && (e -= a(window).scrollTop());
        var h = c.outerHeight() + b.outerHeight();
        g == "center" && (e += h / 2), g == "bottom" && (e += h), g = d.position[1];
        var i = c.outerWidth() + b.outerWidth();
        g == "center" && (f -= i / 2), g == "left" && (f -= i);
        return {top: e, left: f}
    }

    function d(d, e) {
        var f = this, g = d.add(f), h, i = 0, j = 0, k = d.attr("title"), l = d.attr("data-tooltip"), m = b[e.effect], n, o = d.is(":input"), p = o && d.is(":checkbox, :radio, select, :button, :submit"), q = d.attr("type"), r = e.events[q] || e.events[o ? p ? "widget" : "input" : "def"];
        if (!m)throw"Nonexistent effect \"" + e.effect + "\"";
        r = r.split(/,\s*/);
        if (r.length != 2)throw"Tooltip: bad events configuration for " + q;
        d.on(r[0], function (a) {
            clearTimeout(i), e.predelay ? j = setTimeout(function () {
                f.show(a)
            }, e.predelay) : f.show(a)
        }).on(r[1], function (a) {
            clearTimeout(j), e.delay ? i = setTimeout(function () {
                f.hide(a)
            }, e.delay) : f.hide(a)
        }), k && e.cancelDefault && (d.removeAttr("title"), d.data("title", k)), a.extend(f, {
            show: function (b) {
                if (!h) {
                    l ? h = a(l) : e.tip ? h = a(e.tip).eq(0) : k ? h = a(e.layout).addClass(e.tipClass).appendTo(document.body).hide().append(k) : (h = d.next(), h.length || (h = d.parent().next()));
                    if (!h.length)throw"Cannot find tooltip for " + d
                }
                if (f.isShown())return f;
                h.stop(!0, !0);
                var o = c(d, h, e);
                e.tip && h.html(d.data("title")), b = a.Event(), b.type = "onBeforeShow", g.trigger(b, [o]);
                if (b.isDefaultPrevented())return f;
                o = c(d, h, e), h.css({
                    position: "absolute",
                    top: o.top,
                    left: o.left
                }), n = !0, m[0].call(f, function () {
                    b.type = "onShow", n = "full", g.trigger(b)
                });
                var p = e.events.tooltip.split(/,\s*/);
                h.data("__set") || (h.off(p[0]).on(p[0], function () {
                    clearTimeout(i), clearTimeout(j)
                }), p[1] && !d.is("input:not(:checkbox, :radio), textarea") && h.off(p[1]).on(p[1], function (a) {
                    a.relatedTarget != d[0] && d.trigger(r[1].split(" ")[0])
                }), e.tip || h.data("__set", !0));
                return f
            }, hide: function (c) {
                if (!h || !f.isShown())return f;
                c = a.Event(), c.type = "onBeforeHide", g.trigger(c);
                if (!c.isDefaultPrevented()) {
                    n = !1, b[e.effect][1].call(f, function () {
                        c.type = "onHide", g.trigger(c)
                    });
                    return f
                }
            }, isShown: function (a) {
                return a ? n == "full" : n
            }, getConf: function () {
                return e
            }, getTip: function () {
                return h
            }, getTrigger: function () {
                return d
            }
        }), a.each("onHide,onBeforeShow,onShow,onBeforeHide".split(","), function (b, c) {
            a.isFunction(e[c]) && a(f).on(c, e[c]), f[c] = function (b) {
                b && a(f).on(c, b);
                return f
            }
        })
    }

    a.fn.tooltip = function (b) {
        var c = this.data("tooltip");
        if (c)return c;
        b = a.extend(!0, {}, a.tools.tooltip.conf, b), typeof b.position == "string" && (b.position = b.position.split(/,?\s/)), this.each(function () {
            c = new d(a(this), b), a(this).data("tooltip", c)
        });
        return b.api ? c : this
    }
})(jQuery);

(function () {
    if (window.webtrekk) {
        factory();
    }

    function factory() {
        var wt_version = 215;
        var wt_va = Array("wt_sampleValue", "wt_sentFullPixel", "wt_t1", "wt_t2", "wt_cookie_sid", "wt_cookie_eid", "wt_cookie_l_v", "wt_cookie_one", "wt_ep", "wt_ccParams", "wt_mcvalue", "wt_isFlashCookie", "wt_1st_party_checked", "wt_1stPartySet");
        for (var i = 0; i < wt_va.length; i++) {
            eval("if(typeof(" + wt_va[i] + ")!='string') " + wt_va[i] + "='';");
        }
        var wt_browserName = navigator.appName,
            wt_browserName = (wt_indexOf(wt_browserName, "Microsoft") ? wt_browserName : "MSIE"),
            wt_browserNameNS = (wt_browserName == "Netscape"),
            wt_browserNameIE = (wt_browserName == "MSIE");
        var wt_deactivatePixel = false;
        var wt_optOut = false;
        if (!webtrekk.contentId) webtrekk.contentId = wt_url2contentId(document.location.href);

        function wt_href() {
            return wt_location().href;
        }

        function wt_location() {
            var r = document.location;
            if (!document.layers && document.getElementById) {
                eval("try {r=top.document.location;}catch(e){r=document.location;};");
            } else {
                r = top.document.location;
            }
            return r;
        }

        function wt_getWebtrekkPath() {
            if (!document.layers && document.getElementById) {
                var stags = document.getElementsByTagName('script');
                for (var i = 0; i < stags.length; i++) {
                    if (stags[i].src.match(/webtrekk[a-z|A-Z|0-9|_]*\.js/g)) {
                        return stags[i].src.replace(/webtrekk[a-z|A-Z|0-9|_]*\.js/g, '');
                    }
                }
            }
        }

        function wt_length(a) {
            return a != "undefined" ? a.length : 0;
        }

        function wt_getTimezone() {
            return Math.round((new Date().getTimezoneOffset() / 60) * (-1));
        }

        function wt_url2contentId(url) {
            if (!url) return "no_content";
            var tmp = new RegExp("//(.*)").exec(url);
            if (tmp.length < 1) return "no_content";
            var contentId = tmp[1].split("?")[0].replace(/\./g, "_").replace(/\//g, ".").replace(/\.{2,};/g, ".").toLowerCase();
            return contentId.split(";")[0];
        }

        function wt_include(s) {
            if (!document.createElement) return false;
            var html_doc = document.getElementsByTagName('head').item(0);
            var js = document.createElement('script');
            js.setAttribute('language', 'javascript');
            js.setAttribute('type', 'text/javascript');
            js.setAttribute('src', s);
            html_doc.appendChild(js);
            return true;
        }

        function wt_indexOf(a, b, c) {
            return a.indexOf(b, c ? c : 0);
        }

        function wt_typeof(v) {
            return (typeof v != "undefined") ? 1 : 0;
        }

        function wt_registerEvent(obj, e, f) {
            if (obj.addEventListener) {
                obj.addEventListener(e, f, false);
            } else {
                if (obj.attachEvent) {
                    obj.attachEvent("on" + e, f);
                }
            }
        }

        function wt_maxlen(v, l) {
            if (v && v.length > l) return v.substring(0, l - 1);
            return v;
        }

        function wt_escape(u) {
            if (typeof (encodeURIComponent) == 'function') return encodeURIComponent(u);
            return escape(u);
        }

        function wt_unescape(u) {
            if (typeof (decodeURIComponent) == 'function') return decodeURIComponent(u);
            return unescape(u);
        }

        function wt_decoder(u) {
            var tmp = unescape(u);
            if (document.layers) return wt_escape(tmp);
            if (document.getElementById) {
                eval("try {tmp=decodeURIComponent(u);}catch(e){};");
            } else {
                tmp = decodeURIComponent(u);
            }
            return wt_escape(tmp);
        }

        function wt_encoding() {
            var tmp = "";
            if (typeof (encodeURIComponent) != 'function') tmp += "&enc0=old";
            tmp += "&enc1=Ã¼&enc2=";
            if (document.characterSet) tmp += document.characterSet.toLowerCase();
            if (document.charset) tmp += document.charset.toLowerCase();
            return tmp;
        }

        function wt_crypt(t) {
            var org = "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
            var rep = "NOPQRSTUVWXYZABCDEFGHIJKLM5678901234";
            t = t.replace(new RegExp("[A-Z]|[a-z]|[0-9]", "gi"), function ($1) {
                var sp = new RegExp("[A-Z]", "g");
                var pos = org.indexOf($1.toUpperCase());
                if (sp.test($1)) {
                    return rep.charAt(pos);
                } else {
                    return rep.charAt(pos).toLowerCase();
                }
            });
            return t;
        }

        function wt_decrypt(x) {
            if (x) {
                return eval("try {wt_unescape(x.replace(/([0-9a-fA-F][0-9a-fA-F])/g,'%$1'));}catch(e){''};");
            }
        }

        function wt_encrypt(x) {
            var str = '';
            for (var i = 0; i < x.length; i++) {
                if (x.charCodeAt(i) < 255) {
                    str += x.charCodeAt(i).toString(16);
                } else {
                    eval("try {str += encodeURIComponent(x[i]).replace(/%/g,'');}catch(e){};");
                }
            }
            return str;
        }

        function wt_checkSC(x) {
            if (typeof (webtrekk.secureConfig) != 'string') {
                return false;
            }
            var sc = webtrekk.secureConfig.split(';');
            for (var i = 0; i < sc.length; i++) {
                if (sc[i] == x) return true;
            }
            return false;
        }

        function wt_zeroPad(n, countZeros) {
            var result = n + '';
            return "000000000000".substring(0, (countZeros - result.length)) + result;
        }

        function wt_sid() {
            return '2' + wt_zeroPad(Math.floor(new Date().getTime() / 1000), 10) + wt_zeroPad(Math.floor(Math.random() * 1000000), 8);
        }

        function wt_getexpirydate(mins) {
            var UTCstring;
            var Today = new Date();
            var nomilli = Date.parse(Today);
            Today.setTime(nomilli + mins * 60 * 1000);
            UTCstring = Today.toUTCString();
            return UTCstring;
        }

        function wt_setCookie(name, value, duration) {
            var d = location.hostname;
            var dReg = "^[0-9]{1,3" + String.fromCharCode(125) + "\.[0-9]{1,3" + String.fromCharCode(125) + "\.[0-9]{1,3" + String.fromCharCode(125) + "\.[0-9]{1,3" + String.fromCharCode(125) + "$";
            if (d.search(dReg) == -1) {
                d = location.hostname.split(".");
                d = d[d.length - 2] + "." + d[d.length - 1];
            }
            var c;
            if (duration) c = name + "=" + escape(value) + ";domain=" + d + ";path=/;expires=" + wt_getexpirydate(duration);
            else c = name + "=" + escape(value) + ";path=/;domain=" + d;
            document.cookie = c;
        }

        function wt_getCookie(cookiename) {
            var cookiestring = "" + document.cookie;
            var index1 = cookiestring.indexOf(cookiename);
            if (index1 == -1 || cookiename == "") return "";
            var index2 = cookiestring.indexOf(';', index1);
            if (index2 == -1) index2 = cookiestring.length;
            return unescape(cookiestring.substring(index1 + cookiename.length + 1, index2));
        }

        var wt_getSetFlashCookie = {
            elmToReplace: null,
            install: function (elmToReplace, src, id, params) {
                if (!this.checkVersion()) {
                    return;
                }
                this.elmToReplace = document.getElementById(elmToReplace);
                if (this.elmToReplace) {
                    var posY = document.body.scrollTop;
                    if (posY == 'undefined') {
                        posY = document.documentElement.scrollTop;
                    }
                    var obj = '<object style="z-index:10000;position:absolute;left:1px;top:' + (posY + 1) + 'px;"' + ((window.ActiveXObject) ? ' id="' + id + '" classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" data="' + src + '"' : '');
                    obj += ' width=1';
                    obj += ' height=1';
                    obj += '>';
                    var param = '<param';
                    param += ' name="movie"';
                    param += ' value="' + src + '"';
                    param += '>';
                    param += '';
                    var extraParams = '';
                    var extraAttributes = '';
                    for (var i in params) {
                        extraParams += '<param name="' + i + '" value="' + params[i] + '">';
                        extraAttributes += ' ' + i + '="' + params[i] + '"';
                    }
                    var embed = '<embed style="z-index:10000;position:absolute;left:1px;top:' + (posY + 1) + 'px;" id="' + id + '" src="' + src + '" type="application/x-shockwave-flash" width="1" height="1"';
                    var embedEnd = extraAttributes + '></embed>';
                    var objEnd = '</object>';
                    this.elmToReplace.innerHTML = obj + param + extraParams + embed + embedEnd + objEnd;
                }
            },
            checkVersion: function () {
                this.flashIsInstalled = false;
                var flash;
                if (window.ActiveXObject) {
                    try {
                        flash = new ActiveXObject(("ShockwaveFlash.ShockwaveFlash"));
                        this.flashIsInstalled = true;
                    } catch (e) {
                    }
                } else if (navigator.plugins && navigator.mimeTypes.length > 0) {
                    if (navigator.plugins["Shockwave Flash"]) {
                        this.flashIsInstalled = true;
                    }
                }
                return this.flashIsInstalled;
            }
        };

        function wt_flashCookie_callback(val) {
            if (!val) {
                return;
            }
            val = val.replace(/\s/g, '');
            val = val.split(',');
            wt_cookie_sid = val[0];
            wt_cookie_eid = val[2];
            wt_sampleCookieString = false;
            if (val[4] == "0") {
                wt_deactivatePixel = true;
                wt_sampleCookieString = "0|" + val[6];
            }
            if (val[4] == "1") {
                wt_deactivatePixel = false;
                wt_sampleCookieString = "1|" + val[6];
            }
            if (val[1] == 'true') {
                wt_cookie_one = true;
            } else {
                wt_cookie_one = false;
            }
            if (wt_sampleCookieString) {
                wt_setCookie("wt_sample", wt_sampleCookieString, webtrekk.cookieEidTimeout * 30 * 24 * 60);
            }
            wt_setCookie("wt_eid", wt_cookie_eid, webtrekk.cookieEidTimeout * 30 * 24 * 60);
            wt_setCookie("wt_sid", wt_cookie_sid);
            wt_isFlashCookie = "1";
            wt_1stPartySet = "1";
        }

        function wt_flashCookie(fc_name, sid, sid_timeout, eid, eid_timeout, l_v, sampling, sampling_rate) {
            if (!document.createElement) {
                return false;
            }
            var html_doc = document.getElementsByTagName('body').item(0);
            if (document.all && html_doc.document.readyState == "interactive") {
            } else {
                var div = document.createElement('div');
                div.setAttribute('id', 'wt_flashdiv');
                html_doc.appendChild(div);
                if (document.getElementById && document.getElementById("wt_flashdiv")) {
                    wt_getSetFlashCookie.install("wt_flashdiv", wt_getWebtrekkPath() + "flash_pixel.swf", "wt__fc", {
                        flashvars: "action=getset&name=" + fc_name + "&script=wt_flashCookie_callback&sid=" + sid + "&sid_timeout=" + sid_timeout + "&eid=" + eid + "&eid_timeout=" + eid_timeout + "&l_v=" + l_v + "&sampling=" + sampling + "&sampling_rate=" + sampling_rate + "&path=/",
                        name: fc_name,
                        wmode: "transparent",
                        quality: "low",
                        bgcolor: "#ffffff"
                    });
                }
            }
        }

        function wt_urlParam(url, param, def) {
            var p = [];
            if (url.indexOf("?") > 0) p = url.substring(url.indexOf("?") + 1).replace(/&amp;/g, "&").split("&");
            for (var i = 0; i < p.length; i++) {
                if (p[i].indexOf(param + "=") == 0) {
                    return wt_unescape(p[i].substring(param.length + 1).replace(/\+/g, "%20"));
                }
            }
            return def;
        }

        function wt_allUrlParam(param, def) {
            if (wt_typeof(webtrekk.mediaCodeFrames) && webtrekk.mediaCodeFrames != '') {
                var lf = webtrekk.mediaCodeFrames.split(";");
                for (var i = 0; i < lf.length; i++) {
                    var lFrame = false;
                    eval("try { lFrame = eval(lf[i]) }catch(e){};");
                    if (lFrame && lFrame != top && lFrame.location) {
                        var def2 = wt_urlParam(lFrame.location.href, param, def);
                        if (def2 != def) {
                            return def2;
                        }
                    }
                }
                return def;
            } else {
                var topLocation = "";
                eval("try {topLocation = top.location.href;}catch(e){topLocation=document.location.href;};");
                return wt_urlParam(topLocation, param, def);
            }
        }

        var wt_linktrack_p = "";
        var wt_linktrack_namedlinks_only;
        if (webtrekk.linkTrack == "auto") {
            webtrekk.linkTrack = "link";
        }
        if (webtrekk.linkTrack == "link") {
            wt_linktrack_namedlinks_only = false;
        } else {
            wt_linktrack_namedlinks_only = true;
        }
        if (webtrekk.linkTrack) {
            wt_registerEvent(window, "load", wt_ltinstall);
        }
        function wt_ltinstall() {
            for (c = 0; c < document.links.length; c++) {
                var name = document.links[c].getAttribute('name');
                if (wt_typeof(webtrekk.linkTrackAttribute) && webtrekk.linkTrackAttribute != "") {
                    var tmp = "";
                    eval("tmp = (document.links[c].getAttribute(webtrekk.linkTrackAttribute)?document.links[c].getAttribute(webtrekk.linkTrackAttribute):'')");
                    if (tmp) name = tmp;
                }
                if (name || !wt_linktrack_namedlinks_only) {
                    wt_registerEvent(document.links[c], 'mousedown', wt_linktrack);
                }
            }
        }

        function wt_linktrack(e) {
            if ((e.which && e.which == 1) || (e.button && e.button == 1)) {
                var a = document.all ? window.event.srcElement : this;
                for (var i = 0; i < 4; i++) {
                    if (a.tagName && a.tagName.toLowerCase() != "a" && a.tagName.toLowerCase() != "area") {
                        a = a.parentElement
                    }
                }
                a.lname = (a.name ? a.name : "");
                wt_getCCParams(a);
                if (wt_typeof(webtrekk.linkTrackAttribute) && webtrekk.linkTrackAttribute != "") {
                    var tmp = "";
                    eval("tmp = (a.getAttribute(webtrekk.linkTrackAttribute)?a.getAttribute(webtrekk.linkTrackAttribute):'')");
                    if (tmp) a.lname = tmp;
                }
                a.lpos = 0;
                if (!wt_length(a.lpos) && a.tagName) {
                    c = document.links;
                    for (d = 0; d < wt_length(c); d++) {
                        if (a == c[d]) {
                            a.lpos = d + 1;
                            break
                        }
                    }
                }
                if (a.lpos) {
                    if (webtrekk.linkTrack == "link") {
                        var y = a.href.indexOf("//");
                        var y = (y >= 0 ? a.href.substr(y + 2) : a.href);
                        if (wt_typeof(webtrekk.linkTrackPattern)) {
                            if (typeof (webtrekk.linkTrackReplace) != 'string') webtrekk.linkTrackReplace = "";
                            y = y.replace(webtrekk.linkTrackPattern, webtrekk.linkTrackReplace);
                        }
                        wt_linktrack_p = (a.lname ? (a.lname + ".") : "") + y.split("?")[0].replace(/\//g, ".");
                        var p = "";
                        if (wt_typeof(webtrekk.linkTrackParams)) {
                            p = webtrekk.linkTrackParams.replace(/;/g, ",").split(",");
                        }
                        for (var i = 0; i < p.length; i++) {
                            var v = wt_urlParam(y, p[i], "");
                            if (v) wt_linktrack_p += "." + p[i] + "." + v;
                        }
                    } else if (webtrekk.linkTrack == "standard" && a.lname) wt_linktrack_p = a.lname;
                    var wt_isDownloadFile = false;
                    if (typeof (webtrekk.linkTrackDownloads) != "undefined" && webtrekk.linkTrackDownloads != "") {
                        var link_extension = a.href.split(".");
                        link_extension = link_extension.pop();
                        var wt_dfe = webtrekk.linkTrackDownloads.split(";");
                        for (i = 0; i < wt_dfe.length; i++) {
                            if (wt_dfe[i] == link_extension) {
                                wt_isDownloadFile = true;
                                break;
                            }
                        }
                    }
                    if (wt_isDownloadFile || (wt_linktrack_p && a.target != "" && a.target != "_self")) {
                        wt_unload('noForm');
                    }
                }
            }
        }

        function wt_getCCParams(a) {
            var ccParams = '';
            var p = '';
            if (typeof (webtrekk.customClickParameter) == 'object') {
                if (typeof (webtrekk.customClickParameter[a.name]) == 'string') ccParams = webtrekk.customClickParameter[a.name];
                if (typeof (webtrekk.customClickParameter[a.id]) == 'string') ccParams = webtrekk.customClickParameter[a.id];
            }
            if (ccParams) {
                ccParams = ccParams.split(/;/);
                for (var z = 0; z < ccParams.length; z++) {
                    if (wt_typeof(ccParams[z])) {
                        var wtep = ccParams[z].split(/=/);
                        if (wt_checkSC('custom')) {
                            wtep[1] = wt_decrypt(wtep[1]);
                        }
                        wtep[1] = wt_escape(wtep[1]);
                        p += '&' + wtep[0] + '=' + wtep[1];
                    }
                }
            }
            wt_ccParams = p;

        }

        var wt_gatherforms_p = "";
        var wt_form = null;
        var wt_form_name = "";
        var wt_form_focus = "";
        var wt_form_submit = false;
        if (webtrekk.form) {
            wt_registerEvent(window, "load", wt_ftinstall);
        }
        function wt_ftinstall() {
            wt_findform();
            if (!wt_form) return;
            for (var j = 0; j < wt_form.elements.length; j++) {
                var e = wt_form.elements[j];
                wt_registerEvent(e, "focus", wt_formfocus);
            }
            wt_registerEvent(wt_form, "submit", wt_formsubmit);
        }

        function wt_findform() {
            wt_form = null;
            var f = document.forms;
            for (var i = 0; i < f.length; i++) {
                var cf = f[i];
                if (wt_typeof(cf.elements["wt_form"])) {
                    wt_form = cf;
                    return;
                }
            }
        }

        function wt_formsubmit() {
            wt_form_submit = true;
        }

        function wt_formfocus(e) {
            var a = document.all ? window.event.srcElement : e.target;
            if (!a.name || a.type == "submit" || a.type == "image") return;
            var f = wt_form.getAttribute('name') ? wt_form.getAttribute('name') : webtrekk.contentId.split(";")[0];
            if (wt_typeof(webtrekk.formAttribute) && webtrekk.formAttribute != '') {
                var tmp = "";
                eval("tmp = (wt_form.getAttribute(webtrekk.formAttribute)?wt_form.getAttribute(webtrekk.formAttribute):'')");
                if (tmp) f = tmp;
            }
            wt_form_focus = a.name;
        }

        function wt_checkFormFocus(ffname) {
            if (ffname == wt_form_focus) return 1;
            return 0;
        }

        function wt_getFormFieldValue(ff) {
            var p = ff.name;
            if (wt_typeof(webtrekk.formFieldAttribute) && webtrekk.formFieldAttribute != '') {
                p = '';
                var tmp = false;
                eval("tmp = (ff.getAttribute(webtrekk.formFieldAttribute)?ff.getAttribute(webtrekk.formFieldAttribute):'')");
                if (tmp) p = tmp;
            }
            if (p) p = p.replace(/[\.|;]/g, "_");
            return p;
        }

        function wt_gatherForm() {
            var del = ";";
            if (!wt_form) return;
            var f = wt_form;
            var p = wt_form.getAttribute('name') ? wt_form.getAttribute('name') : webtrekk.contentId.split(";")[0];
            if (wt_typeof(webtrekk.formAttribute) && webtrekk.formAttribute != '') {
                var tmp = "";
                eval("tmp = (f.getAttribute(webtrekk.formAttribute)?f.getAttribute(webtrekk.formAttribute):'')");
                if (tmp) p = tmp;
            }
            wt_form_name = p;
            var fl = "";
            if (wt_typeof(f.elements["wt_fields"])) fl = f.elements["wt_fields"].value;
            if (!fl) {
                for (var i = 0; i < f.elements.length; i++) {
                    var e = f.elements[i];
                    if (wt_getFormFieldValue(e)) fl += wt_getFormFieldValue(e) + del;
                }
                fl = fl.substring(0, fl.lastIndexOf(del))
            }
            var fields = fl.split(del);
            var fields_length = fields.length;
            var full_fields = "";
            if (typeof (webtrekk.formFullContent) == 'string') {
                full_fields = webtrekk.formFullContent.split(del);
            }
            var pa = "";
            var emptyradios = [];
            for (var i = 0; i < f.elements.length; i++) {
                var e = f.elements[i],
                    value, value2, use = false;
                if (fl) {
                    for (var j = 0; j < fields_length; j++)
                        if (wt_getFormFieldValue(e) == fields[j]) use = true;
                } else {
                    if (wt_getFormFieldValue(e)) use = true;
                }
                if (use) {
                    value = null;
                    if (e.type == 'select-multiple') {
                        for (var j = 0; j < e.options.length; j++) {
                            var found = false;
                            if (e.options[j].selected) {
                                found = true;
                                pa += ";" + wt_getFormFieldValue(e).replace(/[\.|;]/g, "_") + "." + e.type + "|" + ((typeof (webtrekk.formAnonymous) == "string" && webtrekk.formAnonymous == "1") ? "anon" : e.options[j].value.replace(/[\.|;]/g, "_")) + "|" + wt_checkFormFocus(e.name);
                            }
                            if (!found) value = "empty";
                        }
                    }
                    if (e.type == 'select-one') {
                        if (e.selectedIndex != -1) {
                            value = e.options[e.selectedIndex].value.replace(/[\.|;]/, "_");
                            if (!value) value = "empty";
                        }
                    }
                    if (e.type == 'checkbox') {
                        if (!e.checked) value = "empty";
                        else value = e.value.replace(/[\.|;]/, "_");
                    }
                    if (e.type == 'radio') {
                        if (e.checked) value = e.value.replace(/[\.|;]/g, "_");
                        emptyradios[emptyradios.length] = wt_getFormFieldValue(e);
                    }
                    if (e.type == "password" || e.type == "text" || e.type == "textarea") {
                        value = (e.value ? "filled_out" : "empty");
                        for (var k = 0; k < full_fields.length; k++)
                            if (full_fields[k] == wt_getFormFieldValue(e)) value = wt_maxlen(e.value, 30);
                        if (!value) value = "empty";
                    }
                    if (value) {
                        name = wt_getFormFieldValue(e).replace(/[\.|;]/g, "_");
                        value2 = ";" + name + "." + e.type + "|";
                        if (pa.indexOf(value2) == -1) pa += value2 + ((typeof (webtrekk.formAnonymous) == "string" && webtrekk.formAnonymous == "1") ? "anon" : value) + "|" + wt_checkFormFocus(e.name);
                    }
                }
            }
            for (var i = 0; i < emptyradios.length; i++) {
                var n = ";" + emptyradios[i].replace(/[\.|;]/g, "_") + ".radio|";
                if (pa.indexOf(n) == -1) pa += n + ((typeof (webtrekk.formAnonymous) == "string" && webtrekk.formAnonymous == "1") ? "anon" : "empty") + "|" + wt_checkFormFocus(e.name);
            }
            if (pa) {
                pa = pa.substring(1);
            }
            return pa;
        }

        if (webtrekk.form || webtrekk.linkTrack) {
            wt_registerEvent(window, (wt_browserNameIE && wt_typeof(window.onbeforeunload)) ? "beforeunload" : "unload", wt_unload);
        }
        function wt_unload(sendForm) {
            if (wt_form && sendForm != 'noForm') wt_gatherforms_p = wt_gatherForm();
            var p = "";
            if (wt_linktrack_p) p += "&ct=" + wt_escape(wt_maxlen(wt_linktrack_p, 255));
            if (wt_gatherforms_p) {
                p += "&fn=" + (wt_form_name ? wt_form_name : webtrekk.contentId.split(";")[0]) + '|' + (wt_form_submit ? "1" : "0");
                p += "&ft=" + wt_escape(wt_gatherforms_p);
            }
            if (p) {
                if (typeof (wt_ep) == 'string' && wt_ep != '') {
                    wt_ep = wt_ep.split(/;/);
                    for (var z = 0; z < wt_ep.length; z++) {
                        if (wt_typeof(wt_ep[z])) {
                            wtep = wt_ep[z].split(/=/);
                            if (wt_checkSC('custom')) {
                                wtep[1] = wt_decrypt(wtep[1]);
                            }
                            wtep[1] = wt_escape(wtep[1]);
                            p += '&' + wtep[0] + '=' + wtep[1];
                        }
                    }
                }
                if (typeof (wt_ccParams) == 'string' && wt_ccParams != '') p += wt_ccParams;
                wt_quicksend(wt_escape(webtrekk.contentId.split(";")[0]) + ",1," + wt_baseparams(), p + wt_encoding());
                wt_linktrack_p = "";
                wt_gatherforms_p = "";
            }
        }

        function wt_isOwnDomain(l) {
            var pt = '';
            if (wt_typeof(webtrekk.domain) && webtrekk.domain != "") {
                if (webtrekk.domain.toUpperCase().indexOf("REGEXP:") == 0) {
                    pt = new RegExp(webtrekk.domain.substring(7), "i");
                    if (pt.test(wt_getDomain(l))) {
                        return true;
                    }
                } else {
                    var domains = webtrekk.domain.split(';');
                    var xHost = wt_getDomain(l);
                    for (var i = 0; i < domains.length; i++) {
                        if (xHost == domains[i]) {
                            return true;
                        }
                    }
                }
            } else {
                return false;
            }
            return false;
        }

        function wt_getDomain(l) {
            if (typeof (l) != "string") {
                return '';
            }
            l = wt_unescape(l);
            var rx = new RegExp(location.protocol + '/' + '/', 'i');
            l = l.replace(rx, '');
            var rx = new RegExp('^(?:[^\/]+:\/\/)?([^\/:]+)', 'g');
            l = l.match(rx);
            if (l[0]) {
                return l[0].toLowerCase();
            }
            return '';
        }

        if (typeof (time_start) == "number" && typeof (webtrekk.contentId) == "string" && !document.layers) {
            var time_stop = (new Date()).getTime();
            wt_registerEvent(window, "load", wt_ttonload);
        }
        function wt_ttonload() {
            if (typeof (time_start) == "number") {
                wt_t1 = time_stop - time_start;
                var time_stop2 = new Date().getTime();
                wt_t2 = time_stop2 - time_start;
                wt_send();
                time_start = "";
                wt_t1 = "";
                wt_t2 = "";
            }
        }

        if (webtrekk.mediaCode) {
            var m = webtrekk.mediaCode.split(";");
            var v = '';
            if (typeof (webtrekk.mediaCodeValue) == 'string') {
                v = webtrekk.mediaCodeValue.split(";");
            }
            wt_mcvalue = "";
            for (var i = 0; i < m.length; i++) {
                if (wt_mcvalue != "") wt_mcvalue += "|";
                if (wt_typeof(v[i]) && v[i] != '') {
                    if (typeof (webtrekk.mediaCodeCookie) == 'string' && webtrekk.mediaCodeCookie != '') {
                        if (wt_getCookie('wt_' + m[i].toLowerCase() + v[i].toLowerCase()) == '') {
                            wt_mcvalue += v[i];
                        } else {
                            webtrekk.mediaCode = "ignore";
                            wt_mcvalue = "1";
                        }
                        var tmp_lt = '';
                        if (webtrekk.mediaCodeCookie == 'eid') {
                            tmp_lt = 60 * 30 * 24 * 60;
                        }
                        wt_setCookie('wt_' + m[i].toLowerCase() + v[i].toLowerCase(), 1, tmp_lt);
                    } else {
                        wt_mcvalue += v[i];
                    }
                } else {
                    if (typeof (webtrekk.mediaCodeCookie) == 'string' && webtrekk.mediaCodeCookie != '') {
                        if (wt_getCookie('wt_' + m[i].toLowerCase() + wt_allUrlParam(m[i], "").toLowerCase()) == '') {
                            wt_mcvalue += wt_allUrlParam(m[i], " ");
                        } else {
                            webtrekk.mediaCode = "ignore";
                            wt_mcvalue = "1";
                        }
                        var tmp_lt = '';
                        if (webtrekk.mediaCodeCookie == 'eid') {
                            tmp_lt = 60 * 30 * 24 * 60;
                        }
                        wt_setCookie('wt_' + m[i].toLowerCase() + wt_allUrlParam(m[i], "").toLowerCase(), 1, tmp_lt);
                    } else {
                        wt_mcvalue += wt_allUrlParam(m[i], " ");
                    }
                }
            }
        }
        wt_tmp = wt_allUrlParam("wt_kw", "");
        if (wt_tmp != "") webtrekk.keyword = wt_tmp;
        var wt_heatmap_on = (wt_href().indexOf("wt_heatmap=1") >= 0);
        if (typeof (webtrekk.heatmap) != "undefined" && webtrekk.heatmap == "1" && !wt_heatmap_on) {
            wt_registerEvent(window, "load", wt_hminstall);
        }
        function wt_hminstall() {
            wt_registerEvent(document, "mousedown", wt_recordClick);
        }

        function wt_recordClick(e) {
            if (typeof (webtrekk.heatmapRefpoint) == "undefined" || webtrekk.heatmapRefpoint == '') {
                webtrekk.heatmapRefpoint = 'wt_refpoint';
            }
            var isOpera = (navigator.userAgent.indexOf('Opera') != -1);
            var isIE = (!isOpera && navigator.userAgent.indexOf('MSIE') != -1);
            var pos = {
                left: -1,
                top: -1
            };
            if (document.getElementById(webtrekk.heatmapRefpoint)) {
                var obj = document.getElementById(webtrekk.heatmapRefpoint);
                if (wt_typeof(obj.offsetLeft)) {
                    while (obj) {
                        pos.left += obj.offsetLeft;
                        pos.top += obj.offsetTop;
                        obj = obj.offsetParent;
                    }
                }
            }
            var posx = 0;
            var posy = 0;
            if (!e) {
                var e = window.event;
            }
            if (e.pageX || e.pageY) {
                posx = e.pageX;
                posy = e.pageY;
            } else if (e.clientX || e.clientY) {
                posx = e.clientX;
                posy = e.clientY;
                if (isIE) {
                    if (document.body.scrollLeft > 0 || document.body.scrollTop > 0) {
                        posx += document.body.scrollLeft;
                        posy += document.body.scrollTop;
                    } else if (document.documentElement.scrollLeft > 0 || document.documentElement.scrollTop > 0) {
                        posx += document.documentElement.scrollLeft;
                        posy += document.documentElement.scrollTop;
                    }
                }
            }
            var width1 = 0;
            if (isIE) {
                width1 = document.body.clientWidth;
            } else {
                width1 = self.innerWidth - 16;
            }
            var sendPixel = true;
            if (posx >= width1 || wt_sentFullPixel != 1) {
                sendPixel = false;
            }
            if ((pos.top >= 0 || pos.left >= 0) && posx > pos.left && posy > pos.top) {
                posx = '-' + (posx - pos.left);
                posy = '-' + (posy - pos.top);
            }
            if (sendPixel) wt_quicksend(wt_escape(webtrekk.contentId.split(";")[0]) + "," + posx + "," + posy, '', "hm.pl");
        }

        function wt_heatmap0() {
            if (typeof (wt_heatmap) != "undefined") {
                window.setTimeout("wt_heatmap()", 1000);
            } else {
                if (typeof (wt_heatmap_retry) == "undefined") wt_heatmap_retry = 0;
                wt_heatmap_retry++;
                if (wt_heatmap_retry < 60) window.setTimeout("wt_heatmap0()", 1000);
            }
        }

        if (wt_href().indexOf("wt_heatmap=0") >= 0) {
            wt_heatmap_on = false;
        }
        if (wt_heatmap_on) {
            if (typeof (webtrekk.reporturl) == "undefined" || webtrekk.reporturl == '') {
                webtrekk.reporturl = 'report2.webtrekk.de/cgi-bin/wt';
            }
            if (wt_include(location.protocol + "//" + webtrekk.reporturl + "/heatmap.pl?wt_contentId=" + wt_escape(webtrekk.contentId.split(";")[0]) + "&x=" + new Date().getTime() + wt_encoding()))
                if (navigator.userAgent.indexOf('MSIE 6') != -1 && navigator.userAgent.indexOf('Windows NT 5.0') != -1) {
                    alert("Click OK to start heatmap.");
                }
            wt_registerEvent(window, "load", wt_heatmap0);
        }
        function wt_overlay0() {
            if (typeof (wt_overlay) != "undefined") wt_overlay();
            else {
                if (typeof (wt_overlay_retry) == "undefined") wt_overlay_retry = 0;
                wt_overlay_retry++;
                if (wt_overlay_retry < 60) window.setTimeout("wt_overlay0()", 1000);
            }
        }

        var wt_overlay_on = (wt_href().indexOf("wt_overlay=1") >= 0 || document.cookie.indexOf("wt_overlay=1") >= 0);
        if (wt_href().indexOf("wt_overlay=0") >= 0) {
            wt_overlay_on = false;
            document.cookie = "wt_overlay=0; expires=Thu, 01-Jan-70 00:00:01 GMT;";
        }
        if (wt_overlay_on) {
            document.cookie = "wt_overlay=1";
            if (typeof (webtrekk.reporturl) == "undefined" || webtrekk.reporturl == '') {
                webtrekk.reporturl = 'report2.webtrekk.de/cgi-bin/wt';
            }
            if (wt_include(location.protocol + "//" + webtrekk.reporturl + "/overlay.pl?wt_contentId=" + wt_escape(webtrekk.contentId.split(";")[0]) + "&x=" + new Date().getTime() + wt_encoding())) wt_registerEvent(window, "load", wt_overlay0);
        }
        wt_optOut = wt_getCookie("webtrekkOptOut");
        if (wt_optOut) {
            wt_deactivatePixel = true;
        }
        if (wt_typeof(webtrekk.pixelSampling) && webtrekk.pixelSampling != '' && !wt_optOut) {
            wt_pixelSampling();
        }
        function wt_1stParty() {
            wt_cookie_one = false;
            wt_cookie_sid = wt_getCookie("wt_sid");
            wt_cookie_l_v = wt_getCookie("wt_l_v");
            wt_cookie_eid = wt_getCookie("wt_eid");
            if (!webtrekk.cookieEidTimeout) {
                webtrekk.cookieEidTimeout = 60;
            }
            if (!webtrekk.cookieSidTimeout) {
                webtrekk.cookieSidTimeout = 30;
            }
            var tmp = parseInt(wt_cookie_l_v);
            var tmp2 = Math.floor(new Date().getTime() / 1000);
            if (tmp > 0 && (tmp + webtrekk.cookieSidTimeout * 60) < tmp2) {
                wt_cookie_sid = "";
            }
            if (!wt_cookie_sid) {
                wt_cookie_sid = wt_sid();
                wt_cookie_one = true;
            }
            if (!wt_cookie_eid) {
                wt_cookie_eid = wt_cookie_sid;
                wt_setCookie("wt_eid", wt_cookie_eid, webtrekk.cookieEidTimeout * 30 * 24 * 60);
            }
            wt_cookie_l_v = tmp2;
            wt_setCookie("wt_l_v", wt_cookie_l_v);
            wt_setCookie("wt_sid", wt_cookie_sid);
        }

        if (webtrekk.cookie == "1" && !wt_optOut) {
            wt_1stParty();
            if (wt_typeof(webtrekk.cookieFlash) && webtrekk.cookieFlash == "1") {
                if (!webtrekk.pixelSampling) {
                    webtrekk.pixelSampling = "";
                }
                wt_flashCookie("wt_flashdiv", wt_cookie_sid, (webtrekk.cookieSidTimeout * 60), wt_cookie_eid, (webtrekk.cookieEidTimeout * 30 * 24 * 60), wt_cookie_l_v, wt_sampleValue, webtrekk.pixelSampling);
                wt_1stPartyCheck();
            } else {
                wt_1stPartySet = "1";
            }
        }
        function wt_1stPartyCheck() {
            if (!wt_typeof(webtrekk.cookieFlashTimeout) || webtrekk.cookieFlashTimeout == '') {
                webtrekk.cookieFlashTimeout = 1000;
            }
            if (wt_isFlashCookie != "1" && wt_1st_party_checked != "1") {
                wt_1st_party_checked = "1";
                window.setTimeout("wt_1stPartyCheck()", webtrekk.cookieFlashTimeout);
            } else if (wt_1st_party_checked == "1" && wt_isFlashCookie == "1") {

            } else {
                wt_1stPartySet = "1";
            }
        }

        function wt_pixelSampling() {
            var wt_cookie_sampling = wt_getCookie("wt_sample");
            if (!wt_cookie_sampling || wt_indexOf(wt_cookie_sampling, "|" + webtrekk.pixelSampling) == -1) {
                wt_cookie_sampling = "0|" + webtrekk.pixelSampling;
                if (Math && Math.random && parseInt(Math.random() * webtrekk.pixelSampling) == 0) {
                    wt_cookie_sampling = "1|" + webtrekk.pixelSampling;
                }
                if (!webtrekk.cookieEidTimeout) {
                    webtrekk.cookieEidTimeout = 60;
                }
                wt_setCookie("wt_sample", wt_cookie_sampling, webtrekk.cookieEidTimeout * 30 * 24 * 60);
                wt_cookie_sampling = wt_getCookie("wt_sample");
            }
            wt_sampleValue = "1";
            if (wt_indexOf(wt_cookie_sampling, "1|") == -1) {
                wt_deactivatePixel = true;
                wt_sampleValue = "0";
            }
        }

        function wt_sendinfo(p, mode, ep) {
            if (wt_typeof(webtrekk.cookieFlash) && webtrekk.cookieFlash == "1" && webtrekk.cookie == "1") {
                if ((typeof (time_start) != "number" && (webtrekk.contentId != "" || p != "")) || document.layers) {
                    if (wt_1stPartySet == "1") {
                        wt_send(p, mode, ep);
                    } else {
                        if (!wt_typeof(p)) {
                            p = '';
                        }
                        if (!wt_typeof(mode)) {
                            mode = '';
                        }
                        if (!wt_typeof(ep)) {
                            ep = '';
                        }
                        window.setTimeout("wt_sendinfo('" + p + "','" + mode + "','" + ep + "')", 20);
                    }
                }
            } else {
                if ((typeof (time_start) != "number" && (webtrekk.contentId != "" || p != "")) || document.layers) wt_send(p, mode, ep);
            }
        }

        function wt_quicksend(baseparams, params, script) {
            if (!webtrekk.trackDomain || !webtrekk.trackId || wt_deactivatePixel) {
                return;
            }
            if (!script) script = "wt.pl";
            if (webtrekk.cookie == "1" || wt_1stPartySet == "1") {
                params = "&sid=" + wt_cookie_sid + "&l_v=" + wt_cookie_l_v + "&eid=" + wt_cookie_eid + "&one=" + (wt_cookie_one ? "1" : "0") + params;
            }
            if (webtrekk.cookie != "1" && wt_1stPartySet != "1" && (wt_typeof(webtrekk.cookieEidTimeout) || wt_typeof(webtrekk.cookieSidTimeout))) {
                if (wt_typeof(webtrekk.cookieEidTimeout) && webtrekk.cookieEidTimeout != '') {
                    params = "&cet=" + webtrekk.cookieEidTimeout + params;
                }
                if (wt_typeof(webtrekk.cookieSidTimeout) && webtrekk.cookieSidTimeout != '') {
                    params = "&cst=" + webtrekk.cookieSidTimeout + params;
                }
            }
            if (webtrekk.pixelSampling > 0) {
                params += "&ps=" + webtrekk.pixelSampling;
            }
            params = "&tz=" + wt_getTimezone() + params;
            var protocol = (location.protocol == "https:" ? "https:" : "http:");
            if (webtrekk.forceHTTPS) {
                protocol = "https:";
            }
            var wt_url = protocol + "//" + webtrekk.trackDomain + "/" + webtrekk.trackId + "/" + script + "?p=" + wt_version + "," + baseparams + params;
            if (document.images) {
                if (!wt_typeof(wt_i)) {
                    var wt_i = [];
                }
                var ii = wt_i.length;
                wt_i[ii] = new Image();
                wt_i[ii].src = wt_url;
                wt_i[ii].onload = function () {
                };
            } else {
                document.write("<img src='" + wt_url + "' height='1' width='1'>");
            }
            if (script != 'hm.pl') {
                wt_cookie_one = false;
                wt_sentFullPixel = 1;
            }
        }

        function wt_baseparams() {
            var wt_c = screen.width + "x" + screen.height + "," + (navigator.appName != 'Netscape' ? screen.colorDepth : screen.pixelDepth) + ",";
            wt_c += ((navigator.cookieEnabled == true) ? "1," : ((navigator.cookieEnabled == false) ? "0," : ((document.cookie.indexOf("=") != -1) ? "1," : "0,")));
            wt_c += new Date().getTime() + ",";
            var wt_ref = 0;
            if (webtrekk.framesetReferrer) {
                wt_ref = wt_escape(webtrekk.framesetReferrer);
            } else {
                if (document.referrer.length > 0) {
                    wt_ref = wt_escape(document.referrer);
                }
            }
            if (wt_sentFullPixel == 1) {
                wt_c += "2";
            } else if (!wt_isOwnDomain(wt_ref)) {
                wt_c += wt_ref;
            } else if (wt_isOwnDomain(wt_ref)) {
                wt_c += "1";
            } else {
                wt_c += wt_ref;
            }
            var h = 0;
            if (!document.layers && document.getElementById) {
                eval("try {h = top.window.innerHeight;}catch(e){};");
            } else {
                h = top.window.innerHeight;
            }
            if (!h) eval("try {h = top.document.documentElement.clientHeight;}catch(e){};");
            if (!h) eval("try {h = top.document.body.clientHeight;}catch(e){};");
            var w = 0;
            if (!document.layers && document.getElementById) {
                eval("try {w = top.window.innerWidth;}catch(e){};");
            } else {
                w = top.window.innerWidth;
            }
            if (!w) eval("try {w = top.document.body.clientWidth;}catch(e){};");
            if (typeof (w) == 'undefined') w = -1;
            if (typeof (h) == 'undefined') h = -1;
            wt_c += "," + w + "x" + h;
            wt_c += "," + (navigator.javaEnabled() ? "1" : "0");
            return wt_c;
        }

        function wt_plugInArray(arr, val) {
            if (typeof (arr) != 'object') return false;
            for (var i = 0; i < arr.length; i++) {
                var reg = new RegExp(arr[i].toLowerCase(), 'g');
                if (val.toLowerCase().search(reg) != -1) return arr[i];
            }
            return false;
        }

        function wt_send(p, mode, ep) {
            if (mode == "link") {
                wt_linktrack_p = p;
                webtrekk.linkTrack = "manual";
                wt_ep = ep;
                wt_registerEvent(window, (wt_browserNameIE && wt_typeof(window.onbeforeunload)) ? "beforeunload" : "unload", wt_unload);
                return;
            }
            if (mode == "click") {
                wt_linktrack_p = p;
                wt_ep = ep;
                wt_unload('noForm');
                return;
            }
            var wt_content = (p ? p : webtrekk.contentId);
            if (!wt_content) wt_content = "no_content";
            var wt_s_base = wt_escape(wt_content) + ",1,";
            wt_s_base += wt_baseparams();
            var wt_s = wt_encoding();
            var wt_la = "";
            if (typeof (navigator.language) == "string") {
                wt_la = navigator.language;
            } else if (typeof (navigator.userLanguage) == "string") {
                wt_la = navigator.userLanguage;
            }
            if (typeof (webtrekk.plugins) != 'string' || webtrekk.plugins == '') {
                webtrekk.plugins = ['Adobe Acrobat', 'Windows Media Player', 'Shockwave Flash', 'RealPlayer', 'QuickTime', 'Java', 'Silverlight'];
            } else {
                webtrekk.plugins = webtrekk.plugins.split(';');
            }
            var wt_len = navigator.plugins.length,
                wt_np = "";
            if (wt_len > 0) {
                var wt_plugs = Array();
                var wt_np = '';
                for (var i = 0; i < wt_len; i++) {
                    if (navigator.plugins && navigator.appName != 'Microsoft Internet Explorer') {
                        if (navigator.plugins[i].name == "Shockwave Flash") {
                            wt_np = navigator.plugins[i].description;
                        } else {
                            wt_np = navigator.plugins[i].name;
                        }
                        var wt_plug = wt_plugInArray(webtrekk.plugins, wt_np);
                        if (wt_plug && !wt_plugInArray(wt_plugs, wt_plug)) {
                            wt_plugs.push(wt_plug);
                        }
                    }
                }
                wt_np = wt_plugs.join("|");
            }
            if (typeof (ep) == "string" && ep != "") {
                ep = ep.split(/;/);
                for (var z = 0; z < ep.length; z++) {
                    if (wt_typeof(ep[z])) {
                        wtep = ep[z].split(/=/);
                        if (wt_checkSC('custom')) {
                            wtep[1] = wt_decrypt(wtep[1]);
                        }
                        wtep[1] = wt_escape(wtep[1]);
                        wt_s += '&' + wtep[0] + '=' + wtep[1];
                    }
                }
            } else {
                var wt_cp = '';
                if (typeof (webtrekk.customParameter) == 'object') {
                    for (var z = 0; z < webtrekk.customParameter.length; z++) {
                        if (wt_typeof(webtrekk.customParameter[z]) && typeof (webtrekk.customParameter[z]) == 'string' && webtrekk.customParameter[z] != '') {
                            if (wt_checkSC('custom')) {
                                webtrekk.customParameter[z] = wt_decrypt(webtrekk.customParameter[z]);
                            }
                            wt_cp += '&cp' + z + '=' + wt_escape(webtrekk.customParameter[z]);
                        }
                    }
                }
                var wt_csp = '';
                if (typeof (webtrekk.customSessionParameter) == 'object') {
                    for (var z = 0; z < webtrekk.customSessionParameter.length; z++) {
                        if (wt_typeof(webtrekk.customSessionParameter[z]) && typeof (webtrekk.customSessionParameter[z]) == 'string' && webtrekk.customSessionParameter[z] != '') {
                            if (wt_checkSC('custom')) {
                                webtrekk.customSessionParameter[z] = wt_decrypt(webtrekk.customSessionParameter[z]);
                            }
                            wt_csp += '&cs' + z + '=' + wt_escape(webtrekk.customSessionParameter[z]);
                        }
                    }
                }
                var wt_ce = '';
                if (typeof (webtrekk.customTimeParameter) == 'object') {
                    for (var z = 0; z < webtrekk.customTimeParameter.length; z++) {
                        if (wt_typeof(webtrekk.customTimeParameter[z]) && typeof (webtrekk.customTimeParameter[z]) == 'string' && webtrekk.customTimeParameter[z] != '') {
                            if (wt_checkSC('custom')) {
                                webtrekk.customTimeParameter[z] = wt_decrypt(webtrekk.customTimeParameter[z]);
                            }
                            wt_ce += '&ce' + z + '=' + wt_escape(webtrekk.customTimeParameter[z]);
                        }
                    }
                }
                var wt_cc = '';
                if (typeof (webtrekk.customCampaignParameter) == 'object') {
                    for (var z = 0; z < webtrekk.customCampaignParameter.length; z++) {
                        if (wt_typeof(webtrekk.customCampaignParameter[z]) && typeof (webtrekk.customCampaignParameter[z]) == 'string' && webtrekk.customCampaignParameter[z] != '') {
                            if (wt_checkSC('custom')) {
                                webtrekk.customCampaignParameter[z] = wt_decrypt(webtrekk.customCampaignParameter[z]);
                            }
                            wt_cc += '&cc' + z + '=' + wt_escape(webtrekk.customCampaignParameter[z]);
                        }
                    }
                }
                var wt_cm = '';
                if (typeof (webtrekk.customEcommerceParameter) == 'object') {
                    for (var z = 0; z < webtrekk.customEcommerceParameter.length; z++) {
                        if (wt_typeof(webtrekk.customEcommerceParameter[z]) && typeof (webtrekk.customEcommerceParameter[z]) == 'string' && webtrekk.customEcommerceParameter[z] != '') {
                            if (wt_checkSC('custom')) {
                                webtrekk.customEcommerceParameter[z] = wt_decrypt(webtrekk.customEcommerceParameter[z]);
                            }
                            wt_cm += '&cb' + z + '=' + wt_escape(webtrekk.customEcommerceParameter[z]);
                        }
                    }
                }
                if (webtrekk.orderValue) {
                    if (wt_checkSC('order')) {
                        wt_s += "&ov=" + wt_escape(wt_decrypt(webtrekk.orderValue));
                    } else {
                        wt_s += "&ov=" + wt_escape(webtrekk.orderValue);
                    }
                }
                if (webtrekk.orderCurrency) {
                    if (wt_checkSC('order')) {
                        wt_s += "&cr=" + wt_escape(wt_decrypt(webtrekk.orderCurrency));
                    } else {
                        wt_s += "&cr=" + wt_escape(webtrekk.orderCurrency);
                    }
                }
                if (webtrekk.orderId) wt_s += "&oi=" + wt_escape(webtrekk.orderId);
                if (webtrekk.product) {
                    wt_s += "&ba=" + wt_escape(webtrekk.product);
                    if (webtrekk.productCost) wt_s += "&co=" + wt_escape(webtrekk.productCost);
                    if (webtrekk.productQuantity) wt_s += "&qn=" + wt_escape(webtrekk.productQuantity);
                    if (typeof (webtrekk.productCategory) == 'object') {
                        for (var bcId in webtrekk.productCategory) {
                            if (typeof (webtrekk.productCategory[bcId]) == 'string' && webtrekk.productCategory[bcId] != '') {
                                wt_s += "&ca" + bcId + "=" + wt_escape(webtrekk.productCategory[bcId]);
                            }
                        }
                    }
                    if (typeof (webtrekk.productParameter) == 'object' && wt_cm == "") {
                        for (var bp in webtrekk.productParameter) {
                            if (typeof (webtrekk.productParameter[bp]) == 'string' && webtrekk.productParameter[bp] != '') {
                                wt_s += "&cb" + bp + "=" + wt_escape(webtrekk.productParameter[bp]);
                            }
                        }
                    }
                    if (webtrekk.productStatus) wt_s += "&st=" + wt_escape(webtrekk.productStatus);
                }
                if (webtrekk.customerId) wt_s += "&cd=" + wt_escape(webtrekk.customerId);
                if (wt_t1) wt_s += "&t1=" + wt_escape(wt_t1);
                if (wt_t2) wt_s += "&t2=" + wt_escape(wt_t2);
                if (wt_la) wt_s += "&la=" + wt_escape(wt_la);
                if (typeof (webtrekk.contentGroup) == 'object') {
                    if (typeof (webtrekk.contentGroup[0]) == 'string') {
                        if (webtrekk.contentGroup[0] != '') {
                            wt_s += "&cg=" + wt_escape(webtrekk.contentGroup[0]);
                        }
                    } else {
                        for (var cgId in webtrekk.contentGroup) {
                            if (typeof (webtrekk.contentGroup[cgId]) == 'string' && webtrekk.contentGroup[cgId] != '') {
                                wt_s += "&cg" + cgId + "=" + wt_escape(webtrekk.contentGroup[cgId]);
                            }
                        }
                    }
                }
                if (wt_mcvalue) wt_s += "&mcv=" + wt_escape(wt_mcvalue);
                if (wt_length(wt_mcvalue)) {
                    wt_s += "&mc=" + webtrekk.mediaCode;
                    wt_s += "&mcd=" + wt_location().hostname;
                }
                if (webtrekk.trackingSwitchMediaCode) {
                    wt_s += "&tmc=" + wt_escape(webtrekk.trackingSwitchMediaCode);
                }
                if (webtrekk.trackingSwitchMediaCodeValue) {
                    wt_s += "&tmcv=" + wt_escape(webtrekk.trackingSwitchMediaCodeValue);
                }
                if (webtrekk.parameter) wt_s += "&pa=" + wt_escape(wt_maxlen(webtrekk.parameter, 255));
                if (webtrekk.keyword) wt_s += "&kw=" + wt_escape(wt_maxlen(webtrekk.keyword, 255));
                if (webtrekk.internalSearch) wt_s += "&is=" + wt_escape(wt_maxlen(webtrekk.internalSearch, 255));
                if (wt_cp) wt_s += wt_cp;
                if (wt_cc) wt_s += wt_cc;
                if (wt_cm) wt_s += wt_cm;
                if (wt_ce) wt_s += wt_ce;
                if (wt_csp) wt_s += wt_csp;
                if (wt_typeof(webtrekk.customSid) && webtrekk.customSid != '') wt_s += "&csid=" + webtrekk.customSid;
                if (wt_typeof(webtrekk.customEid) && webtrekk.customEid != '') wt_s += "&ceid=" + webtrekk.customEid;
                if (wt_typeof(webtrekk.xwtip) && webtrekk.xwtip != '') wt_s += "&X-WT-IP=" + wt_escape(webtrekk.xwtip);
                if (wt_typeof(webtrekk.xwtua) && webtrekk.xwtua != '') wt_s += "&X-WT-UA=" + wt_escape(webtrekk.xwtua);
                if (wt_typeof(webtrekk.xwtrq) && webtrekk.xwtrq != '') wt_s += "&X-WT-RQ=" + wt_escape(webtrekk.xwtrq);
            }
            if (webtrekk.cookie == "1") {
                if (wt_cookie_one) wt_s += "&np=" + wt_escape(wt_np);
            } else {
                wt_s += "&np=" + wt_escape(wt_np);
            }
            wt_quicksend(wt_s_base, wt_s);
        }

        if (webtrekk.sendinfo && webtrekk.sendinfo == '1') {
            wt_sendinfo();
        }
    }
})();

/* Modernizr 2.6.2 (Custom Build) | MIT & BSD
 * Build: http://modernizr.com/download/#-localstorage-sessionstorage-shiv-cssclasses-load
 */
;



window.Modernizr = (function( window, document, undefined ) {

    var version = '2.6.2',

    Modernizr = {},

    enableClasses = true,

    docElement = document.documentElement,

    mod = 'modernizr',
    modElem = document.createElement(mod),
    mStyle = modElem.style,

    inputElem  ,


    toString = {}.toString,    tests = {},
    inputs = {},
    attrs = {},

    classes = [],

    slice = classes.slice,

    featureName,



    _hasOwnProperty = ({}).hasOwnProperty, hasOwnProp;

    if ( !is(_hasOwnProperty, 'undefined') && !is(_hasOwnProperty.call, 'undefined') ) {
      hasOwnProp = function (object, property) {
        return _hasOwnProperty.call(object, property);
      };
    }
    else {
      hasOwnProp = function (object, property) { 
        return ((property in object) && is(object.constructor.prototype[property], 'undefined'));
      };
    }


    if (!Function.prototype.bind) {
      Function.prototype.bind = function bind(that) {

        var target = this;

        if (typeof target != "function") {
            throw new TypeError();
        }

        var args = slice.call(arguments, 1),
            bound = function () {

            if (this instanceof bound) {

              var F = function(){};
              F.prototype = target.prototype;
              var self = new F();

              var result = target.apply(
                  self,
                  args.concat(slice.call(arguments))
              );
              if (Object(result) === result) {
                  return result;
              }
              return self;

            } else {

              return target.apply(
                  that,
                  args.concat(slice.call(arguments))
              );

            }

        };

        return bound;
      };
    }

    function setCss( str ) {
        mStyle.cssText = str;
    }

    function setCssAll( str1, str2 ) {
        return setCss(prefixes.join(str1 + ';') + ( str2 || '' ));
    }

    function is( obj, type ) {
        return typeof obj === type;
    }

    function contains( str, substr ) {
        return !!~('' + str).indexOf(substr);
    }


    function testDOMProps( props, obj, elem ) {
        for ( var i in props ) {
            var item = obj[props[i]];
            if ( item !== undefined) {

                            if (elem === false) return props[i];

                            if (is(item, 'function')){
                                return item.bind(elem || obj);
                }

                            return item;
            }
        }
        return false;
    }



    tests['localstorage'] = function() {
        try {
            localStorage.setItem(mod, mod);
            localStorage.removeItem(mod);
            return true;
        } catch(e) {
            return false;
        }
    };

    tests['sessionstorage'] = function() {
        try {
            sessionStorage.setItem(mod, mod);
            sessionStorage.removeItem(mod);
            return true;
        } catch(e) {
            return false;
        }
    };

    for ( var feature in tests ) {
        if ( hasOwnProp(tests, feature) ) {
                                    featureName  = feature.toLowerCase();
            Modernizr[featureName] = tests[feature]();

            classes.push((Modernizr[featureName] ? '' : 'no-') + featureName);
        }
    }



     Modernizr.addTest = function ( feature, test ) {
       if ( typeof feature == 'object' ) {
         for ( var key in feature ) {
           if ( hasOwnProp( feature, key ) ) {
             Modernizr.addTest( key, feature[ key ] );
           }
         }
       } else {

         feature = feature.toLowerCase();

         if ( Modernizr[feature] !== undefined ) {
                                              return Modernizr;
         }

         test = typeof test == 'function' ? test() : test;

         if (typeof enableClasses !== "undefined" && enableClasses) {
           docElement.className += ' ' + (test ? '' : 'no-') + feature;
         }
         Modernizr[feature] = test;

       }

       return Modernizr; 
     };


    setCss('');
    modElem = inputElem = null;

    ;(function(window, document) {
        var options = window.html5 || {};

        var reSkip = /^<|^(?:button|map|select|textarea|object|iframe|option|optgroup)$/i;

        var saveClones = /^(?:a|b|code|div|fieldset|h1|h2|h3|h4|h5|h6|i|label|li|ol|p|q|span|strong|style|table|tbody|td|th|tr|ul)$/i;

        var supportsHtml5Styles;

        var expando = '_html5shiv';

        var expanID = 0;

        var expandoData = {};

        var supportsUnknownElements;

      (function() {
        try {
            var a = document.createElement('a');
            a.innerHTML = '<xyz></xyz>';
                    supportsHtml5Styles = ('hidden' in a);

            supportsUnknownElements = a.childNodes.length == 1 || (function() {
                        (document.createElement)('a');
              var frag = document.createDocumentFragment();
              return (
                typeof frag.cloneNode == 'undefined' ||
                typeof frag.createDocumentFragment == 'undefined' ||
                typeof frag.createElement == 'undefined'
              );
            }());
        } catch(e) {
          supportsHtml5Styles = true;
          supportsUnknownElements = true;
        }

      }());        function addStyleSheet(ownerDocument, cssText) {
        var p = ownerDocument.createElement('p'),
            parent = ownerDocument.getElementsByTagName('head')[0] || ownerDocument.documentElement;

        p.innerHTML = 'x<style>' + cssText + '</style>';
        return parent.insertBefore(p.lastChild, parent.firstChild);
      }

        function getElements() {
        var elements = html5.elements;
        return typeof elements == 'string' ? elements.split(' ') : elements;
      }

          function getExpandoData(ownerDocument) {
        var data = expandoData[ownerDocument[expando]];
        if (!data) {
            data = {};
            expanID++;
            ownerDocument[expando] = expanID;
            expandoData[expanID] = data;
        }
        return data;
      }

        function createElement(nodeName, ownerDocument, data){
        if (!ownerDocument) {
            ownerDocument = document;
        }
        if(supportsUnknownElements){
            return ownerDocument.createElement(nodeName);
        }
        if (!data) {
            data = getExpandoData(ownerDocument);
        }
        var node;

        if (data.cache[nodeName]) {
            node = data.cache[nodeName].cloneNode();
        } else if (saveClones.test(nodeName)) {
            node = (data.cache[nodeName] = data.createElem(nodeName)).cloneNode();
        } else {
            node = data.createElem(nodeName);
        }

                                    return node.canHaveChildren && !reSkip.test(nodeName) ? data.frag.appendChild(node) : node;
      }

        function createDocumentFragment(ownerDocument, data){
        if (!ownerDocument) {
            ownerDocument = document;
        }
        if(supportsUnknownElements){
            return ownerDocument.createDocumentFragment();
        }
        data = data || getExpandoData(ownerDocument);
        var clone = data.frag.cloneNode(),
            i = 0,
            elems = getElements(),
            l = elems.length;
        for(;i<l;i++){
            clone.createElement(elems[i]);
        }
        return clone;
      }

        function shivMethods(ownerDocument, data) {
        if (!data.cache) {
            data.cache = {};
            data.createElem = ownerDocument.createElement;
            data.createFrag = ownerDocument.createDocumentFragment;
            data.frag = data.createFrag();
        }


        ownerDocument.createElement = function(nodeName) {
                if (!html5.shivMethods) {
              return data.createElem(nodeName);
          }
          return createElement(nodeName, ownerDocument, data);
        };

        ownerDocument.createDocumentFragment = Function('h,f', 'return function(){' +
          'var n=f.cloneNode(),c=n.createElement;' +
          'h.shivMethods&&(' +
                    getElements().join().replace(/\w+/g, function(nodeName) {
              data.createElem(nodeName);
              data.frag.createElement(nodeName);
              return 'c("' + nodeName + '")';
            }) +
          ');return n}'
        )(html5, data.frag);
      }        function shivDocument(ownerDocument) {
        if (!ownerDocument) {
            ownerDocument = document;
        }
        var data = getExpandoData(ownerDocument);

        if (html5.shivCSS && !supportsHtml5Styles && !data.hasCSS) {
          data.hasCSS = !!addStyleSheet(ownerDocument,
                    'article,aside,figcaption,figure,footer,header,hgroup,nav,section{display:block}' +
                    'mark{background:#FF0;color:#000}'
          );
        }
        if (!supportsUnknownElements) {
          shivMethods(ownerDocument, data);
        }
        return ownerDocument;
      }        var html5 = {

            'elements': options.elements || 'abbr article aside audio bdi canvas data datalist details figcaption figure footer header hgroup mark meter nav output progress section summary time video',

            'shivCSS': (options.shivCSS !== false),

            'supportsUnknownElements': supportsUnknownElements,

            'shivMethods': (options.shivMethods !== false),

            'type': 'default',

            'shivDocument': shivDocument,

            createElement: createElement,

            createDocumentFragment: createDocumentFragment
      };        window.html5 = html5;

        shivDocument(document);

    }(this, document));

    Modernizr._version      = version;

    docElement.className = docElement.className.replace(/(^|\s)no-js(\s|$)/, '$1$2') +

                                                    (enableClasses ? ' js ' + classes.join(' ') : '');

    return Modernizr;

})(this, this.document);
/*yepnope1.5.4|WTFPL*/
(function(a,b,c){function d(a){return"[object Function]"==o.call(a)}function e(a){return"string"==typeof a}function f(){}function g(a){return!a||"loaded"==a||"complete"==a||"uninitialized"==a}function h(){var a=p.shift();q=1,a?a.t?m(function(){("c"==a.t?B.injectCss:B.injectJs)(a.s,0,a.a,a.x,a.e,1)},0):(a(),h()):q=0}function i(a,c,d,e,f,i,j){function k(b){if(!o&&g(l.readyState)&&(u.r=o=1,!q&&h(),l.onload=l.onreadystatechange=null,b)){"img"!=a&&m(function(){t.removeChild(l)},50);for(var d in y[c])y[c].hasOwnProperty(d)&&y[c][d].onload()}}var j=j||B.errorTimeout,l=b.createElement(a),o=0,r=0,u={t:d,s:c,e:f,a:i,x:j};1===y[c]&&(r=1,y[c]=[]),"object"==a?l.data=c:(l.src=c,l.type=a),l.width=l.height="0",l.onerror=l.onload=l.onreadystatechange=function(){k.call(this,r)},p.splice(e,0,u),"img"!=a&&(r||2===y[c]?(t.insertBefore(l,s?null:n),m(k,j)):y[c].push(l))}function j(a,b,c,d,f){return q=0,b=b||"j",e(a)?i("c"==b?v:u,a,b,this.i++,c,d,f):(p.splice(this.i++,0,a),1==p.length&&h()),this}function k(){var a=B;return a.loader={load:j,i:0},a}var l=b.documentElement,m=a.setTimeout,n=b.getElementsByTagName("script")[0],o={}.toString,p=[],q=0,r="MozAppearance"in l.style,s=r&&!!b.createRange().compareNode,t=s?l:n.parentNode,l=a.opera&&"[object Opera]"==o.call(a.opera),l=!!b.attachEvent&&!l,u=r?"object":l?"script":"img",v=l?"script":u,w=Array.isArray||function(a){return"[object Array]"==o.call(a)},x=[],y={},z={timeout:function(a,b){return b.length&&(a.timeout=b[0]),a}},A,B;B=function(a){function b(a){var a=a.split("!"),b=x.length,c=a.pop(),d=a.length,c={url:c,origUrl:c,prefixes:a},e,f,g;for(f=0;f<d;f++)g=a[f].split("="),(e=z[g.shift()])&&(c=e(c,g));for(f=0;f<b;f++)c=x[f](c);return c}function g(a,e,f,g,h){var i=b(a),j=i.autoCallback;i.url.split(".").pop().split("?").shift(),i.bypass||(e&&(e=d(e)?e:e[a]||e[g]||e[a.split("/").pop().split("?")[0]]),i.instead?i.instead(a,e,f,g,h):(y[i.url]?i.noexec=!0:y[i.url]=1,f.load(i.url,i.forceCSS||!i.forceJS&&"css"==i.url.split(".").pop().split("?").shift()?"c":c,i.noexec,i.attrs,i.timeout),(d(e)||d(j))&&f.load(function(){k(),e&&e(i.origUrl,h,g),j&&j(i.origUrl,h,g),y[i.url]=2})))}function h(a,b){function c(a,c){if(a){if(e(a))c||(j=function(){var a=[].slice.call(arguments);k.apply(this,a),l()}),g(a,j,b,0,h);else if(Object(a)===a)for(n in m=function(){var b=0,c;for(c in a)a.hasOwnProperty(c)&&b++;return b}(),a)a.hasOwnProperty(n)&&(!c&&!--m&&(d(j)?j=function(){var a=[].slice.call(arguments);k.apply(this,a),l()}:j[n]=function(a){return function(){var b=[].slice.call(arguments);a&&a.apply(this,b),l()}}(k[n])),g(a[n],j,b,n,h))}else!c&&l()}var h=!!a.test,i=a.load||a.both,j=a.callback||f,k=j,l=a.complete||f,m,n;c(h?a.yep:a.nope,!!i),i&&c(i)}var i,j,l=this.yepnope.loader;if(e(a))g(a,0,l,0);else if(w(a))for(i=0;i<a.length;i++)j=a[i],e(j)?g(j,0,l,0):w(j)?B(j):Object(j)===j&&h(j,l);else Object(a)===a&&h(a,l)},B.addPrefix=function(a,b){z[a]=b},B.addFilter=function(a){x.push(a)},B.errorTimeout=1e4,null==b.readyState&&b.addEventListener&&(b.readyState="loading",b.addEventListener("DOMContentLoaded",A=function(){b.removeEventListener("DOMContentLoaded",A,0),b.readyState="complete"},0)),a.yepnope=k(),a.yepnope.executeStack=h,a.yepnope.injectJs=function(a,c,d,e,i,j){var k=b.createElement("script"),l,o,e=e||B.errorTimeout;k.src=a;for(o in d)k.setAttribute(o,d[o]);c=j?h:c||f,k.onreadystatechange=k.onload=function(){!l&&g(k.readyState)&&(l=1,c(),k.onload=k.onreadystatechange=null)},m(function(){l||(l=1,c(1))},e),i?k.onload():n.parentNode.insertBefore(k,n)},a.yepnope.injectCss=function(a,c,d,e,g,i){var e=b.createElement("link"),j,c=i?h:c||f;e.href=a,e.rel="stylesheet",e.type="text/css";for(j in d)e.setAttribute(j,d[j]);g||(n.parentNode.insertBefore(e,n),m(c,0))}})(this,document);
Modernizr.load=function(){yepnope.apply(window,[].slice.call(arguments,0));};
;
(function() {

	/**
	 * A jQuery plugin to make stars fly around your home page.
	 * @function external:"jQuery.fn".isVisible
	 * @see {@link http://learn.jquery.com/plugins/|jQuery Plugins}
	 *
	 */
	$.fn.isVisible = function() {
		return $.expr.filters.visible(this[0]);
	};

	/**
	 * Uses internal $.serializeArray to get list of form elements which is consistent with $.serialize
	 *
	 * From version 2.0.0, $.serializeObject will stop converting [name] values to camelCase format. This is *consistent* with other serialize methods:
	 *  - $.serializeArray
	 *  - $.serialize
	 *  If you require camel casing, you can either download version 1.0.4 or map them yourself.
	 * @function external:"jQuery.fn".serializeObject
	 */
	$.fn.serializeObject = function() {
		"use strict";
		var result = {};
		var extend = function(i, element) {
			var node = result[element.name];

			// If node with same name exists already, need to convert it to an array as it
			// is a multi-value field (i.e., checkboxes)

			if ('undefined' !== typeof node && node !== null) {
				if ($.isArray(node)) {
					node.push(element.value);
				} else {
					result[element.name] = [node, element.value];
				}
			} else {
				if (element.value !== "") {
					result[element.name] = element.value;
				}
			}
		};

		$.each(this.serializeArray(), extend);
		return result;
	};


})();

(function () {


    /**
     * This class gets values from a properties files configured in the Configuration Service component.
     * 
     * 2016.10.14: Some properties are used in portal load time. To save time on this library load all properties are 
     * loaded in line and saved. Later all gets will read cache.
     * 
     * @exports core/configService
     *
     * @requires module:jquery
     * @requires module:core/dbesp-init
     */
    var configService = dbesp.configService?dbesp.configService:{};
    configService.paramCache=false; // is still not loaded
    configService.allInfo=false; // is still not loaded
    
    var rootURL = dbesp.contextRoot + "/rest/config";

    $.ajax({
        type: 'GET',
        contentType: 'application/json',
        url: rootURL,
        cache: false,
        async: false,
        success: function( /*Anything*/ data, /*String*/ textStatus, /*jqXHR*/ jqXHR ) {
            configService.paramCache=data.parameters;
            configService.allInfo=data;
            // refresh dbesp values user dependent set in custom-head.jsp, as sometimes jsp values are wrong (from other users)
            dbesp.loggedInUserId=data.loggedInUserId;
            dbesp.userGroupName=data.userGroupName;
            dbesp.sessionId=data.sessionId;
        },
        error: function(data){
        	dbesp.info('configService', 'call to /rest/config error: '+data);
        } 
    });
    

    /**
     * Gets all parameter of the specified application.
     * application files in configuration are "app_properties_"+application+".properties" files
     * @param {string} application
     * @param {function} onSuccess
     * @param {function} onError
     */
    configService.getApplication = function (application, onSuccess, onError) {
        if (application) {
            $.ajax({
                type: 'GET',
                contentType: 'text/plain',
                url: rootURL + "/application/" + application,
                dataType: "json",
                //data: parameter,
                cache: false,
                success: onSuccess,
                error: onError
            });
        } else {
            dbesp.log.error('configService:getApplication', 'application must be defined');
        }
    };

    /**
     * Gets the specified parameter value from the Configuration Service component
     * property name in configServices file must be "property."+parameter
     * @param {string} parameter
     * @param {function} onSuccess
     * @param {function} onError
     */
    configService.getParameter = function (parameter, onSuccess, onError) {
    	/*var value = configService.getParameterSynch(parameter);
		onSuccess(value);
		*/
       if (parameter) {
        	if (configService.paramCache) {
        		var parKey='property.'+parameter;
        		var parValue=configService.paramCache[parKey];
        		onSuccess(parValue);
        	} else {
                $.ajax({
                    type: 'GET',
                    contentType: 'text/plain',
                    url: rootURL + "/" + parameter,
                    dataType: "text",
                    //data: parameter,
                    cache: false,
                    success: onSuccess,
                    error: onError
                });
        	}
        } else {
            dbesp.log.error('configService:getParameter', 'parameter must be defined');
        }
    };

    /**
     * Gets the specified parameter value from the Configuration Service component
     * @param {string} parameter whata parameter to read from configService configuration file
     */
    configService.getParameterSynch = function (parameter) {
        if (parameter) {
            if (!configService.paramCache) {
                this.getAllParameters(function(){},null,true);
            }
            if (configService.paramCache) {
            	var parKey=parameter;
            	var parVal=configService.paramCache[parKey];
            	if (parVal===undefined) {
            		parKey='property.'+parameter;
            		parVal=configService.paramCache[parKey];
            	}
                return clean(parVal);
            }
        } else {
            dbesp.log.error('configService:getParameter', 'parameter must be defined');
        }
    };

    function clean(value) {
        if (!value) value=""; // property is not defined
        if (value.substring(0,2)=="$\{") value=""; // property placeholder is not defined and has still placeholder
        return value;
    }

    /**
     * Gets the all parameter values from the Configuration Service component
     * @param {function} onSuccess
     * @param {function} onError
     * @param {boolean} sync when true, communicate synchronous (async false)
     * @return {jQuery.Deferred}
     */
    configService.getAllParameters = function (onSuccess, onError, sync) {
    	if (onSuccess) {
    		onSuccess(configService.paramCache);
    	}
    	return configService.paramCache;
/*        var goAsync = sync ? false : true;
        if (configService.paramCache) {
            onSuccess(configService.paramCache);
        } else {
            return $.ajax({
                type: 'GET',
                contentType: 'application/json',
                url: rootURL,
                cache: false,
                async: goAsync,
                success: function( /*Anything* / data, /*String* / textStatus, /*jqXHR* / jqXHR ) {
                    configService.paramCache=data.parameters;
                    configService.allInfo=data;
                    // refresh dbesp values user dependent set in custom-head.jsp, as sometimes jsp values are wrong (from other users)
                    dbesp.loggedInUserId=data.loggedInUserId;
                    dbesp.userGroupName=data.userGroupName;
                    dbesp.sessionId=data.sessionId;
                    if (onSuccess) onSuccess(configService.paramCache, textStatus, jqXHR);
                },
                error: onError
            });
        }*/
    }

    dbesp.configService = configService;
    
})();




/**
 * @class
 * @memberOf constants
 * @namespace
 * @description Class to group all constants javascript.
 */
(function () {
    'use strict';
    
    var constants = (function () {
        var values= {
            	  "__comment__1": "constants to access DB direct menu",
            	  "menu": "menu",
            	  "menuStub": "stub",
            	  "menuLocal": "local",
            	  "dbdirectMenu": "menuActiva.xml",
            	  "activaUpperMenu": "menuActivaupper.xml",

            	  "__comment__2": "PATH REST SERVICES",
            	  "pathRestServicesContext": "",
            	  "pathRestNavigation": "/rest/navigation/menu",
            	  "pathRestSecurityUser": "/rest/securityuser",
            	  "pathRestSecurityUserParameter": "/rest/securityuser/parameter",

            	  "__comment__3": "ENHANCEDSHAREDCONTEXT",
            	  "escTransient": "/transient",
            	  "escPermanent": "/permanent",

            	  "__comment__4": "HEADERFOOTER AND TYPE LINK OF MENU",
            	  "utilityTypeExternalLink": "externalLink",
            	  "utilityTypeInternalLink": "internalLink",
            	  "utilityTypeOverlayLink": "overlayLink ",
            	  "utilityTypeLogoutLink": "logoutLink",
            	  "utilityTypeNoLink": "noLink",
            	  "utilityTypeFile": "file",
            	  "utilityTypeLang": "lang",
            	  "utilityTypeLangSelected": "langSelected",
            	  "menuLinkTypeMenu": "menuLink",
            	  "menuLevelsContextual": "3",

            	  "__comment__5": "STYLE HEADER",
            	  "typeStyleHeaderBranding": "branding",
            	  "typeStyleHeaderCustom": "custom",

            	  "__comment__6": "CHANNEL",
            	  "menuChannel": "menu",
            	  "goToMenuOptionChannel": "goToMenuOption",
            	  "pageNavigationAlert": "core_pageNavigationAlert",
            	  "performNavigation": "core_performNavigation",

            	  "__comment__7": "BROWSER HANDLING",
            	  "browserHandlingToken": "portal_token",

            	  "__comment__8": "NAVIGATION",
            	  "nonavigationcomm": "nonavigationcomm",

            	  "__comment__9": "WIDGET LOCATION REGISTRY (WLR) KEY IN ESC",
            	  "wlr": "wlr"
            	};
        function getValue(/* String */key) {
          	 return values[key];
        }

	      return {
	      getValue: getValue
	  };
	
	})();
//        var registry;
//        var configServiceProperties;
//
//        /**
//         *  Function to get a specific value with the key.
//         *  @param {String} key The value to read
//         *  @returns The value from constants file
//         */
//        function getValue(/* String */key) {
//            if (!registry) {
//                registry = loadConstants();
//            }
//            if(registry != null){
//            	 return registry[key];
//            }
//           
//        }
//
//        /**
//         * Function to load the constants of the project
//         * @private
//         * @param {String} value The value to read
//         * @returns The value from constants file
//         */
//        function loadConstants() {
//            var res;
//            require(['b-core/js/constants'],function(constants){
//            	res=constants; 
//            });
//                   
////            $.ajax({
////                    contentType: "application/json", 
////                    dataType: 'json',
////                    url: dbesp.contextRoot + '/static/b-core/js/constants.json',
////                    //url: 'http://localhost/portalserver/static/b-core/js/constants.json',
////                    async: false,
////                    success: function (data) {
////                        res = _.isString(data)? JSON.parse(data) : data;
////                    }
////                }
////            );
//            return res;
//        }
//
//        return {
//            getValue: getValue
//        };
//
//    })();

    dbesp.menu = constants.getValue('menu');
    dbesp.menuStub = constants.getValue('menuStub');
    dbesp.menuLocal = constants.getValue('menuLocal');
    dbesp.dbdirectMenu = constants.getValue('dbdirectMenu');
    dbesp.activaUpperMenu = constants.getValue('activaUpperMenu');

//PATH REST SERVICES
    dbesp.pathRestServicesContext = constants.getValue('pathRestServicesContext');
    dbesp.PATH_REST_NAVIGATION = constants.getValue('pathRestNavigation');
    dbesp.PATH_REST_SECURITY_USER = constants.getValue('pathRestSecurityUser');
    dbesp.PATH_REST_SECURITY_USER_PARAMETER = constants.getValue('pathRestSecurityUserParameter');


//ENHANCEDSHAREDCONTEXT
    dbesp.ESC_TRANSIENT = constants.getValue('escTransient');
    dbesp.ESC_PERMANENT = constants.getValue('escPermanent');

//HEADERFOOTER
    dbesp.UTILITY_TYPE_EXTERNAL_LINK = constants.getValue('utilityTypeExternalLink');
    dbesp.UTILITY_TYPE_INTERNAL_LINK = constants.getValue('utilityTypeInternalLink');
    dbesp.UTILITY_TYPE_OVERLAY_LINK = constants.getValue('utilityTypeOverlayLink');
    dbesp.UTILITY_TYPE_LOGOUT_LINK = constants.getValue('utilityTypeLogoutLink');
    dbesp.UTILITY_TYPE_NO_LINK = constants.getValue('utilityTypeNoLink');
    dbesp.UTILITY_TYPE_FILE = constants.getValue('utilityTypeFile');
    dbesp.UTILITY_TYPE_LANG = constants.getValue('utilityTypeLang');
    dbesp.UTILITY_TYPE_LANG_SELECTED = constants.getValue('utilityTypeLangSelected');

//STYLE HEADER
    dbesp.TYPE_STYLE_HEADER_BRANDING = constants.getValue('typeStyleHeaderBranding');
    dbesp.TYPE_STYLE_HEADER_CUSTOM = constants.getValue('typeStyleHeaderCustom');

//CHANNELS
    dbesp.CHANNEL_MENU = constants.getValue('menuChannel');
    dbesp.CHANNEL_GO_TO_MENU_OPTION = constants.getValue('goToMenuOptionChannel');
    dbesp.CHANNEL_PAGE_NAVIGATION_ALERT = constants.getValue('pageNavigationAlert');
    dbesp.CHANNEL_PERFORM_NAVIGATION = constants.getValue('performNavigation');


//MENU
    dbesp.MENU_LEVELS_CONTEXTUAL = constants.getValue('menuLevelsContextual');
    dbesp.MENU_LINK_TYPE_MENU = constants.getValue('menuLinkTypeMenu');
    dbesp.MENU_LINK_TYPE_EXTERNAL = constants.getValue('utilityTypeExternalLink');
    dbesp.MENU_LINK_TYPE_INTERNAL = constants.getValue('utilityTypeInternalLink');

//BROWSER HANDLING
    dbesp.BROWSER_HANDLING_TOKEN = constants.getValue('browserHandlingToken');

//EXPIRATION SESSION HANDLING
    dbesp.EXPIRATION_SESSION_HANDLING_TOKEN = constants.getValue('browserSessionTimerToken');

//NAVIGATION
    dbesp.NO_NAVIGATION_COMM = constants.getValue('nonavigationcomm');

//WIDGET LOCATION REGISTRY KEY
    dbesp.WLR_KEY = constants.getValue('wlr');

//PORTAL LANG
    dbesp.PORTAL_CORE_LANG = "";

    dbesp.configService.getAllParameters(function (properties) {
        //WIDGET LOCATION REGISTRY IS ENABLED OR NOT
        dbesp.WLR_ENABLED = properties['property.wlr.enabled'] || false;

        //WIDGET LOCATION REGISTRY BROWSER STORAGE IS ENABLED OR NOT
        dbesp.WLR_CLIENT_ENABLED = properties['property.wlr.client.enabled'] || false;

        //LOG
        dbesp.LOG_CS = properties['property.log.cs'] || 'NONE';

        dbesp.LOG_CS_2_SS = properties['property.log.cs2ss'] || false;

        //domStorage enable
        dbesp.DOM_STORAGE = properties['property.domStorage.enabled'] || false;

        //PRIORITY CHANEL SUBSCRIBE
        dbesp.IS_UNIPAGE_PORTAL = properties['property.isUnipagePortal'] === "true" || false;

        //PRIORITY CHANEL SUBSCRIBE
        dbesp.DEFAULT_SUBSCRIBE_PRIORITY = properties['property.chanels.defaultPriority'] || false;
        
        //CACHE LOCAL PARAMS WRITE ALWAYS IN BE
        dbesp.WRITE_ESC_CACHE = properties['property.cacheESCWrite'] || 1;
        
        //PERMANENT PARAMS
        dbesp.PERMANENT_PARAMS = properties['property.paramPermanent'] || '';
        
    });
})();
(function () {
    'use strict';

    /**
     * @description a browser's console.log wrapper
     * @exports core/log
     *
     * @requires module:jquery
     * @requires module:lodash
     * @requires module:core/dbesp
     */
    var log = {};

    /**
     * A shorthand that contextualizes the log module, so all method calls to the returned instance will autofill the first argument as the provided context
     *
     * @example
     *
     var contextLog = require('core/log').runInContext('moduleName');
     contextLog.error('message'); // -> will implicitly call log.error('moduleName', 'message');

     * @param {String} context A text by wich logged messages should be prefi
     * @return {core/log} A curried log where the first argument will always be the context
     *
     */
   // log.runInContext = function (context) {
   //     return _.assign({}, log, function (objectValue, sourceValue) {
   //         return _.partial(sourceValue, context);
   //     });
   // };

    /**
     *  Function to log a message with level LOG
     *  @param {String} where Name of the class where this message was generated.
     *  @param {String} msj Message we want to write in the log.
     *  @param {Boolean} [server = false] Has to be logged in the server.
     */
    log.log = function (where, msj, server) {
//        if (dbesp.LOG_CS !== undefined && dbesp.LOG_CS === sLog) {
        if (doLogUpToLevel(sLog)) {
            logThis(createLogString(sLog, where, msj));
            if (server && checkCS2SS()) {
                logToServer(sInfo, where, msj);
            }
        }
    };

    /**
     *  Function to log a message with level LOG or INFO
     *  @param {String} where Name of the class where this message was generated.
     *  @param {String} msj Message we want to write in the log.
     *  @param {Boolean} [server = false] Has to be logged in the server.
     */
    log.info = function (where, msj, server) {
//        if (dbesp.LOG_CS !== undefined && dbesp.LOG_CS === sLog || dbesp.LOG_CS === sInfo) {
        if (doLogUpToLevel(sInfo)) {
            logThis(createLogString(sInfo, where, msj), 'info');
            if (server && checkCS2SS()) {
                logToServer(sInfo, where, msj);
            }
        }
    };

    /**
     *  Function to log a message with level LOG or INFO or WARN
     *  @param {String} where Name of the class where this message was generated.
     *  @param {String} msj Message we want to write in the log.
     *  @param {Boolean} [server = false] Has to be logged in the server.
     */
    log.warn = function (where, msj, server) {
//        if (dbesp.LOG_CS !== undefined && dbesp.LOG_CS === sLog || dbesp.LOG_CS === sInfo || dbesp.LOG_CS === sWarn) {
        if (doLogUpToLevel(sWarn)) {
            logThis(createLogString(sWarn, where, msj), 'warn');
            if (server && checkCS2SS()) {
                logToServer(sWarn, where, msj);
            }
        }
    };


    /**
     *  Function to log a message with level LOG or INFO or WARN
     *  @param {String} where Name of the class where this message was generated.
     *  @param {String} constant Message we want to write in the log.
     *  @param {String} values Message we want to write in the log.
     */
    log.warnServer = function (where, constant, values) {
        logAsException(sWarn, constant, values);
        //if (dbesp.LOG_CS !== undefined && dbesp.LOG_CS === sLog || dbesp.LOG_CS === sInfo || dbesp.LOG_CS === sWarn) {
        if (doLogUpToLevel(sWarn)) {
            logThis(createLogString(sWarn, where, constant + '[' + values + ']'), 'warn');
        }
    };

    /**
     *  Function to log a message with level LOG or INFO or WARN or DEBUG
     *  @param {String} where Name of the class where this message was generated.
     *  @param {String} msj Message we want to write in the log.
     *  @param {Boolean} [server = false] Has to be logged in the server.
     */
    log.debug = function (where, msj, server) {
        //if (dbesp.LOG_CS !== undefined && dbesp.LOG_CS === sLog || dbesp.LOG_CS === sInfo || dbesp.LOG_CS === sWarn || dbesp.LOG_CS === sDebug) {
        if (doLogUpToLevel(sDebug)) {
            logThis(createLogString(sDebug, where, msj));
            if (server && checkCS2SS()) {
                logToServer(sDebug, where, msj);
            }
        }
    };

    /**
     *  Function to log a message with level ERROR
     *  @param {String} where Name of the class where this message was generated.
     *  @param {String} msj Message we want to write in the log.
     *  @param {Boolean} [server = false] Has to be logged in the server.
     */
    log.error = function (where, msj, server) {
        //if (dbesp.LOG_CS !== undefined && dbesp.LOG_CS === sLog || dbesp.LOG_CS === sInfo || dbesp.LOG_CS === sWarn || dbesp.LOG_CS === sDebug || dbesp.LOG_CS === sError) {
        if (doLogUpToLevel(sError)) {
            logThis(createLogString(sError, where, msj), 'error');
            if (server && checkCS2SS()) {
                logToServer(sError, where, msj);
            }
        }
    };

    /**
     *  Function to log a message with level WARN
     *  @param {String} where Name of the class where this message was generated.
     *  @param {String} type  Type of the error to server.
     *  @param {String} constant Message we want to write in the log.
     *  @param {String} values Message we want to write in the log.
     */
    log.errorServer = function (where, type, constant, values) {
        logAsException(type, constant, values);
        //if (dbesp.LOG_CS !== undefined && dbesp.LOG_CS === sLog || dbesp.LOG_CS === sInfo || dbesp.LOG_CS === sWarn || dbesp.LOG_CS === sDebug || dbesp.LOG_CS === sError) {
        if (doLogUpToLevel(sError)) {
            logThis(createLogString(sError, where, constant + '[' + values + ']'), 'error');
        }
    };

    /**
     *  Function to create a message string fo the log.
     *  @private
     *  @param {String} type Level of the log.
     *  @param {String} where Name of the class where this message was generated.
     *  @param {String} msj Message we want to write in the log.
     */
    function createLogString(type, where, msj) {

        var d = new Date();
        var sd = formatNumberDate(d.getHours(), 2) + ':' + formatNumberDate(d.getMinutes(), 2) + ':' + formatNumberDate(d.getSeconds(), 2);
        return '[' + type + '] ' + sd + ' [' + where + '] ' + msj;
    }
    /**
     *
     *  @param {number} number
     *  @param {number} size
     */
    function formatNumberDate(number, size) {
        return ("0" + number).slice(-size);
    }

    /**
     * Function to log a message to the server side.
     *  @private
     *  @param {String} type Level of the log.
     *  @param {String} where Name of the class where this message was generated.
     *  @param {String} msj Message we want to write in the log.
     *  @param {Function} [onSuccess] Function to execute on a successful operation
     *  @param {Function} [onError] Function to execute on error
     */
    function logToServer(/* String */type, /* String */where, /* String */msj, /* Function */onSuccess, /* Function */onError) {
        if (checkCS2SS()) {
            $.ajax({
                type: "POST",
                contentType: "text/plain",
                url: logRootURL + '/' + type,
                dataType: "text",
                data: where + ':: ' + msj,
                cache: false,
                success: onSuccess,
                error: onError
            });
        }
    }


    /**
     * Function to log a message to the server side.
     *  @private
     *  @param {String} type Level of the log.
     *  @param {String} constant Name of the class where this message was generated.
     *  @param {String} values Message we want to write in the log.
     *  @param {Function} [onSuccess] Function to execute on a successful operation
     *  @param {Function} [onError] Function to execute on error
     */
    function logAsException(/* String */type, /* String */constant, /* String */values, /* Function */onSuccess, /* Function */onError) {
        var logURL = logRootURL + '/' + type + '/' + constant;

        if (values !== undefined || values !== null || values !== '') {
            logURL = logURL + '/' + values;
        }
        if (checkCS2SS()) {
            $.ajax({
                type: "POST",
                contentType: "text/plain",
                url: logURL,
                dataType: "text",
                cache: false,
                success: onSuccess,
                error: onError
            });
        }
    }

    /**
     * Experimental
     * A default error handler
     */
    $(document).ajaxError(function (event, jqxhr, settings, thrownError) {
        log.error("Ajax Error", 'url: + ' + settings.url + '\n Error: ' + thrownError + '\n response: ' + jqxhr.responseText);
    });


    var regExp = /\(([^)]+)\)/;
    function getErrorStackLine(){
        if ($.browser.chrome) {
            var stack;
            try { throw Error('') } catch(err) {
                stack = err.stack.split('\n')[5];
            }
            var filtered = regExp.exec(stack)
            return  (filtered && ' @ ' + filtered[1]) || '';
        } 
        return "";
    }

    function logThis(msg, verb) {
        try {
        	var stack=getErrorStackLine();
			var msgOut=msg+stack;
			if (verb==sLog) {
				console.log(msgOut);
			} else if (verb==sDebug) {
				console.debug(msgOut);
			} else if (verb==sInfo) {
				console.info(msgOut);
			} else if (verb==sWarn) {
				console.warn(msgOut);
			} else if (verb==sError) {
				console.error(msgOut);
			} else if (verb==sNone) {
				// do not log
			} else {
				console.log(msgOut);
			}
//            if ($.browser.chrome) { // Chrome devtools shortcut to log caller
//                console[verb || 'log'](msg  + getErrorStackLine());
//            } else {
//                console[verb || 'log'](msg);
//            }
        } catch (ex) {
            // console is not defined (still?) and we should just ignore this, if not debugging
        	console.error('logThis error: '+ex.description);
        }
    }

    /**
     * NONE < ERROR < WARN < INFO < DEBUG < LOG
     * @param {type} logLevel log to evaluate if should be executed  
     * @returns {undefined}
     */
    function doLogUpToLevel(/*String*/logLevel) {
        var configLoLevel=dbesp.LOG_CS?dbesp.LOG_CS:sNone;
        var doLog=false;
        if (configLoLevel===sNone) {
            // no logs allowed
            doLog=false;
        } else if (configLoLevel===sError) {
            doLog=logLevel===sError;
        } else if (configLoLevel===sWarn) {
            doLog=logLevel===sError || logLevel===sWarn;
        } else if (configLoLevel===sInfo) {
            doLog=logLevel===sError || logLevel===sWarn || logLevel===sInfo;
        } else if (configLoLevel===sDebug) {
            doLog=logLevel===sError || logLevel===sWarn || logLevel===sInfo || logLevel===sDebug;
        } else if (configLoLevel===sLog) {
            doLog=logLevel===sError || logLevel===sWarn || logLevel===sInfo || logLevel===sDebug || logLevel===sLog;
        }
        return doLog;
    }

    // The root URL for the RESTful services for contexts
    var logRootURL = dbesp.contextRoot + "/rest/log";
    var sLog = 'LOG';
    var sDebug = 'DEBUG';
    var sInfo = 'INFO';
    var sWarn = 'WARN';
    var sError = 'ERROR';
    var sNone = 'NONE';

    function checkCS2SS() {
        var aux = false;
        if (dbesp.LOG_CS_2_SS !== undefined && (dbesp.LOG_CS_2_SS === "TRUE" || dbesp.LOG_CS_2_SS === 'true' || dbesp.LOG_CS_2_SS === '1')) {
            aux = true;
        }
        return aux;
    }

    dbesp.log = log;
})();
(function () {
    'use strict';

    var logName='eps';
    //var contextLog = dbesp.log.runInContext('eps');


    /**
     * Enhanced pub/sub
     * @exports core/eps
     * @type {{publish: Function, subscribeWithPriority: Function, subscribe: Function, unsubscribe: Function, checkChannels: Function}}
     */
    var eps = {

        /**
         * Function to publish some data on a named channel
         * @param {String} channel The channel to publish on
         * @param {Array} args Array with parameters for the callbacks
         * @param {String} [publisher] Name of the publisher, composed of page and name separated by '.'
         * @param {Array} [targets] Intended targets composed of page and name separated by '.' If null it's a broadcast
         * @param {String} [commID] Id of the communication, reads the communication parameters from the registry
         * @param {Boolean} [secure] Indicates if the communication is secure or not.
         * @return {Boolean} true if the event reached all subscribers, false if some subscriber decided to stop propagation
         */
        publish: function (/* String */channel, /* Array */args, /* String */publisher, /* Array */targets, /* String */commID, /* Boolean */secure) {
            dbesp.log.info(logName,"Init eps.publish channel: " + channel + ", targets: " + targets + ", publisher: " + publisher, true);
            //Reset session timer
            dbesp.internal.sessionTimer.reset();
            var interpage = false;
            if (!dbesp.IS_UNIPAGE_PORTAL) {
                if (publisher && publisher.indexOf("_checkChannels_") != -1) {
                    interpage = true;
                    publisher = publisher.substring("_checkChannels_".length, publisher.length);
                }
            } else {
                interpage = false;
            }

            dbesp.log.info(logName,"Init eps.publish channel: "
            + channel + ", targets: " + targets + ", publisher: " + publisher, true);
            
            // 20.9.2016: eps: due to collateral effect in activa (Poland at least), removed [] encapsulation. 
//            // args must be an array as it will be used as generic argument. If is another thing, change it to array
//            if (!(typeof(args)=="object" && args.lenth)) {
//            	// args is not array, change it to array
//            	args=[args];
//            }


            //Check if its a secure or common communication.
            if (commID && secure) {
                //Make a secure publication through the registry.
                return securePublish(interpage, channel, publisher, targets, commID);
            } else if (commID && !secure) {
                //Make a common publication through the registry.
                return commonPublish(interpage, channel, args, publisher, targets, commID);
            } else {
                //Make a standard publication.
                return simplePublish(interpage, channel, args, publisher, targets);
            }

        },

        /**
         * Function to register a callback on a named channel with a specified certain priority
         * @param {String} channel The channel to subscribe to
         * @param {Function} callback The handler event. Anytime something is eps.publish'ed on a subscribed channel,
         *                   the callback will be called with the published array as ordered arguments.
         * @param {number} [priority=dbesp.DEFAULT_SUBSCRIBE_PRIORITY]
         * @param {String} [subscriber] The name of the subscriber
         * @param {String} [publisher] The publisher we are interested in, all if no argument provided
         * @param {String} [commID] The id of the secure communication.
         * @param {Boolean} [secure] Indicates if the communication is secure or not.
         * @return {Array} A handle which can be used to unsubscribe this particular subscription
         */
        subscribeWithPriority: function (/* String */channel, /* Function */callback, /*Integer*/ priority, /* String */subscriber, /* String */publisher, /* String */commID, /* Boolean */secure) {

            if (priority == null) {
                priority = dbesp.DEFAULT_SUBSCRIBE_PRIORITY;
            }
            var logMessage = ' to channel: ['+ channel + ']';
            if (subscriber) logMessage +=  ', subscriber: ['+ subscriber + ']';
            if (publisher) logMessage +=  ', publisher: ['+ publisher + ']';
            if (priority) logMessage +=  ', priority: ['+ priority + ']';
            //Check if its a secure or common communication.
            if (commID && secure) {
                dbesp.log.info(logName,"Secure subscription" + logMessage, true);
                //Make a secure subscription through the registry.
                return secureSubscribe(channel, subscriber, publisher, callback, commID, this.priority);
            } else if (commID && !secure) {
                dbesp.log.info(logName,"Common subscription" + logMessage, true);
                //Make a common subscription through the registry.
                return commonSubscribe(channel, subscriber, publisher, callback, commID, this.priority);
            } else {
                dbesp.log.info(logName,"Simple subscription" + logMessage, true);
                //Make a standard subscription.
                return simpleSubscribe(channel, subscriber, publisher, callback, priority);
            }

        },


        /**
         * Function to register a callback on a named channel with default priority
         * @param {String} channel The channel to subscribe to
         * @param {Function} callback The handler event. Anytime something is eps.publish'ed on a subscribed channel,
         *                   the callback will be called with the published array as ordered arguments.
         * @param {String} [subscriber] The name of the subscriber
         * @param {String} [publisher] The publisher we are interested in, all if no argument provided
         * @param {String} [commID] The id of the secure communication.
         * @param {Boolean} [secure] Indicates if the communication is secure or not.
         * @return {Array} A handle which can be used to unsubscribe this particular subscription
         */
        subscribe: function (/* String */channel, /* Function */callback, /* String */subscriber, /* String */publisher, /* String */commID, /* Boolean */secure) {
            return this.subscribeWithPriority(channel, callback, dbesp.DEFAULT_SUBSCRIBE_PRIORITY, subscriber, publisher, commID, secure);
        },

        /**
         *  Disconnect a subscribed function for a channel.
         *
         *  @param {Array} handle This is the array returned by the subscription methods
         *  @param {string} handle.0 the channel
         *  @param {string} handle.1 the subscriber
         */
        unsubscribe: function (/* Array */handle) {
            dbesp.log.info(logName,"Init eps.unsubscribe", true);
            // handle: Array - The return value from a eps.subscribe call.
            var t = handle[0];
            cache[t] && $.each(cache[t], function (idx) {
                if (this == handle[1]) {
                    cache[t].splice(idx, 1);
                }
            });
        },

        /**
         * Function to check if we have pending events on some channels stored in ESC
         * @param {Array} channels The channels to check to the ESC.
         * @param {Function} callback Function To call after checking the channels.
         */
        checkChannels: function (/* Array */channels, /* Function */callback) {
            dbesp.log.info(logName,"Init eps.checkChannels channels: " + channels, true);
            for (var i = 0; i < channels.length; i++) {
                var channel = channels[i];
                //We check the channel from ESC and publish it
                dbesp.internal.commesc.findParamSync(channel,
                    function (data) {
                        //Delete the channel from the dbesp.internal.commesc.
                        var _chn = channel;
                        dbesp.internal.commesc.deleteParamSync(_chn,
                            function () {
                                dbesp.log.info(logName,"Delete of channel '" + _chn + "' performed successfully.", true)
                            },
                            function () {
                                dbesp.log.error(logName,"Delete of channel '" + _chn + "' not acomplished. ", true)
                            }
                        );
                        dbesp.log.info(logName,"Data: " + data, true);
                        if (data) {
                            var ev = JSON.parse(data);
                            eps.publish(ev.channel, ev.args, "_checkChannels_" + ev.publisher, ev.targets, ev.commID, ev.secure);
                        }
                    },
                    function () {
                        dbesp.log.error(logName,"We couldn't retrieve the data from channel " + channel, true);
                    }
                );
            }

            if (callback && typeof (callback) === "function") {
                dbesp.log.info(logName,"Executing callback.", true);
                callback();
            }

        }
    };

    // the channel/subscription hash
    /* Array[][] */
    var cache = {};
    var sessionPubSub = Math.random();
    var isMSIE = /*@cc_on!@*/0;


    /********************************************************
     *
     *               PRIVATE FUNCTIONS
     *
     ********************************************************/

    /**
     * Function to get the simpliest name of a widget.
     * @private
     * @param {String} complexName Name of the widget we want to simplify.
     * @param {String} splitter If we want a specific splitter to find the name.
     *                  By default is the dot (.)
     * @returns {String} The name of the widget.
     */
    function getWidgetSimpleName(/* String */complexName, /* String */splitter) {
        splitter = splitter || '.';
        var tokenName = complexName.split(splitter);
        return tokenName[tokenName.length - 1];
    }

    /**
     * Function to see if a subscriber can see an event.
     * The function takes the simplest name of the widget.
     * @private
     * @param {Subscriber} subs Subscriber
     * @param {Array} targets Array with intended targets, if null it's a broadcast
     * @return {Boolean} true if the subscriber can see the event
     */
    function isTarget(/* Subscriber */subs, /* Array */targets) {
        // if there's no target defined we return true
        if (!targets) {
            return true;
        }
        var subName = getWidgetSimpleName(subs.name);
        for (var i = 0; i < targets.length; i++) {
            if (subName === getWidgetSimpleName(targets[i])) {
                return true;
            }
        }
        return false;
    }

    /**
     * Function to validate the communication.
     * @private
     * @param {String} pub The name of the publisher.
     * @param {String} sub The name of the subscriber.
     * @returns {boolean} ture if the communication is valid.
     */
    function isCommunicationValid(/*String*/pub, /*String*/sub) {
        return true;
    }

    /**
     * Function to see if a subscriber wants to listen to a publisher.
     * The function takes the simplest name of the widget.
     * @private
     * @param {String} publisher Name of the publisher
     * @return {Boolean} true if the subscriber wants to listen to this publisher
     */
    function listensToPublisher(/* String */publisher) {
        var res = true;
        // if there's no publisher defined we return true
        if (this.publisher) {
            // else we need to see if publisher equals this.publisher
            res = getWidgetSimpleName(this.publisher) === getWidgetSimpleName(publisher);
        }
        return res;
    }

    /**
     * @private
     * @param {String} Name
     * @return {String} Location
     */
    function getLocation(/* String */name) {
        var i = name.indexOf('.');
        if (i > 0) {
            return name.substring(0, i);
        }
    }

    /**
     * Function to see if an event needs to navigate to a new page
     * @private
     * @param {String} publisher Actual publisher (We can extract the location throug the publisher).
     * @param {Array} targets Array with intended targets, if null it's a broadcast
     * @return {String} New page to go to, null if we don't change pages
     */
    function getNewPage(/* String */publisher, /* Array */targets) {
        var subsLocation;
        var location;
        dbesp.log.info('eps.getNewPage', 'Init publisher[' + publisher + '] targets[' + targets + '] ', true);
        //If we don't have publisher AND targets defined we return null.
        if (publisher && targets) {
            //Get the location from the publisher.
            location = getLocation(publisher);
            if (location) {
                dbesp.log.info('eps.getNewPage', 'Page/Location of publisher: ' + location, true);
                if (location !== dbesp.pageName) {
                    dbesp.log.warn('eps.getNewPage', 'Page/Location of publisher wrong. The location[' + location + '] is diferent to  actual page [' + dbesp.pageName + ']', true);
                    return null;
                }
            }
            //Check the locations of the targets.
            for (var i = 0; i < targets.length; i++) {
                subsLocation = getLocation(targets[i]);
                if (location != subsLocation && subsLocation != dbesp.pageName) {
                    dbesp.log.info('eps.getNewPage', 'Publisher[' + publisher + '] whit location [' + location + ']', true);
                    dbesp.log.info('eps.getNewPage', 'Target[' + targets[i] + '] whit location [' + subsLocation + ']', true);
                    return subsLocation;
                }
            }
        }
        dbesp.log.info('eps.getNewPage', 'There are no publishers or targets. So, communication will be established in the same page or tab', true);
        return null;
    }

    /**
     * Function to get the channel name depending on the session
     * @private
     * @param {String} name The name of the channel
     * @returns {String} Channel name with session
     */
    function getSessionChannelName(/* String */name) {
        return sessionPubSub + name;
    }

    /**
     * Function to push the events to the targets.
     * @private
     * @param {String} sessionChannel The name of the channel in the actual session.
     * @param {Array} targets Array with the name of the targets to push the event.
     * @param {String} publisher The name of the publisher.
     * @param {Array} args The args we want to push.
     * @returns {Boolean} True if all is ok.
     */
    function pushEvent(/* String */sessionChannel, /* Array */targets, /* String */publisher, /* Array */args) {
        var res = true;
        dbesp.log.info("eps.pushEvent", "Init sessionChannel[" + sessionChannel + "] targets[" + targets +
        "] publisher[" + publisher + "] args[" + args + "]", false);

        if (cache[sessionChannel]) {
            // we send the event to each subscriber if needed
            for (var i = 0; i < cache[sessionChannel].length; i++) {
                var subs = cache[sessionChannel][i];
                if (isTarget(subs, targets)) {
                    if (subs.listensToPublisher(publisher)) {
                        dbesp.log.info('eps.pushEvent', 'Push arguments: [' + args + '] to ' + subs.name, true);
                        res = subs.callback.apply(subs.callback, args || []);
                        // TOMAS (4.7.216): don't understand why stop event propagation if one returns undefined or false or null. As maximum with false explicit but it is not documented.
                        // if the subscriber returns false/undefined/null we skip the rest
//                        if (!res) {
//                            dbesp.eps.subscribers = true;
//                            break;
//                        }
                    }
                }
            }
        } else {
            //If we arrive here it may be because we have to:
            //First we have to do the subscriber then the publish. If not, some subscriber may miss a message.
            //Second, there is no subscirbers in this DOM.
            dbesp.log.warn("eps.pushEvent", "No listeners to this channel in this DOM.", true);
            // We return this code when there are no suscribers, so the emitter knows whether any has consumed the even or not.
            dbesp.eps.subscribers = false;
        }
        return res;
    }

    /**
     * Function to get the text inside a node like <node><value>text to read</value></node>
     * @private
     * @param {Node} node Node that have the text to read.
     */
    function getText(node) {
        var value = node.textContent || node.innerText || node.nodeValue || node.innerHTML || '';
        //IE needs to go for the child.
        if (isMSIE && node.firstChild) {
            value = node.firstChild.nodeValue;
        }
        return value;
    }

    /**
     * Function to create a xmlDefinition with a list
     * @constructs
     * @private
     * @param {Array} nodeList List with the names and mor
     */
    function XmlDefinitionObject(/*Array*/nodeList) {
        this.name = '';
        this.contextItemName = '';
        this.parentItemName = '';
        this.extendedItemName = '';
        this.properties = '';
        this.itemHandlerBeanName = '';
        this.createdBy = '';
        this.createdTimestamp = '';
        this.lastModifiedBy = '';
        this.lastModifiedTimestamp = '';
        this.securityProfile = '';
        this.contents = '';
        this.tags = '';
        this.publishState = '';
        this.uuid = '';

        for (var i = 0; i < nodeList.length; i++) {
            switch (nodeList[i].tagName) {
                case "name":
                    this.name = getText(nodeList[i]);
                    break;
                case "contextItemName":
                    this.contextItemName = getText(nodeList[i]);
                    break;
                case "parentItemName":
                    this.parentItemName = getText(nodeList[i]);
                    break;
                case "extendedItemName":
                    this.extendedItemName = getText(nodeList[i]);
                    break;
                case "properties":
                    this.properties = getText(nodeList[i]);
                    break;
                case "itemHandlerBeanName":
                    this.itemHandlerBeanName = getText(nodeList[i]);
                    break;
                case "createdBy":
                    this.createdBy = getText(nodeList[i]);
                    break;
                case "createdTimestamp":
                    this.createdTimestamp = getText(nodeList[i]);
                    break;
                case "lastModifiedBy":
                    this.lastModifiedBy = getText(nodeList[i]);
                    break;
                case "lastModifiedTimestamp":
                    this.lastmodifiedtimestamp = getText(nodeList[i]);
                    break;
                case "securityProfile":
                    this.securityProfile = getText(nodeList[i]);
                    break;
                case "contents":
                    this.contents = getText(nodeList[i]);
                    break;
                case "tags":
                    this.tags = getText(nodeList[i]);
                    break;
                case "publishState":
                    this.publishState = getText(nodeList[i]);
                    break;
                case "uuid":
                    this.uuid = getText(nodeList[i]);
                    break;
            }
        }
    }

    /**
     * Function to get the parent name of a given item (widget, container or page)
     * @private
     * @param {String} itemName Name of the item to find the parent name
     * @param {String} itemType Type of the object (WIDGET/CONTAINER/PAGE)
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     * @returns {String} The parent name of the object associated to the itemName
     */
    function getParentItemName(/* String */itemName, /* String */itemType, /* Function */onSuccess, /* Function */onError) {

        var baseUrl = b$.portal.config.serverRoot + '/portals/' + encodeURI(b$.portal.portalName);
        var type = '';
        var operator = 'eq';
        if (itemType === 'WIDGET') {
            operator = 'like';
            type = '/widgets';
        }
        if (itemType === 'CONTAINER') {
            type = '/containers';
        }
        if (itemType === 'PAGE') {
            type = '/pages';
        }

        $.ajax({
            url: baseUrl + type + '?f=name(' + operator + ')' + itemName + '&f=parentItemName(not)" "', // + '.xml',
            async: false,
            cache: false,
            success: function (data) {
                var parentItemName = '';
                var itemFound = '';
                var _numInstances = 0;
                var _indexOne = 0;
                if (isMSIE) {
                    _indexOne = 1;
                }

                var _length = data.childNodes[_indexOne].childNodes.length;
                if (_length > 0) {
                    //INFO: In case of several instances of the widget. Check how many of them have parents.
                    //If more than one, we get the exact match, if not END.
                    for (var _i = 0; _i < _length; _i++) {
                        var _aux = new XmlDefinitionObject(data.childNodes[_indexOne].childNodes[_i].childNodes);
                        if (_aux.parentItemName) {
                            parentItemName = _aux.parentItemName;
                            itemFound = _aux.name;
                        }
                        if (_aux.name == itemName) { //If exact match break.
                            _numInstances = 1;
                            break;
                        }
                        _numInstances++;
                    }
                    //If we have more than one instance error!! But not calling error (avoiding dead lock).
                    //Logging it.
                    if (_numInstances > 1) {
                        dbesp.log.error('eps.getParentItemName', 'The widget/container/page "' + itemName + '" has several instances.', true);
                        return;
                    }
                    if (onSuccess && typeof (onSuccess) === "function") {
                        onSuccess(parentItemName, itemName, itemFound);
                    }
                } else {
                    //If we don't find any widget, error!!
                    onError();

                }

            },
            error: function (jqXHR, textStatus, errorThrown) {
                //We couldn't find the widget/container/page.
                dbesp.log.info('eps.getParentItemName', 'A <controlled> error occurred when we tried to get the parent name of ' + itemName + '. \n Error: ' + errorThrown, true);
                if (onError && typeof (onError) === "function") {
                    onError();
                }
            }
        });
    }

    /**
     * Function to get the qualified name of an item (widget, container or page)
     * @private
     * @param {String} itemName Name of the item to find the qualified name
     * @param {Function} onSuccess Function to execute on a successful operation
     * @returns {String} The full qualified name of the object associated to the itemName
     */
    function getQualifiedName(/* String */itemName, /*Function*/onSuccess) {
        var qualifiedName = getWidgetSimpleName(itemName);
        //alert('getQualifiedNameaaa. itemName=' + itemName + '  qualifiedName=' + qualifiedName + '  loggedInUserId=' + loggedInUserId);
        //var _onSuccess = onSuccess;
        var logURL = dbesp.contextRoot + '/rest/wlr/' + b$.portal.loggedInUserId + '/' + qualifiedName;
        $.ajax({
            type: "GET",
            contentType: "application/json",
            url: logURL,
            cache: false,
            success: function (data, textStatus, jqXHR) {
                //console.log('*********', data);
                if (data) {
                    onSuccess(data.location);
                } else {
                    onSuccess(itemName);
                }
            },
            error: function (jqXHR, textStatus, errorThrown) {
                dbesp.log.error('eps.getQualifiedName', 'Error :' + textStatus + ' , ' + errorThrown);
            }
        });


    }

    /**
     *
     * @param {String} itemName
     * @param {Function} onSuccess
     */
    function getQualifiedName2(/* String */itemName, /*Function*/onSuccess) {
        var qualifiedName = getWidgetSimpleName(itemName);
        var onError = function () {
            dbesp.log.error('eps.getQualifiedName', 'The widget "' + itemName + '" does not exists or it has several instances.', true);
        };

        var checkContainerOrPage = function (/*String */parentName, /*String */originalItemName, /*String */itemFound) {
            var _checkContainerOrPage = checkContainerOrPage;
            var _onSuccess = onSuccess;

            //In case we didn't find the exact match with the name of the widget, we replace the name.
            if (itemFound && itemFound != originalItemName)
                qualifiedName = qualifiedName.replace(originalItemName, itemFound);
            if (parentName && parentName != dbesp.portalName) {
                qualifiedName = parentName + "." + qualifiedName;
                //Keep digging
                var _checkContainer = function () {
                    getParentItemName(parentName, 'CONTAINER', _checkContainerOrPage);
                };
                var _checkPage = function () {
                    //If ok execute recursively the callback, if not, check container.
                    getParentItemName(parentName, 'PAGE', _checkContainerOrPage, _checkContainer);
                };
                //If ok execute recursively the callback, if not, check page.
                getParentItemName(parentName, 'CONTAINER', _checkContainerOrPage, _checkPage);
            }

            if (parentName == dbesp.portalName) {
                dbesp.log.info('eps.getQualifiedName', 'The qualified name of ' + itemName + ' is ' + qualifiedName, true);
                if (_onSuccess && typeof (_onSuccess) === "function") {
                    _onSuccess(qualifiedName);
                }
            }

        };
        //First check widget, only once, then check container or page recursively.
        getParentItemName(getWidgetSimpleName(itemName), 'WIDGET', checkContainerOrPage, onError);

    }

    /**
     *  Function to get the 'level' ancestor of a given widget.
     *  @private
     */
    function getAncestor(item, level) {
        var tokens = item.split('.');
        if (tokens.length >= level) {
            //log.info('eps.getAncestor', 'Ancestor #' + level + ' from item: ' + item + ' is ' + tokens[level]);
            return tokens[level];
        }
        return null;
    }

    /**
     * Function to get the number of ancestors of a given widget.
     * @private
     */
    function ancestors(item) {
        return item && item.split('.').length ? item.split('.').length : 0;
    }

    /**
     *  Function to navigate to a Tab.
     *  @private
     */
    function navigateToTab(tabname) {
        dbesp.log.info('eps.navigateToTab', 'Navigation to: ' + tabname, true);
        $('[data-index="'+ tabname +'"] > a').click();
    }

    /**
     * Function to check if the is navigation between to widgets, and the kind of it.
     * @private
     * @param {String} origin Name of the starting widget
     * @param {String} destiny Qualified name of the ending widget
     * @returns
     */
    function abstractNavigation(/* String */origin, /* String */destiny) {
        //There are two possible kinds of navigation.
        // 1. Render a new page
        // 2. Tab change
        //To detect a change of page, we have to check the current page with
        //the first item in the qualified name of the destiny
        if (dbesp.pageName != destiny.substring(0, destiny.indexOf('.'))) {
            //There is a page change. Navegate!!
            dbesp.log.info("eps.abstractNavigation", "We are in front of a navigational PAGE. Origin: " + origin + ", Destiny: " + destiny, true);
            return dbesp.utils.navigation.goToPage(destiny.substring(0, destiny.indexOf('.')));
        }

        var destinyArray = destiny.split('.');
        //Search in DOM what TAB we must to navigate
        for (var i = 0; i < destinyArray.length; i++) {
            var destinyStr = destinyArray[i];
            var object = $('div[data-pid="' + destinyStr + '"]');

            if (object) {
                if (object.length > 0 && !object.is(':visible')) {
                    dbesp.log.info("eps.abstractNavigation", "It is necessary navigate to " + destinyStr + " the object has length>0 and it is not visible", true);
                    navigateToTab(destinyStr);
                    break;
                } else if (object.length > 0 && object.is(':visible')) {
                    dbesp.log.info("eps.abstractNavigation", "It is not necessary navigate to " + destinyStr, true);
                } else {
                    dbesp.log.info("eps.abstractNavigation", "It is necessary navigate to " + destinyStr + " the object has length 0 and it is not visible", true);
                    navigateToTab(destinyStr);
                    break;
                }
            } else {
                dbesp.log.info("eps.abstractNavigation", "It is necessary navigate to " + destinyStr + " the object is null", true);
                navigateToTab(destinyStr);
                break;
            }
        }
        return true;

    }

    /*********************************************************
     *
     *                  CONSTRUCTORS
     *
     *********************************************************/

    /**
     * Function to create a subscriber
     * @constructs
     * @private
     * @param {String} name Name of the subscriber
     * @param {String} publisher Name of the publisher we want to listen to
     * @param {Function} callback Function to execute as callback
     * @param {number} priority
     */
    function Subscriber(/* String */name, /* String */publisher, /* Function */callback, /*Integer*/ priority) {
        this.name = name || '';
        if (name) {
            var i = name.indexOf('.');
            if (i > 0)
                this.location = name.substring(0, i);
        }
        this.publisher = publisher;
        this.callback = callback;
        this.listensToPublisher = listensToPublisher;
        this.priority = priority;
    }

    /**
     * Function to represent an event
     * @constructs
     * @private
     * @param {String} channel The channel for the event
     * @param {String} publisher The publisher
     * @param {String} commID The commID
     * @param {Array} args The args for the callbacks
     * @param {Array} targets The intended subscribers
     * @param {Boolean} secure Is a secure communication
     */
    function Event(/* String */channel, /* String */publisher, /* String */commID, /* Array */args, /* Array */targets, /* Boolean */secure) {
        this.channel = channel;
        this.publisher = publisher;
        this.commID = commID;
        this.args = args;
        this.targets = targets;
        this.secure = secure;
    }

    /*********************************************************
     *
     *                  PRIVATE MAIN FUNCTIONS
     *
     *********************************************************/

    /**
     * Function to publish some data on a secured channel
     * @private
     * @param {Boolean} interpage Indicates if the communication is between pages or not.
     * @param {String} channel The channel to publish on
     * @param {String} publisher Name of the publisher, composed of page and name separated by '.'
     * @param {Array} targets Intended targets composed of page and name separated by '.' If null it's a broadcast
     * @param {String} commID Id of the communication, reads the communication parameters from the registry
     * @return {Boolean} true if the event reached all subscribers, false if some subscriber decided to stop propagation
     */
    function securePublish(/* Boolean */interpage, /* String */channel, /* String */publisher, /* Array */targets, /* String */commID) {
        var res = true;

        //Call the RESTful service that executes the secure operation.
        dbesp.internal.secureComm.triggerSecComm(
            commID,
            publisher,
            function (data) {
                if (data != '') {
                    //Publish the key returned to the given channel. (Meaning that we did ok)
                    var dataArray = [];
                    dataArray[0] = data;
                    return simplePublish(interpage, channel, dataArray, publisher, targets);
                } else {
                    dbesp.log.error("eps.securePublish", "Something went wrong with the secure communication.", true);
                }
            },
            function () {
                dbesp.log.error("eps.securePublish", "We couldn't trigger the secured communication with commID " + commID, true);
            }
        );

        return res;
    }

    /**
     * Function to publish some data on a named channel
     * @private
     * @param {Boolean} interpage Indicates if the communication is between pages or not.
     * @param {String} channel The channel to publish on
     * @param {Array} args Array with parameters for the callbacks
     * @param {String} publisher Name of the publisher, composed of page and name separated by '.'
     * @param {Array} targets Intended targets composed of page and name separated by '.' If null it's a broadcast
     * @param {String} commID Id of the communication, reads the communication parameters from the registry
     * @return {Boolean} true if the event reached all subscribers, false if some subscriber decided to stop propagation
     */
    function commonPublish(/* Boolean */interpage, /* String */channel, /* Array */args, /* String */publisher, /* Array */targets, /* String */commID) {

        //Call the RESTful service that checks if the publication is valid.
        dbesp.internal.commRegistry.getProperties(commID,
            function (registry) {
                //Check if the publisher is authorised
                if (publisher !== registry.publisher) {
                    dbesp.log.error("eps.commonPublish", "The publisher is not authorised to call this communication.", true);
                    return null;
                }
                targets = registry.subscriber;
                return simplePublish(interpage, channel, args, publisher, targets, commID, false);
            },
            function () {
                dbesp.log.error("eps.commonPublish", "We couldn't retrieve the registry communication with commID " + commID, true);
            }
        );

    }

    /**
     * Function to publish some data on a named channel
     * @private
     * @param {Boolean} interpage Indicates if the communication is between pages or not.
     * @param {String} channel The channel to publish on
     * @param {Array} args Array with parameters for the callbacks
     * @param {String} publisher Name of the publisher, composed of page and name separated by '.'
     * @param {Array} targets Intended targets composed of page and name separated by '.' If null it's a broadcast
     * @param {String} commID Id of the communication, reads the communication parameters from the registry
     * @param {Boolean} secure Indicates if the communication is secure or not.
     * @return {Boolean} true if the event reached all subscribers, false if some subscriber decided to stop propagation
     */
    function simplePublish(/* Boolean */interpage, /* String */channel, /* Array */args, /* String */publisher, /* Array */targets, /* String */commID, /* Boolean */secure) {
        var res;
        dbesp.log.info(logName,"Init interpage[" + interpage + "] channel[" + channel +
        "] args[" + args + "] publisher[" + publisher + "] targets[" + targets + "] commID[" + commID + "] secure[" + secure + "]", false);

        //Get the session channel name.
        var sessionChannel = getSessionChannelName(channel);

        //Push the event.
        res = pushEvent(sessionChannel, targets, publisher, args);
        dbesp.log.info(logName,"] res[" + res + "]", false);
        //{interpage: true} If we come from the checkChannels, we don't have to navigate.
        if (!dbesp.IS_UNIPAGE_PORTAL && res && !interpage) {
            //Delete the channel from the ESC (in case it's necessary).
            //fix bug not necessary calls to esc???


            dbesp.internal.commesc.deleteParamSync(channel,
                function () {
                    dbesp.log.info(logName,"Delete of channel '" + channel + "' performed successfully.", true)
                },
                function () {
                    dbesp.log.info(logName,"Delete of channel '" + channel + "' not acomplished. ", true)
                }
            );


            //Check if is interpage or not splitting the name of the widget. Old way.
            var newpage = getNewPage(publisher, targets);

            var ev = JSON.stringify(new Event(channel, publisher, commID, args, targets, secure));
            dbesp.internal.commesc.updateParam(channel, ev,
                function () {
                    if (newpage) {//{newpage: true} If the event is interpage we store it in the ESC and change the page.
                        dbesp.log.info(logName,'Navigate to page[' + newpage + '] ', false);
                        dbesp.utils.navigation.goToPage(newpage);
                    } else {//{newpage: false} If the event is not old interpage and we have targets check qualified names.
                        dbesp.log.info(logName,'Same page', false);
                        var getQName = function (qName) {
                            //Navigate in case it's needed.
                            abstractNavigation(publisher, qName);
                        };
                        if (targets && targets.length == 1) {
                            //Check the qualified name.
                            getQualifiedName(targets[0], getQName);
                        }
                        //If the communication has not involved navigation this var is populated as not navigational
                        //This value will be checked in checkpageload. If true, 
                        //dbesp.communication = dbesp.NO_NAVIGATION_COMM;
                    }
                },
                function () {
                    dbesp.log.info(logName,"We couldn't update the data from channel " + channel, true);
                }
            );

        }
        return res;
    }

    /**
     * Function to register a callback on a secured channel
     * @private
     * @param {String} channel The channel to subscribe to
     * @param {String} subName The name of the subscriber
     * @param {String} publisher The publisher we are interested in, all if no argument provided
     * @param {Function} callback The handler event. Anytime something is eps.publish'ed on a subscribed channel,
     *                   the callback will be called with the published array as ordered arguments.
     * @param {String} commID The id of the secure communication.
     * @param {number} priority
     * @return {Array} A handle which can be used to unsubscribe this particular subscription
     */
    function secureSubscribe(/* String */channel, /* String */subName, /* String */publisher, /* Function */callback, /* String */commID, /*Integer*/ priority) {

        return simpleSubscribe(channel, subName, publisher,
            //We wrap the callback to a call to the secure ESC
            function (message) {
                dbesp.internal.secureComm.getSecCommValue(commID, message, subName,
                    function (data) {
                        var _callback = callback;
                        var params = new Array(data);

                        //We have to delete the SecCommValue here.
                        dbesp.internal.secureComm.removeSecCommValue(commID, message, publisher,
                            function () {
                                dbesp.log.info("eps.secureSubscribe", "Delete of secured communicaton with commID '" + commID + "' performed successfully.", true)
                            },
                            function () {
                                dbesp.log.error("eps.secureSubscribe", "Delete of secured communicaton with commID '" + commID + "' not acomplished. ", true)
                            }
                        );

                        //We execute the callback from the user here.
                        return _callback.apply($, params || []);
                    },
                    function () {
                        dbesp.log.error("eps.secureSubscribe", "We couldn't retrieve the data from the secure communication with commID " + commID, true);
                    }
                );

                return true;
            }, priority
        );

    }

    /**
     * Function to register a callback on a named channel through the registry
     * @private
     * @param {String} channel The channel to subscribe to
     * @param {String} subName The name of the subscriber
     * @param {String} publisher The publisher we are interested in, all if no argument provided
     * @param {Function} callback The handler event. Anytime something is eps.publish'ed on a subscribed channel,
     *                   the callback will be called with the published array as ordered arguments.
     * @param {String} commID The id of the communication.
     * @param {number} priority
     * @return {Array} A handle which can be used to unsubscribe this particular subscription
     */
    function commonSubscribe(/* String */channel, /* String */subName, /* String */publisher, /* Function */callback, /* String */commID, /*Integer*/ priority) {

        dbesp.internal.commRegistry.getProperties(commID,
            function (registry) {
                if (registry && registry.eventHandler && registry.eventHandler != '') {
                    //Recreating the function for the callback.
                    var startBody = registry.eventHandler.indexOf('{') + 1;
                    var endBody = registry.eventHandler.lastIndexOf('}');
                    var startArgs = registry.eventHandler.indexOf('(') + 1;
                    var endArgs = registry.eventHandler.indexOf(')');

                    callback = new Function(
                        registry.eventHandler.substring(startArgs, endArgs),
                        registry.eventHandler.substring(startBody, endBody)
                    );
                }

                return simpleSubscribe(channel, subName, publisher, callback, priority);
            },
            function () {
                dbesp.log.error("eps.standardSubscribe", "We couldn't retrieve the data from the registry with commID " + commID, true);
            }
        );
    }

    /**
     * Function to register a callback on a named channel (simpliest way)
     * @private
     * @param {String} channel The channel to subscribe to
     * @param {String} subName The name of the subscriber
     * @param {String} publisher The publisher we are interested in, all if no argument provided
     * @param {Function} callback The handler event. Anytime something is eps.publish'ed on a subscribed channel,
     *                   the callback will be called with the published array as ordered arguments.
     * @param {number} priority
     * @return {Array} A handle which can be used to unsubscribe this particular subscription
     */
    function simpleSubscribe(/* String */channel, /* String */subName, /* String */publisher, /* Function */callback, /*Integer*/ priority) {
        var sessionChannel = getSessionChannelName(channel);
        if (!cache[sessionChannel]) {
            cache[sessionChannel] = [];
        }
        var subs = new Subscriber(subName, publisher, callback, priority);
        cache[sessionChannel].push(subs);
        cache[sessionChannel].sort(function (a, b) {
            return (a.priority - b.priority);
        });
        return [sessionChannel, subs]; // Array
    }

    _.assign($, eps);
    dbesp.eps = eps;
})();
(function () {
    'use strict';

    /**
     * Enhanced shared context
     * @exports core/esc
     *
     * @requires module:jQuery
     * @requires module:core/dbesp
 	 * @description The purpose of this function is to allow to get/put/update/delete
 	 * objects in the Enhanced Shared Context in the backend.
     */
    var _esc = {};
    
    // storedCache should be local in localCacheESC, and not published in dbesp !!??
    var storedCache = dbesp.localESCCache = {};
    var DEFINE_WRITE_CACHE = {
    		ALWAYS: "1",
    		ONLY_PERM_PARAM: "2",
    		NEVER: "-1"
    	};

    // The root URL for the RESTful services for contexts
    var escRootURL = dbesp.contextRoot + "/rest/esc";
    
    var localCacheESC = {
    	storedCache: {},
	    remove: function (idESC) {
	        if(this.storedCache[idESC] != null){
	        	dbesp.log.debug('dbesp.esc', "Remove cached key(" + idESC+") value("+this.get(idESC)+")");
				//console.log("Remove CACHE " + idESC);
				delete this.storedCache[idESC];
			}
	    },
	    exist: function (idESC) {
	        /*if(this.storedCache[idESC] != null && !this.storedCache[idESC] == ""){
	        	return this.storedCache[idESC] !== null;
	        }*/
	        return this.storedCache[idESC] != null;
	    },
	    get: function (idESC) {
	    	if(this.storedCache[idESC] != null){
	        	return this.storedCache[idESC].val;
	    	}
	    	return "";
	    },
	    set: function (idESC, cachedData) {
	    	this.storedCache[idESC]={id:idESC,val:cachedData};
/*	        if(cachedData != null && !cachedData == ""){
	        	dbesp.log.debug('dbesp.esc', "Remove CACHE " + idESC);
//	        	console.log("Set CACHE " + idESC + " with value: " + cachedData);	        	
	        	this.storedCache[idESC] = cachedData;
	        }*/
	    },
	    removeAll: function() {
	    	this.storedCache = {};
	    }
	};
	
	function isParamPermanent(idPermanentParam) {
    	var sc = dbesp.PERMANENT_PARAMS.split(',');
    	for(var i=0; i<sc.length; i++){
    		if(sc[i] == idPermanentParam){
    			return true;
    		}
    	}
    	return false;
    }
	
	function mustWriteParam(idParam) {
		return dbesp.WRITE_ESC_CACHE === DEFINE_WRITE_CACHE.ALWAYS || (dbesp.WRITE_ESC_CACHE === DEFINE_WRITE_CACHE.ONLY_PERM_PARAM && isParamPermanent(idParam));
	}

    /**
     * Function to add an element to the ESC, gives an error if the id is already in use
     * @param {String} id Id to use
     * @param {String} value Value to store
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     * @param {boolean} ignoreCache true: allways exeucte ajax
     */
    _esc.addESC = function(/* String */id, /* String */value, /* Function */onSuccess, /* Function */onError, /* boolean */ignoreCache) {
       
    	var updateServer=ignoreCache || mustWriteParam(id);
    	if (updateServer) {
		//if(dbesp.WRITE_ESC_CACHE == (DEFINE_WRITE_CACHE.ALWAYS || (DEFINE_WRITE_CACHE.ONLY_PERM_PARAM && isParamPermanent(id)) ) ){
    		
    		var request = $.ajax({
                type: "POST", 
                contentType: "text/plain", 
                url: escRootURL + '/' + id, 
                dataType: "text",
                data: value, 
                cache: false
            });
			if (onSuccess) {
				request.done(onSuccess)
			}
			if (onError) {
				request.fail(onError)
			}
    	}
    	var success=true;
		if (localCacheESC.exist(id)) {
			success=false;
    	} else {
			localCacheESC.set(id, value);
		}
		if (!updateServer) {
			if (success) {
				if (onSuccess) onSuccess();
			} else {
				if (onError) onError();
			}
		}
    };

    /**
     * Function to add or update an element to the ESC
     * @param {String} id Id to use
     * @param {String} value Value to store
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     */
    _esc.updateESC = function(/* String */id, /* String */value, /* Function */onSuccess, /* Function */onError, /* boolean */ignoreCache) {
        
		localCacheESC.set(id, value);
    	var updateServer=ignoreCache || mustWriteParam(id);
    	if (updateServer) {
        // if(dbesp.WRITE_ESC_CACHE == (DEFINE_WRITE_CACHE.ALWAYS || (DEFINE_WRITE_CACHE.ONLY_PERM_PARAM && isParamPermanent(id)) ) ){
    		
    		var request = $.ajax({
    			// 2016.11.29: PUT is blocked in some browsers and POST in backed has exactly the same feature.
                type: "POST", //"PUT",
                contentType: "text/plain", 
                url: escRootURL + '/' + id, 
                dataType: "text", 
                data: value,
                cache: false
            });
			if (onSuccess) {
				request.done(onSuccess)
			}
			if (onError) {
				request.fail(onError)
			}
    	} else {
    		if (onSuccess) onSuccess();
    	}
    	
    	//else if (dbesp.WRITE_ESC_CACHE == (DEFINE_WRITE_CACHE.NEVER || (DEFINE_WRITE_CACHE.ONLY_PERM_PARAM && !isParamPermanent(id))) ){
		//}
    };

    /**
     * Function to delete an element from the ESC
     * @param {String} id Id to delete
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     */
    _esc.deleteESC = function(/* String */id, /* Function */onSuccess, /* Function */onError, /* boolean */ignoreCache) {
    	deleteESCInternal(id, onSuccess, onError, false, ignoreCache);
    };

    /**
     * Function to delete an element from the ESC
     * @param {String} id Id to delete
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     */
    _esc.deleteESCSync = function(/* String */id, /* Function */onSuccess, /* Function */onError, /* boolean */ignoreCache) {
    	deleteESCInternal(id, onSuccess, onError, true, ignoreCache);
    };

    /**
     * Function to delete an element from the ESC.
     * @param {String} id Id to delete
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     */
    function deleteESCInternal (/* String */id, /* Function */onSuccess, /* Function */onError, /* boolean */ synch, /* boolean */ignoreCache) {
        
    	var isSynch=synch?true:false;
    	var updateServer=ignoreCache || mustWriteParam(id);
    	if (updateServer) {
//		if(dbesp.WRITE_ESC_CACHE == (DEFINE_WRITE_CACHE.ALWAYS || (DEFINE_WRITE_CACHE.ONLY_PERM_PARAM & isParamPermanent(id)) ) ){
    		var okCallback=onSuccess?onSuccess:(function(data){dbesp.debug('deleteESCInternal.onSuccessCallback', data);});
    		var koCallback=onError?onError:(function(data){dbesp.debug('deleteESCInternal.onErrorCallback', data);});
    		var request = $.ajax({
    			async: isSynch,
                type: "DELETE",
                url: escRootURL + '/' + id,
                cache: false,
				success: okCallback,
				error: koCallback
            });
    	}
	
		localCacheESC.remove(id);
		if(!updateServer) {
			if (onSuccess)onSuccess();
		}
    }

    /**
     * Function to find an element in the ESC
     * @param {String} id Id to find
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     * @param {boolean) ignoreCache if true, rest GET is allways executed ignoring local content -> value will be stored in cache normally
     */
    _esc.findESC = function(/* String */id, /* Function */onSuccess, /* Function */onError, /* Boolean */ignoreCache) {
        findEscInternal(id, onSuccess, onError, false, ignoreCache);
    };

    /**
     * Function to find an element in the ESC (Synchronous)
     * @param {String} id Id to find
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     * @param {boolean) ignoreCache if true, rest GET is allways executed ignoring local content -> value will be stored in cache normally
	 * @return esc key value
     */
    _esc.findESCSync = function(/* String */id, /* Function */onSuccess, /* Function */onError, /* Boolean */ignoreCache) {
        return findEscInternal(id, onSuccess, onError, true, ignoreCache);
    };
    /**
     * Function to find an element in the ESC
     * @param {String} id Id to find
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     * @param {boolean} syndh if communication is synchronous or not
     * @param {boolean) ignoreCache if true, rest GET is allways executed ignoring local content -> value will be stored in cache normally
     */
    function findEscInternal(/* String */id, /* Function */onSuccess, /* Function */onError, /* boolean */ synch, /* boolean */ignoreCache) {
    	var useCache=ignoreCache?false:true;
    	var isSynch=synch?true:false;
		var retVal=null;
		if(useCache && localCacheESC.exist(id)){
			retVal=localCacheESC.get(id);
    		if (onSuccess) onSuccess(retVal);
    	} else {
	    	$.ajax({
	            async: !isSynch,
	            type: "GET",
	            url: escRootURL + '/' + id,
	            dataType: "text",
	            cache: false,
	            success: function(data) {
					retVal=data;
			//		if (dbesp.WRITE_ESC_CACHE == (DEFINE_WRITE_CACHE.NEVER || (DEFINE_WRITE_CACHE.ONLY_PERM_PARAM & !isParamPermanent(id))) ) {
						localCacheESC.set(id, data);
			//		}
					if (onSuccess) onSuccess(data);
                }, 
	            error: onError
	        });  
    	}
		return retVal;
    }

    /**
     * Function to clean the ESC values from a user
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     */
    _esc.cleanESC = function(/* Function */onSuccess, /* Function */onError) {
        $.ajax({
            type: "DELETE",
            url: escRootURL + '/clean',
            cache: false,
            success: onSuccess,
            error: onError
        });
        localCacheESC.removeAll();
    };

    dbesp.esc = {
        addESC : _esc.addESC,
        updateESC : _esc.updateESC,
        deleteESC : _esc.deleteESC,
        deleteESCSync : _esc.deleteESCSync,
        findESC : _esc.findESC,
        findESCSync : _esc.findESCSync,
        cleanESC : _esc.cleanESC
	};

})();


/**
 * @class
 * @memberOf dbesp.changeLanguage
 * @namespace
 * @description Class to manage the languages. Ex.: Switch values between languages
 * It has two features: label change and add language change feature to buttons.
 * LANGUAGE CHANGE (findDOM):
 * tags with lang class and pLang attribute: on language change event, pLang value is used as label key and tag text is replaced by label value.
 * BUTTON FEATURE (registerWidgetLanguageButtons):
 * tags with lang class and language attribute are modified to add click event ()
 */
(function () {
    var changeLanguage = (function () {
    	// channel used to notify language change events
    	var changeLanguageEventName="changeLanguage";
    	// current portal language
    	var currentPortalLanguage="";
    	// current portal language literals in json
    	var currentPortalLanguageLabels=null;
    	// list of widgets to refresh when language event comes
    	var managedWidgetList=[];
    	// flag to don't do in parallel two language modifications
    	var isRunningLanguageChangeEvent=false;
    	
    	// deprecated. this variable stores last language pressed in a change language button
        //var languageRequest;
        
        //name session Topic in ESC
        var escLangVariableName = "LANG";
        
        

        /**
         * public
         * updates portal language using /rest/lang/{codeLang} interface and triggers changeLanguage event in portal.
         * As this method is called from widgets, when no change is done, leaves a log in console
         * @param {String} codeLang
         * @returns {undefined}
         */
        function updateLang(/*String*/ codeLang) {
        	if (currentPortalLanguage == codeLang) {
        		dbesp.log.debug('[dbesp.changeLanguage.updateLang]', 'No action done as new language (' + codeLang+') is equal to current language ('+ currentPortalLanguage+')');
        		return;
        	}
        	internalUpdateLang(codeLang);
        }
        
        /**
         * private
         * updates portal language using /rest/lang/{codeLang} interface and triggers changeLanguage event in portal.
         * As this method is called internally, when language is already set does not log anything
         * @param codeLang (String) new language code: es_ES, es, it, en_EN...
         */
        function internalUpdateLang(/*String*/ codeLang) {
        	if (currentPortalLanguage == codeLang) {
        		return;
        	}
        	if (isRunningLanguageChangeEvent) {
        		return;
        	}
        	isRunningLanguageChangeEvent=true;
            var root = dbesp.contextRoot + '/rest/lang/' + codeLang;
            dbesp.log.debug('[dbesp.changeLanguage.updateLang]', 'Updating language to ' + codeLang+' POST request url: ('+root+')' );
            //{codeLang}
            $.ajax({
                type: "POST",
                async: true,
                url: root,
                dataType: "text",
                cache: false,
                success: function () {
                    dbesp.log.debug('[dbesp.changeLanguage.updateLang]', 'Updated ok language to ' + codeLang);
                    setCurrentPortalLanguage(codeLang);
                    internalRefreshWidgets();
                    $.publish(changeLanguageEventName, [codeLang]);
                	isRunningLanguageChangeEvent=false;
                	// refresh local cache value.
                	dbesp.esc.updateESC(escLangVariableName, codeLang, function(){});
                },
                error: function () {
                	isRunningLanguageChangeEvent=false;
                    dbesp.log.error('[dbesp.changeLanguage.updateLang]', 'Error updating language to ' + codeLang);
                }
            });
        }

        /**
         * Function to initializate the language management.
         * asks current language to portal
         * register to "changeLanguage" channel
         */
        function internalInit() {
        	// get initial portal language
            var root = dbesp.contextRoot + '/rest/lang';
            $.ajax({
                type: "GET",
                url: root,
                dataType: "text",
                cache: false,
                success: function (codeLang, textStatus, jqXHR) {
                    dbesp.log.debug('[dbesp.changeLanguage.internalInit]', 'Initial portal language ' + codeLang);
                    setCurrentPortalLanguage(codeLang);
//                    $.publish("changeLanguage", [codeLang]); // Not sure if publis here: widget may not be loaded&registered
                },
                error: function (data, textStatus, jqXHR) {
                    dbesp.log.error('[dbesp.changeLanguage.internalInit]', 'Error getting language: ' + textStatus+', ('+data.status+') '+ data.statusText);
                }
            });
            
            // register to change language event
            $.subscribe(changeLanguageEventName, changeLangCallback, "dbesp.changeLanguage");
            
            function changeLangCallback(newLang) {
            	internalUpdateLang(newLang);
            }
            
        }
        
        /**
         * public
         * adds widget to list to be monitored: when portal language changes, widget will be changed
         * by the way executes labels change for current language
         * @param name unique name. If set to a valid value and new object with same name is set, replaces previous element.
         * @param object DOM object, jquery selected element, widget instance or jquery filter (String) 
         */
        function addWidgetToLanguageChangeMonitoring(/*String*/name, /* Object */object) {
        	// step 1: add to monitored widget list
        	var widget2add=new managedWidgetElement(name, object);
        	var pending2add=true;
        	if (name) {
        		managedWidgetList.forEach(function(elem, index, array){
        			if (elem && elem.name && name==elem.name) {
        				managedWidgetList[index]=widget2add;
        				pending2add=false;
        			}
        		});
        	}
        	if (pending2add) {
        		managedWidgetList[managedWidgetList.length]=widget2add;
        	}
        	// step 2: check labels on the widget.
        	changeLanguageDOM(object);
        }
        
        /**
         * public
         * scans widget DOM searching for objects with lang class and language attribute and adds them 
         * change language feature.
         * Requisite to bind click event to notifyLangChange function: have Lang class and language attribute
         * @returns number of registered items.
         */
        function registerWidgetLanguageButtons(/* Object */object) {
        	var numButtonsBinded=0;
        	var findBase=get$filter(object);
        	if (findBase && findBase.find) {
        		var butsList=findBase.find('.lang');
        		if (butsList && butsList.length>0) {
            		for (var i=0;i<butsList.length;i++) {
            			var oneBut=$(butsList[i]);
            			if(oneBut && oneBut.attr('language') != undefined){
	            			var language=oneBut.attr('language');
	            			if (language) {
	            				oneBut.bind('click', notifyLangChange);
	            				oneBut.addClass('dbesp_lang_link');
	            				numButtonsBinded++;
	            				var butName=oneBut.attr('id');
	            				if(!butName) butName=oneBut.attr('name');
	            				if(!butName) butName=oneBut.attr('class');
	            				dbesp.log.info('dbesp.changeLangugage.registerWidgetLanguageButtons', 'bind done for language '+language+' on object '+butName);
	            			}
            			}
            		}
        		}
        	} else {
        		dbesp.log.error('dbesp.changeLangugage.registerWidgetLanguageButtons', 'required parameter '+object+' is not filtrable. No language button bind done ');
        	}
        	dbesp.log.info('dbesp.changeLangugage.registerWidgetLanguageButtons', 'Number of language buttons linked: '+numButtonsBinded);
        	return numButtonsBinded;
        }
        /**
         * private
         * returns a jquery object with .filter function 
         */
        function get$filter(/* Object */object) {
        	var retObj=null;
        	if (object) {
        		if (object.filter) { // object is already filter able
        			retObj=object;
        		} else if (object.body) { // object is a widget
        			retObj=$(object.body);
        		} else { // let jquery do its best. Hopefuly this is a filter string
        			retObj=$(object);
        		}
        	}
        	return retObj;
        }
        
        /**
         * private
         * function to be bind to language change buttons.
         * When the button is pressed, the new language is attribute languge value
         */
        function notifyLangChange(event) {
            if (event.preventDefault) {
                event.preventDefault();
            } else {
                event.returnValue = false;
            }
            // get event source. At least on firefox it does not work srcElement
            var srcElement=null;
            if (event.originalEvent) {
            	srcElement=event.originalEvent.target || event.originalEvent.srcElement;
            } else {
            	srcElement=event.target || event.srcElement;
            }
            var langAttrVal = $(srcElement).attr("language");
            //if (languageRequest !== null || languageRequest !== undefined) {
            if (langAttrVal !== null && langAttrVal !== undefined) {
                dbesp.log.debug('dbesp.changeLangugage.init', 'Language request ' + langAttrVal);
                updateLang(langAttrVal);
//                dbesp.esc.findESC(escLangVariableName,
//                    function (data) {
//                        if (data !== '') {
//                            var languageSession = data;
//                            dbesp.log.info('dbesp.changeLanguage.init', 'Language in ESC  ' + languageSession);
//                            //changeLanguage
//                            //if (languageRequest != languageSession){
//                            dbesp.log.debug('dbesp.changeLangugage.init', 'Changing language ' + languageSession + ' to ' + languageRequest);
//                            updateLang(languageRequest);
//                            //}
//                        } else {
//                            dbesp.log.info('dbesp.changeLanguage.init', 'There is not language in ESC  ');
//                        }
//                    }
//                    , function () {
//                        dbesp.log.error('[dbesp.changeLanguage.init]', 'Error finding language in ESC');
//                    }
//                );
            }
        }
        /**
         * deprecated. use registerWidgetLanguageButtons instead
         * scans ALL DOM searching for objects with lang class and adds change language feature to them 
         * @returns void
         */
        function init() {
        	registerWidgetLanguageButtons($(document));
/*
            //Set function to elements with class lang
            $('.lang').bind('click', function (event) {
                if (event.preventDefault) {
                    event.preventDefault();
                } else {
                    event.returnValue = false;
                }
                languageRequest = $(this).attr("language");
                //if (languageRequest !== null || languageRequest !== undefined) {
                if (languageRequest !== null && languageRequest !== undefined) {
                    dbesp.log.debug('dbesp.changeLangugage.init', 'Language request ' + languageRequest);
                    dbesp.esc.findESC(escLangVariableName,
                        function (data) {
                            if (data !== '') {
                                var languageSession = data;
                                dbesp.log.info('dbesp.changeLanguage.init', 'Language in ESC  ' + languageSession);
                                //changeLanguage
                                //if (languageRequest != languageSession){
                                dbesp.log.debug('dbesp.changeLangugage.init', 'Changing language ' + languageSession + ' to ' + languageRequest);
                                updateLang(languageRequest);
                                //}
                            } else {
                                dbesp.log.info('dbesp.changeLanguage.init', 'There is not language in ESC  ');
                            }
                        }
                        , function () {
                            dbesp.log.error('[dbesp.changeLanguage.init]', 'Error finding language in ESC');
                        }
                    );
                }
            });
*/
        }
        
        /**
         * private
         * on language change, refresh regitered widgets DOM with new language labels text
         */
        function internalRefreshWidgets() {
        	managedWidgetList.forEach(function(elem, index, list){
        		// all elem's are managedWidgetElement type
        		dbesp.log.debug('dbesp.changeLangugage.internalRefreshWidgets', 'change labels on widget ' + elem.name);
        		changeLanguageDOM(elem.object);
        	});
        	
        	
        }


        /**
         * Function to change the language of a given DOM.
         * @param {Object} object Id of the DOM we want to change the language.
         */
        function changeLanguageDOM(/* Object */object) {
        	findDOM(object, currentPortalLanguage);
//            var languageD = languageRequest;
//            if (languageD === null) {
//                //alert('languageD is null');
//                var rootURLLang = dbesp.contextRoot + "/rest/lang";
//                $.ajax({
//                    type: "GET",
//                    contentType: "text/plain",
//                    url: rootURLLang,
//                    async: false,
//                    cache: false,
//                    //processData: false,
//                    success: function (data, textStatus, jqXHR) {
//                        //alert('1.languageD ' + data);
//                        if (data === undefined || data === 'undefined') {
//                            //alert('aqui!');
//                            //todo: Change by errHandling or property
//                            data = "fr_FR";
//                        }
//                        findDOM(object, data);
//
//                    },
//                    error: function (jqXHR, textStatus, errorThrown) {
//                        //alert("Error getting language");
//                        dbesp.log.error('[dbesp.changeLanguage.changeLanguageDOM]', 'Error :' + textStatus + ' , ' + errorThrown);
//
//                    }
//                });
//
//
//            } else {
//                findDOM(object, languageD);
//            }
//

        }

//        /**
//         *
//         * @returns {String}
//         */
//        function getSessionTopic() {
//            return escLangVariableName;
//        }
//
        /**
         *
         * @param {DOMObject} object
         * @param {String} language
         * @returns {undefined}
         */
        function findDOM(/*DOMObject*/object, /*String*/ language) {
        	var currentLabels=getCurrentPortalLabels();
        	var obj=get$filter(object);
        	if (currentLabels!=null && obj && obj.find) {
        		var curLang=getPortalLanguage();
        		obj.find('.lang').each(function () {
                    var objectLang = $(this);
                    var labelKey = objectLang.attr('pLang');
                    if (labelKey) {
                        var labelValue = dbesp.utils.misc.getjSonValueUnic(currentLabels, labelKey);
                        if (!labelValue) labelValue=labelKey;
                        objectLang.text(labelValue);
                    }
        			if(objectLang.attr('language') != undefined){
        				// this is a change language link
            			var linkLang=objectLang.attr('language');
            			objectLang.removeClass('dbesp_lang_link_selected');
            			if (linkLang==curLang) {
            				objectLang.addClass('dbesp_lang_link_selected');
            			} 
        			}
                });
        	}
//            var rootURL = dbesp.contextRoot + "/rest/lang/props/" + language;
//            dbesp.log.debug('[dbesp.changeLanguage.findDOM]', 'rootURL ' + rootURL);
//            $.ajax({
//                type: "GET",
//                contentType: "application/json",
//                url: rootURL,
//                async: false,
//                cache: false,
//                //processData: false,
//                success: function (data, textStatus, jqXHR) {
//                    object.find('.lang').each(function () {
//                        var objectLang = $(this);
//                        var pLang = objectLang.attr('pLang');
//                        var value = dbesp.utils.misc.getjSonValueUnic(data, pLang);
//                        objectLang.text(value);
//                    });
//                },
//                error: function (jqXHR, textStatus, errorThrown) {
//                    //alert('findDOM error getting literal in object\n' + object.html() + '\n language ' + language) ;
//                    dbesp.log.error('[dbesp.changeLanguage.findDOM]', 'Error :' + textStatus + ' , ' + errorThrown);
//
//                }
//            });
        }
        
        /**public*/
        function getPortalLanguage() {
        	return currentPortalLanguage; //dbesp.PORTAL_CORE_LANG;
        }

        /**private
         * only updates local value stored for portal language.
         * Does not propagata any event*/
        function setCurrentPortalLanguage(language) {
        	if (currentPortalLanguage!=language) {
            	currentPortalLanguage=language; //dbesp.PORTAL_CORE_LANG;
            	dbesp.PORTAL_CORE_LANG=language;
            	currentPortalLanguageLabels=null;
        	}
        }
        
        /**
         * private
         * returns labels for current language in json.
         */
        function getCurrentPortalLabels() {
        	if (currentPortalLanguageLabels==null) {
        		// lang/props service will return default language labels, but rest interface cannot manage not having language parameter
        		var lang=currentPortalLanguage?currentPortalLanguage:'unknown';
                var rootURL = dbesp.contextRoot + "/rest/lang/props/" + lang;
                $.ajax({
                    type: "GET",
                    contentType: "application/json",
                    url: rootURL,
                    async: false, // synchronous communication
                    cache: false, // do not use previous values
                    //processData: false,
                    success: function (data, textStatus, jqXHR) {
                        dbesp.log.debug('[dbesp.changeLanguage.findDOM]', 'ok rootURL ' + rootURL);
                    	currentPortalLanguageLabels=data;
                    },
                    error: function (jqXHR, textStatus, errorThrown) {
                        //alert('findDOM error getting literal in object\n' + object.html() + '\n language ' + language) ;
                        dbesp.log.error('[dbesp.changeLanguage.getCurrentPortalLabels]', 'Error rootURL ' + rootURL+': ' + textStatus + ' , ' + errorThrown);

                    }
                });
        	}
        	return currentPortalLanguageLabels;
        }
        
        
        // launch initial configuration.
        internalInit();


        return {
        	// init: scan ALL DOM searching for objects with lang class and adds change language feature on click.
        	// deprecated: must be enclosed to a widget. use registerWidgetLanguageButtons instead
            init: init,
            // changeLanguageDOM: scan a section to change language items. same feature than findDOM but also checks language
            // deprecated: use addWidgetToLanguageChange instead
            changeLanguageDOM: changeLanguageDOM,
            //getSessionTopic: getSessionTopic,
            // findDOM: scan a section to change language items.
            // deprecated: use addWidgetToLanguageChange instead
            findDOM: findDOM,
            
            // String: name of the event where the change language pubsubs are propagated
            changeLanguageEventName:changeLanguageEventName,
            // returns current portal language (String)
            getPortalLanguage: getPortalLanguage,
            // widget asks to parse its DOM and add to language buttons the change language feature
            registerWidgetLanguageButtons: registerWidgetLanguageButtons,
            // widgets asks to be registered to parse its DOM and change labes on language change events
            registerWidgetToLanguageChangeMonitoring: addWidgetToLanguageChangeMonitoring,
            // widget notifies that language is changed. Parameter is new language. This starts portal labels change
            changePortalLanguage:updateLang
        };
        
        function managedWidgetElement(name, object) {
        	var myName=name;
        	var myObject=object;
        	return {
        		name:myName,
        		object:myObject
        	}
        }
    })();

    dbesp.changeLanguage = changeLanguage;
    dbesp.i18n = changeLanguage;
})();




(function () {
    'use strict';

    /**
     * Create message windows
     * @exports core/overlay
     */
    var overlay = {};

    /**
     *
     */
    overlay.overlayThis = function () {
        // if the function argument is given to overlay,
        // it is assumed to be the onBeforeLoad event listener

        $('a[rel]').overlay({
            mask: {
                color: '#ebecff',
                loadSpeed: 200,
                opacity: 0.9
            },
            closeOnClick: false,
            onBeforeLoad: function () {

                // grab wrapper element inside content
                var wrap = this.getOverlay().find(".contentWrap");
                // load the page specified in the trigger
                wrap.load(this.getTrigger().attr("href"));
            }

        });
    };

    /**
     * Show a popup window
     * @param {type} msg Message to show inside the window
     * @param {type} isClosable Show or not a close button
     */
    overlay.showMsg = function (msg, isClosable) {

        //div with the message
        var $coreOverlay = $("<div id=\"coreOverlay\" class=\"coreOverlay\"></div>");
        $coreOverlay.append(msg);
        if (isClosable) {
            $coreOverlay.append("<div style=\"margin-left:auto; margin-right:auto; width:7em;\"><br/><br/><a title=\"Click to close\" "
            + "href=\"#\" id= \"coreOverlayButton\" class= \"coreOverlayButton\">Close</a></di>");
            //  + "href=\"#\" id= \"coreOverlayButton\" class= \"coreOverlayButton\"  onClick=\"$('#overlayMsg').remove();return false;\">Close</a></di>");
        }
        var $overlay = $("<div id='overlayMsg' class=\"coreOverlayMsg\">");

        $overlay.append($coreOverlay).append("</div>").appendTo($("body").css("position", "relative"));

        if (isClosable) {
            $('#coreOverlayButton').click(function () {
                $('#overlayMsg').remove();
            });
        }
    };


    dbesp.overlay = overlay;
})();
(function () {
    'use strict';

    /**
     * The purpose of this function is to be a class for the tracking object.
     * Tracking encapsulates access to tracking services in the backend.
     * @exports core/tracking
     *
     * @requires module:jQuery
     * @requires module:core/dbesp
     * @requires module:core/log
     */
    var tracking = {};

    // The root URL for the RESTful services for contexts
    var rootURL = dbesp.contextRoot + "/rest/";

    /**
     * Function to send a security event
     * @param {String} xmlDocument XML with the security event
     */
    tracking.sendSecurityEvent = function (xmlDocument) {
        dbesp.log.debug('core-tracking.sendSecurityEvent', 'SendSecurityEvent');
        $.ajax({
            type: 'POST',
            contentType: 'application/xml',
            url: rootURL + "security",
            processData: false,
            data: xmlDocument,
            cache: false,
            success: function (data, textStatus, jqXHR) {
                dbesp.log.debug('core-tracking.sendSecurityEvent', 'Success in sending event');
            },
            error: function (jqXHR, textStatus, errorThrown) {
                dbesp.log.error('core-tracking.sendSecurityEvent', 'Error:' + textStatus + ',' + errorThrown);
            }
        });
    };

    /**
     * Function to send a navigation event with the content id
     * @param {String}      eventType   The type of the event produced
     * @param {String}      widgetId    The id from the widget associated to the event
     * @param {String}      linkTrack   The url from the link we are clicking
     */
    tracking.sendNavigationEvent = function (eventType, widgetId, linkTrack) {
        //TODO: define a better method for getting the actual page (for example store it in a global variable, or send it from the widget, or...)
        var actualPage = (document.URL).split('/').reverse()[0];
        var xmlDocument = '<?xml version="1.0" encoding="UTF-8" standalone="yes"?><navigationEvent><type>' + eventType + '</type><contentId>' + actualPage + '</contentId><widgetId>' + widgetId + '</widgetId><linkTrack>' + linkTrack + '</linkTrack></navigationEvent>';
        postNavigationEvent(xmlDocument)
    };

    /**
     * Function to send a navigation event
     * @private
     * @param {String} xmlDocument XML with the navigation event
     */
    function postNavigationEvent(xmlDocument) {
        $.ajax({
            type: 'POST',
            contentType: 'application/xml',
            url: rootURL + "navigationAudit",
            processData: false,
            data: xmlDocument,
            cache: false,
            success: function (data, textStatus, jqXHR) {
                dbesp.log.debug('core-tracking.postNavigationEvent', 'Success in sending event');
            },
            error: function (jqXHR, textStatus, errorThrown) {
                dbesp.log.debug('core-tracking.postNavigationEvent', 'Error:' + textStatus + ',' + errorThrown);
            }
        });
    }

    dbesp.tracking = tracking;
})();
/*
 * @class
 * @memberOf session
 * @namespace 
 * @description  The purpose of this class is to handle all the logic logout from
 * the session.
 */
define('b-core/js/session', function () {
    'use strict';
	var session = function () {

        /**
         * Function that does all the needed things in a logout.
         * @param stay: when true does not redirect to welcome page (hopefully to display a "disconnected message")
         */
        function internetLogout(stay) {
            dbesp.log.info('logout.internetLogout', 'logout process: remove window occupetion token');
        	dbesp.internal.browserHandling.voidToken();
            dbesp.log.info('logout.internetLogout', 'logout process: stop session handling');
        	dbesp.internal.sessionHandling.stop();
            dbesp.log.info('logout.internetLogout', 'logout process: remove backend session');
            //Clean the ESC cache and close the ECDL session.
            $.ajax({
                type: "DELETE",
                url: dbesp.contextRoot + '/rest/loginLogout',
                cache: false,
                success: function () {
                    dbesp.log.info('logout.internetLogout', 'Logout successfully.');
                    cleanAndRedirect(stay);
                },
                error: function (jqXHR, textStatus, errorThrown) {
                    dbesp.log.error('logout.internetLogout', 'Error logging out: ' + textStatus + ' , ' + errorThrown);
                    cleanAndRedirect(stay);
                }
            });
        }

        /**
         * even deleting mod_auth_cas cookie, cas restores it on first query. Therefore explicit logout must be executed
         * on portals that are protected with CAS solution. 
         * For other solutions remove portal session in case backend have failed on session expire and redirect to / 
         */
        function cleanAndRedirect(stay) {
            // portal cookie (in case backed call failed)
            deleteCookie('JSESSIONID');
            // other cookies generated on portal load
            deleteCookie('F5_Cookie');
            var newLocaltion="/";
        	if (existsCookie('MOD_AUTH_CAS_S')) {
                // dbdirect CAS cookies
                deleteCookie('MOD_AUTH_CAS_S');
                deleteCookie('casLang');
                // call CAS logout service to close CAS session
            	newLocaltion = '/cas/logout?service=' + location.protocol + "//" + location.host + dbesp.contextRoot + "/portals/" + dbesp.portalName;
        	}
            if (!stay) {
                // call CAS logout service to close CAS session
                window.location = newLocaltion;
            }
        }

        function deleteCookie(cookiename) {
            var d = new Date();
            d.setDate(d.getDate() - 1);
            var expires = ";expires=" + d;
            var name = cookiename;
            //alert('Borrando cookie: ' + name);
            var value = "";
            document.cookie = name + "=" + value + expires + "; path=/";
        }

        function existsCookie(cookieName) {
        	var isThere=false;
        	var allCookies=document.cookie;
        	var cname=cookieName+"=";
        	if (allCookies && allCookies.indexOf(cname)>0) {
        		isThere=true;
        	}
        	return isThere;
        }

        return {
            logout:internetLogout
        }

    }();
    dbesp.session = session;
	return session;
});

// force load to create elements
require(['b-core/js/session'],function(session){});


(function() {
    'use strict';

    /**
     * @description Common utilities
     * @exports core/utils/commons
     *
     * @requires module:lodash
     */
    var commons = {};

    // Create alias for shorter variable resolution
    var slice = Array.prototype.slice;
    /**
     * Acts as a function invoker when 'fn' is a function and as a simple identity function when 'fn' is not a function
     * @param {object} [context] An optional context to which the function's "this" will be bound
     * @param {Function|*} fn The function to check and to invoke or an object
     * @param {...*} [extraArgs] an optional set of arguments that will be applied to function
     * @return {*} the functions invocation result or the same passed object
     */
    commons.fireFunctionSafe = function (context, fn, extraArgs) {
        var args;
        if (_.isFunction(context)) {
            fn = context;
            context = null;
            args = slice.call(arguments, 1);
        } else {
            args = slice.call(arguments, 2);
        }
        if (_.isFunction(fn)) {
            return fn.apply(context, args);
        } else if (fn === void(0)) {
            return context;
        } else {
            return fn;
        }
    };

    dbesp.utils = dbesp.utils || {};
    dbesp.utils.commons = commons;
})();

(function() {
    'use strict';

    /**
     * @description Common utilities
     * @exports core/utils/fn
     *
     * @requires module:lodash
     */
    var fn = {};


    // Create alias for shorter variable resolution
    var slice = Array.prototype.slice;

    /**
     * Replaces and returns the constructor with one that calls the constructor
     * specified. In order to keep the prototype chain right, it assigns the
     * prototype of the new constructor to the parents prototype and then
     * re-points the prototype constructor.
     * If mixins are provided, they will be merged into the final constructor
     *
     * @param {Function} source the source constructor that will inherit from another one
     * @param {Function} parent the parent constructor function to extend from
     * @param {Array|Object} [mixins]
     * @param {...*} [extraArgs]
     *
     * @return {Function} the new constructor
     */
    fn.inherit = function(source, parent, mixins, extraArgs) {
        var parentArgs,
            childConstructor,
            helperConstructor;
        // Check argument
        if (!_.isFunction(parent)) {
            throw new TypeError('First argument must be a constructor function');
        }

        if (mixins && !_.isArray(mixins)) {
            mixins = [mixins];
        }
        parentArgs = slice.call(arguments, 3) || [];
        // Store the original constructor
        childConstructor = source;
        // Replace the constructor function using one that invokes
        // parent constructor
        helperConstructor = function() {
            var args = slice.call(arguments);
            // Call parent constructor using parent args and children ones
            parent.apply(this, parentArgs.concat(args));
            if (mixins) {
                _.forEach(mixins, function(mixin) {
                    mixin.apply(this, args);
                }, this);
            }
            // Call self constructor
            childConstructor.apply(this, args);
            return this;
        };
        // Set the source and the instantiator prototypes to the parent prototype
        helperConstructor.prototype = Object.create(parent.prototype, {});
        if (mixins) {
            mixinWithDependencies(helperConstructor, mixins);
        }
        // Re-point constructor to original constructor property
        helperConstructor.prototype.constructor = source;
        // Return the new constructor
        return helperConstructor;
    };

    /**
     * Returns an instance of the self constructors prototype with arguments applied.
     * Basically it hides the uglyness of the new operator by calling Object create
     *
     * @param {Function} source constructor that will be instantiated
     * @param {...*} [extraArgs] comma separated set of arguments to pass to constructor
     *
     * @return {object} An instance of the constructor functions prototype with arguments applied
     */
    fn.createInstance = function(source, extraArgs) {
        var instance = Object.create(source.prototype, {});
        var args = slice.call(arguments, 1) || [];
        return source.apply(instance, args) || instance;
    };

    function mixinWithDependencies(constructor, mixins) {
        constructor.prototype.mixinInitializers = constructor.prototype.mixinInitializers || [];
        _.forEach(mixins, function (mixin) {
            if (mixin.dependencies && mixin.dependencies.length > 0) {
                mixinWithDependencies(constructor, mixin.dependencies);
            }
            _.mixin(constructor.prototype, mixin.prototype);
            constructor.prototype.mixinInitializers = _(mixins).map("mixinInitializer").concat(constructor.prototype.mixinInitializers).uniq().value();
        });
    }

    dbesp.utils = dbesp.utils || {};
    dbesp.utils.fn = fn;
})();
/**
 * @description Objective is group all avaliable utilities in javascript.
 */
(function () {
    'use strict';

    var charToScape = ['.', ':'];

    /**
     * Function to scape a String.
     * @param {String} message String to scape.
     */
    function stringCharScape(/* String */message) {
        var returnValue = message + '';
        var charScape = '';
        for (var i = 0; i < charToScape.length; i++) {
            charScape = charToScape[i];
            //alert(charScape + " - " + message);
            //alert('typeof(message) --> ' + typeof(message));

            //if(typeof(message)=='string' && isNaN(message)){
            returnValue = replaceAll(returnValue, '\\' + charScape, '\\' + charScape)
            //}
            //message = message.split(charScape).join('\\'+charScape);
            //alert(charScape + " _ " + message);

        }

        return returnValue;
    }

    /**
     *
     * @private
     * @param {String} txt
     * @param {String} replace
     * @param {String} with_this
     */
    function replaceAll(/* String */txt, /* String */replace, /* String */with_this) {
        return txt.replace(new RegExp(replace, 'g'), with_this);
    }

    //    function replaceAllS(content,findWith,replaceWith){
    //        var str = content;
    //        var str2replace = content;
    //        alert('str ' + str + '\nfindWith '+ findWith + '\nreplaceWith ' +replaceWith);
    //        alert('2.\nstr ' + str + '\nfindWith '+ findWith + '\nreplaceWith ' +replaceWith);
    //        var ind = '1.1'.indexOf(findWith);
    //        alert (ind);
    //        while(ind != -1){
    //            str = str2replace.replace(findWith,replaceWith);
    //            ind = str.indexOf(findWith);
    //            if (ind>0){
    //                replaceAllS(str)
    //            }
    //            alert (str);
    //        }
    //        return str;
    //    }

    /**
     *
     * @param {} data: json with selected language labels map
     *   example: {"language":{"propagationContentArea.tasksTab":"Activity","menuOnlyUpper.text.myAppNavigation":"Snelkoppelingen:"}}
     * @param {} parameter key of requested label
     */
    function getjSonValueUnic(data, parameter) {
        dbesp.log.debug('[core-misc.getjSonValueUnic]', 'Init : Search ' + parameter + ' in ' + JSON.stringify(data));
        for (var key in data) {
            if (data.hasOwnProperty(key)) {
                if (key == parameter) {
                    return (data[key]);
                } else if ("object" == typeof(data[key])) {
                    // Older versions only works if JSON object only have one level or if a JSON object (sub-tree) depends of first child
                    //Examples: Search K12 value in {K1:{K11:V11, K12:V12}, K2:V2} --> Woks fine, it returns V12.
                    //          Search K22 value in {K1:V1, K2:{K21:V21, K22:V22}} --> Fails because K22 is not a child of the first element.
                    //return getjSonValueUnic(data[key], parameter);

                    //This code allows search in all sub-trees and leaves
                    var value = getjSonValueUnic(data[key], parameter)
                    if (value != undefined) {
                        return value;
                    }
                }
            }
        }
        // TODO: console log error level that value has not been found
        dbesp.log.error('[core-misc.getjSonValueUnic]', 'Error :' + parameter + ' not found in ' + JSON.stringify(data));
        //return '';
    }


    /**
     *
     *  @param {} data
     *  @param {String} str
     *  @param {} rep
     */
    function intoObject(data, /* String */str, rep) {
        if (!rep) {
            rep = 0;
        }
        for (var key in data) {

            if ("object" == typeof(key)) {
                rep += 1;
                intoObject(key, str, rep);
            } else {
                var strConsole = "· ";
                for (var i = 1; i < rep; i++) {
                    strConsole += "· ";
                }
                var value = "";
                if ("undedfined" != typeof(data[key])) {
                    value = data[key];
                }
                if (strConsole && key && value) {
                    try {
                        dbesp.log.log('core-misc', strConsole + key + "(" + typeof(key) + ")" + "-->" + value, false);
                    } catch (ex) {
                        dbesp.log.log('core-misc', 'something weird happened', false);
                    }
                }
            }

        }
    }

    /**
     *
     * @param {} name
     */
    function getUrlParam(name) {
        //alert(name);
        if (name != null) {
            var results = new RegExp('[\\?&]' + name + '=([^&#]*)').exec(window.location.href);
            if (results != null && results[1] != null) {
                return results[1] || 0;
            } else {
                return 0;
            }

        } else {
            return 0;
        }

    }


    /**
     * Util function from dashboard
     * @param params
     */
    var xmlToJson = function (xml) {	// Create the return object
        // Create the return object
        var obj = {};

        if (xml.nodeType == 1) { // element
            // do attributes
            if (xml.attributes.length > 0) {
                obj["attributes"] = {};
                for (var j = 0; j < xml.attributes.length; j++) {
                    var attribute = xml.attributes.item(j);
                    obj["attributes"][attribute.nodeName] = attribute.nodeValue;
                }
            }
        } else if (xml.nodeType == 3) { // text
            obj = xml.nodeValue;
        }

        // do children
        if (xml.hasChildNodes()) {
            /*for (var i = 0; i < xml.childNodes.length; i++) {
             var item = xml.childNodes.item(i);
             var nodeName = item.nodeName;
             if (typeof(obj[nodeName]) == "undefined") {
             obj[nodeName] = xmlToJson(item);
             } else {
             if (typeof(obj[nodeName].push) == "undefined") {
             var old = obj[nodeName];
             obj[nodeName] = [];
             obj[nodeName].push(old);
             }
             obj[nodeName].push(xmlToJson(item));
             }
             }*/
            for (var i = 0; i < xml.childNodes.length; i++) {
                var TEXT_NODE_TYPE_NAME = '#text',
                    item = xml.childNodes.item(i),
                    nodeName = item.nodeName,
                    content;

                if (TEXT_NODE_TYPE_NAME === nodeName) {
                    //single textNode or next sibling has a different name
                    if ((null === xml.nextSibling) || (xml.localName !== xml.nextSibling.localName)) {
                        content = xml.textContent;

                        //we have a sibling with the same name
                    } else if (xml.localName === xml.nextSibling.localName) {
                        //if it is the first node of its parents childNodes, send it back as an array
                        content = (xml.parentElement.childNodes[0] === xml) ? [xml.textContent] : xml.textContent;
                    }
                    return content;
                } else {
                    if ('undefined' === typeof(obj[nodeName])) {
                        obj[nodeName] = xmlToJson(item);
                    } else {
                        if ('undefined' === typeof(obj[nodeName].length)) {
                            var old = obj[nodeName];
                            obj[nodeName] = [];
                            obj[nodeName].push(old);
                        }

                        obj[nodeName].push(xmlToJson(item));
                    }
                }
            }
        }
        return obj;
    };


    var misc = {
        stringCharScape: stringCharScape,
        getjSonValueUnic: getjSonValueUnic,
        getUrlParam: getUrlParam,
        intoObject: intoObject,
        replaceAll: replaceAll,
        xmlToJson: xmlToJson
    };

    dbesp.utils = dbesp.utils || {};
    dbesp.utils.misc = misc;
})();


(function() {
    'use strict';

    /**
     * @description Navigation utilities
     * @exports core/utils/navigation
     *
     * @requires module:jquery
     */
    var navigation = {};

    /**
     * To comment
     */
    var _selectedTab;

    /**
     * with bb 5.5.1.4 container html rendering  has changed. Suggestion from BackBase in https://backbase.atlassian.net/browse/DIPS-55
var containerElement = $('.bp-tabContFn-main')[0]; // change .bp-tabContFn-main to appropriate id or class to find the exact tab container
var childItemName = containerElement.viewController.model.childNodes[1].name; // childNodes contains tabs and indexing starts from 0. This code gets name for the second tab.
be.tabContainer.liveMode.switchTab(containerElement, childItemName); // switchTab is the method i have found inside container source
     * @param {String} tabName
     * @returns {boolean} Whether the specified tab was found and clicked or not
     */
    navigation.selectTab = function(tabName){
    	var selected=false;
        var _object = $('[data-index="'+ tabName +'"] > a')
        if(_object.length > 0){
            _selectedTab = tabName;
            _object.click();
            // selected tab may be inside another tab container, select also parent tab folder.
            var parentTab=navigation.getMyTab(tabName);
            navigation.selectTab(parentTab);
            selected=true;
        }
        // else: if length is 0 this is not a tab container identifier
        return selected;
    };


    navigation.setSelectedTab = function(tabName){
        _selectedTab = tabName;
    };

    /**
     * @returns {String} selected Tab name
     */
    navigation.getSelectedTab = function(){
        if (!_selectedTab) {
            _selectedTab = $('.bp-TabCont-tab-horizontal.bp-TabCont-tab-selected').data('index');
        }
        return _selectedTab;
    };

    /**
     * Checks if passed dom object is inside the specified tab or the currently selected tab
     * @param $element
     * @param [tabName = currently_selected_tab] parent tab PID to check for
     * @returns {boolean}
     */
    navigation.isInTab = function($element, tabName){
        if (tabName) {
            return $element.parents('[data-pid="' + tabName + '"]').length > 0;
        } else {
            if (!_selectedTab) {
                navigation.getSelectedTab();
            }
            $element.parents('.bp-TabCont-tab-horizontal[data-index="' + _selectedTab +'"]').length > 0;
        }
    };


    /**
     * @param widgetId The widget ID as defined in the import scripts
     * @return {string|undefined} The widget's tab name if the widget is in a tab, or else undefined if outside of a tab container.
     */
    navigation.getMyTab = function(widgetId){
        var myTab = $('[data-pid="' + widgetId + '"]').parents('.bp-container.bp-ColumnLayout.bp-ui-dragRoot');
        if (myTab.parent('.bp-TabCont-body').length) {
            return myTab.data('pid');
        } else {
            return;
        }
    };



    navigation.goToPage = function(pageName) {
        var link = $('.myPortalNavigation .' + pageName);
        if (link.length != 0) {
            document.location = link.attr('href');
        }
    }

    dbesp.utils = dbesp.utils || {};
    dbesp.utils.navigation = navigation;
})();

(function () {
    'use strict';

    /**
     * @description Preferences utilities
     * @exports core/utils/prefs
     *
     * @requires module:jquery
     * @requires module:lodash
     * @requires module:moment
     * @requires module:core/utils/commons
     * @requires module:core/utils/ui
     * @requires module:core/utils/service
     */
    var prefs = {};

    /**
     * The JQuery container which HTML content has the preferences that are being shown
     */
    var $preferenceContainer;

    /**
     * Sets the preference container being shown. Caching container provides
     * faster execution since it is not necessaty to search it again on DOM.
     * It has to be invoked on each preference window open since HTML is
     * detached when closed.
     * @param preferenceContainer
     */
    prefs.setPreferenceContainer = function (preferenceContainer) {
        $preferenceContainer = preferenceContainer;
    };

    /**
     * Hides the preference input specified by name
     * @param {string} preferenceName the name of the preference as specified on catalog
     */
    prefs.hidePreference = function (preferenceName) {
        $preferenceContainer.find('input[name="' + preferenceName + '"]').closest('tr').hide();
    };

    /**
     *  Encapsulates an AJAX request adapted to the specific requirements of core and services
     * @param {string} pipeName the string url for combo retrieval
     * @param {string} requestData Additional parameters for the request
     * @return {jQuery.Deferred}
     */
    prefs.fetchAjaxCombos = function (pipeName, requestData) {
        // Show loading and do the request
        dbesp.utils.ui.showLoading($preferenceContainer);
        return dbesp.utils.service.fetchJSON(pipeName, requestData).always(function () {
            dbesp.utils.ui.hideLoading($preferenceContainer);
        });
    };

    /**
     * @returns {{addDependingCombo: Function, load: Function}} A dependening combos builder
     * @example
     prefs.getDependingCombosLoader()
            .addDependingCombo('portal', bbWidgetInstance.getPreference('portal'), getPortals)
            .addDependingCombo('page', bbWidgetInstance.getPreference('page'), getPages)
            .addDependingCombo('widget', bbWidgetInstance.getPreference('widget'), getWidgets)
            .load(this.savedPrefs)
            .done(function () {
                               dbesp.log.debug('propagation.widget.testing-publisher.js', 'Depending preferences loaded successfully');
                           })
            .fail(function (xhr, status, error) {
                               dbesp.log.debug('propagation.widget.testing-publisher.js', 'Depending preferences failed to load with status: ' +
                               status + ': ' + error);
                           });

     */
    prefs.getDependingCombosLoader = function () {
        var comboDependencies = [];
        var result = {};
        result.addDependingCombo = function (preferenceName, currentValue, pipeNameOrComboOptions, comboId) {
            addDependingCombo.apply(this, Array.prototype.concat.apply([comboDependencies], arguments));
            return result;
        };
        result.load = function () {
            return loadDependingPreferences.apply(this, Array.prototype.concat.apply([comboDependencies], arguments));
        };
        return result;
    };


    /**
     * @deprecated Use DependingCombosLoader.addDependingCombo
     * @see prefs.getDependingCombosLoader
     */
    prefs.addDependingCombo = function (comboDependencies, preferenceName, currentValue, pipeNameOrComboOptions, comboId) {
        addDependingCombo(comboDependencies, preferenceName, currentValue, pipeNameOrComboOptions, comboId);
    };

    /**
     * Adds a single combo data to the array of dependencies
     * @param {Array} comboDependencies The array of depending preference data of the combo
     * @param {string} preferenceName The name of the preference as specified on catalog
     * @param {*} currentValue The current selected value of the preference
     * @param {String|object} pipeNameOrComboOptions It can be either a string url for combos that load remotely,
     *          or the combo options for the ones that know them before the sequential load
     * @param {String} [comboId] The id of the combo having the options that want to be retrieved. Optional when the service returns only one combo.
     * @public
     */
    function addDependingCombo (comboDependencies, preferenceName, currentValue, pipeNameOrComboOptions, comboId) {
        comboDependencies.push({
            preferenceName: preferenceName,
            comboId: comboId || preferenceName,
            currentValue: currentValue,
            // Use the pipe URL specified or combo options
            url: _.isString(pipeNameOrComboOptions)? pipeNameOrComboOptions : undefined,
            comboOptions: !_.isString(pipeNameOrComboOptions)? pipeNameOrComboOptions : undefined
        });
    }

    /**
     * Retrieves a specific array of options from a response combos object by comboId
     * @param {string} comboId The id of the combo having the options that want to be retrieved
     * @param {object} responseCombos An object containing a array of combo objects or a single combo
     * @return {array}
     */
    prefs.filterComboById = function (comboId, responseCombos) {
        var combos = responseCombos && responseCombos.combo,
            singleCombo;
        if (combos instanceof Array) {
            for (var i = combos.length; i--;) {
                singleCombo = combos[i];
                if (singleCombo.idCombo === comboId) {
                    return singleCombo.item;
                }
            }
        } else {
            if (combos && (!comboId || combos.idCombo === comboId)) {
                return combos.item;
            }
        }
        return [];
    };

    /**
     * @deprecated Use DependingCombosLoader.load
     * @see prefs.getDependingCombosLoader
     */
    prefs.loadDependingPreferences = function (comboDependencies, savedPrefs, dependingUrlParams) {
        return loadDependingPreferences(comboDependencies, savedPrefs, dependingUrlParams);
    };

    /**
     * Loads an array of depending preferences sequentially using recursion by the order they where pushed into the dependencies array.
     * @param {Array} comboDependencies The array of depending preference data of the combo
     * @param savedPrefs A boolean indicating if empty value, usually related
     * @param [dependingUrlParams] An object containing the data parameters for dependant preferences URLs
     * @return {jQuery.Deferred}
     * @public
     */
    function loadDependingPreferences (comboDependencies, savedPrefs, dependingUrlParams) {
        if (!(dependingUrlParams instanceof Array)) {
            //dirty fix when arguments get flattened
            dependingUrlParams = Array.prototype.slice.call(arguments, 2);
        }
        var loadingDeps = $.Deferred();
        var otherCombos = [];
        var comboData = comboDependencies.shift();
        while (!comboData.url) {
            otherCombos.push(comboData);
            comboData = comboDependencies.shift();
        }
        var preferenceName = comboData.preferenceName;
        var comboId = comboData.comboId;
        var selectedValue = comboData.currentValue;
        var urlParams = dependingUrlParams || [];
       
        var retrieveComboValues = function() {
			var parameters = {},
				i, dependingPref;
			// url parameters array is transformed to the pipe format
			for (i = urlParams.length; i--;) {
				dependingPref = urlParams[i];
                if (typeof dependingPref !== 'string') {
                    $.extend(parameters,dependingPref );
                } else {
                    parameters[dependingPref] = $preferenceContainer.find("select[data-prop-id='"+dependingPref+"']").val();
                }
			}
			// Do the request
			prefs.fetchAjaxCombos(comboData.url, parameters)
				.done(function(response, status, xhr) {
					// Once options are retrived, combo can be rendered and
					// next preference processd
					var responseCombos = response.combos;
                    for (i = otherCombos.length; i--;) {
                        addCombo(responseCombos, otherCombos[i]);
                    }
                    addComboAndLoadDependingPreferences(prefs.filterComboById(comboId, responseCombos));
                    loadingDeps.resolve(response);
				}).fail(loadingDeps.reject);
            return loadingDeps;
		};
    // Function to add combo
        var addCombo = function(responseCombos, comboData) {
            prefs.addComboPreference(comboData.preferenceName, comboData.currentValue, prefs.filterComboById(comboData.comboId, responseCombos), comboDependencies.slice(0), savedPrefs, urlParams);
        };

        // Function to add combo and load the next depending preference
        var addComboAndLoadDependingPreferences = function (comboOptions) {
            /* During the render of preferences the value of selected preference can't be changed, thus the call to this function
             is a source of bugs */
            //selectedValue = updateSelectedValue(selectedValue, comboOptions, savedPrefs);
            prefs.addComboPreference(preferenceName, selectedValue, comboOptions, comboDependencies.slice(0), savedPrefs, urlParams);
            if (comboDependencies.length > 0) {
                for (i = otherCombos.length; i--;) {
                    urlParams.push(otherCombos[i].preferenceName);
                }
                urlParams.push(preferenceName);
                loadDependingPreferences(comboDependencies, savedPrefs, urlParams)
                    .done(loadingDeps.resolve)
                    .fail(loadingDeps.reject);
            } else {
                //urlParams = [];
                loadingDeps.resolve();
            }
        };

        // Combo needs an url to retrieve its data
        if (comboData.url) {
            retrieveComboValues();
            // Otherwise the combo options are preloaded
        } else {
            var comboOptions = dbesp.utils.commons.fireFunctionSafe(comboData.comboOptions, getParamsValues(urlParams));
            if (comboOptions) {
                $.when(comboOptions).done(addComboAndLoadDependingPreferences);
            } else {
                dbesp.log.warn('[propagation.utils.preferences.js]', 'Preference combo' +
                preferenceName + ' should specify either an URL or combo options in order to load.');
            }

        }
        return loadingDeps;
    }

    function getParamsValues (params) {
        var result = {};
        _.forEach(params, function(preferenceName) {
            result[preferenceName] = $preferenceContainer.find("select[data-prop-id='"+preferenceName+"']").val();
        });
        return result;
    }

    // Creates an HTML select box or replace it with new values if exists
    // @param preferenceName: The name of the preference as specified on catalog
    // @param currentValue: The current selected value of the preference
    // @param comboOptions: The available options array
    // @param comboDependencies: The array of depending preference data of the combo
    // @param savedPrefs: A boolean indicating if empty value, usually related
    // to all filter, should remain over web service selection
    // @param dependingUrlParams: An object containing the data parameters for dependant preferences URLs
    /**
     *  Creates an HTML select box or replace it with new values if exists
     * @param {string} preferenceName The name of the preference as specified on catalog
     * @param {string} currentValue The current selected value of the preference
     * @param {Array} comboOptions The available options array
     * @param {Array} [comboDependencies] The array of depending preference data of the combo
     * @param {boolean} [savedPrefs] A boolean indicating if empty value, usually related to all filter, should remain over web service selection
     * @param {string} [dependingUrlParams] An object containing the data parameters for dependant preferences URLs
     */
    prefs.addComboPreference = function (preferenceName, currentValue, comboOptions, comboDependencies, savedPrefs, dependingUrlParams) {
        var input = $preferenceContainer.find("input[name='" + preferenceName + "']");
        var combo = $preferenceContainer.find("select[data-prop-id='" + preferenceName + "']");
        // If combo exists, event is detached and HTML removed from DOM
        if (combo[0]) {
            $preferenceContainer.off('change', 'select[data-prop-id="' + preferenceName + '"]');
            combo.remove();
            combo = $(createBufferedCombo(preferenceName, currentValue, comboOptions));
            // If new, create
        } else {
            combo = $(createBufferedCombo(preferenceName, currentValue, comboOptions));
            input.hide();
        }
        input.after(combo);
        $preferenceContainer.on('change', 'select[data-prop-id="' + preferenceName + '"]', handleValueChange(preferenceName, comboDependencies, dependingUrlParams, savedPrefs));
    };

    /**
     * Creates a simple HTML select box with integer options and replaces the source preference text input with it
     * @param {number} begin value to begin with
     * @param {number} end value for the enumeration to end
     * @param {number} step Distance among values
     * @param {string} preferenceName The name of the preference as specified on catalog
     * @param {string} [currentValue] The current selected value of the preference
     */
    prefs.addEnumPreference = function (begin, end, step, preferenceName, currentValue) {
        var input = $preferenceContainer.find('input[name="' + preferenceName + '"]');
        var enumCombo = $(createEnumCombo(begin, end, step, preferenceName, parseInt(currentValue, 10)));
        input.hide();
        input.after(enumCombo);
        $preferenceContainer.on('change', 'select[data-prop-id="' + preferenceName + '"]', handleValueChange(preferenceName));
    };

    /**
     * Creates a simple HTML check box input and replaces the source preference text input with it
     * @param {string} preferenceName The name of the preference as specified on catalog
     * @param {string} [currentValue] The current selected value of the preference
     */
    prefs.addSimpleCheckbox = function (preferenceName, currentValue) {
        var input = $preferenceContainer.find('input[name="' + preferenceName + '"]');
        var checkboxInput = $(createCheckbox(preferenceName, currentValue));
        input.hide();
        input.after(checkboxInput);
        $preferenceContainer.on('change', 'input[data-prop-id="' + preferenceName + '"]', handleCheckboxChange(preferenceName));
    };

    /**
     * Creates a datepicker using jQuery UI library component and replaces the source preference text input with it
     * @param {string} preferenceName The name of the preference as specified on catalog
     * @param {string} [currentValue] The current selected value of the preference
     */
    prefs.addDatePicker = function (preferenceName, currentValue) {
        var input = $preferenceContainer.find('input[name="' + preferenceName + '"]');
        var datepickerInput = $('<input type="text" data-prop-id="' + preferenceName + '" value="' + currentValue + '"/>');
        input.hide();
        input.after(datepickerInput);
        datepickerInput.datepicker({dateFormat: 'dd/mm/yy'});
        $preferenceContainer.on('change', 'input[data-prop-id="' + preferenceName + '"]', handleValueChange(preferenceName));
    };

    /**
     * Creates a custom time picker compose by hours and minutes selects and replaces the source preference text input with it
     * @param {string} preferenceName The name of the preference as specified on catalog
     * @param {string} [currentValue] The current selected value of the preference
     */
    prefs.addTimePicker = function (preferenceName, currentValue) {
        var input = $preferenceContainer.find("input[name='" + preferenceName + "']");
        var hour = parseInt(((currentValue && currentValue.length >= 4) ? currentValue.substring(0, 2) : '00'), 10);
        var minute = parseInt(((currentValue && currentValue.length >= 4) ? currentValue.substring(2, 4) : '00'), 10);
        var hourSelectName = preferenceName + '-hour';
        var minutesSelectName = preferenceName + '-minutes';
        var realTimePicker = createTimePicker(hourSelectName, minutesSelectName, hour, minute);
        input.hide().after(realTimePicker);
        $preferenceContainer.on(
            'change',
            'select[data-prop-id="' + hourSelectName + '"],select[data-prop-id="' + minutesSelectName + '"]',
            handleHourChange(hourSelectName, minutesSelectName, preferenceName)
        );
    };
    /**
     * Resets a date preference using current date
     * @param {baseWidget} baseInstance The widget owner of the time preference
     * @param {string} preferenceName The name of the time preference
     * @param {number|string} timestamp Timestamp of the preferences
     */
    prefs.resetDatePreference = function (baseInstance, preferenceName, timestamp) {
        var instant = moment().startOf('day');

        // If date must be reseted every day, this conditional will prevent
        // more than one modifications a day
        if (!isNaN(timestamp) && Number(timestamp) < instant.getTime()) {
            var formattedDate = instant.format('DD/MMM/YYYY');
            baseInstance.setPreferencesAndPersistModel(preferenceName, formattedDate);
        }
    };

    /**
     * Resets a time preference using either, current time or from current day's start
     * @param {baseWidget} baseInstance The widget owner of the time preference
     * @param {string} preferenceName The name of the time preference
     * @param {number|string} timestamp Timestamp of the preferences
     * @param {boolean} resetFromDayStart Boolean indicating if time is current or the beginningof  day
     */
    prefs.resetTimePreference = function (baseInstance, preferenceName, timestamp, resetFromDayStart) {
        var instant = moment().startOf('day');
        var formattedTime = resetFromDayStart ? '000000' : moment().format('HHmmss');


        // If time must be reseted every day, this conditional will prevent
        // more than one modifications a day
        if (!isNaN(timestamp) && Number(timestamp) < instant.valueOf()) {
            baseInstance.setPreferencesAndPersistModel(preferenceName, formattedTime);
        }
    };

    /**
     * Provides preference sorting using an array of preference names as mask.
     * Since BackBase makes no internal difference between preferences and the
     * other widget properties, the algorithm used for sorting is forced to be
     * quadrant O(n^2) instead of linear O(n), but there is not much performance
     * penalty since preferences are usually not higher than 10 so the worst
     * use case takes 100 time cycles
     * @param preferenceArray A reference to the array of preferences as stored by BackBase
     * @param maskArray An array of preferences names that acts as mask for preference sorting
     */
    prefs.sort = function (preferenceArray, maskArray) {
        var i, j,
            maskLen = (maskArray && maskArray.length) || 0,
            prefsLen = (preferenceArray && preferenceArray.length) || 0;
        // Loop through mask
        for (i = 0; i < maskLen; i++) {
            // Loop through model items
            for (j = 0; j < prefsLen; j++) {
                // If preference is in items array
                if (maskArray[i] === preferenceArray[j].name) {
                    // Remove preference from wrong index and add it to correct
                    // index (and move others +1 position)
                    preferenceArray.splice(i, 0, preferenceArray.splice(j, 1)[0]);
                    // Search next preference
                    break;
                }
            }
        }
    };

    // ********************** //
    // ** Helper functions ** //
    // ********************** //

    // Creates an HTML select box handling too large array inputs by buffering
    // String concatenation
    // @param selectDataId: String used as data-prop-id
    // @param currentValue: The current selected value
    // @param comboOptions: The available options array
    function createBufferedCombo(preferenceName, currentValue, comboOptions) {
        // "Array" concatenation is used in order to improve large combo loading on
        // IE7 since "plus" one is quite slow
        var newHTML = ['<select data-prop-id="', preferenceName, '" >'].join(''),
            trimmedCurrentValue, comboBuildFn, createHtmlFn, BUFFER = 100, iterations, subset, endIndex, totalLength;
        if (comboOptions instanceof Array && comboOptions.length > 0) {
            trimmedCurrentValue = currentValue.replace(/\s/g, '');
            // A closure are used here to process subsets of data sequentially
            // and avoid out of memory error
            createHtmlFn = function (compareType) {
                return function (index, value) {
                    var id = (value.id) ? (value.id).toString() : '',
                        description = value.description,
                        type = (value[compareType]) ? value[compareType].toString() : '',
                        htmlSubset = [];
                    if (type.replace(/\s/g, '') === trimmedCurrentValue) {
                        htmlSubset.push("<option value='", escapeHTML(id), "' selected='selected'>", description, "</option>");
                    }
                    else {
                        htmlSubset.push("<option value='", escapeHTML(id), "'>", description, "</option>");
                    }
                    newHTML += htmlSubset.join('');
                };
            };
            totalLength = comboOptions.length;
            // Buffer array to avoid out of memory error
            iterations = Math.ceil(totalLength / BUFFER);
            for (var i = 0; i < iterations; i++) {
                // Calculate next subset
                if (i === iterations - 1) {
                    endIndex = (BUFFER * i) + (totalLength % BUFFER);
                } else {
                    endIndex = BUFFER * (i + 1);
                }
                subset = comboOptions.slice((BUFFER * i), endIndex);
                if (currentValue || currentValue === "") {
                    comboBuildFn = createHtmlFn('id');
                    // Mandatory is current selection
                    $.each(subset, comboBuildFn);
                }
                else {
                    comboBuildFn = createHtmlFn('selected');
                    $.each(subset, comboBuildFn);
                }
            }
        } else if (comboOptions) {
            newHTML += ["<option value='' selected='selected'>", comboOptions.description, "</option>"].join('');
        } else {
            // FIXME translate label
            newHTML += ["<option value='' selected='selected'>", 'No options loaded', "</option>"].join('');
        }
        newHTML += "</select>";
        return newHTML;
    }

    // Creates a simple HTML select box with integer options
    // @param begin: Integer value to begin with
    // @param end: Integer value for the enumeration to end
    // @param step: Distance among values
    // @param preferenceName: The name of the preference as specified on catalog
    // @param currentValue: The current selected value of the preference an the
    // one that will be used as data-prop-id for the enhanced one
    function createEnumCombo(begin, end, step, preferenceName, currentValue) {
        var newHTML = ['<select data-prop-id="', preferenceName, '" >'];
        var value = begin;
        while (value <= end) {
            if (value === currentValue) {
                newHTML.push('<option value="', value, '" selected="selected">', value, '</option>');
            } else {
                newHTML.push('<option value="', value, '">', value, '</option>');
            }
            value = value + step;
        }
        newHTML.push('</select>');
        return newHTML.join('');
    }

    // Creates a simple HTML check box
    // @param preferenceName: The name of the preference as specified on catalog
    // @param currentValue: The current selected value of the preference an the
    // one that will be used as data-prop-id for the enhanced one
    function createCheckbox(preferenceName, value) {
        var newHTML = ['<input type="checkbox" data-prop-id="', preferenceName, '"  value="', preferenceName, '"'];
        if (value === 'true') {
            newHTML.push(' checked="checked"');
        }
        newHTML.push(' />');
        return newHTML.join('');
    }

    // Creates a custom HTML time picker
    // @param hourSelectName: Name of the hour select to be used as data-prop-id
    // @param minutesSelectName: Name of the minutes select to be used as data-prop-id
    // @param currentHour: The current selected hour value
    // @param currentMinute: The current selected minute value
    function createTimePicker(hourSelectName, minutesSelectName, currentHour, currentMinute) {
        var newHTML = createTimeSelect(hourSelectName, currentHour, 24);
        newHTML = newHTML.concat(['&nbsp;:&nbsp;']);
        newHTML = newHTML.concat(createTimeSelect(minutesSelectName, currentMinute, 60));
        return newHTML.join('');
    }

    // Creates a select time picker
    // @param selectDataId: String used as data-prop-id
    // @param currentValue: The current selected value
    // @param maxValue: The max value that an option can take
    function createTimeSelect(selectDataId, currentValue, maxValue) {
        var selectHTML = ['<select data-prop-id="', selectDataId, '">'];
        var i, value;
        for (i = 0; i < maxValue; i++) {
            value = (i < 10) ? '0' + i : i; //add a '0' tu values from 0 to 9.
            if (i === currentValue) {
                selectHTML.push('<option value="', value, '" selected="selected">', value, '</option>');
            }
            else {
                selectHTML.push('<option value="', value, '">', value, '</option>');
            }
        }
        selectHTML.push('</select>');
        return selectHTML;
    }

    // Handles a combo change event by modifying the original input
    // @param preferenceName: The name of the preference
    // @param comboDependencies: The array of dependant preferences in case of
    // the combo is a dependency for other/s
    // @param dependingUrlParams: An object containing the dependencies to be passed
    // as parameters for the request
    // @param savedPrefs: A boolean indicating if empty value, usually related
    // to all filter, should remain over web service selection
    function handleValueChange(preferenceName, comboDependencies, dependingUrlParams, savedPrefs) {
        return function (evt) {
            var value = $(this).val();
            changeSourcePreference(preferenceName, value);
            // If combo has depencencies, load them sequentially
            if (comboDependencies instanceof Array && comboDependencies.length > 0) {
                // Load depending preferences is invoked specifying a swallow copy
                // of the combo dependencies since it will be modified for recursion
                prefs.loadDependingPreferences(comboDependencies.slice(0), savedPrefs, dependingUrlParams);
            }
        };
    }

    // Handles a checkbox change event by modifying the original input
    // @param preferenceName: The name of the preference
    function handleCheckboxChange(preferenceName) {
        return function (evt) {
            var value = $(this).is(':checked');
            changeSourcePreference(preferenceName, value);
        };
    }

    // Handles a timepicker change event by modifying the original input
    // @param hourSelectId: The data-prop-id string for the hours select
    // @param minutesSelectId: The data-prop-id string for the minutes select
    // @param preferenceName: The name of the preference
    function handleHourChange(hourSelectId, minutesSelectId, preferenceName) {
        return function (evt) {
            var hours = $preferenceContainer.find('select[data-prop-id="' + hourSelectId + '"]').val();
            var mins = $preferenceContainer.find('select[data-prop-id="' + minutesSelectId + '"]').val();
            var value = hours + mins + '00'; // milliseconds are needed
            changeSourcePreference(preferenceName, value);
        };
    }

    // Fires the change event on the original input preference as the way
    // to notify BackBase that the preference has changed
    // @param preferenceName: The name of the preference
    // @param value: The value that the source preference must take
    function changeSourcePreference(preferenceName, value) {
        var input = $preferenceContainer.find('input[name="' + preferenceName + '"]');
        // The value of the hidden text input is changed:
        input.val(value);
        // It is required to launch the change event in order to notify BB that the preference has been modified
		// ALM 39880: even when cancelling modification, changes was already saved. It is no more necessay to 
		//   use this event from BB 5.5
        // input.change();
    }


    // Checks if a value id is available among an options array
    // @param preferenceValue: The value id to check
    // @param options: The available options array
    function isPreferenceValueInComboOptions(preferenceValue, options) {
        var found = false;
        if (options) {
            $.each(options, function (index, value) {
                var valueId = value.id || '';
                // Validations are slightly different here since empty string is the
                // value for 'All' default in combo options but is a JavaScript falsy value
                if ((valueId === '' || valueId) && (preferenceValue === '' || preferenceValue) &&
                    valueId.replace(/\s/g, '') == preferenceValue.replace(/\s/g, '')) {
                    found = true;
                    return false;
                }
            });
        }
        return found;
    }

    function escapeHTML(str) {
        return str ? str.replace(/</g, '&lt;').replace(/>/g, '&gt;').replace(/"/g, '&quot;').replace(/'/g, '&apos;') : '';
    }

    dbesp.utils = dbesp.utils || {};
    dbesp.utils.prefs = prefs;
})();
// Utilities for services and remote calls
// @author jsanz
(function() {
    'use strict';


	/**
	 * @description Utilities for services and remote calls
	 * @exports core/utils/service
	 *
	 * @requires module:jquery
	 * @requires module:core/dbesp
	 */
	var service =  {};

	/**
	 *  Constant specifying the jsonParameter name used by convention for requests
	 *  @const
	 * @type {string}
	 */
	var JSON_PARAM_NAME = 'requestData';

	/**
	 * Default timeout for ajax calls
	 * @const
	 * @type {number}
	 */
	service.DEFAULT_TIMEOUT = 30000;


	/**
	 * Serializes the JSON data and prepends the default parameter name
	 * @param {Object} data
	 * @return {string}
	 */
	service.serializeRequestData = function(data) {
		return JSON_PARAM_NAME + '=' + encodeURIComponent(JSON.stringify(data));
	};


	/**
	 * Generates a parameter query string from a JSON parsed object.
	 * If startQuery is informed and true, the first "&" character will be replaced by "?"
	 * @param {Object} params Parsed JSON object specifying the parameters to be converted
	 // to query string
	 * @param {boolean} [startQuery=false] startQuery is true, the first "&" character will be replaced by "?"
	 * @return {string}
	 */
	service.generateParametersQueryString = function(params, startQuery) {
		var queryString = '';
		if (params) {
			// Iterate through object if exists and concatenate
			for (var key in params) {
				if(params.hasOwnProperty(key)) {
					// Key and values are implicitly parsed to string. In addition latter
					// is UTF-8 encoded
					queryString += '&' + key + '=' + encodeURIComponent(params[key]);
				}
			}
			// Prepend the query character if indicated by removing the concatenator one
			if(startQuery) {
				queryString = queryString.replace(/&/, '?');
			}
		}
		return queryString;
	};

	/**
	 * Encapsulates an AJAX request adapted to the specific requirements of core and services
	 * @param {String} pipeName
	 * @param {Object} requestData Additional parameters for the request
	 * @return {jQuery.Deferred}
	 */
	service.fetchJSON = function(pipeName, requestData) {
		return $.ajax({
			// All request should use method POST due that core architecture
			// uses the method of the source request to invoke SOAP WS
			type: 'POST',
			url: dbesp.contextRoot + '/proxy?pipe=' + pipeName,
			data:  service.serializeRequestData(requestData || {}),
			// It is necessary to specify the data type since portal core does
			// not return HTML text but XML #document node
			dataType: 'json',
			// Default timeout for all requests
			timeout: service.DEFAULT_TIMEOUT
		});
	};

	dbesp.utils = dbesp.utils || {};
	dbesp.utils.service = service;
})();
(function () {
    'use strict';

    /**
     * @description Utilities for ui
     * @exports core/utils/ui
     *
     * @requires module:jquery
     */
    var ui = {};

    /**
     * Shows a loading layer positioned over a container
     * @param {jQuery} $container
     */
    ui.showLoading = function ($container) {
        var $loadingTpl;
        ui.hideLoading($container);
        if ($container.height() < 40) {
            $container.addClass('prop-loading-min-height');
        }
        if ($container.is('td')) {
            $container.html('');
        }
        $loadingTpl = getLoadingTemplate();
        $loadingTpl.appendTo($container);
        $loadingTpl.fadeTo(300, 0.7).css({
            'display': 'block'
        });
    };

    /**
     *  Hides and removes a layer positioned over a container
     * @param {jQuery} $container
     */
    ui.hideLoading = function ($container) {
        $container
            .removeClass('prop-loading-min-height')
            .find('[data-prop-class="prop-loader"]')
            .fadeOut(400, function () {
                $(this).remove();
            });
    };

    /**
     * Checks if there is a loading layer over a container
     * @param {jQuery} $container
     * @return {boolean}
     */
    ui.isLoading = function ($container) {
        return !!$container.find('[data-prop-class="prop-loader"]')[0];
    };

    /**
     * contextualizes a propagation icon
     * @param $emptyIconContainer
     * @param context
     */
    ui.populateEmtyIcon = function($emptyIconContainer, context) {
        // TODO Document more clearly the expected format
        if ($($emptyIconContainer)) {
            context.description = context.description.replace(/&amp;/g, '&');
            var $icon = $($emptyIconContainer).find('[data-prop-propagation-context-type]')
                .attr('data-prop-propagation-context-type', context.type)
                .attr('data-prop-propagation-context-id', context.id)
                .attr('data-prop-propagation-context-description', context.description);
            if (context.content) { $icon.attr('data-prop-propagation-context-content', JSON.stringify(context.content));}
            $($emptyIconContainer).find('[data-prop-class="prop-icon-description"]').text(context.description);
            $($emptyIconContainer).show();
        }
    };

    /**
     * Scrolls to node's position
     * @param {jQuery} $node
     * @param {Boolean} [always] indicates if it should scroll even when already visible on screen
     */
    ui.scrollToNode = function ($node, always) {
        var y = $node.offset().top;
        if (always || (!always && !isOnScreen($node, 50))) {
            $('html, body').animate({
                scrollTop: y
            }, 'slow');
        }
    };


    /**
     *
     * @param templateId
     * @returns {*|jQuery}
     */
    ui.getMustacheTemplate = function(templateId) {
        return $(document).find('[data-prop-id="' + templateId + '"]').html();
    };

    /**
     *
     * @param {[]<String>} partialIds
     * @returns {{mustachePartials}}
     */
    ui.getMustachePartials = function(partialIds) {
        var result = {};
        if (partialIds) {
            for (var i = 0; i < partialIds.length; i++) {
                result[partialIds[i]] = ui.getMustacheTemplate(partialIds[i]);
            }
        }
        return result;
    };

	ui.dialog = function(data) {
		getDialogTemplate(data).appendTo($('#main')).fadeIn(100);
	};
	
    // ****************************** //
    // ** Private helper functions ** //
    // ****************************** //

    function isOnScreen($elm, margin) {
        margin = margin || 0;
        var $window = $(window),
            vpH = $window.height(), // Viewport Height
            st = $window.scrollTop(), // Scroll Top
            y = $elm.offset().top,
            elementHeight = $elm.height();

        return ((y + margin) < (vpH + st)); // we only check the top boundary for the moment && (y > (st - elementHeight)));
    }

    // Returns the loading template. This function should be lazy invoked
    // only one time.
    function getLoadingTemplate() {
        return $(
            '<div data-prop-class="prop-loader" class="prop-loading-backgrd">' +
                '<span class="prop-loading-icon"></span>' +
            '</div>'
        );
    }
    
    /*
	"data": {
		"title": "",
		"body": "",
		"buttons": [{
			"text": "",
			"selected": true|false
			"callback": function
		}]
	}
	*/
	function getDialogTemplate(data) {
		var bodyHtml = '<div class="prop-dialog-body">' +
			'<h2>' + data.title + '</h2>' +
			'<p>' + data.body + '</p>' +
			'</div>';

		var buttonsHTML = ' <table class="prop-dialog-buttons"> <tbody> <tr>';
		var buttonHtml;
		for (var i = 0; i < data.buttons.length; i++) {
			buttonHtml = '<td> <button data-prop-dialog-index="' + i + '" class="prop-detail-dialog-save-fa ' + (data.buttons[i].selected ? 'aa-buttonGradientGreen' : 'aa-buttonGradientGrey') + '">' + data.buttons[i].text + '</button> </td>';
			buttonsHTML += buttonHtml;
		}
		buttonsHTML += ' </tr> </tbody> </table>';

		var $dialog = $('<div class="prop-dialog-wrapper"> <div class="prop-dialog-container">' + bodyHtml + buttonsHTML + '  </div></div>');

		$dialog.on('click', 'button', function () {
			var index = $(this).attr('data-prop-dialog-index');
			$('.prop-dialog-wrapper').fadeOut(100, 
					function() {
						$(this).remove();
					});
			data.buttons[index].callback();
			return false;
		}).find('button.aa-buttonGradientGreen').focus();
		return $dialog;
	}
    

    dbesp.utils = dbesp.utils || {};
    dbesp.utils.ui = ui;
})();
// Utilities for iframe handling
// @author jsanz
(function() {
	'use strict';
	
	/**
     * @description Utilities for iframe
     * @exports core/utils/iframe
     *
     * @requires module:jquery
     */
    var iframe = {};

	// Create aliases for shorten variable resolution
	var service = dbesp.utils.service;
	var ui = dbesp.utils.ui;

	// Constant indicating the overlay pipe name
	var ACTIVA_OVERLAY_PIPE = 'ActivaOverlayPipe';
	// Array that specify the images to be rewrited by transform links
	var dialogWithRewritableImages = ['FollowUpPositionDialog', 'FollowUpCommercialDialog'];
	// FIFO array of intervals
	var resizeIntervals = [];
	// Fallback for iframe heigh
	var ERROR_PAGE_HEIGHT = 400;
	var hasOwn = Object.prototype.hasOwnProperty;

	// ******************* //
	// ** Iframe utils ** //
	// ******************* //
	// There is no constructor since all utils are static functions

	// Creates an iframe using a direct access operation and optional URL
	// parameters
	// @param operation: The Activa direct access operation
	// @param inputParams: Optional object containing GET parameters
	// @param interactiveClickHandler: Click handler for links interacting with portal
	// @returns $iframe: The jQuery weapped iframe created
	iframe.createActivaIframe = function(operation, inputParams, interactiveClickHandler) {
		// Create iframe and set URL
		var $iframe = $('<iframe frameborder="0" scrolling="no" style="overflow-y: hidden;" src="" />');

		var params = inputParams || {};
		// Add operation to params and format them to query string
		params.operation = operation;
		var parameters = service.generateParametersQueryString(params);
		$iframe.attr('src', generatePipedActivaUrl(encodeURIComponent(dbesp.Activa.constants.BASE_URL + parameters)));
		// Resize iframe on window resize
		$iframe.resize(handleIframeResize);
		// Listen to load event
		$iframe.load(iframe.handleIframeLoad(interactiveClickHandler));
		return $iframe;
	};

	// Destroys an iframe by removing it from DOM
	// @param $iframe: The jQuery weapped iframe to remove
	iframe.destroyIframe = function($iframe) {
		if ($iframe) {
			$iframe.remove();
		}
	};

	// Shows a loading layer over an iframe
	// @param $iframe: The jQuery weapped iframe
	iframe.showLoading = function($iframe) {
		ui.showLoading($iframe.parent().parent());
	};

	// Hides the loading showing over an iframe
	// @param $iframe: The jQuery weapped iframe
	iframe.hideLoading = function($iframe) {
		ui.hideLoading($iframe.parent().parent());
	};


	iframe.loadOperation = function($iframe, operation) {
		if (operation) {
			var params = {
				operation: operation
			};
			var parameters = service.generateParametersQueryString(params);
			$iframe.attr('src', generatePipedActivaUrl(encodeURIComponent(dbesp.Activa.constants.BASE_URL + parameters)));
			// Resize iframe on window resize
			$iframe.resize(handleIframeResize);
		}
		return $iframe;
	};

	// Executes some functions when the iframe has loaded its source
	iframe.handleIframeLoad = function(interactiveClickHandler) {
		return function() {
			/*jshint validthis:true */
			var $this = $(this);
			onIframeLoaded($this, interactiveClickHandler);
			//resize the iframe to adapt it to its content
			resizeIframe($this);
			// Show loading on iframe unload
			showLoadingOnBeforeUnload($this);
		};
	};

	// Executes some functions when the iframe has loaded its source
	iframe.refreshTasks = function() {
		var propagationManager = dbesp.propagation.PropagationManager.getInstance();
		var eventsRepository = dbesp.propagation.repository.events;
		var taskFormLoadedEvent = eventsRepository.retrieve('TASK_UPDATED');
		propagationManager.broadcastNotifyEvent(null, taskFormLoadedEvent.id);
	};

	// ********************** //
	// ** Helper functions ** //
	// ********************** //

	// Triggers iframe resize
	function handleIframeResize() {
		/*jshint validthis:true */
		resizeIframe($(this));
	}

	// Controls the transformation and enhancement of ifram once loaded
	// @param $iframe: The jQuery weapped iframe to initialize
	function onIframeLoaded($iframe, interactiveClickHandler) {
		//reads iframe data. All data is optional
		var currentDialog = getDialogById($iframe, 'dialogId');
		transformLinks($iframe, currentDialog, interactiveClickHandler);
		//Hide header links
		$iframe.contents().find('.links_header').hide();
		launchDOMEnhancedPostOperations($iframe);
		iframe.hideLoading($iframe);
	}

	// Retrieves the current activa dialog from iframe's content
	// @param $iframe: The jQuery weapped iframe from which to retrieve the
	// dialog
	function getDialogById($iframe, id) {
		var data = $iframe.contents().find('#' + id);
		return (data !== null) ? data.val() : null;
	}


	// Links inside the iFrame must be transformed in order to
	// perform interaction correctly.
	// @param $iframe: The jQuery weapped iframe which links must be transformed
	function transformLinks($iframe, dialog, interactiveClickHandler) {
		//Transform anchor's 'href' attribute.
		var iframeContents = $iframe.contents(),
			anchors = iframeContents.find('a');
		anchors.each(function() {
			var $this = $(this);

			// capture customer link and rewrite for direct propagation
			// Handle click on anchor - copied from [R1]actw-core.js
			var urlString = $this.attr('href');
			// we exlude links that contain some of the key params but shouln't be transformed to propagations
			// here, links with .linkControl are tabs that contain 'customerInfo' but should keep the overlay
			var isInternalLink = $this.hasClass('linkControl');
			//If the url contains customerInfo we asume that this link is a customer crosslink
			var idParamName = '';
			var propagationContext = {};
			var actionId;
			if (urlString && !isInternalLink) {
				//customer Link
				if (urlString.indexOf('customerInfo') > -1) {
					idParamName = 'customerInfo';
					propagationContext.type = "customer";
					actionId = "CUSTOMER_GLOBAL_DETAIL";
					//contact Link
				} else if (urlString.indexOf('contactDetailId') > -1) {
					idParamName = 'contactDetailId';
					propagationContext.type = "contact";
					actionId = "CONTACT_DETAIL";
					//task Link (only Advisor tasks)
				} else if (urlString.indexOf('taskId') > -1) {
					idParamName = 'taskId';
					propagationContext.type = "task";
					actionId = "TASK_DETAIL";
				}
			}
			if (idParamName !== '') {
				$this.on('click', function(evt) {
					evt.preventDefault();

					var idInitPos, linkParamStr;

					// Get init and end position for id string
					idInitPos = urlString.indexOf(idParamName) + (idParamName.length + 1);
					// Search from key param
					linkParamStr = urlString.substring(idInitPos);
					// End character could be "%", "&" or end of string
					if (linkParamStr.indexOf('%') !== -1) {
						linkParamStr = linkParamStr.substring(0, linkParamStr.indexOf('%'));
					}
					if (linkParamStr.indexOf('&') !== -1) {
						linkParamStr = linkParamStr.substring(0, linkParamStr.indexOf('&'));
					}

					// Propagation Context Params
					propagationContext.id = linkParamStr;
					propagationContext.description = $.trim($this.text());

					if (typeof interactiveClickHandler === "function") {
						interactiveClickHandler(actionId, propagationContext);
					}
				});
			} else if (urlString !== '#') {
				/*var url;
				if (urlString.indexOf('excel') > -1) {
					url = dbesp.Activa.backendHost + $(this).attr('href');
				} else {
					var link = dbesp.Activa.backendHost + $(this).attr('href');
					url = generatePipedActivaUrl(link);
				}
				$this.attr('href', url);*/
				var link = dbesp.Activa.backendHost + $(this).attr('href'),
					url = generatePipedActivaUrl(link);
				$this.attr('href', url);
			}
		});
		//Transform form's 'action' attribute.
		var forms = iframeContents.find('form');
		forms.each(function() {
			var link = dbesp.Activa.backendHost + $(this).attr('action'),
				url = generatePipedActivaUrl(encodeURIComponent(link));
			$(this).attr('action', url);
			$(this).attr('method', 'POST'); //needed for solving problem with form parammeters
		});

		// on cancel or dispatch, reload tasks in widgets
		 iframeContents.find('#button-cancel-task, #button-dispatch-task').each(function() {
		 	var onclickContent = $(this).attr('onclick');
		 	onclickContent += 'parent.dbesp.propagation.utils.iframe.refreshTasks();';
			$(this).attr('onclick', onclickContent);
		 });

		//Transform images
		if ($.inArray(dialog, dialogWithRewritableImages) !== -1) {
			var images = iframeContents.contents().find('img');
			images.each(function() {
				var src = dbesp.Activa.backendHost + "" + $(this).attr('src'),
					url = generatePipedActivaUrl(src);
				$(this).attr('src', url);
			});
		}

		//Enhance propagable content
		iframeContents.on('click', '[data-aacc-propagable-content]',
			function() {
				interactiveClickHandler.apply(this, ($(this).data('aacc-propagable-content')));
			}
		);
	}

	// Sometimes Activa application has public methods for launchung some operations once the widget has
	// enhanced Activa iframe's content.
	// @param $iframe: The jQuery weapped iframe from which to retrieve activa
	// namespace
	function launchDOMEnhancedPostOperations($iframe) {
		try {
			var activaNS = $iframe[0].contentWindow.aacc; //Activa iframe namespace
			if (activaNS) {
				if (typeof activaNS.DOMEnhancedCallback === 'function') {
					activaNS.DOMEnhancedCallback();
				}
				if (typeof activaNS.setupAlerts === 'function') {
					activaNS.setupAlerts();
				}
				if (typeof activaNS.initAutoCompleteResultProduct === 'function') {
					activaNS.initAutoCompleteResultProduct();
				}
				if (typeof activaNS.applyResize === 'function') {
					activaNS.applyResize();
				}
			}
		} catch (err) {
			dbesp.log.error('Error when trying to call activa method');
		}
	}

	// Creates an interval that tries to resize iframe every 300 milliseconds.
	// The resizeIntervals control array avoids created intervals to execute
	// forever without disturbing other resizing events.
	// @param $iframe: The jQuery weapped iframe to resize
	function resizeIframe($iframe) {
		// Try resize every 300 millis
		var itrvl = setInterval(doIframeResize($iframe), 300);
		// Add itrvl to array
		resizeIntervals.push(itrvl);
	}

	// Handles iframe resizing depending on content loaded
	// @param $iframe: The jQuery weapped iframe to resize
	function doIframeResize($iframe) {
		// Stores last iframe content height
		var lastHeight = 0;
		return function() {
			//  check  if iframe stil in DOM
			if ($iframe.closest('body').length > 0 && ('contentWindow' in $iframe[0])) {
				var content = $iframe.contents().find('#contentArea'),
					currentHeight = 0,
					itrvl;
				try {
					currentHeight = content.height();
					if (currentHeight && currentHeight !== lastHeight) {
						$iframe.height(currentHeight + 3); //we add exactly the same activa padding
					} else if (!currentHeight && lastHeight !== ERROR_PAGE_HEIGHT) {
						//When the current heigh is 0 surely the page is an error from server
						//then we have to force a height in order to see the error
						currentHeight = ERROR_PAGE_HEIGHT;
						$iframe.height(currentHeight + 3);
					}
					lastHeight = currentHeight;
				} catch (err) {
					dbesp.log.error(err);
				}
				// Clear first interval on array
				if (resizeIntervals.length > 0) {
					itrvl = resizeIntervals.shift();
					// Max page load limit is 3 seconds, so that's the
					// limit to do the resize
					setTimeout(function() {
						clearInterval(itrvl);
					}, 3000);
				}
			}
		};
	}

	// Manages onbeforeunload event produced on an iframe window and clicks
	// on its content
	// @param $iframe: The jQuery weapped iframe to manage
	function showLoadingOnBeforeUnload($iframe) {
		/***** WARNING "PORTALGEIST" *****/
		/* The "$iframe[0].contentWindow" caching makes iframe window
		 * beforeunload works on IE.
		 * Don't ask me why, I'm not able to give you an answer
		 * but the following line becomes untouchable because
		 * make things work!
		 */
		var iframewindow = $iframe[0].contentWindow,
			oldBeforeUnload = iframewindow.onbeforeunload,
			isSaveDialog = false; // Flag to avoid show loading on open/save dialogs
		// Show ajax loading before iframe window unloads
		iframewindow.onbeforeunload = function() {
			var prevFnReturn;
			if (typeof oldBeforeUnload === 'function') {
				prevFnReturn = oldBeforeUnload.call(this);
			}
			// Do not show loading if beforeunload has been
			// launched by open/save dialog
			if (isSaveDialog) {
				isSaveDialog = false;
			} else /*if (prevFnReturn)*/ {
				iframe.showLoading($iframe);
			}
			if (prevFnReturn) {
				return prevFnReturn;
				// Necessary for correct behavior on IE
			} else if ($.browser.msie) {
				return;
			}
		};
		// Check if inline onclick event has fired showAjaxLoading and hide it or
		// change isSaveDialog flag
		var checkIfLoading = function() {
			if (ui.isLoading($iframe.parent().parent())) {
				iframe.hideLoading($iframe);
			} else {
				isSaveDialog = true;
			}
		};

		// Resize iframe on every click to avoid possible sliced content
		$iframe.contents().on('click', function(evt) {
			var target = $(evt.target),
				href = target.attr('href');
			// If open/save dialog, activate flag
			if ((href && href === '#') ||
				target.filter('.excel, .xls, .xlsx,.excelTitle, .wordicon, .pdf, .pdf_ICON, .folder').length ||
				target.parent().filter('.excel, .xls, .xlsx, .excelTitle, .wordicon, .pdf, .pdf_ICON, .folder').length) {
				// Release control to allow loading to show
				setTimeout(checkIfLoading, 200);
			}
			resizeIframe($iframe);
		});
		// Hide loading
		iframe.hideLoading($iframe);
	}

	// Creates a piped URL for request activa pages
	// @param destUrl: The Activa dialog URL to be piped
	function generatePipedActivaUrl(destUrl) {
		return dbesp.contextRoot + '/proxy?pipe=' + ACTIVA_OVERLAY_PIPE + '&url=' + destUrl;
	}
	
	dbesp.utils = dbesp.utils || {};
    dbesp.utils.iframe = iframe;

})();

/**
 * @class
 * @memberOf dbesp.domCaching
 * @namespace 
 * @description This class manage a specific variable to set/get an entire DOM.
 */ 
(function() {
    'use strict';
var domCaching = (function(){
    //Check if HTML5 is supported
    var isHTML5 = Modernizr.sessionstorage;
    
    //dbesp.log.debug('[core-domCaching.initi]', 'isHTML5='+isHTML5, true);
    //alert("isHTML5===" + isHTML5);
    /*if(dbesp.DOM_STORAGE && isHTML5){
        isHTML5=true;
    }else{
        isHTML5=false;
    }
    
    if(isHTML5) {
        alert("isHTML5=true");
    }else{
        alert("isHTML5=false");
    }*/
        
    var id = 'domCache';
    
    /**
     * Function to get the DOM saved, if it is one.
     * @return DOM Object saved.
     */
    function getDom(/*id*/){
        dbesp.log.debug('[core-domCaching.getDom]', 'Getting DOM', true);
        var obj;
        
        //dbesp.log.debug('[core-domCaching.getDom]', 'isHTML5===' + isHTML5 + ' -- dbesp.DOM_STORAGE=' + dbesp.DOM_STORAGE, true);
        
        if (isHTML5 && dbesp.DOM_STORAGE){
            obj = sessionStorage.getItem(id);
        } else {//if not HTML5 search in ESC
           dbesp.internal.commesc.findParamSync(id,
                function(data){ 
                    obj = data;
                },
                function (jqXHR, textStatus, errorThrown) { 
                   dbesp.log.error('[core-domCaching.getDom]', 'Error :' + textStatus + ' , ' + errorThrown, true);
                }
            ); 
        }
        dbesp.log.debug('[core-domCaching.getDom]', 'DOM value: ' + obj, true);
        return obj;
    }
    
    function setDomStructure(domStructure){
        dbesp.log.debug('[core-domCaching.setDomStructure]', 'Updating DOM [' + domStructure + ']', true);
        
       //dbesp.log.debug('[core-domCaching.setDomStructure]', 'isHTML5===' + isHTML5 + ' -- dbesp.DOM_STORAGE=' + dbesp.DOM_STORAGE, true);
        
        if (isHTML5 && dbesp.DOM_STORAGE){
            sessionStorage.setItem(id, domStructure);
        } else {//if not HTML5 put in ESC
            dbesp.internal.commesc.updateParam(id, domStructure, 
                function(data){ 
                    dbesp.log.info('[core-domCaching.setDomStructure]', 'DOM updated successfully', true);
                },
                function (jqXHR, textStatus, errorThrown) { 
                   dbesp.log.error('[core-domCaching.setDomStructure]', 'Error :' + textStatus + ' , ' + errorThrown, true);
                }
            );
        }
    }
    
    /**
     * Function to set the DOM.
     */
    function setDom(/*id, */selector){
        var obj = $(selector).html();
        dbesp.log.debug('[core-domCaching.setDom]', 'Setting DOM [' + selector + '] ' + obj, true);
        
        //dbesp.log.debug('[core-domCaching.setDom]', 'isHTML5===' + isHTML5 + ' -- dbesp.DOM_STORAGE=' + dbesp.DOM_STORAGE, true);     
        if (isHTML5 && dbesp.DOM_STORAGE){
            sessionStorage.setItem(id, obj);
        } else {//if not HTML5 put in ESC
            dbesp.internal.commesc.updateParam(id, obj, 
                function(){ 
                    dbesp.log.info('[core-domCaching.setDom]', 'DOM setted successfully.', true);
                },
                function (jqXHR, textStatus, errorThrown) { 
                   dbesp.log.error('[core-domCaching.setDom]', 'Error :' + textStatus + ' , ' + errorThrown, true);
                }
            );
        }
    }
    
    /**
     * Function to delete the DOM saved, if it is one.
     */
    function deleteDomCache(){
        dbesp.log.debug('[core-domCaching.deleteDom]', 'Deletting DOM', true);
        
        //dbesp.log.debug('[core-domCaching.deleteDom]', ' isHTML5===' + isHTML5 + ' -- dbesp.DOM_STORAGE=' + dbesp.DOM_STORAGE, true);  
        if (isHTML5 && dbesp.DOM_STORAGE){
            sessionStorage.removeItem(id);
        } else {//if not HTML5 put in ESC
            dbesp.internal.commesc.deleteParam(id, 
                function(){ 
                    dbesp.log.info('[core-domCaching.deleteDom]', 'DOM deleted successfully.', true);
                },
                function (jqXHR, textStatus, errorThrown) { 
                   dbesp.log.error('[core-domCaching.deleteDom]', 'Error :' + textStatus + ' , ' + errorThrown, true);
                }
            );
        }
    }
    
    return {
        getDom:getDom,
        setDom:setDom,
        deleteDomCache:deleteDomCache,
        setDomStructure:setDomStructure
    }
})();

dbesp.utils = dbesp.utils || {};
dbesp.utils.domCaching = domCaching;

})();
//Group all actions on portal with one init function called on building dom element.
dbesp.GlobalDropHandler = {
    authorizedDrop: {
        Container_center: [1, 2],
        Activa_column_table: [0, 2]
    },
    behaviors: {
        'dragDrop': function(ev) {
            var targetParent = ev.target;
			try { 
				var targetParentName = targetParent.get_nodeName();
			} catch (err) { 
				ev.stopImmediatePropagation();
			}
            
            var dm = this.ownerDocument.dragManager;
            var targetArea = dm.__tmpArea;

            dbesp.log.info('dbesp.GlobalDropHandler', 'targetParent ' + targetParent);
            dbesp.log.info('dbesp.GlobalDropHandler', 'targetParentName ' + targetParentName);
            dbesp.log.info('dbesp.GlobalDropHandler', 'targetArea ' + targetArea);
            var okAreas = typeof dbesp.GlobalDropHandler.authorizedDrop[targetParentName] !== 'undefined' ? dbesp.GlobalDropHandler.authorizedDrop[targetParentName] : null;
            dbesp.log.info('dbesp.GlobalDropHandler', 'dbesp.GlobalDropHandler.authorizedDrop[targetParentName] :: ' + dbesp.GlobalDropHandler.authorizedDrop[targetParentName]);
            dbesp.log.info('dbesp.GlobalDropHandler', 'Drop Event in ' + targetParentName + ' ' + targetArea);

            if (bd.designMode) {
                dbesp.log.info('', 'designMode');
                return;
            }

            if (!okAreas || (okAreas !== "all" && okAreas.indexOf(targetArea) < 0)) {
                dbesp.log.info('dbesp.GlobalDropHandler', 'Drop Event Cancelled');
                ev.preventDefault(); 
				ev.stopImmediatePropagation();				
            } else if(!okAreas || (okAreas !== "all" && okAreas.indexOf(targetArea) > -1)){
				dbesp.log.info('dbesp.GlobalDropHandler', 'Drop Event Success');
			} else {
				ev.stopImmediatePropagation();
			}
			
        }
    }
};
/*
 * @class 
 * @memberOf dbesp.contextualMenuController
 * @namespace
 * @description The purpose of this function is to be a constructor for the contextualMenuController
 * object. contextualMenuController encapsulates access to NavigationFacade in the backend
 */


(function () {

    var rootRest = dbesp.contextRoot + '/rest/navigation/menu';
    var globalData = '';
    var menuContentId = 'menuContent';
    var inputMenuSearchId = 'inputMenuSearch';
    var menuSearchId = 'menuSearch';
    var menuItemsId = 'menuItems';
    var classStyleAccordion = 'accordion';
    var _className = 'core-contextualMenuController';
    var filtering = false;
    var _actual_menu_option = '';
    var _filterIntervalHandler = null;
    var usingFilter = false;
    var _searchMenu = false;

    /**
     * Function to compose the menu search
     * @private
     * @param {MenuData} menuData Object with the menu data
     * @return {String} Html with the menu search
     */
    function composeMenuSearch(/* MenuData */menuData) {
        var text = 'Search menu...';
        if (menuData.search && menuData.search.text) {
            text = menuData.search.text;
        }

        var html = '<div class="' + menuSearchId + '">';
        html += '<input type="text" class="' + inputMenuSearchId + '" value="' + text + '"/>&nbsp;';
        html += '</div>';

        $('.' + menuContentId).delegate('.' + inputMenuSearchId + '', 'focus', function (event) {
            if ($(this).attr('value') == text) {
                $(this).attr('value', '');
            }
        });

        $('.' + menuContentId).delegate('.' + inputMenuSearchId + '', 'keyup', function (event) {
            if (!usingFilter) {
                //Clear _old interval.
                clearInterval(_filterIntervalHandler);
                //We could control if we are already doing stuff, don't charge the system.
                var numCharStartSearch = 3;
                var decreasing = false;
                var _attrValue = $(this).attr('value');
                var _length = _attrValue ? _attrValue.length : 0;

                //If delete or backspace
                if (event.keyCode == 46 || event.keyCode == 8)
                    decreasing = true;

                //If the letters introduced are enough
                if (_length >= numCharStartSearch) {
                    _filterIntervalHandler = setInterval(function () {
                        usingFilter = true;
                        //Clear myself.
                        clearInterval(_filterIntervalHandler);
                        filtering = true;
                        searchDOM($('.' + menuItemsId), _attrValue);
                        usingFilter = false;
                    }, 250);

                } else if ((_length <= numCharStartSearch - 1 || _attrValue == '') && decreasing) {
                    _filterIntervalHandler = setInterval(function () {
                        usingFilter = true;
                        //Clear myself.
                        clearInterval(_filterIntervalHandler);
                        //Recreate the menu.
                        filtering = false;
                        createMenu_AndLogics();

                        //In a Timeout because IE7 needs it!! (Give time to render the menu)
                        setTimeout(function () {
                            //very important to keep the focues on the searchbox, if not they are going to go history back!!
                            $('.' + inputMenuSearchId).focus();
                            //Make believe doesn't happened putting the old value
                            $('.' + inputMenuSearchId).attr('value', _attrValue);
                        }, 10);
                        usingFilter = false;
                    }, 250);
                }
            }
        });

        return html;
    }

    /**
     *  Function to find a string to a given DOM Element.
     *  @private
     *  @param {Element} object DOM Element where we want to search.
     *  @param {String} value String to find in the DOM.
     */
    function searchDOM(/* Element */object, /* String */value) {
        var regex = new RegExp(value.replace(/[-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g, "\\$&"), 'i');
        recursiveSearchDOM(object, regex);
    }

    /**
     *  Function to check if an element DOM has a title class.
     *  @private
     *  @param {Element} option Element to check.
     */
    function isTitle(/* Element */option) {
        if (option.hasClass('title')) {
            return true;
        }
        for (var i = 1; i < dbesp.MENU_LEVELS_CONTEXTUAL + 1; i++) {
            if (option.hasClass('title' + i)) {
                return true;
            }
        }
        return false;
    }

    /**
     *  Function to show the parent of an element DOM.
     *  @private
     *  @param {Element} object Child element.
     */
    function showParent(/* Element */object) {
        var objectParent = object.parent();

        objectParent.prev().addClass('active');
        objectParent.prev().show();
        objectParent.addClass('active');
        objectParent.show();

        if (objectParent.parent().hasClass("container")) {
            showParent(objectParent);
        }
    }

    /**
     *  Function to find recursively a regular expresion to a given DOM Element.
     *  @private
     *  @param {Element} object DOM Element where we want to search.
     *  @param {String} regex String with a regular expresion.
     */
    function recursiveSearchDOM(/* Element */object, /* String */regex) {
        var funcIsTitle = isTitle;
        var funcIsLink = isLink;
        var funcShowParent = showParent;
        object.children().each(function () {
            var _this = $(this);
            //We take the <a> inside the <div>
            var _thisA = _this.children(":first");
            var textHref = _thisA.text();
            var isTitle = funcIsTitle(_this);
            var isLink = funcIsLink(_this);
            if (regex.test(textHref)) {
                _this.show();
                _thisA.addClass('isSearch');
                if (isTitle) {
                    _this.addClass('active');
                }
                if (isLink) {
                    funcShowParent(_this);
                }
            } else {
                //If it's not a container hide it.
                if (!_this.hasClass('container')) {
                    _this.hide();
                }
            }
            if (isTitle) {
                recursiveSearchDOM(_this.next(), regex);
            }
        });
    }

    /**
     *
     *  @private
     *  @param {String} str
     */
    function cutStr(/*String*/ str, /*int*/maxLength) {
        //console.log('>>>>' + str);
        if (str.length > maxLength) {
            var strAux = str.substring(0, maxLength - 1);
            //console.log('> strAux >' + strAux);
            var lastSpace = strAux.lastIndexOf(' ');
            //console.log('> lastSpace >' + lastSpace);
            if (lastSpace > 0) {
                strAux = strAux.substring(0, lastSpace);
                //console.log('> strAux >' + strAux);
                return strAux + '<br/>' + cutStr(str.substring(lastSpace + 1), maxLength);
            } else {
                return str;
            }
        } else {
            return str;
        }
    }

    /**
     *
     *  @private
     *  @param {String} str
     */
    function addBreakLine(/* String */str) {

        if (dbesp.isIE7) {
            var strAux = '';
            var strDecode = $("<div/>").html(str).text();
            //strDecode=strDecode.trim();
            var _length = strDecode ? strDecode.length : 0;

            if (_length > 26) {
                //return str.repl;
                return cutStr(strDecode, 26);
            } else {
                return str;
            }

        } else {
            return str;
        }
    }

    /**
     * Function to compose the menu
     * @private
     * @param {MenuData} menuData Object with the menu data
     * @return {String} Html with the menu search
     */
    function composeMenu(menuData) {
        var selected = menuData.selected;
        var html = '<div class="' + menuItemsId + ' ' + classStyleAccordion + '">';
        html += menuData.item ? recursiveComposer(menuData.item, selected) : '';
        html += '</div>';
        return html;
    }

    /**
     * Function to compose the menu recursively
     * @private
     * @param {Item} object Item
     * @param {String} selected Selected value
     * @return {String} Html with the menu data
     */
    function recursiveComposer(object, selected) {
        var html = '';
        var funcAddBreakLine = addBreakLine;
        var _length = object ? object.length : 0;

        if (_length > 0) {
            for (var i = 0; i < _length; i++) {
				var thisEntry=object[i];
				html+=composeOneEntry(thisEntry);
              /*  //IE7 has a bug, ie7 adds full url  to href, this is becaus we add a #.
                var msjHref = '#' + $.trim(object[i].link);
                if (object[i].items) {
                    html += '<div class="title ' + object[i].key + ' ' + object[i].style + '"><a href="' + msjHref + '" channel="' + object[i].target + '" class="action ' + tSelected + '">' + funcAddBreakLine(object[i].label) + '</a></div>';
                    html += '<div class="container">';
                    html += recursiveComposer(object[i].items.item, selected);
                    html += '</div>';
                } else {
                    var tSelected = '';
                    if (selected == (object[i].key)) {
                        tSelected = 'selected';
                    }
                    html += '<div class="' + object[i].key + ' ' + object[i].style + '"><a href="' + msjHref + '" channel="' + object[i].target + '" class="action ' + tSelected + '">' + funcAddBreakLine(object[i].label) + '</a></div>';
                }*/
            }
        } else {
			html+=composeOneEntry(object);
			/*
            //IE7 has a bug, ie7 adds full url  to href, this is becaus we add a #.
            var msjHref = '#' + $.trim(object.link);
            if (object.items) {
            	if(i){
            		html += '<div class="' + object[i].key + ' ' + object[i].style + '"><a href="' + msjHref + '" channel="' + object.target + '" class="action title ' + tSelected + '">' + funcAddBreakLine(object.label) + '</a></div>';
            	}else{
            		//i is undefined
            		html += '<div class="' + object.key + ' ' + object.style + '"><a href="' + msjHref + '" channel="' + object.target + '" class="action title">' + funcAddBreakLine(object.label) + '</a></div>';
            	}
                
                html += '<div class="container">';
                html += recursiveComposer(object.items.item, selected);
                html += '</div>';
            } else {
                var tSelected = '';
                if (selected == (object.key)) {
                    tSelected = 'selected';
                }
                html += '<div  class="' + object.key + ' ' + object.style + '"><a href="' + msjHref + '" channel="' + object.target + '" class="action ' + tSelected + '">' + funcAddBreakLine(object.label) + '</a></div>';
            }*/
        }
		
		function composeOneEntry(entry, selected) {
			//IE7 has a bug, ie7 adds full url  to href, this is becaus we add a #.
			var msjHref = '#' + $.trim(entry.link);
			var entrySons="";
			var tSelected="";
			var titleClass="";
			if (entry.items) {
				entrySons = '<div class="container">';
				entrySons += recursiveComposer(entry.items.item, selected);
				entrySons += '</div>';
				titleClass="title ";
			} else if (selected == (entry.key)) {
				tSelected = 'selected';
			}
			var entryHtml = '<div class="' + titleClass + entry.key + ' ' + entry.style + '"><a href="' + msjHref + '" channel="' + entry.target + '" class="action ' + tSelected + '">' + funcAddBreakLine(entry.label) + '</a></div>';
			entryHtml += entrySons;
			return entryHtml;
		}
        return html;
    }

    /**
     * Function to compose the hierarchy combos
     * @private
     * @param {HierarchyData} hierarchyData Object with the menu data
     * @return {String} Html with the hierarchy combos
     */
    function composeHierarchyCombos(hierarchyData) {
        var selected = '';
        var html = '<div class="hierarchyCombos">';
        html += hierarchyData.labels.region;
        html += '<select class="sRegions hierarchySelector">';
        var _region = hierarchyData.regions.region;
        var _length = _region ? _region.length : 0;
        for (var i = 0; i < _length; i++) {
            selected = '';
            if (_region == _region[i].key) {
                selected = 'selected="selected"';
            }
            html += '<option value="' + _region[i].key + '" ' + selected + '>' + _region[i].label + '</option>';
        }
        html += '</select>';
        html += hierarchyData.labels.office;
        html += '<select class="sOffices hierarchySelector">';
        var _office = hierarchyData.offices.office;
        _length = _office ? _office.length : 0;
        for (i = 0; i < _length; i++) {
            //FIXME: Check if var selected = '' is mising or not.
            if (_office == _office[i].key) {
                selected = 'selected="selected"';
            }
            html += '<option value="' + _office[i].key + '" ' + selected + '>' + _office[i].label + '</option>';
        }
        html += '</select>';
        html += hierarchyData.labels.advisor;
        html += '<select class="sAdvisors hierarchySelector">';
        var _advisor = hierarchyData.advisors.advisor;
        _length = _advisor ? _advisor.length : 0;
        for (i = 0; i < _length; i++) {
            selected = '';
            if (_advisor == _advisor[i].key) {
                selected = 'selected="selected"';
            }
            html += '<option value="' + _advisor[i].key + '" ' + selected + '>' + _advisor[i].label + '</option>';
        }
        html += '</select>';
        html += '</div>';
        return html;
    }

    /*
     * Function that creates the menu and add the logics ans behavior.
     * @private
     */
    function createMenu_AndLogics() {
        var data = globalData;
        var html = '';
        var menu_option = '';

        if (data && data.menu) {
            if (data.menu.hierarchy) {
                html += composeHierarchyCombos(data.menu.hierarchy);
            }
            if (_searchMenu) {//data.menu.search && data.menu.items){
                html += composeMenuSearch(data.menu);
            }
            if (data.menu.items) {
                html += composeMenu(data.menu.items);
                //After subscribe the events for the menu.
                if (!_actual_menu_option) {
                    //This should be only the first time!
                    menu_option = dbesp.utils.misc.getUrlParam('MENU_ID');
                    if (!menu_option) {
                        if (data && data.menu && data.menu.items) {
                            menu_option = '' + data.menu.items.selected;
                        }
                    }
                } else {
                    menu_option = _actual_menu_option;
                }
            }
        }

        $('.' + menuContentId).html(html);
        accordionBehavior();
        if (menu_option) {
            showMenuOption(menu_option, true);
        }

    }
    
    var menuAjaxPromise=false;

    /**
     * Function that gets the desired menu by calling a REST service.
     * support multiple calls using jquery desired object:
     *   while there is a request ongoing request does not accept others, if  
     * @private
     */
    function getMenuAjax() {
        var rootRestMenu = rootRest + '/' + dbesp.loggedInUserId + '/' + dbesp.pageName;
        dbesp.log.info(_className + '.getMenuAjax ', 'rootRest : ' + rootRestMenu);
        if (!menuAjaxPromise) {
        	var reqLang=dbesp.i18n.getPortalLanguage();
        	menuAjaxPromise=$.ajax({
                url: rootRestMenu,
                cache: false,
                requestHeaders: {
                    'If-Modified-Since': 'Sat, 1 Jan 2000 00:00:00 GMT'
                }
            }).then(function(data){
            	var curLan=dbesp.i18n.getPortalLanguage();
            	menuAjaxPromise=false;
            	if (curLan==reqLang) {
                    dbesp.log.info(_className + '.getMenuAjax ', 'menu response received for lang '+curLan);
                    globalData = data;
                    createMenu_AndLogics();
            	} else {
                    dbesp.log.info(_className + '.getMenuAjax ', 'retry menu connection. Received for lang '+reqLang+' but current lang is '+curLan);
            		// language has been modified, redo the request
            		getMenuAjax();
            	}
            },function(a,b,c){
            	menuAjaxPromise=false;
            	dbesp.log.info(_className + '.getMenuAjax ', 'menu response communication error: '+a+'/'+b+'/'+c);
            	// there was a ajax communication error
            });
        }
    }

    /**
     * Function to show a menu section
     * @private
     * @param {Event} event Type of menu: 'menu', 'stub' or 'local'
     */
    function showMenuSection(/* Event */event) {
        if (event.preventDefault) {
            event.preventDefault();
        } else {
            event.returnValue = false;
        }
        var elementActive = $('div.active');
        var _this = $(this);
        var _parent = _this.parent();
        var _grandpa = _parent.parent();

        //If it's not me or an ancestor slideUp
        if (elementActive[0] != _this[0] && elementActive[0] != _parent.prev()[0] && elementActive[0] != _grandpa.prev()[0]) {
            if (isTitle(elementActive)) {
                elementActive.next().slideUp('slow');
            }
        }
        //Has children slidUp
        for (var num = 1; num < elementActive.length; num++) {
            $(elementActive[num]).next().slideUp('slow');
        }

        //check if is title
        if (isTitle(_this)) {
            // if had parent title select parent then select parent title
            if (_parent.hasClass("container")) {
                _parent.slideDown('slow');
                _parent.prev().addClass('active');
                if (_grandpa.hasClass("container")) {
                    _grandpa.slideDown('slow');
                    _grandpa.prev().addClass('active');
                }
            }
        }

        //THIS IS TO SLIDEUP CHILDRENS???
        _this.siblings('.container:visible').slideUp('slow');
        //_this.siblings('.container').css('display','block').slideUp('slow');
        var _title = $('.title');
        if (!_this.hasClass('active')) {
            _this.next('div').slideDown('slow');
            _title.removeClass('active');
            _title.removeClass('activeLink');
            _this.addClass('active');
        } else {
            _title.removeClass('active');
            _title.removeClass('activeLink');
        }
        _this.parents('.container:visible').prev('div').addClass('active');
    }

    /**
     * Function to prepare the accordion behavior
     * @private
     */
    function accordionBehavior() {
        $('.' + classStyleAccordion + ' > div:first').addClass('active');
        $('div.container:not(:first)').hide();
        $('.' + classStyleAccordion + ' .title').bind('click', showMenuSection);
        bindActions();
    }

    /**
     *  Function to remove the hash (#) from a URL.
     *  @private
     */
    function relativeUrl(urlStr) {
        var hash = urlStr;
        //SEPARO EL HASH DE LA URL PARA IE7
        hash = hash.replace(/^.*?#(.*?)$/, "#$1");
        hash = hash.substring(1, hash.length);
        return hash;
    }

    /**
     *  Function
     *  @private
     */
    function pseudoClick(element) {
        var _accordionA = $('.' + classStyleAccordion + ' a');
        var _accordionDIV = $('.' + classStyleAccordion + ' div .active');
        _accordionA.removeClass('selected');
        _accordionA.removeClass('isSearch');
        _accordionA.removeClass('activeLink');

        //If it's is not me... and If I'm not a son slide up the active div container
        if (_accordionDIV && _accordionDIV.length == 1 && element.parent()
            && _accordionDIV[0] != element.parent()[0]
            && element.parent().parent() && element.parent().parent().prev()
            && _accordionDIV[0] != element.parent().parent().prev()[0]) {
            _accordionDIV.removeClass('active');
            _accordionDIV.next('div').slideUp('slow');
        }

        $('.' + classStyleAccordion + ' div ').removeClass('activeLink');

        element.addClass('selected');

        if (element.hasClass('isSearch')) {
            //_accordionA.removeClass('isSearch');
            showMenuOption(element.parent().attr('id'), false);
        }
        element.parent().addClass('activeLink');

    }

    /**
     * bindActions
     */
    function bindActions() {
        $('.' + classStyleAccordion + ' .action').bind('click', function (event) {
            if (event.preventDefault) {
                event.preventDefault();
            } else {
                event.returnValue = false;
            }
            var _this = $(this);
            _actual_menu_option = _this.parent().attr('id');
            pseudoClick(_this);
            //relativeUrl('localhsots:777/asdflasdf/asdfasdfi#/mipagina.html#href');
            //If we are filtering don't throw the action.
            if (!usingFilter) {
                publishToWidget(_this.attr('channel'), relativeUrl(_this.attr('href')));
            }
        });
    }

    /**
     * Function to publish a menu event
     * @private
     * @param {String} channel Channel
     * @param {String} message Message
     */
    function publishToWidget(channel, message) {
        dbesp.log.debug(_className + '.publishToWidget', 'Channel -> ' + channel + ' ::  message -> ' + message);
        $.publish("chnn_" + channel, [message]);
    }

    /**
     * Function to subscribe to the menu channel for invocation from widgets
     * @private
     */
    function subscribe() {
        dbesp.log.info(_className + '.subscribe', ' subscribe to ' + dbesp.CHANNEL_GO_TO_MENU_OPTION);
        $.subscribe(dbesp.CHANNEL_GO_TO_MENU_OPTION, function (message) {
            if (message) {
                //Check if literal message contains for example ',', '.', ':'. It is modified if is necessary
                dbesp.log.info(_className + '.subscribe', 'Subscribe message ' + message);
                var identificadorStr = dbesp.utils.misc.stringCharScape(message);
                var divObject = $('.' + identificadorStr);
                var aObject = divObject.children(":first");
                $('.' + classStyleAccordion + ' a').removeClass('selected');
                $('.' + classStyleAccordion + ' div').removeClass('activeLink');
                $('.' + classStyleAccordion + ' div').removeClass('active');
                $('div.container:not(:first)').hide();
                aObject.addClass('selected');

                //showMenuOption(message, false);

                $('.' + classStyleAccordion + ' a').removeClass('isSearch');
                divObject.addClass('activeLink');
                showMenuOption(message, true);
            }//TODO: Check exception when no message??
            return true;
        }, 'menu');
        $.subscribe(dbesp.i18n.changeLanguageEventName, function (message) {
            dbesp.log.info(_className + '.subscribe', 'Listen : ' + message);
            getMenuAjax();
            return true;
        });
    }

    /**
     * Function to show a menu option when we get an invocation from a widget
     * @private
     * @param {String} identificadorStr Option to show
     * @param {Boolean} navigate If true, the menu navigates. If false, it only shows
     */
    function showMenuOption(identificadorStr, navigate) {
        identificadorStr = dbesp.utils.misc.stringCharScape(identificadorStr);

        var identificador = $('.' + identificadorStr);
        var isSearch = identificador.children(":first").hasClass("isSearch");

        if (!filtering) {
            showTitle($('.' + menuItemsId), isSearch);
        }
        if (identificador.hasClass('invisible0')) {
            dbesp.log.info(_className + '.showMenuOption', 'has class invisible0');
        }

        $('.' + classStyleAccordion + ' .action').unbind('click');
        lookMenuTitles(null, identificador);
        pseudoClick($('.' + identificadorStr + " > a"));
        bindActions();

        //We navegate always exept when navigate == false
        if (navigate != false) {
            $('.' + identificadorStr + " > a").trigger('click');
        }
    }

    /**
     *
     *  @param {} object
     *  @param {} isSearch
     */
    function showTitle(object, isSearch) {
        object.children().each(function () {
            var kid = $(this);
            if (isSearch || kid.hasClass("title")) {
                kid.show();
            }
            if (kid.hasClass("container")) {
                showTitle(kid, isSearch);
            }
        });
    }

    /**
     * Function to look for the menu titles to activate when showing an option
     * @private
     * @param {String} option Option to show.
     * @param {Element} identificador Element to search.
     */
    function lookMenuTitles(option, identificador) {
        if (option == null) {
            option = $('.' + menuItemsId);
        }

        var prevElement;
        var presentElement;

        option.children().each(function () {
            presentElement = $(this);
            if (presentElement.hasClass('active')) {
                presentElement.trigger('click');
            }
            var foundElem = presentElement.find(identificador);
            if (foundElem && foundElem.length > 0) {
                prevElement.trigger('click');
                prevElement.addClass('active');
                lookMenuTitles(presentElement, identificador);
            }
            if (presentElement.hasClass('title')) {
                prevElement = presentElement;
            }
        });

    }

    /**
     *  Function to check if an element DOM has a link class.
     *  @private
     *  @param {Element} option Element to check.
     */
    function isLink(/* Element */option) {
        if (option.hasClass('link1T')) {
            return true
        } else {
            for (var i = 1; i < dbesp.MENU_LEVELS_CONTEXTUAL + 1; i++) {
                if (option.hasClass('link' + i)) {
                    return true;
                }
            }
        }
        return false;
    }


    /**
     * functions to reload menu
     * **/

    function optionSelected(object) {
        var valor = null;
        var funcIsTitle = isTitle;
        var funcOptionSelected = optionSelected;
        object.children().each(function () {
            var kid = $(this);
            if (kid.hasClass('activeLink')) {
                valor = kid.attr('id');
                //to break loop
                return false;
            }
            if (funcIsTitle(kid)) {
                valor = funcOptionSelected(kid.next());
                if (valor !== null) {
                    //to break loop
                    return false;
                }
            }
        });
        return valor;
    }

    /**
     * Function to compose the menu
     * @private
     * @param {MenuData} menuData Object with the menu data
     * @return {String} Html with the menu search
     */
    function composeMenuReload(menuData) {
        var selected = menuData.selected;
        var html = recursiveComposer(menuData.item, selected);
        return html;
    }


    function reloadMenuAjax(object, selectedItem) {
        var rootRestReload = rootRest + '/' + dbesp.loggedInUserId + '/' + dbesp.pageName;
        dbesp.log.info(_className + '.reloadMenuAjax', rootRestReload);
        $.ajax({
            url: rootRestReload,
            cache: false,
            requestHeaders: {
                'If-Modified-Since': 'Sat, 1 Jan 2000 00:00:00 GMT'
            },
            success: function (data, textStatus, jqXHR) {
                globalData = data;
                var html = '';

                if (data && data.menu && data.menu.items) {
                    html += composeMenuReload(data.menu.items);
                }
                object.html(html);
                accordionBehavior();
                if (selectedItem) {
                    showMenuOption(selectedItem);
                }
                else {
                    showMenuOption(undefined);
                }

            },
            error: function (data, textStatus, jqXHR) {
                dbesp.log.error(_className + '.reloadMenuAjax', 'Failure');
            }
        });


    }

    /**
     * Function to compose the page menu in reload
     */
    function reloadMenu(isSelectedNavigate) {
        var selectedItem = null;

        if (isSelectedNavigate) {
            selectedItem = optionSelected($('.' + menuItemsId));
        }
        reloadMenuAjax($('.' + menuItemsId), selectedItem);
    }

    /**
     * Function to check if the search menu box is required or not.
     * @private
     */
    function checkIfSearchMenuIsNeeded() {
        var _okMenuPages = function (/*String*/ menuPages) {
            if (menuPages && menuPages.indexOf(dbesp.pageName) != -1) {//Not checked as an array with a bucle for better performance.
                _searchMenu = true;
            }
        };
        var _failMenuPages = function () {
            dbesp.log.warn(_className + '.init', 'Failed to retrieve if the search menu is needed.');
        };

        dbesp.configService.getParameter('pagesWithMenuSearch',
            _okMenuPages,
            _failMenuPages
        );
    }


    /**
     * Function to see if a value is even
     * @param {Integer} val Value to test
     * @return {Boolean} Value is even
     */
    function isEven(val) {
        return val % 2 === 0;
    }

    /**
     * Function to compose non FAB page menu.
     */
    function init() {
        checkIfSearchMenuIsNeeded();
        menuContentId = 'menuContent';
        inputMenuSearchId = 'inputMenuSearch';
        menuSearchId = 'menuSearch';
        menuItemsId = 'menuItems';
        classStyleAccordion = 'accordion';
        _className = 'core-contextualMenuController';
        getMenuAjax();
        subscribe();
    }

    /**
     * Function to compose FAB page menu.
     */
    function initFAB() {
        checkIfSearchMenuIsNeeded();
        menuContentId = 'menuContentFAB';
        inputMenuSearchId = 'inputMenuSearchFAB';
        menuSearchId = 'menuSearchFAB';
        menuItemsId = 'menuItemsFAB';
        classStyleAccordion = 'accordionFAB';
        _className = 'core-contextualMenuControllerFAB';
        getMenuAjax();
        subscribe();
    }

    var contextualMenuController = {
        init: init,
        isEven: isEven,
        publishToWidget: publishToWidget,
        showMenuOption: showMenuOption,
        reloadMenu: reloadMenu,
        initFAB: initFAB
    };

    dbesp.common = dbesp.common || {};
    dbesp.common.contextualMenuController = contextualMenuController;
})();
// Context Manager controller to enable portal (intra-widgets) contextualization.
(function() {
    'use strict';

	/**
	 *  Context Manager controller to enable portal (intra-widgets) contextualization.
	 * @exports core/context/contextManager
	 *
	 * @requires module:lodash
	 * @requires module:core/utils/fn
	 * @requires module:core/context/stores/basicStore
	 */
	var contextManager = {};

	/**
	 * A unique dictionary where every context type has a mapped store
	 * @type {object}
	 */
	var storeRegistry = {};

	// ***************************** //
	// ** Public functions ** //
	// ***************************** //

	/**
	 * Saves a context {type, id, description} in that type's store
	 * @param {propagationContext} context
	 * @param {boolean} [overwrite] overwrite even if already last
	 * @returns {{wasLast: boolean, wasInactive: boolean}} flags that indicate if element was already the last one of that type's store and if it was inactive
	 */
	contextManager.save = function(context, overwrite) {
		var store = storeRegistry[context.type];
		if (!store) {
			store = storeRegistry[context.type] = dbesp.utils.fn.createInstance(dbesp.context.stores.BasicStore);
		}
		var prevItem = store.push(context, overwrite);
		var saveResult  = {
			wasLast : Boolean(prevItem),
			wasInactive : prevItem && prevItem.inactive
		};
		return saveResult;
	};

	/**
	 * removes that type's store (String) or the specific context of that type (Object)
	 */
	contextManager.remove = function(contextOrContextType) {
		if (_.isString(contextOrContextType)) {
			delete storeRegistry[contextOrContextType];
		} else {
			var store = storeRegistry[contextOrContextType.type];
			if (store) {
				store.remove(contextOrContextType);
			}
		}
	};

	/**
	 * Given a context type, retrieves the corresponding saved data
	 * @param  {String} contextType name of the store we wish to pull data from
	 * @return {Array}  last N (store's MAX_SIZE) saved elements
	 */
	contextManager.retrieve = function(contextType) {
		var store = storeRegistry[contextType];
		return (store && store.pull(contextType)) || [];
	};

	/**
	 * Shorthand to retrieve last saved element of that type's store
	 * @param  {String} contextType Name of the store we wish to pull data from
	 * @return {Object}             Last saved element
	 */
	contextManager.last = function(contextType) {
		return contextManager.retrieve(contextType)[0];
	};

	/*  Unused for the moment
	 contextManager.isLast = function(context) {
	 var last = managerInstance.last(context.type);
	 if (last) {
	 var store = storeRegistry[context.type];
	 return store.compare(last, context);
	 } else {
	 return false;
	 }
	 };
	 */

    /**
     *
     * @param contextA
     * @param contextB
     * @return {Boolean} equality result
     */
	contextManager.isSame = function(contextA, contextB) {
		if (contextA.type !== contextB.type) {
			return false;
		}
		var store = storeRegistry[contextA.type];
		if (!store) {
			store = dbesp.utils.fn.createInstance(dbesp.context.stores.BasicStore);
		}
		return store.compare(contextA, contextB);
	};

	/**
	 * Assigns an instance of the passed store to the specified type
	 * This is useful when a more complex store is needed for a certain type.
	 * @param {string|Array} types
	 * @param {module:core/context/stores/basicStore} Store
	 */
	contextManager.registerStore = function(types, Store) {
		var store = dbesp.utils.fn.createInstance(Store);
		types = _.isArray(types)? types : [types];
		for(var i = 0; i < types.length; i++) {
			storeRegistry[types[i]] = store;
		}
		return store;
	};

	dbesp.context = dbesp.context || {};
	dbesp.context.contextManager = contextManager;
})();


/**
 * General purpose store
 * Stores should only be accessed through the contextManager
 * Specific stores should inherit from this base
 *
 * @module core/context/stores/basicStore
 *
 */
(function() {
    'use strict';

	/**
	 *
	 * @constructor
	 * @alias module:core/context/stores/basicStore
	 * @private
	 */
	var BasicStore = function() {
		this.items = [];
	};

	/**
	 * Default store size
	 * @type {number}
	 *
	 * @protected
	 */
	BasicStore.prototype.MAX_SIZE = 5;

	/**
	 * Updates the store re-locating the data if exists or storing it if not.
	 * Relocation is implemented following an LRU caching algorithm.
	 * See http://en.wikipedia.org/wiki/Cache_algorithms
	 * @param  {propagationContext} item data to save
	 * @param  {boolean} [overwrite] Whether to overwrite the item if already last
	 * @return {propagationContext|undefined} the previous element
	 *
	 * @protected
	 */
	BasicStore.prototype.push = function(item, overwrite) {
		var position = fetch(this, item);
		var returnValue;
		if (position === 0) {
			returnValue = this.items[position];
			if (overwrite) {
				this.items[position] = item;
			}
		} else {
			save(this, item, position);
		}
		return returnValue;
	};

	/**
	 * @param {String} type not used in BasicStore but declared here for clarity - necessary for inherited stores
	 * @returns {Array<propagationContext>} the stored elements
	 *
	 * @protected
	 */
	BasicStore.prototype.pull = function(type) {
		return this.items;
	};

	/**
	 * Removes an element from the store
	 * @param {propagationContext} item
	 * @protected
	 */
	BasicStore.prototype.remove = function(item) {
		var position = fetch(this, item);
		if (position >= 0) {
			this.items.splice(position, 1);
		}
	};

	/**
	 * Comparator of store's elements
	 * @param  {propagationContext} item1
	 * @param  {propagationContext} item2
	 * @return {Boolean} equality result
	 *
	 * @protected
	 */
	BasicStore.prototype.compare = function(item1, item2) {
		return item1.id === item2.id;
	};


	// ****************************** //
	// ** Private helper functions ** //
	// ****************************** //

	function fetch(store, item) {
		var items = store.items;
		for (var i = items.length; i--;) {
			if (store.compare(items[i], item)) {
				return i;
			}
		}
		return -1;
	}

	function save(store, item, position) {
		var items = store.items;
		if (position > -1) {
			// commenting this line as the store will overwrite the item instead of moving it
			//  items.unshift(items.splice(position, 1)[0]);
			//  replacing with these lines:
			items.splice(position, 1);
			items.unshift(item);
		} else {
			// Keep maximum storage size
			if (store.MAX_SIZE === items.length) {
				items.pop();
			}
			items.unshift(item);
		}
	}

	dbesp.context = dbesp.context || {};
	dbesp.context.stores = dbesp.context.stores || {};
	dbesp.context.stores.BasicStore = BasicStore;
})();

/**
 * @class
 * @memberOf dbesp.browserhandling
 * @namespace
 * @description This class intends to avoid two portal sessions on same browser, based on window.name value
 * 
 * technology overview:
 * Current window name is stored in session storage that is unique per window tab: https://developer.mozilla.org/en-US/docs/Web/API/Web_Storage_API
 * Active tab is shared in a session cookie, visible between all tabs on same server session.
 * As there is an issue in iexplorer (https://support.microsoft.com/en-us/kb/3012780) that makes session storage to be incorrectly
 *  shared between tabs, window.name is used as backup. Portals where other actors change window.name loses this backup.
 * 
 * detail, see checkToken function:
 *  1. set random name to current tab
 *  2. check current active tab in dbesp.BROWSER_HANDLING_TOKEN cookie
 *  2.1 If active tab is empty, try to save current tab name as active tab in cookie and server.
 *  2.1.1 If server says that current tab is other, call again forcing current as active tab
 *  2.2 If active tab has value, ask backed if may become active tab (case seesion closed in backend)
 *  2.2.1 if backed agrees, continue loading and save current tab as active.
 *  2.2.2 if backed confirms active tab is other, redirect to tab protection error page
 *  
 * When is done this verification:
 *  dbesp.browserhandling.checkToken() is executed on portal load in gftportal-libs[-min].jsp
 * 
 * 25.2.2016 (Tomas Duran) possible improvement: do not use cookies. 
 * cookie is sent to server on every execution, causing noise (logs on server someone can 
 * check when searching for issues) and innecessary overload.
 * Solution to do not use cookie: use localStorage (shared between all tabs)
 * as localStorage is shared also with different sessions (unlike session cookie), it must be 
 * either defined a name univoke per sessin (adding for instance JSESSIONID cookie value) or
 * lose option to have single tab but multiple window.
 * 
 * example local storage (shared between tabs and sessions on same browser, persistent on time): 
 * for (var i=0, len=localStorage.length;i<len;++i) {console.log(localStorage.key(i)+': '+localStorage.getItem(localStorage.key(i)));}
 * 
 * example session storage (unique per tab):
 * for (var i=0, len=sessionStorage.length;i<len;++i) {console.log(sessionStorage.key(i)+': '+sessionStorage.getItem(localStorage.key(i)));}
 * 
 * @dependencies jQuery, jQuery-cookie
 */
(function () {
    
    'use strict';
    // key to store current tab id in session storage
    var SESSION_STORAGE_ID='FAB-Tab-Unic-identifier';
    // prefix 
    var WINDOW_NAME_PREFIX='FAB_PORTAL_ID-';
    /**
     * Function that generates the UID for the value of the token.
     */
    function getUUID() {
        var uuid = (function () {
            var i,
                c = "89ab",
                u = [];
            for (i = 0; i < 36; i += 1) {
                u[i] = (Math.random() * 16 | 0).toString(16);
            }
//            u[8] = u[13] = u[18] = u[23] = "-";
//            u[14] = "4";
            u[19] = c.charAt(Math.random() * 4 | 0);

            return u.join("");
        })();
        return {
            toString: function () {
                return uuid;
            },
            valueOf: function () {
                return uuid;
            }
        };
    }
    
    function getCookieName() {
        // In same tab could be loaded 
        var environment=dbesp.configService.getParameterSynch('property.environment');
        var cookieName = 'dbesp.BROWSER_HANDLING_TOKEN_' + environment;
        return cookieName;
    }
    
    function getCurActiveTabUid() {
        var cookieName=getCookieName();
        return $.cookie(cookieName);
    }
    
    /**
     * saves in cookie active tab name.
     * another place to save this value could be window.localStorage
     * @param {string} activeTabName
     */
    function setCurActiveTabName(/*string*/activeTabName) {
        var cookieName=getCookieName();
        $.cookie(cookieName, activeTabName, {expires: 1, path: b$.portal.config.serverRoot});
    }
    
    function existsCurActiveTabName() {
        var cookieValue=getCurActiveTabUid();
        if (cookieValue == null
            || cookieValue == ''
            || cookieValue == undefined
            || cookieValue.length < 30) {
            return false;
        }
        return true;
    }
    
    function getCurTabUid() {
        var tabName=window.name;
        if (tabName.indexOf(WINDOW_NAME_PREFIX)!==0 && tabName.length > 0) {
            tabName=window.sessionStorage.getItem(SESSION_STORAGE_ID);
        }
        if (tabName===null || tabName.length < 10) {
            tabName=WINDOW_NAME_PREFIX+getUUID();
            window.sessionStorage.setItem(SESSION_STORAGE_ID,tabName);
            if (window.name == undefined || window.name.length===0) {
                window.name=tabName;
            }
        }
        return tabName;
    }
    
    function isItMe() {
        var cookieValue=getCurActiveTabUid();
        var windowName = getCurTabUid();
        return windowName == cookieValue;
    }

    function createToken(/*boolean*/force) {
        var windowName = getCurTabUid();
//        if (windowName==null || windowName.length<30) {
//            windowName=getUUID();
//        }
        var saveFunction=force?forceSaveTokenInServer:saveTokenInServer;
        var created=false;
        // TODO: verify calling /rest/checkWindow/save/newuuid that there is no collision for this session
        // in the meanwhile, accept cookie existness as collision
        if (saveFunction(windowName)) {
            dbesp.log.debug('browserHandling:createToken', 'cookie created: '+windowName);
            created=true;
            setCurActiveTabName(windowName);
            //var cookieName=getCookieName();
            //$.cookie(cookieName, windowName, {expires: 1, path: b$.portal.config.serverRoot});
//            window.name = windowName;
        } else {
            dbesp.log.error('browserHandling:createToken', 'session is busy');
        }
        return created;
    }
    
    function deleteTokenInServer(/*String*/ token) {
        return doInServer('delete', token);
    }
    
    function saveTokenInServer(/*String*/ token) {
        return doInServer('save', token);
    }
    //    
    function forceSaveTokenInServer(/*String*/ token) {
        return doInServer('forceSave', token);
    }
    
    function doInServer(/*String*/ action, /*String*/ token, /*function*/ onSuccess, /*function*/onError) {
        var resultOk=false;
        var errCallback=function(data){
            var sdata=JSON.stringify(data);
            try{dbesp.log.error('browserHandling:'+action, 'Error savin token '+token+': '+sdata);}catch(e){}
            if (onError) onError(data);
        };
        var okCallBack=function(data){
            var sdata=JSON.stringify(data);
            resultOk=data && data.result=='ok';
            try{dbesp.log.debug('browserHandling:'+action, 'action('+action+') result('+resultOk+') token('+token+'): '+sdata);}catch(e){}
            if (onSuccess) onSuccess(data);
        };
        // The root URL for the RESTful services for contexts
        var checkWindowUrl = dbesp.contextRoot + "/rest/utils/checkWindow";

        $.ajax({
            type: "GET",
            contentType: "text/plain",
            url: checkWindowUrl + '/'+action+'/' + token,
            dataType: "json",
            cache: false, // allways ask server
            async: false, // as this verification is prerequisito to window load, communication is synch
            success: okCallBack,
            error: errCallback
        });
        return resultOk;
    }

//    var unloadWithError = false;

    /**
     * Function that checks if the token exists or not.
     * @param force: first time call with false. If first try fails (server says 
     *  cookie exists and is busy) but here there is no cookie, retry forcing.
     * return: nothing
     * 
     */
    function checkToken(/*boolean*/ force) {
        // TODO: verify current page (dbesp.pageName) is not in property.singleTab.disabled.pagelist
        var excludedPageList=" "+dbesp.configService.getParameterSynch('property.singleTab.excluded.pagelist')+" ";
        var currentPage=" "+dbesp.pageName+" ";
        var redirect=false;
        if (excludedPageList.indexOf(currentPage)>=0) {
            // current page must not be checked.
            dbesp.log.debug('browserHandling:checkToken', 'current page is excluded of tab verification');
        } else if (existsCurActiveTabName()) {
            if (isItMe()) {
                // ok, page is being reloaded
                dbesp.log.debug('browserHandling:checkToken', 'singleTab is ready and it is me');
            } else if (createToken()) {
                // server says that cookie is empty -> OK
                dbesp.log.debug('browserHandling:checkToken', 'singleTab cookie existed but was expired. Created ok and now it is me');
            } else {
                redirect=true;
            }
        } else {
            if (createToken(force)) {
                // session did not exist
                dbesp.log.debug('browserHandling:checkToken', 'singleTab cookie created ok and now it is me');
            } else if (!force) {
                // case cookie has been deleted in local but not in session
                checkToken(true);
            } else {
                // sesion is busy
                redirect=true;
            }
        }
        if (redirect) {
            dbesp.log.error('browserHandling:checkToken', 'singleTab cookie busy. Redirecto to session collision page');
            var url = dbesp.contextRoot;
            window.location.href = url + "/errorPage/session.jsp";
        }
    }

    /**
     * Function that sets an empty token, only if it belonged to current window
     * This function is intended to be called before close
     */
    function voidToken() {
        if (existsCurActiveTabName() && isItMe()) {
//            var cookieName=getCookieName();
//            $.cookie(cookieName, '', {expires: 1, path: b$.portal.config.serverRoot});
            setCurActiveTabName('');
            var windowName = getCurTabUid();
            deleteTokenInServer(windowName);
        }
//        var cookieName = 'dbesp.BROWSER_HANDLING_TOKEN_' + parEnvironment;
//        if (unloadWithError == false) {
//            //An empty cookie must not be deleted.
//            if ($.cookie(cookieName) != null
//                && $.cookie(cookieName) != ''
//                && $.cookie(cookieName) != undefined) {
//                //If other page has over-writed the cookie, on unload method must not delete the cookie
//                // only owner page can delete the cookie
//                if ($.cookie(cookieName) == window.name) {
//                    $.cookie(cookieName, '', {expires: 1, path: b$.portal.config.serverRoot});
//                }
//            }
//        }
    }

//    /**
//     * Function that sets an empty token.
//     */
//    function deleteToken() {
////        unloadWithError = false;
//
//        voidToken();
//    }

    var browserHandling = {
        checkToken: checkToken,
//        createToken: createToken,
        voidToken: voidToken,
//        deleteToken: deleteToken
        getCurTabUid:getCurTabUid
    }

    dbesp.internal = dbesp.internal || {};
    dbesp.internal.browserHandling = browserHandling;
})();

/**
 * @class
 * @memberOf dbesp.commesc
 * @namespace
 * @description Facade javascript of the Communication ESC in the backend.
 * The class allows to add/delete/find/update parameters for the communication.
 */
(function () {

    // The root URL for the RESTful services for contexts
    var commescRootURL = dbesp.contextRoot + "/rest/commesc";

    /**
     * Function that stores a parameter of the communication.
     * @param {String} id Id to use
     * @param {String} value Value to store
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     */
    function addParam(/* String */id, /* String */value, /* Function */onSuccess, /* Function */onError) {
    	dbesp.esc.addESC(id, value, onSuccess, onError);
//        $.ajax({
//            type: "POST",
//            contentType: "text/plain",
//            url: commescRootURL + '/' + id,
//            dataType: "text",
//            cache: false,
//            data: value,
//            success: onSuccess,
//            error: onError
//        });
    }

    /**
     * Function to add or update a parameter of the communication.
     * @param {String} id Id to use
     * @param {String} value Value to store
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     */
    function updateParam(/* String */id, /* String */value, /* Function */onSuccess, /* Function */onError) {
    	dbesp.esc.updateESC(id, value, onSuccess, onError);
//        $.ajax({
//            type: "PUT",
//            contentType: "text/plain",
//            url: commescRootURL + '/' + id,
//            dataType: "text",
//            cache: false,
//            data: value,
//            success: onSuccess,
//            error: onError
//        });
    }

    /**
     * Function to delete a parameter of the communication.
     * @param {String} id Id to delete
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     */
    function deleteParam(/* String */id, /* Function */onSuccess, /* Function */onError) {
    	dbesp.esc.deleteESC(id, onSuccess, onError);
//        $.ajax({
//            type: "DELETE",
//            url: commescRootURL + '/' + id,
//            cache: false,
//            success: onSuccess,
//            error: onError
//        });
    }

    /**
     * Function to find a parameter of the communication.
     * @param {String} id Id to find
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     */
    function findParam(/* String */id, /* Function */onSuccess, /* Function */onError) {
    	dbesp.esc.findESC(id, onSuccess, onError);
//        $.ajax({
//            type: "GET",
//            url: commescRootURL + '/' + id,
//            dataType: "text",
//            cache: false,
//            success: onSuccess,
//            error: onError
//        });
    }

    /**
     * Function to delete a parameter of the communication synchronously
     * @param {String} id Id to delete
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     */
    function deleteParamSync(/* String */id, /* Function */onSuccess, /* Function */onError) {
    	dbesp.esc.deleteESCSync(id, onSuccess, onError);
//        $.ajax({
//            async: false,
//            type: "DELETE",
//            url: commescRootURL + '/' + id,
//            cache: false,
//            success: onSuccess,
//            error: onError
//        });
    }

    /**
     * Function to find a parameter of the communication synchronously.
     * @param {String} id Id to find
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     */
    function findParamSync(/* String */id, /* Function */onSuccess, /* Function */onError) {
    	dbesp.esc.findESCSync(id, onSuccess, onError);
//        $.ajax({
//            async: false,
//            type: "GET",
//            url: commescRootURL + '/' + id,
//            dataType: "text",
//            cache: false,
//            success: onSuccess,
//            error: onError
//        });
    }

    var commesc = {
        addParam: addParam,
        updateParam: updateParam,
        deleteParam: deleteParam,
        findParam: findParam,
        findParamSync: findParamSync,
        deleteParamSync: deleteParamSync
    };

    dbesp.internal = dbesp.internal || {};
    dbesp.internal.commesc = commesc;
})();



/**
* @description This class alows to get a registry of communication or a
* list of all of them.
*/
(function () {


    // The root URL for the RESTful services for contexts
    var rootURL = dbesp.contextRoot + "/rest/registry";
    var comRegistryArray = [];

    /**
     * Function to represent a registry
     * @constructs
     * @private
     * @param {String} publisher The name of the publisher
     * @param {Array} targets The intended subscribers
     * @param {Function} eventHandler The callback function
     * @param {String} commID Id of the communication
     * @param {String} channel Channel used in the communication
     */
    function registry(/* String */publisher, /* Array */targets, /* Function */eventHandler, /* String */commID, /* String */channel) {
        this.publisher = publisher;
        this.targets = targets;
        this.eventHandler = eventHandler;
        this.commID = commID;
        this.channel = channel;
    }

    /**
     * Function to request the registry from the Communication Regsitry.
     * @param {String} commID Id of the communication
     * @param {Function} onSuccess Function to execute on a successful operation
     * @param {Function} onError Function to execute on error
     */
    function getProperties(/* String */commID, /* Function */onSuccess, /* Function */onError) {
        var callback = function () {
            for (i = 0; i < comRegistryArray.length; i++) {
                if (comRegistryArray[i].commID == commID) {
                    if (onSuccess && typeof(onSuccess) === "function") {
                        return onSuccess(comRegistryArray[i]);
                    }
                }
            }
        };
        getFullRegistry(callback, onError);

    }

    /**
     * Function to request all the registries from the Communication Regsitry.
     * @param {Function} onSuccess Function to execute on a successful operation
     */
    function getFullRegistry(onSuccess) {
        if (!comRegistryArray || !comRegistryArray.length || comRegistryArray.length < 1) {
            $.ajax({
                type: "GET",
                contentType: "application/json",
                url: rootURL,
                dataType: 'json',
                cache: false,
                success: function (fullReg) {
                    comRegistryArray = fullReg.registry;
                    if (onSuccess && typeof(onSuccess) === "function") {
                        return onSuccess(comRegistryArray);
                    }
                },
                error: function (jqXHR, textStatus, errorThrown) {
                    dbesp.log.error("core-commRegistry.getFullRegistry", "Error:" + textStatus + "," + errorThrown);
                }
            });
        } else {
            if (onSuccess && typeof(onSuccess) === "function") {
                return onSuccess(comRegistryArray);
            }
        }
    }

    var commRegistry = {
        getProperties: getProperties,
        getFullRegistry: getFullRegistry
    }

    dbesp.internal = dbesp.internal || {};
    dbesp.internal.commRegistry = commRegistry
})();
/**
 * secureComm
 * @class The purpose of this function is to be a javascript facade
 * to encapsulate the Secure Communication in the backend.
 * @memberOf dbesp.secureComm
 * @namespace
 * @description The purpose of this function is to be a javascript facade
 * to encapsulate the Secure Communication in the backend.
 */
(function () {

        // The root URL for the RESTful services for contexts
        var rootSecureURL = dbesp.contextRoot + "/rest/secureComm";

        /**
         * Trigger a secure operation identified by a communication id and stores it encrypted.
         * @param {String} publisher Name of the publisher of the communication.
         * @param {String} commID String that identifies the communication.
         * @param {Function} onSuccess Function to execute on a successful operation
         * @param {Function} onError Function to execute on error
         * @return String with the key for the communication. If empty it went wrong.
         */
        function triggerSecComm(/* String */commID, /* String */publisher, /* Function */onSuccess, /* Function */onError) {
            $.ajax({
                type: "POST",
                contentType: "text/plain",
                url: rootSecureURL + "/" + publisher + "/" + commID,
                dataType: "text",
                cache: false,
                success: onSuccess,
                error: onError
            });
        }

        /**
         * Function to delete a secure communication value
         * @param {String} commID Id of the communication
         * @param {String} key Key of the item of the communication
         * @param {String} publisher Name of the publisher.
         * @param {Function} onSuccess Function to execute on a successful operation
         * @param {Function} onError Function to execute on error
         */
        function removeSecCommValue(/* String */commID, /* String */key, /* String */publisher, /* Function */onSuccess, /* Function */onError) {
            $.ajax({
                type: "DELETE",
                url: rootSecureURL + "/" + publisher + "/" + commID,
                data: key,
                cache: false,
                success: onSuccess,
                error: onError
            });
        }

        /**
         * Method that gets an object encrypoted identified by a communication id
         * and returns it decrypted.
         * @param {String} commID String that identifies the communication.
         * @param {String} key String that identifies the object.
         * @param {String} subscriber Name of the subscriber that wants to get the
         * information.
         * @param {Function} onSuccess Function to execute on a successful operation
         * @param {Function} onError Function to execute on error
         * @return Returns a string with the value of the communication.
         */
        function getSecCommValue(/* String */commID, /* String */key, /* String */ subscriber, /* Function */onSuccess, /* Function */onError) {
            $.ajax({
                type: "GET",
                contentType: "text/plain",
                url: rootSecureURL + "/" + subscriber + "/" + commID,
                dataType: "text",
                cache: false,
                data: {"key": key},
                success: onSuccess,
                error: onError
            });
        }

    var secureComm =  {
            triggerSecComm: triggerSecComm,
            removeSecCommValue: removeSecCommValue,
            getSecCommValue: getSecCommValue
        }

    dbesp.internal = dbesp.internal || {};
    dbesp.internal.secureComm = secureComm;
})();

/**
 * feature: "only one portal per computer"
 * it is used dbesp.BROWSER_SESSION_TOKEN cookie to verify it.
 * If collision detected, user is asked to use current insteado of other
 * if timeout is set, curren will pool on cookie to see if other has become 'principal' and autodisable
 * on error: set an overlay with a message.
 */
(function () {

    //Current SESSION_ID
    var currentSession = $.cookie('JSESSIONID');
    dbesp.log.debug('dbesp.sessionHandling', 'currentSession=' + currentSession, false);

    function checkSession() {
        dbesp.log.debug('dbesp.sessionHandling', 'checkSession', false);

        if ($.cookie('dbesp.BROWSER_SESSION_TOKEN') == null
            || $.cookie('dbesp.BROWSER_SESSION_TOKEN') == ''
            || $.cookie('dbesp.BROWSER_SESSION_TOKEN') == 'null'
            || $.cookie('dbesp.BROWSER_SESSION_TOKEN') == 'undefined'
            || $.cookie('dbesp.BROWSER_SESSION_TOKEN') == undefined) {

            // No dbesp.BROWSER_SESSION_TOKEN created. this could be the first session o a page reload?
            //alert("is empty=" + $.cookie('dbesp.BROWSER_SESSION_TOKEN') + " ? " + currentSession);
            dbesp.log.info('dbesp.sessionHandling', 'checkSession: cookie empty ', false);
            $.cookie('dbesp.BROWSER_SESSION_TOKEN', currentSession, {expires: 1, path: b$.portal.config.serverRoot});
            //alert("is empty now:" + $.cookie('dbesp.BROWSER_SESSION_TOKEN'));
        } else {
            dbesp.log.info('dbesp.sessionHandling', 'checkSession: cookie already exist ', false);
            //alert("NOT Empty=" + $.cookie('dbesp.BROWSER_SESSION_TOKEN') + " vs. " + currentSession);

            if ($.cookie('dbesp.BROWSER_SESSION_TOKEN') != currentSession) {
                //Current session and active session stored doesn't match up
                dbesp.log.info('dbesp.sessionHandling', 'checkSession: cookie and current sessionid are different: cookie=' + $.cookie('dbesp.BROWSER_SESSION_TOKEN') + ' session=' + currentSession, false);
                //User must choose between current session or stored session
                $(document).ready(function () {
                    //If user selects current session as active then process calls: changeActiveSession() to dot it
                    //else, it calls: stop()
                    $('body').append(drawMessage());
                    $('#mainOverlay').show();
                });
            }
        }
    }

    function changeActiveSession() {
        //User selects current window as active session, so it saves current session as active session
        dbesp.log.info('dbesp.sessionHandling', 'changeActiveSession. Active session is now: ' + $.cookie('JSESSIONID'), false);
        $.cookie('dbesp.BROWSER_SESSION_TOKEN', $.cookie('JSESSIONID'), {expires: 1, path: b$.portal.config.serverRoot});
        $('#mainOverlay').hide();
    }

    function drawMessage() {
        //Return a popup window
        return $('<div id="mainOverlay">\n    <div id="overlay" class="overlay-popup"></div>\n    <div align="center" class="overlay-window"><STRONG>DETECTED ACTIVE SESSION.</STRONG>\n        <hr color="#dbe0e6"/>\n        A previous session of your user is still active. <br/>Do you want to turn this session into the active session\n        and invalidate the other one?<br/><a href="#" data-action="changeActiveSession"\n                                             class="button">Yes</a>&nbsp;&nbsp;<a  data-action="stop"\n                href="#" class="button">No</a></div>\n</div>')
            .on('click', 'a', function() {
                var $this = $(this);
                    if ($this.data('action') === "stop") {
                        stop();
                    } else {
                        changeActiveSession();
                    }
            });
    }

    var cookieVerificationInterval = 0;
    var timer;

    function init(seconds) {
        if (!isNaN(seconds) && (parseInt(seconds) > 0)) {
            //Starts a countdown of "seconds" parameter
            dbesp.log.debug('dbesp.sessionHandling', 'init: Timer started every ' + seconds + " seconds.", false);
            cookieVerificationInterval = seconds * 1000;
            //When timer reaches 0 it calls to countDown() function
            timer = setTimeout(function () {
                countDown();
            }, cookieVerificationInterval);
        } else {
            dbesp.log.debug('dbesp.sessionHandling', 'init: No seconds received=' + seconds, false);
        }
    }

    function stop() {
        if ($.cookie('dbesp.BROWSER_SESSION_TOKEN') == currentSession) {
            //If an unload event of current page is reveived and current page is the active session
            //the session cookie is deleted and timer is stoped.
            dbesp.log.debug('dbesp.sessionHandling', 'stop: Unload page', false);
            $.cookie('dbesp.BROWSER_SESSION_TOKEN', null, {expires: 1, path: b$.portal.config.serverRoot});
            clearTimeout(timer);
        } else {
            //User doesn't want to mantain current browser session as active.
            disable();
            dbesp.log.debug('dbesp.sessionHandling', 'stop: Disable page', false);
        }
    }

    function countDown() {
        //When countdown finishes, it's time to test if current browser window is the active portal session or not
        if ($.cookie('dbesp.BROWSER_SESSION_TOKEN') == currentSession) {
            //Current window match with active session and restart timer
            timer = setTimeout(function () {
                countDown();
            }, cookieVerificationInterval);
            dbesp.log.debug('dbesp.sessionHandling', 'After cookie verification, current tab is still active tab. Set next verification in '+cookieVerificationInterval+' milis', false);
        } else {
            //Current window doesn't match with active session
            disable();
            dbesp.log.debug('dbesp.sessionHandling', 'After cookie verification, Page deactivated. Neew session id:' + currentSession, false);
        }
    }

    function disable() {
        //Create a semitransparent layer to inactive the page
        $('body').append('<div id="mainOverlay2"><div id="overlay2" class="overlay-popup" ></div><div>');
        $('#mainOverlay').hide();
        $('#mainOverlay2').show();
        clearTimeout(timer);
    }

    var sessionHandling =  {
        checkSession: checkSession,
        init: init,
        stop: stop,
        changeActiveSession: changeActiveSession,
        disable: disable
    };

    dbesp.internal = dbesp.internal || {};
    dbesp.internal.sessionHandling = sessionHandling;
})();
/**
 * @class
 * @memberOf dbesp.internal.sessionTimer
 * @namespace
 * @description Class to manage time for client-side user session and keeping alive server session.
 */
(function () {
    var initTime = new Date();
    var sessionTimeoutDuration;

	// timestamp of last activity reported.
    var lastActivityTimestamp = new Date();
	// timestampo of last keepalive sent
	var lastKeepaliveTimestamp = 0;
	
    function checkExcludedSessionTimerPage(){
    	// TODO: verify current page (dbesp.pageName) is not in property.logout.excluded.pagelist
        var excludedPageList=" "+dbesp.configService.getParameterSynch('property.logout.excluded.pagelist')+" ";
        var currentPage=" "+dbesp.pageName+" ";
        if (excludedPageList.indexOf(currentPage)>=0) {
            // current page must not be checked.
            dbesp.log.debug('sessionTimer:checkSessionTimerPage', 'current page is excluded of session timer verification');
			sessionTimeoutDuration = -1;
            return false;
        }
        return true;
        
    }
    
    if(checkExcludedSessionTimerPage()){
	    dbesp.configService.getParameter('logout.sessionTimer',
	        function (data) {
	            if (data && data > 0) {
	                sessionTimeoutDuration = data * 60 * 1000;
	            } else {
	                sessionTimeoutDuration = -1;
	            }
	            if (sessionTimeoutDuration > 0) {
					reset();
	                verifyExpiration();
	
	                /* Resetting the timer with each ajax call to the server */
	                var XMLHttpRequestOpen = XMLHttpRequest.prototype.open;
	                XMLHttpRequest.prototype.open = function () {
	                    resetSessionTimer();
	                    XMLHttpRequestOpen.apply(this, arguments);
	                }
	
	                dbesp.log.debug('core-sessionTimer.getParameter', 'Successful recover logout.sessionTimer with sessionTimeoutDuration=' + data, true);
	            }
	        },
	        function (jqXHR, textStatus, errorThrown) {
	            sessionTimeoutDuration = -1;
	            dbesp.log.debug('core-sessionTimer.getParameter', 'Error when recover logout.sessionTimer.', true);
	        }
	    );
	}
    
    
		function verifyExpiration() {
			if (sessionTimeoutDuration > 0) {
				// verify if time has expired
				var elapsedTime = new Date().getTime() - lastActivityTimestamp.getTime();
				dbesp.log.debug('core-sessionTimer.verifyExpiration', 'init time: ' + date2str(initTime)+ ' last Timestamp: '+date2str(lastActivityTimestamp)+' elapsed: '+elapsedTime);
				if (elapsedTime<sessionTimeoutDuration) {
					// program next verification
					var nextVerification=sessionTimeoutDuration-elapsedTime;
					setTimeout(verifyExpiration, nextVerification);
					dbesp.log.debug('dbesp.internal.sessionTimer.reset', 'Elapsed ('+elapsedTime+') < timeout durantion ('+sessionTimeoutDuration+'). Next verification in '+nextVerification+' miliseconds', true);
				} else {
					// call reset facade
					verifyExpirationOnServer();
				}
			}
		}


		/**
		 sets lastActivityTimestamp to now
		*/
		function resetSessionTimer() {
			setSessionTimer(new Date());
			return true;
		}
		/**
		 * This function sets the session timer at client-side given a timestamp.
		 */
		function setSessionTimer(timestampdate) {
			lastActivityTimestamp = timestampdate;
			return true;
		}


		function verifyExpirationOnServer() {
				//Recover logout url
				$.ajax({
					type: "GET",
					url: dbesp.contextRoot + '/rest/loginLogout',
					cache: false,
					requestHeaders: {
						'If-Modified-Since': 'Sat, 1 Jan 2000 00:00:00 GMT'
					},
					success: function (data, textStatus, jqXHR) {
						if (data != '') {
							dbesp.log.debug('core-sessionTimer.verifyExpirationOnServer', 'Successful recover logout url call: '+data, true);
							var jsonData = JSON.parse(data);
							if (jsonData.isAlive == true){
								var newActionTimeStamp=new Date(jsonData.timestamp);
								setSessionTimer(newActionTimeStamp);
								dbesp.log.debug('core-sessionTimer.verifyExpirationOnServer', 'reprogram timeout with last action set to: '+date2str(newActionTimeStamp), true);
								verifyExpiration();
							}
							else{
								// run logout to expire session and delete cookies
//								require(['b-core/js/session'],function(session){
//									session.logout();
//								});
								// call with stay=true to see disconnect message
								dbesp.session.logout(true);
								// build message notifying logout done (should be done on promise done?)
								var body = buildSessionExpiredPopUp(jsonData);
								$('body').append(body);
								$('#overlay').show();
								dbesp.log.debug('core-sessionTimer.verifyExpirationOnServer', 'displayed timeout overlay', true);
							}
						}
					},
					error: function (data, textStatus, jqXHR) {
						var textoError = "<div id=\"overlay\" style=\"border:6px solid #EFEFEF;position:absolute; top: 200px;left: 440px;height: 300px;width: 400px;background:#fff;z-index:1;font-size:15px;line-height: 177px;vertical-align: middle;text-align:left; \" >"
							+ "<div align=\"center\">Error disconnecting. </div>";
						$('body').append(textoError);
						$('#overlay').show();
						dbesp.log.error('core-sessionTimer.verifyExpirationOnServer', 'Error when trying to recover logout url. Status: ' + textStatus + ' Message received:' + data, true);
					}
				});
		};
		
		
		
		function date2str (date) {
			return date.getHours()+":"+date.getMinutes()+":"+date.getSeconds();
		}

		/**
		 * This function is invoked when a pubsub event is produced between widgets.
		 * @public
		 * This function resets the session timer at client-side and sents keepalive event to host.
		 */
		function reset() {
			if (resetSessionTimer()){
				var elapsedFromLastKeepalive = (new Date())-lastKeepaliveTimestamp;
				// if there is a broadcast of pubsubs events, do not notify server for every one.
				if (elapsedFromLastKeepalive>10000) { // 10 secs with no keepalives to host
					elapsedFromLastKeepalive = new Date();
					dbesp.esc.updateESC('LAST_SESSION_KEEPALIVE', '',
						function (data) {
							//...
							dbesp.log.debug('dbesp.internal.sessionTimer.reset', 'Http Session keepalive time updated to ESC', true);
						},
						function (jqXHR, textStatus, errorThrown) {
							//...
							dbesp.log.debug('dbesp.internal.sessionTimer.reset', 'Http Session keepalive time cannot be updated to ESC', true);
						}
					);
				}
			} else {
				dbesp.log.debug('dbesp.internal.sessionTimer.reset', 'Elapsed timeout session is lesser to half. Reset is not accomplished.', true);
			}
		}
		
		/**
		 *
		 * @public
		 * This function builds session expired pop up at client-side.
		 */
		function buildSessionExpiredPopUp(jsonData) {
			
			var body = "<div> <div id='overlay' class='"+jsonData.styleOverlay+"'></div><div align='center' class='"+jsonData.styleMsg+"'>" + jsonData.text;
			if (!jsonData.specialAction) {
			    body  +="</div>";
			} else {
			
			    if (jsonData.redirectMessage == null || jsonData.redirectMessage == "") {
			    	jsonData.redirectMessage = "Continue";
			    }
			    body += "<div align='center'><br><a href='" + jsonData.urlRedirect + "' class='btn btn-primary'>" + jsonData.redirectMessage + "</a></div></div>";
			}
			body += "</div>";
			return body;
		}
		
    var sessionTimer = {
    	checkExcludedSessionTimerPage: checkExcludedSessionTimerPage,
        reset: reset
    };
	

    dbesp.internal = dbesp.internal || {};
    dbesp.internal.sessionTimer = sessionTimer;
    dbesp.sessionTimer = sessionTimer;
})();
(function () {
    'use strict';


    /**
     * Propagation adaptor manager for Propagation portal. Provides a transparent system for widgets to propagate data between them.
     * The propagation manager uses a unique channel to maintain communications between widgets that use the PropagationBehaviour mixin.
     *
     * It actually offers 4 operations:
     *  propagationManager.OPERATION.MENU_QUERY: given a context type
     *
     * @exports core/propagation/propagationManager
     *
     * @requires module:jquery
     * @requires module:core/eps
     * @requires module:core/context/contextManager
     * @requires module:core/utils/commons
     */

    var propagationManager = {};
    /**
     *
     * @const
     * @type {string}
     */
    var PROPAGATION_CHANNEL = 'propagation_channel';

    var fireFunctionSafe = dbesp.utils.commons.fireFunctionSafe;

    /**
     *
     */
    var actionsLabels;


    $(function() {
        // a little hack: We create an invible element that forces the action sprite to be downloaded before invoking the propagation menu (Before this, buttons appear empty  in the menu during a second)
        $('<span title="invisible span to preload propagation sprite" class="prop-action-icon-" />').height(0).width(0).appendTo($('body'));
    });

    propagationManager.setActionsLabels = function (labels) {
        actionsLabels = labels;
    };


    /**
     * Allowed operations
     * @const
     * @type {{MENU_QUERY: string, MENU_ITEM: string, EXECUTE_ACTION: string, NOTIFY_EVENT: string}}
     */
    propagationManager.OPERATION = {
        MENU_QUERY: "menu_query",
        MENU_ITEM: "menu_item",
        EXECUTE_ACTION: "execute_action",
        NOTIFY_EVENT: "notify_event"
    };


    /**
     * Broadcasts to all widgets asking for available actions for the propagation context
     * @param  {propagationContext} propagationContext  Contains the type and value of the propagation
     * @param  {widgetBase} widgetInstance         the widget that originated the propagation
     * @param  {jQuery} $propagationProxyIcon    The icon that was clicked to originate the
     propagation, necessary to calculate where to show the propagation layer
     */
    propagationManager.broadcastMenuQuery = function (propagationContext, widgetInstance, $propagationProxyIcon) {
        // When there is a new broadcast, previous propagation is destroyed
        initializePropagation();
        // Create the propagation
        var $propagationTpl = createPropagation(propagationContext, $propagationProxyIcon, widgetInstance);
        var $container = $propagationProxyIcon.parents('#propagationMainContainer');
        // Add an operation "menu_item" handler
        widgetInstance.attachOperationHandler(propagationManager.OPERATION.MENU_ITEM, function (propagationContext, action) {
            var isActionAdded = addActionToPropagation(widgetInstance, action, $propagationTpl);
        });
        // Broadcast menu query specifying the data that will be propagated
        $.publish(PROPAGATION_CHANNEL, [propagationManager.OPERATION.MENU_QUERY, propagationContext, null], widgetInstance.widgetId);
        return $propagationTpl;
    };

    /**
     * Broadcasts passed actions to whoever is listening for an OPERATION.MENU_ITEM publication
     * @param {propagationContext} propagationContext
     * @param {baseWidget} widgetInstance
     * @param actions
     */
    propagationManager.broadcastMenuItem = function (propagationContext, widgetInstance, actions) {
        for (var i = actions.length - 1; i >= 0; i--) {
            // Broadcast action as menu item
            var action = $.extend({}, actions[i], {
                relevance: fireFunctionSafe(widgetInstance, actions[i].relevance)
            });
            $.publish(PROPAGATION_CHANNEL, [propagationManager.OPERATION.MENU_ITEM, propagationContext, action], widgetInstance.widgetId);
        }
    };

    /**
     * Some kind of "Feeling lucky" MENU_QUERY that returns the top priority action available.
     * A MENU_QUERY is launched, all MENU_ITEM responses are compared, and the action with the lowest relevance is returned
     * @returns {propagationAction} actionToExecute
     */
    propagationManager.broadcastMenuQueryAndFindAction = function (propagationContext, widgetInstance, actionKey) {
        var actionToExecute;
        widgetInstance.attachOperationHandler(propagationManager.OPERATION.MENU_ITEM, function (propagationContext, action) {
            if (actionKey === action.id && (!actionToExecute || fireFunctionSafe(widgetInstance, actionToExecute.relevance) > fireFunctionSafe(widgetInstance, action.relevance)) && action.enabled) {
                actionToExecute = action;
            }
        });
        $.publish(PROPAGATION_CHANNEL, [propagationManager.OPERATION.MENU_QUERY, propagationContext, null], widgetInstance.widgetId);
        widgetInstance.detachOperationHandler(propagationManager.OPERATION.MENU_ITEM);
        return actionToExecute;
    };

    /**
     * Some kind of "Feeling lucky" or direct propagation.
     * A MENU_QUERY is launched, all MENU_ITEM responses are compared, and the action with the lowest relevance is selected then executed (EXECUTE_ACTION)
     * @returns {propagationAction} actionToExecute
     */
    propagationManager.broadcastMenuQueryAndExecuteAction = function (propagationContext, widgetInstance, actionKey) {
        var actionToExecute = this.broadcastMenuQueryAndFindAction(propagationContext, widgetInstance, actionKey);
        if (actionToExecute) {
            $.publish(PROPAGATION_CHANNEL, [propagationManager.OPERATION.EXECUTE_ACTION, propagationContext, actionToExecute]);
        }
        return actionToExecute;
    };

    /**
     *
     * @param {propagationContext} propagationContext
     * @param {propagationAction} action
     */
    propagationManager.broadcastExecuteAction = function (propagationContext, action) {
        $.publish(PROPAGATION_CHANNEL, [propagationManager.OPERATION.EXECUTE_ACTION, propagationContext, action]);
    };

    /**
     *
     * @param {propagationContext} propagationContext
     * @param {propagationEvent} event
     * @return {*}
     */
    propagationManager.broadcastNotifyEvent = function (propagationContext, event) {
        return $.publish(PROPAGATION_CHANNEL, [propagationManager.OPERATION.NOTIFY_EVENT, propagationContext, event]);
    };

    /**
     * Parses the passed dom object to extract a propagation context
     * @param {jQuery} $propagationButton
     * @return {propagationContext}
     */
    propagationManager.buildPropagationContext = function ($propagationButton) {
        var propagationContext = {
            type: $propagationButton.data('prop-propagation-context-type')
        };
        var id = $propagationButton.data('prop-propagation-context-id');
        var description = $propagationButton.data('prop-propagation-context-description');
        var content = $propagationButton.data('prop-propagation-context-content');
        if (id) {
            propagationContext.id = id;
        }
        if (description) {
            propagationContext.description = description;
        }
        if (content) {
            propagationContext.content = content;
        }
        return propagationContext;
    };

    /**
     * Deactivation means that an "inactive" flag is added to the last item of the store and a global  sync (to propagation buttons) is launched
     * When syncing an inactive element, all propagation buttons of that contextType will be switched off
     *
     * @param {string} contextType
     */
    propagationManager.deactivateLastPropagated = function (contextType) {
        var lastOfType = dbesp.context.contextManager.last(contextType);
        if (lastOfType) {
            lastOfType.inactive = true;
            propagationManager.performGlobalSync(lastOfType);
        }
    };

    /**
     * Syncs all propagation buttons in the page of the context's type
     * @param  {propagationContext} propagationContext
     */
    propagationManager.performGlobalSync = function (propagationContext) {
        // fetch all propagation button of the context's type
        var buttons = $('[data-prop-class="prop-propagation-button"][data-prop-propagation-context-type="' + propagationContext.type + '"]');

        // deactivate them all
        buttons.attr('class', function (idx, className) {
            if (/(prop-icon-propagate-(?:[A-z0-9]+-)*)on/g.test(className)) {
                return className.replace(/(prop-icon-propagate-(?:[A-z0-9]+-)*)on/g, '$1off');
            }
        });

        // filter the buttons to thos with the matching id and activate them
        if (!propagationContext.inactive) {
            buttons
                .filter('[data-prop-propagation-context-id="' + propagationContext.id + '"]')
                .attr('class', function (idx, className) {
                    if (/(prop-icon-propagate-(?:[A-z0-9]+-)*)off/g.test(className)) {
                        return className.replace(/(prop-icon-propagate-(?:[A-z0-9]+-)*)off/g, '$1on');
                    }
                });
        }
    };

    /**
     * Syncs all propagation buttons of the passed widget
     * @param  {widgetBase} widgetInstance
     */
    propagationManager.performWidgetSync = function (widgetInstance) {
        var $wBody = $(widgetInstance.widget.body);
        propagationManager.performLocalizedSync($wBody);
    };

    /**
     * Syncs all propagation icons of the passed container
     * @param  {jQuery} $container
     */
    propagationManager.performLocalizedSync = function ($container) {
        var buttons = $container.find('[data-prop-class="prop-propagation-button"]');
        buttons.each(function (idx, el) {
            var $el = $(el);
            var type = $el.attr('data-prop-propagation-context-type');
            var id = $el.attr('data-prop-propagation-context-id');
            var lastContext = dbesp.context.contextManager.last(type);
            if (lastContext && !lastContext.inactive && lastContext.id === id) {
                $el.attr('class', function (idx, className) {
                    if (/(prop-icon-propagate-(?:[A-z0-9]+-)*)off/g.test(className)) {
                        return className.replace(/(prop-icon-propagate-(?:[A-z0-9]+-)*)off/g, '$1on');
                    }
                });
            }
        });
    };

    /**
     * Makes a subscription to the propagation channel with a common callback that for each received operation,
     * retrieves the widget's corresponding handler and executes it if available.
     *
     * This is part of PropagationBehaviour mixin initialization routine. It should be called only then.
     * @param  {widgetBase} widgetInstance the subscribing widget
     * @protected
     */
    propagationManager.subscribeToPropagation = function (widgetInstance) {
        $.subscribeWithPriority(PROPAGATION_CHANNEL, function (operation, propagationContext, action) {
            var handler = $.proxy(widgetInstance.retrieveOperationHandler(operation), widgetInstance);
            if (handler) {
                handler(propagationContext, action);
            }
            return true; //needed for correct behaviour of publish broadcast
        }, widgetInstance.priority, widgetInstance.widgetId);
    };

    // ****************************** //
    // ** Private helper functions ** //
    // ****************************** //

    function calculateMenuPosition($mainContainer, $propagationProxyIcon, $propagationBox) {
        var menuWidth = $propagationBox.outerWidth(true);
        var iconOffset = $propagationProxyIcon.offset();
        var iconWidth = $propagationProxyIcon.width();
        var containerOffset = $mainContainer.offset();

        if ($(window).width() - (iconOffset.left + iconWidth + menuWidth) < 0) {
            $propagationBox.css({
                'top': iconOffset.top - containerOffset.top + $propagationProxyIcon.outerHeight(true) + 'px',
                'right': $(window).width() + $(window).scrollLeft() - (iconOffset.left + iconWidth + containerOffset.left) + 'px',
                'left': 'auto'
            });
        } else {
            $propagationBox.css({
                'top': iconOffset.top - containerOffset.top + 'px',
                'left': iconOffset.left - containerOffset.left + iconWidth + 'px'
            });
        }
    }

    function createPropagation(propagationContext, $propagationProxyIcon, widgetInstance) {
        // Set coordinates for template
        // Do not cache template to avoid derreferenced DOM leaks
        var $propagationTpl = getPropagationTemplate(propagationContext);
        var $container = $propagationProxyIcon.parents('#propagationMainContainer');
        var isMaximized = $container.length === 0;
        if (isMaximized) {
            $container = $propagationProxyIcon.parents('.bd-dialog-maximizedLayout');
        }
        // propagationOverlay covers all the page, to capture all clicks
        var $propagationOverlay = $($propagationTpl[0]);
        // propagationBox is the menu
        var $propagationBox = $($propagationTpl[1]);
        // Add the propagation layer to DOM
        $container.append($propagationTpl);
        calculateMenuPosition($container, $propagationProxyIcon, $propagationBox);
        // Add close button handler
        $propagationBox.on('click mousedown', '.prop-icon-close-small', function (evt) {
            removePropagationTpl($propagationProxyIcon);
            evt.stopPropagation();
        });
        // Add handler to template that will be invoked
        $propagationBox.on('click', '[data-prop-type="propagator"]', function (evt) {
            // Action properties
            var $self = $(this);
            var action = {
                id: $self.data('prop-action'),
                relevance: $self.data('prop-relevance'),
                keepperspective: $self.data('prop-keepperspective')
            };
            if (isMaximized && !action.keepperspective) {
                $('.bd-dialog-closeIcon').click();
            }
            // Remove propagation template
            removePropagationTpl($propagationProxyIcon);

            widgetInstance.detachOperationHandler(propagationManager.OPERATION.MENU_ITEM);
            propagationManager.broadcastExecuteAction(propagationContext, action);
            evt.stopPropagation();
        });
        $propagationBox.on('click mousedown', ':not(.prop-icon-close-small, [data-prop-type="propagator"])', function (evt) {
            evt.stopPropagation();
        });
        // When the overlay is clicked, we hide it first to get what was clicked under
        $propagationOverlay.on('click mousedown', function (evt) {
            if (evt.type === 'mousedown') {
                return false;
            }
            $propagationTpl.hide();
            var $clickedElement = $(document.elementFromPoint(evt.clientX, evt.clientY));
            if ($clickedElement.data('prop-action') === 'propagation-proxy' && $clickedElement.data('prop-class') !== 'prop-propagation-button') {
                // This case was added to permit clicking on a parent element for propagation.
                // i.e, in personal agenda clicking the event should trigger a click into its propagation button.
                // For this to work the parent element should have a [data-prop-action="propagation-proxy"] and a single [data-prop-class="prop-propagation-button"] inside.
                $clickedElement = $clickedElement.find('[data-prop-class="prop-propagation-button"]:first');
            }
            // if the clicked element is not the same propagation icon, we remove the template, and trigger the intented click
            if (!$propagationProxyIcon.is($clickedElement)) {
                removePropagationTpl($propagationProxyIcon);
                $clickedElement.trigger(evt);
                if ($clickedElement.data('prop-action') === 'propagation-proxy') {
                    $clickedElement.trigger('click');
                }
            } else {
                // if its the same propagation icon, we reshow the template, and trigger the fake double click
                $propagationTpl.show();
                $clickedElement.trigger('click');
            }
            evt.stopPropagation();
        });
        return $propagationBox;
    }

    function addActionToPropagation(widgetInstance, action, $propagationTpl) {
        // Action properties
        var actionId = action.id;
        var actionRelevance = fireFunctionSafe(widgetInstance, action.relevance);
        // Handle button relevance
        var existingPropButtons = $propagationTpl.find('[data-prop-action="' + actionId + '"]'),
            existingPropButton, existingRelevance;
        if (existingPropButtons.length && existingPropButtons.length > 0) {
            existingPropButtons.each(function () {
                existingPropButton = $(this);
                existingRelevance = existingPropButton.data('prop-relevance');
                // The relevance of the action is higher than current
                // action.iconClass will be used to distinguish between internal actions that shouldn't be displayed in menu
                if (actionRelevance < existingRelevance && action.iconClass) {
                    // Remove the button and add the new one
                    existingPropButton.remove();
                    addSinglePropagationToLayer(action, $propagationTpl);
                    return true;
                }
            });
        } else {
            // action.iconClass will be used to distinguish between internal actions that shouldn't be displayed in menu
            if (action.iconClass) {
                // Add the action to layer
                addSinglePropagationToLayer(action, $propagationTpl);
                return true;
            }
        }
        return false;
    }

    function initializePropagation() {
        removePropagationTpl();
    }

    function removePropagationTpl($propagationProxyIcon) {
        var $propagationTpl = $('.prop-template-full-overlay, .prop-template-backgrd');
        if ($propagationTpl[0]) {
            // Remove event handling on propagator icon click
            $propagationTpl.off('click', '.prop-icon-close-small');
            $propagationTpl.off('click', '[data-prop-type="propagator"]');
            // Remove propagation template from the DOM to keep it lightweight
            $propagationTpl.remove();
        }
        if ($propagationProxyIcon) {
            $propagationProxyIcon.removeClass('active').trigger('propagationOver');
        }
    }

    function capitaliseFirstLetter(string) {
        return string && string.charAt(0).toUpperCase() + string.slice(1);
    }

    // Gets the propagation template. This function should be lazy invoked only
    // one time.
    function getPropagationTemplate(propagationContext) {
        // README Maybe replace by an AJAX call requesting template?		
        var title;

        if (actionsLabels.type && actionsLabels.type[propagationContext.type]) {
            title = actionsLabels.type[propagationContext.type];
        }
        else {
            title = capitaliseFirstLetter(propagationContext.type) + ' actions';
        }
		
        return $(
            '<div class="prop-template-full-overlay">' +
            '</div>' +
            '<div class="prop-template-backgrd" data-prop-menu-context-id="' + propagationContext.id + '" data-prop-menu-context-type="' + propagationContext.type + '">' +
            '<div class="prop-template-header">' +
            '<div class="prop-icon-close-small"></div>' +
		    '<h5>' + title + '</h5>' +
            '<div class="prop-clear" />' +
            '</div>' +
            '<div class="prop-template-content">' +
            '</div>' +
            '</div>'
        );
    }

    function addSinglePropagationToLayer(action, $propagationTpl) {
        var $iconTpl = getIconTemplate(action);
        var previousButtons = $propagationTpl.find('[data-prop-class="button-action"]');
        var buttonInserted = false;

        previousButtons.each(function () {
            var previousButtonIter = $(this);
            var previousActionIndex = previousButtonIter.find('[data-prop-action]').data('prop-order');
            if (previousActionIndex > action.order) {
                $iconTpl.insertBefore(previousButtonIter);
                buttonInserted = true;
                return false; //Skip remaining iterations
            }
        });
        if (!buttonInserted) {
            $propagationTpl.find('.prop-template-content').append($iconTpl);
        }
    }

    function getIconTemplate(action) {
        var title;
        if (action.enabled) {
            title = actionsLabels[action.title];
            if (!title) {
                dbesp.log.warn('[propagation.manager.agnostic.js]', 'Label ' + action.title + ' for the action has not been defined.');
                title = action.title;            
			}
        } else {
            title = actionsLabels[action.title + '_off'] || actionsLabels[action.title] || action.title;
        }
        return $(
            // Action name is used as icon as well
			'<div style="display:inline-block;" data-prop-class="button-action" title="' + title + '">' +
            '<button' +
            ' data-prop-type="propagator"' +
            ' data-prop-action="' + action.id + '"' +
            ' data-prop-relevance="' + action.relevance + '"' +
            ' data-prop-order="' + action.order + '"' +
            ' data-prop-keepperspective="' + !!action.keepperspective + '"' +     
            ' class="' + action.iconClass + '"' +
            ' ' + (action.enabled ? '' : ' disabled="true"') +
            '></button>'+
			'</div>'
        );
    }

    dbesp.propagation = dbesp.propagation || {};
    dbesp.propagation.propagationManager = propagationManager;

})();

(function () {

    'use strict';

    /**
     * @description Repository for propagation actions
     * @exports core/repos/actionsRepo
     *
     * @requires module:lodash
     * @requires module:core/log
     */
    var actionsRepo = {};

    /**
     *
     * @param {String} key The key for the action on the repository
     * @param {Function} [actionFn] function to invoke when action is selected
     * @param {number} [relevance = action.relevance] relevance that will override default one
     * @param {Function} [evaluatorFn] function that evaluates if action can be executed within the current context (should return true/false). <br>
     *            It can return a String (truthy) that will be appended to the title/key for dynamic alterations of the tooltip
     * @returns {PropagationAction} the action cloned and enhanced
     */
    actionsRepo.retrieve = function (key, actionFn, relevance, evaluatorFn) {
        var action = repository[key];
        if (action) {
            // Return the clone and enhanced action
            return {
                // The id for the action is the key that it uses
                id: key,
                // The propagation type to which action responds
                respondsToType: action.respondsToType,
                // Title that will be shown on mouse over
                // By default mapped to the key mapped in the labels.xml as action.key
                title: action.title || key,
                // Name of the class for the icon
                iconClass: action.iconClass,
                // Action is shown enabled or disabled
                enabled: true,
                // Hides action from menu when disabled
                hideWhenDisabled: action.hideWhenDisabled,
                // Relevance can be provided dynamically and indicates the
                // prevalence respect others widgets with the same action
                relevance: relevance || action.relevance,
                // The function to execute if action is selected by user
                execute: actionFn,
                // If p rovided, this function will be called before action execution to check if this one is enabled or not
                // It can return a String (truthy) that will be appended to the title/key for dynamic alterations of the tooltip
                evaluate: evaluatorFn,
                // The order to be used when placing actions in a display
                order: indexOf(key),

                keepperspective: action.keepperspective
            };
        } else {
            dbesp.log.error('actionsRepo', 'Key ' + key + ' not found on actions repository.');
        }
        return {};
    };

    /**
     * returns all actions for debug purposes
     * @return {Object} repository
     */
    actionsRepo.listActions = function () {
        return repository;
    };

    /**
     * Merges the passed actions into the repository.
     * This method should be called only once by each bundle, if needed, to declare all bundle's actions
     * Note that order in repository is relevant for its position in menu
     * @param {ActionsRepository} actions map of actions to be merged into the repository
     */
    actionsRepo.addActions = function (actions) {
        _.merge(repository, actions);
    };


    // ********************** //
    // **  Private stuff   ** //
    // ********************** //

    /**
     * @typedef PropagationAction
     * @type {Object}
     * @property {String} key - The action identifier.
     * @property {PropagationAction} action - The action's definition
     */

    /**
     * @typedef ActionsRepository
     * @type {Object}
     * @property {String} key - The action identifier.
     * @property {Object} action - The action's definition
     */

    /**
     * a map where actions will be stored
     * @type {ActionsRepository}
     */
    var repository = {};

    var indexOf = function (key) {
        var index = 0;

        //Iterating object properties will retrieve also inherited properties.
        //As it seems not a real issue for this case,
        // hasOwnProperty check will be omitted
        for (var keyIter in repository) {
            if (keyIter === key) {
                return index;
            } else {
                index++;
            }
        }
    };

    dbesp.repository = dbesp.repository || {};
    dbesp.repository.actions = actionsRepo;

})();

// Repository for propagation events
(function() {
	'use strict';

	/**
	 * @description Repository for propagation events
	 * @exports core/repos/eventsRepo
	 *
	 * @requires module:lodash
	 * @requires module:core/log
	 */
	var eventsRepo = {};

	/**
	 *
	 * @param {String} key
	 * @param {Function} callback
	 *
	 * @return {propagationEvent}
	 */
	eventsRepo.retrieve = function(key, callback) {
		if (repository[key]) {
			return {
				id: key,
				callback: callback
			};
		} else {
			dbesp.log.error('eventsRepo', 'Key ' + key +' not found on events repository.');
		}
		return {};
	};

	/**
	 * returns all events for debug purposes
	 * @return {Object} eventRepository
	 */
	eventsRepo.listEvents = function() {
		return repository;
	};


	/**
	 * Merges the passed events into the repository.
	 * This method should be called only once by each bundle, if needed, to declare all bundle's events
	 * @param {EventsRepository} events set of actions to be merged into the repository
	 */
    eventsRepo.addEvents = function(events) {
        _.merge(repository, events);
    };


	// ********************** //
	// **  Private stuff   ** //
	// ********************** //

	/**
	 * @typedef EventsRepository
	 * @type {Object}
	 * @property {String} key - The event idetifier.
	 * @property {Boolean} flag - always true.
	 */

	/**
	 * a set where actions will be stored
	 * @type {}.<EventsRepository>
	 */
	var repository = {};


	dbesp.repository = dbesp.repository || {};
	dbesp.repository.events = eventsRepo;
})();

/**
 * Basic widget skeleton
 * @module core/widgets/baseWidget
 * @requires module:jquery
 * @requires module:lodash
 * @requires module:core/log
 *
 * @example Usage:
 *
 define(['core/utils/fn', 'core/widgets/baseWidget'], function (fn, BaseWidget) {
         var ExampleWidget = fn.inherit(function () {

         }, BaseWidget);

         return function (bbwidget) {
            fn.createInstance(SampleWidget, bbwidget).init();
        };
     });

 */

(function () {

    /**
     * @param {__WIDGET__} bbWidget A Backbase widget instance provided by BB in the g:onload directive as __WIDGET__
     *
     * @constructor
     * @alias module:core/widgets/baseWidget
     */
    var BaseWidget = function (bbWidget) {
        var widgetInstance = this;
        // Asign the widget instance as member property
        widgetInstance.widget = bbWidget;
        // Keep a shortcut of the widgetId
        widgetInstance.widgetId = widgetInstance.widget.id;
        // The deferred used for instance initialization
        widgetInstance.initDef = $.Deferred();
        // Handle initialization errors
        widgetInstance.initDef.fail(handleInitializationError(widgetInstance));
    };

    /**
     * Main initializer, to be called once the instance is constructed
     *
     * @returns {jQuery.Deferred} A promise object resolved when initialization is done.
     *
     * @final
     */
    BaseWidget.prototype.init = function () {
        var widgetInstance = this;
        dbesp.log.info(widgetInstance.widgetId, 'Initializing widget');
        try {
            // Keep the initialization safe from be called more than once per instance
            if (widgetInstance.initDef.state() === 'pending') {
                // Invoke initialization functions
                bindBaseEvents(widgetInstance);
                initBaseSubscriptions(widgetInstance);
                if (widgetInstance.mixinInitializers) {
                    _.each(widgetInstance.mixinInitializers, _.partial(_.invoke, [widgetInstance]));
                }
                widgetInstance.setup();
            } else {
                // Show a warn if someone tries to initialize more than one time
                dbesp.log.warn(widgetInstance.widgetId, 'Widget has been previously initializated.');
            }
        } catch (e) {
            widgetInstance.initDef.reject(e);
        }

        widgetInstance.initDef.resolveWith(widgetInstance);

        // Return deferred
        return widgetInstance.initDef;
    };

    /**
     * Shows not implemented function warning but does not mean that
     * functions must necessarily be overwritten
     * @param {String} file the file where the error was produced
     * @param {String} functionName The name of the function not implemented
     */
    BaseWidget.prototype.showAbstractMethodWarn = function (file, functionName) {
        dbesp.log.warn(
            this.widgetId,
            'Widget did not implement the abstract method [' + functionName + '] of ' + file
        );
    };


    // ********************** //
    // ** Private methods ** //
    // ********************** //

    /**
     * Logs and shows error on widget intance initialization routine
     * @param  {BaseWidget} baseInstance The widget instance to be binded
     *
     * @private
     */
    function handleInitializationError(baseInstance) {
        return function (errorCause) {
            dbesp.log.error(baseInstance.widgetId, errorCause.stack);
            var errMessage = '[An error occurred during ' + baseInstance.widgetId + ' initialization: ' + errorCause + ']';
            baseInstance.showWidgetMessage(errMessage);
        };
    }

    /**
     * Makes common bindings to all widget instances, then invokes particular
     * bindings function
     * @param {BaseWidget} baseInstance The widget instance to be binded
     *
     * @private
     */
    function bindBaseEvents(baseInstance) {
        // Invoke particular bind events function
        baseInstance.bindEvents();
    }

    /**
     * Initializes common subscriptions to all widget instances, then invokes particular
     * subscription initialization function
     * @param {BaseWidget} baseInstance The widget instance to be binded
     *
     * @private
     */
    function initBaseSubscriptions(baseInstance) {
        // Invoke particular init subscriptions function
        baseInstance.initSubscriptions();
    }


    // ********************** //
    // ** Abstract methods ** //
    // ********************** //

    /**
     * Binds event listeners on the widget instance.
     * This method is invoked during initialization routine.
     * @abstract
     */
    BaseWidget.prototype.bindEvents = function () {
        this.showAbstractMethodWarn('BaseWidget', 'bindEvents');
    };

    /**
     * Inits subscription listeners on the widget instance.
     * This method is invoked during initialization routine.
     * @abstract
     */
    BaseWidget.prototype.initSubscriptions = function () {
        this.showAbstractMethodWarn('BaseWidget', 'initSubscriptions');
    };

    /**
     * Specific initialization routine should be implemented with this method
     * This method is invoked during initialization routine.
     * @abstract
     */
    BaseWidget.prototype.setup = function () {
        this.showAbstractMethodWarn('BaseWidget', 'setup');
    };

    /**
     * @abstract
     */
    BaseWidget.prototype.showWidgetMessage = function () {
        this.showAbstractMethodWarn('BaseWidget', 'showWidgetMessage');
        dbesp.log.error(this.widgetId, errMessage + '\n' + errMessage);
    };

    dbesp.widgets = dbesp.widgets || {};
    dbesp.widgets.BaseWidget = BaseWidget;
})();
/**
 * @class
 * @memberOf dbesp.checkPageLoad
 * @namespace
 * @description Class that checks the origin of a communication and prepare 
 * some parameters to check it.
 */ 
(function() {
    'use strict';
var checkPageLoad = (function(){

    /**
     * Function to init the check page load. This function checks 
     * from where the communication comes.
     */
    function init(){
        dbesp.log.info("core-checkPageLoad.init", "Initializing checkPageLoad", true);
        //Initialize default values.
        dbesp.communication = null;
        dbesp.restoration = '_empty_';
        dbesp.initial = true;
        dbesp.checkPageLoadReady = false;
        
        //Check communication
        checkCommunication(
            function() {
                //If not dbesp.communication check restauration
                if(!dbesp.communication) {
                    checkRestoration(
                        function() {
                            //If not dbesp.restoration check initial
                            if(!dbesp.restoration) {
                                checkInitial();
                            } else {
                                dbesp.initial = false;
                                dbesp.checkPageLoadReady = true;
                            }
                        });
                } else {
                    dbesp.restoration = null;
                    dbesp.initial = false;
                    dbesp.checkPageLoadReady = true;
                }
            });
    }

    /**
      * Function to check if the communication comes from an explicit communication.
      * @private
      * @param {Function} onSuccess Function to execute on a successful operation
      */
    function checkCommunication(onSuccess){
        dbesp.log.info("core-checkPageLoad.checkCommunication", "Checking communication", true);
        //Get the registry
        dbesp.internal.commRegistry.getFullRegistry(
            function(fullRegistry){
                var channels = [];
                //Check the registry to find the one we have to check and use
                for(var i = 0; i < fullRegistry.length; i++){
                    //if it has channel, is an special communication
                    if(fullRegistry[i].channel){
                        dbesp.log.info("core-checkPageLoad.checkCommunication", "For fullRegistry communication with i: " + i + " and length: " +fullRegistry.length, true);
                        //Save the channel for checking channels.
                        channels.push(fullRegistry[i].channel);
                        //We have to subscribe all the subscribers.
                        for(var j = 0; j < fullRegistry[i].subscriber.length; j++){
                            dbesp.log.info("core-checkPageLoad.checkCommunication", "For subscriber communication with j: " + j + " and length: " +fullRegistry[i].subscriber.length, true);
                              $.subscribe(
                                fullRegistry[i].channel, 
                                function(message){
                                    dbesp.communication = message;
                                    dbesp.log.info("core-checkPageLoad.checkCommunication", "Publishing communication", true);
                                    return true;
                                },
                                fullRegistry[i].subscriber[j]
                                //Not taking into account the publisher
                                //fullRegistry[i].publisher, 
                                //fullRegistry[i].commID
                                );
                        }
                    }
                }
                //Check for the channels we have subscribed.
                $.checkChannels(channels, onSuccess);
            }
        );
    }
   
    
    /**
      * Function to check if the communication comes from a restoration.
      * @private
      * @param {Function} onSuccess Function to execute on a successful operation
      */
    function checkRestoration(onSuccess){
        dbesp.log.info("core-checkPageLoad.checkRestoration", "Checking restoration", true);
        dbesp.restoration = dbesp.utils.domCaching.getDom();
        //After using domCaching, delete it.
        //dbesp.utils.domCaching.deleteDomCache();
        
        var _int = setInterval( function() {
            var _onS = onSuccess;
            if(dbesp.restoration != '_empty_'){
                clearInterval(_int);
                _int = 0;
                if (_onS && typeof(_onS) === "function") {  
                    _onS(); 
                }
            }
        },10);
    }
    
    /**
      * Function to check if the communication comes from an initial load.
      * @private
      */
    function checkInitial(){
        dbesp.log.info("core-checkPageLoad.checkInitial", "Checking initial", true);
        //If none of them, it's initial
        if(dbesp.communication || dbesp.restoration){
            dbesp.initial = false;
        }
        dbesp.checkPageLoadReady = true;
    }
    
    function execute(/*Function*/ checkFunction) {
        dbesp.log.info("core-checkPageLoad.execute", "Executing checkPageLoad.", true);
        var _int = setInterval(
            function() {
                var _f = checkFunction;
                if(dbesp.checkPageLoadReady) {
                    clearInterval(_int);_int=0; 
                    if (_f && typeof(_f) === "function") {
                        dbesp.log.info("core-checkPageLoad.execute", "Executing the function to check if it's communication/restoration/initial.", true);
                        _f(); 
                    }
                }    
            }, 10);
    }    
    
    return {
        init:init,
        execute:execute
    }
})();

dbesp.widgets = dbesp.widgets || {};
dbesp.widgets.checkPageLoad = checkPageLoad;
checkPageLoad.init();

})();
/**
 * Basic UI behaviour mixin
 * @module core/widgets/mixins/basicUIBehaviour
 *
 * @augments module:core/widgets/baseWidget
 *
 * @requires module:jquery
 * @requires module:moment
 * @requires module:core/log
 * @requires module:core/utils/ui
 * @requires module:core/utils/navigation
 *
 * @example Usage:
 *
 define(['core/utils/fn', 'core/widgets/baseWidget', 'core/widgets/mixins/basicUIBehaviour'], function (fn, BaseWidget, BasicUIBehaviour) {
         var ExampleWidget = fn.inherit(function () {

         }, BaseWidget, [BasicUIBehaviour]);

         return function (bbwidget) {
            fn.createInstance(SampleWidget, bbwidget).init();
        };
     });

 */
(function () {

    var PREFERENCES = {
        START_MINIMIZED: 'startMinimized'
    };

    /**
     * @constructor
     * @private
     * @alias module:core/widgets/mixins/basicUIBehaviour
     */
    var BasicUIBehaviour = function BasicUIBehaviour() {};


    /**
     * @this BasicUIBehaviour
     * @private
     */
    BasicUIBehaviour.mixinInitializer = function () {
        var widgetInstance = this;

        if (widgetInstance.widget.getPreference(PREFERENCES.START_MINIMIZED)) {
            widgetInstance.initDef.done(widgetInstance.minimize);
        }
    }

    /**
     * Evaluates if current widget is visible on the specified tabName (If not provided, falls back to evaluate the currently selected tab)
     * @param {String} [tabName=currently selected tab]
     * @return {Boolean}
     */
    BasicUIBehaviour.prototype.isVisible = function (tabName) {
        var widgetInstance = this;
        if (!tabName) {
            tabName = dbesp.utils.navigation.getSelectedTab();
        }
        var widgetTab = dbesp.utils.navigation.getMyTab(widgetInstance.widgetId);
        if (typeof widgetTab === "string") {
            return dbesp.utils.navigation.isInTab($(widgetInstance.widget.body), tabName);
        } else {
            // if widget is not on a tab, dbesp.utils.navigation.getMyTab returns an array with the dom obejct..
            // We assume that the widget is always visible (header, footer, ...)
            return true;
        }
    };

    /**
     * Collapses the widget
     */
    BasicUIBehaviour.prototype.minimize = function () {
        var widgetInstance = this;
        $(widgetInstance.widget.body).slideUp(function () {
            widgetInstance.widget.setPerspective('Minimized');
            // Hack! bbWidget doesn't do it's job.. we have to change the chrome manually after minimizing
            $(widgetInstance.widget.htmlNode).find('.custom-aa-button-minimize').attr('data-action', 'widget-restore');
        });
    };

    /**
     * Collapses the widget if it's currently visible
     */
    BasicUIBehaviour.prototype.minimizeIfVisible = function () {
        var widgetInstance = this;
        if (widgetInstance.isVisible() && widgetInstance.widget.perspective.type.name !== 'Minimized') {
            widgetInstance.minimize();
        }
    };

    /**
     * Restores widget to normal perspective
     */
    BasicUIBehaviour.prototype.widgetize = function () {
        var widgetInstance = this;
        $(widgetInstance.widget.body).slideDown(function () {
            widgetInstance.widget.setPerspective('Widget');
            // Hack! bbWidget doesn't do it's job.. we have to change the chrome manually after widgetizing
            $(widgetInstance.widget.htmlNode).find('.custom-aa-button-minimize').attr('data-action', 'widget-minimize');
        });
    };

    /**
     * Restores widget to normal state if it's currently minimized
     */
    BasicUIBehaviour.prototype.restoreIfMinimized = function () {
        var widgetInstance = this;
        if (widgetInstance.widget.perspective.type.name === 'Minimized') {
            widgetInstance.widgetize();
        }
    };


    /**
     * Scrolls the page to the widget's position if visible in the viewport
     * @param {Boolean} [always] indicates if it should scroll even when already visible on screen
     */
    BasicUIBehaviour.prototype.scrollToWidget = function (always) {
        var widgetInstance = this;
        if (widgetInstance.isVisible()) {
            dbesp.utils.ui.scrollToNode($(widgetInstance.widget.htmlNode));
        }
    };

    /**
     * Navigates to the tab where the widget is
     */
    BasicUIBehaviour.prototype.revealWidget = function () {
        dbesp.utils.navigation.selectTab(dbesp.utils.navigation.getMyTab(this.widgetId));
    };

    /**
     * Shows a loading layer positioned over the widget's body or the passed DOM element
     * @param {jQuery} [$loaderContainer = widget.body]
     */
    BasicUIBehaviour.prototype.showLoading = function ($loaderContainer) {
        this.loadersCount = (this.loadersCount + 1) || 1;
        dbesp.utils.ui.showLoading($loaderContainer || $(this.widget.body));
    };

    /**
     * Hides the loading layer
     */
    BasicUIBehaviour.prototype.hideLoading = function () {
        if (!--this.loadersCount) {
            var bbWidget = this.widget;
            dbesp.utils.ui.hideLoading($(bbWidget.body));
        }
    };

    /**
     * Prepends a message on widget's body.
     * These messages by default are used to inform of errors, timestamped and logged in the console as so
     * @param {String} message
     * @param {Boolean} [clearOldMessages = false] clear all widget messages before printing this one
     * @param {Boolean} [isSimpleMessage = false] simple messages don't get timestamped nor logged as errors
     * @return {jQuery} The message container
     */
    BasicUIBehaviour.prototype.showWidgetMessage = function (message, clearOldMessages, isSimpleMessage) {
        if (clearOldMessages) {
            this.clearWidgetMessages();
        }
        var $wBody = $(this.widget.body);
        var criticalDataClass = '';
        if (!isSimpleMessage) {
            dbesp.log.error(this.widgetId, message);
            message += ' <span>[' + this.widgetId + ' - ' + moment().format('YYYY-MM-DD HH:mm:ss') + ']</span> ';
            criticalDataClass = 'data-prop-class="critical"';
        }
        return $('<div class="prop-error-container" ' + criticalDataClass + '>' + message + '</div>').prependTo($wBody).slideDown(300);
    };

    /**
     * Removes widget messagees
     * @param {Boolean} [criticalOnly = false] When true, simple messages are kept.
     */
    BasicUIBehaviour.prototype.clearWidgetMessages = function (criticalOnly) {
        var criticalDataClass = '';
        if (criticalOnly === true) {
            criticalDataClass = '[data-prop-class="critical"]';
        }
        $(this.widget.body).find('.prop-error-container' + criticalDataClass).remove();
    };

    dbesp.widgets.mixins = dbesp.widgets.mixins || {};
    dbesp.widgets.mixins.BasicUIBehaviour = BasicUIBehaviour;
})();
/**
 * Preferences behaviour mixin
 * @module core/widgets/mixins/preferencesBehaviour
 *
 * @augments module:core/widgets/baseWidget
 *
 * @requires module:jquery
 * @requires module:moment
 * @requires module:lodash
 * @requires module:core/log
 * @requires module:core/utils/ui
 * @requires module:core/utils/prefs
 *
 * @example Usage:
 *
 define(['core/utils/fn', 'core/widgets/baseWidget', 'core/widgets/mixins/preferencesBehaviour'], function (fn, BaseWidget, PreferencesBehaviour) {
         var ExampleWidget = fn.inherit(function () {

         }, BaseWidget, [PreferencesBehaviour]);

         return function (bbwidget) {
            fn.createInstance(SampleWidget, bbwidget).init();
        };
     });

 */
(function () {

    var TIMESTAMP_PREF_NAME = 'timestamp';

    /**
     * @constructor
     * @private
     * @alias module:core/widgets/mixins/preferencesBehaviour
     */
    var PreferencesBehaviour = function PreferencesBehaviour () {
    };

    /**
     * @this PreferencesBehaviour
     * @private
     */
    PreferencesBehaviour.mixinInitializer = function () {
        var widgetInstance = this;
        bindPreferencesEvents(widgetInstance);
        // Workaround to sort preferences
        dbesp.utils.prefs.sort(widgetInstance.widget.model.preferences.array, widgetInstance.getPreferencesMask());
    };

    /**
     * Handles the preferences enhancing routine originated by a user click on the preferences chrome button
     * @return {boolean}
     */
    PreferencesBehaviour.prototype.handlePreferences = function () {
        var widgetInstance = this;
        var bbWidget = widgetInstance.widget;
        bbWidget.addEventListener('preferenceFormReady', function readyListener(event) {
            bbWidget.removeEventListener('preferenceFormReady', readyListener);
            var $preferencesContainer = $(event.target.htmlNode);
            if ($preferencesContainer[0]) {
                // Attach the preference container
                dbesp.utils.prefs.setPreferenceContainer($preferencesContainer);
                // Store saved preferences state for correct behavior when "all" option is selected
                $preferencesContainer.find('.aa-buttons').one('click', '.portal-userPreferencesForm-okButton', widgetInstance.activateSavedPrefsFlag);
                // If widget has a timestamp preference, it is time to set
                if (bbWidget.getPreference(TIMESTAMP_PREF_NAME) !== void 0) { // void 0 is the safer way to evaluate to undefined
                    // Hide and set the preference
                    dbesp.utils.prefs.hidePreference(TIMESTAMP_PREF_NAME);
                    bbWidget.setPreference(TIMESTAMP_PREF_NAME, Date.now());
                }
                // Each widget should handle specific preferences
                widgetInstance.handleWidgetPreferences();
            }
        });
        bbWidget.addEventListener('preferencesSaved', function saveListener(event) {
            bbWidget.removeEventListener('preferencesSaved', saveListener);
            widgetInstance.onPreferencesSaved(_.clone(event.detail));
        });

        bbWidget.addEventListener('savePreferenceForm', function saveListener(event) {
            bbWidget.removeEventListener('savePreferenceForm', saveListener);
            widgetInstance.prePreferencesSaved(_.clone(event.detail));
        });



        return true;
    };

    /**
     * Sets the savedPrefs flag neccessary to keep "all" prefs selected since their value are mapped to empty string
     */
    PreferencesBehaviour.prototype.activateSavedPrefsFlag = function () {
        this.savedPrefs = true;
    }


    // ********************** //
    // ** Private methods ** //
    // ********************** //

    /**
     * Attaches preferences event listeners
     * @param {BaseWidget} baseInstance
     * @private
     */
    function bindPreferencesEvents(baseInstance) {
        var $widgetHead = $(baseInstance.widget.htmlHead);

        // Attach only chrome events if widget has header
        if ($widgetHead[0]) {
            $widgetHead.on('click', '.custom-aa-chrome-button[data-action="widget-preferences"]', _.bind(baseInstance.handlePreferences, baseInstance));
        }
    }


    // ********************** //
    // ** Abstract methods ** //
    // ********************** //

    /**
     * Handles widget preferences by properly enhancing them and setting their dependencies.
     * Called before displaying the preferences overlay.
     *
     * @example
             widgetInstance.handleWidgetPreferences = function () {
                var bbWidgetInstance = widgetInstance.widget;
                // Enhances the 'date' preference by transforming the text input into a datepicker field
                dbesp.utils.prefs.addDatePicker('date', bbWidgetInstance.getPreference('date'));
                // Enhances the 'time' preference by transforming the text input into a pair of combos with HH and mm selectors
                dbesp.utils.prefs.addTimePicker('time', bbWidgetInstance.getPreference('time'));
            };

     * @abstract
     */
    PreferencesBehaviour.prototype.handleWidgetPreferences = function () {
        this.showAbstractMethodWarn('PreferencesBehaviour', 'handleWidgetPreferences');
    };

    /**
     * This is where the widget should implement any logic that depends on preferences updates
     * @param {Array} preferences
     *
     * @abstract
     */
    PreferencesBehaviour.prototype.onPreferencesSaved = function (preferences) {
        var widgetInstance = this;
        widgetInstance.showAbstractMethodWarn('PreferencesBehaviour', 'onPreferencesSaved (using defaultwidgetInstance.refresh())');
        widgetInstance.refresh();
        dbesp.log.debug('[PreferencesBehaviour]', 'Saved preferences: ' + JSON.stringify(preferences));
    };


    /**
     * This is where the widget should implement any logic that depends on preferences updates
     * @param {Array} preferences
     *
     * @abstract
     */
    PreferencesBehaviour.prototype.prePreferencesSaved = function (preferences) {
        var widgetInstance = this;
        widgetInstance.showAbstractMethodWarn('PreferencesBehaviour', 'prePreferencesSaved (using defaultwidgetInstance.refresh())');
        dbesp.log.debug('[PreferencesBehaviour]', 'Preferences to save: ' + JSON.stringify(preferences));
    };

    /**
     * As backbase doens't maintain the preference order specified in the imported widget definitions,
     * widgets should define this method to specify the correct order of these.
     * Undeclared preferences defined in the import scripts will still be shown, but after the specified ones
     *
     * @return {Array} an ordered list of preference indentifiers
     *
     * @example
            widgetInstance.getPreferencesMask = function () {
                return ["pref_1", "pref_2", "pref_3"];
            };
     *
     * @abstract
     */
    PreferencesBehaviour.prototype.getPreferencesMask = function () {
        this.showAbstractMethodWarn('PreferencesBehaviour', 'getPreferencesMask');
        return [];
    };

    dbesp.widgets.mixins = dbesp.widgets.mixins || {};
    dbesp.widgets.mixins.PreferencesBehaviour = PreferencesBehaviour;
})();
/**
 * Basic UI behaviour mixin
 * @module core/widgets/mixins/propagationBehaviour
 *
 * @augments module:core/widgets/baseWidget
 * @borrows module:core/widgets/mixins/basicUIBehaviour
 *
 * @requires module:jquery
 * @requires module:lodash
 * @requires module:core/propagation/propagationManager
 * @requires module:core/context/contextManager
 * @requires module:core/eps
 * @requires module:core/utils/ui
 * @requires module:core/utils/commons
 * @requires module:core/widgets/mixins/basicUIBehaviour
 *
 * @example Usage:
 *
 define(['core/utils/fn', 'core/widgets/baseWidget', 'core/widgets/mixins/propagationBehaviour'], function (fn, BaseWidget, PropagationBehaviour) {
         var ExampleWidget = fn.inherit(function () {

         }, BaseWidget, [PropagationBehaviour]);

         return function (bbwidget) {
            fn.createInstance(SampleWidget, bbwidget).init();
        };
     });

 */
(function () {
    "use strict";

    var PREFERENCES = {
        SHOW_CONTEXT_HEADER: 'showContextHeader',
        RENDER_WITHOUT_CONTENT: 'renderWithoutContent',
        TAB_CHANGER: 'tabChanger'
    };

    /**
     * @constructor
     * @protected
     * @alias module:core/widgets/mixins/propagationBehaviour
     */
    var PropagationBehaviour = function PropagationBehaviour() {};

    PropagationBehaviour.dependencies = [dbesp.widgets.mixins.BasicUIBehaviour];

    /**
     * @this PropagationBehaviour
     * @protected
     */
    PropagationBehaviour.mixinInitializer = function () {
        var widgetInstance = this;
        widgetInstance.initDef.done(widgetInstance.preRender);
        // Overwrite refresh behavior to do a render
        widgetInstance.widget.refreshHTML = $.proxy(widgetInstance.refresh, this);
        _.defaults(widgetInstance, {
            // initialize a KVO store for operations handled
            operationHandler: {},
            // default priority for propagation subscription
            priority: 50,
            // tab changers trigger tab changes on propagation action
            isTabChanger: widgetInstance.widget.getPreference(PREFERENCES.TAB_CHANGER) || false,
            isRenderWithoutContext: widgetInstance.widget.getPreference(PREFERENCES.RENDER_WITHOUT_CONTENT) || false
        });
        // Set widget's available actions
        initActionsAndEvents(widgetInstance);
        // Set propagation operations handlers
        initOperationHandlers(widgetInstance);

        initPropagationSubscriptions(widgetInstance);
        bindPropagationEvents(widgetInstance);
    };

    /**
     */

    /**
     * Prerender complex routine.
     *
     *
     * widgetInstance._nextWidgetContext: will be set  when no callback is defined in an execute_action operation
     * widgetInstance._widgetContext.refresh: will be set  when no callback is defined in an notify_event operation
     * isRenderWithoutContext: widgets will set this property in their constructor when they should render once the first time they are visible
     *
     * @param {Boolean} [widgetIsVisible=widgetInstance.isVisible()]
     * @return {Promise|undefined} A promise of the PropagationBehaviour#render method if called or an undefined value
     *
     * @protected
     */
    PropagationBehaviour.prototype.preRender = function (widgetIsVisible) {
        var widgetInstance = this;
        var promise;
        widgetIsVisible = widgetIsVisible || widgetInstance.isVisible();
        if (widgetInstance._nextWidgetContext) {
            if (widgetInstance._nextWidgetContext.refresh || !widgetInstance._widgetContext || !dbesp.context.contextManager.isSame(widgetInstance._widgetContext, widgetInstance._nextWidgetContext)) {
                if (widgetIsVisible) {
                    widgetInstance._widgetContext = widgetInstance._nextWidgetContext;
                    widgetInstance._nextWidgetContext = null;
                    widgetInstance.restoreIfMinimized();
                    promise = widgetInstance.render();
                } else {
                    widgetInstance.destroy();
                }
            } else if (widgetInstance._widgetContext) {
                // Premature optimisation: current and next contexts are the same, delete next context for future preRender Runs
                widgetInstance._nextWidgetContext = null;
                widgetInstance.restoreIfMinimized();
            }
        } else if (widgetInstance._widgetContext && widgetInstance._widgetContext.refresh) {
            delete widgetInstance._widgetContext.refresh;
            if (widgetIsVisible) {
                widgetInstance.restoreIfMinimized();
                promise = widgetInstance.render();
            } else {
                widgetInstance._nextWidgetContext = widgetInstance._widgetContext;
                widgetInstance.destroy();
            }
        } else if (widgetInstance.isRenderWithoutContext && widgetIsVisible && !dbesp.context.contextManager.last(widgetInstance.widgetId)) {
            dbesp.context.contextManager.save({
                type: widgetInstance.widgetId
            });
            widgetInstance.restoreIfMinimized();
            promise = widgetInstance.render();
        } else {
            // This for the direct action callbacks
        }
        return promise;
    };

    /**
     * Successful render post routine common to all render strategies
     */
    PropagationBehaviour.prototype.postRender = function () {
        var widgetInstance = this;
        if (widgetInstance.isRenderWithoutContext && !widgetInstance._widgetContext) {
            parseServerSideWidgetContext(widgetInstance);
            if (widgetInstance._widgetContext) {
                dbesp.propagation.propagationManager.performGlobalSync(widgetInstance._widgetContext);
            }
        }
        setWidgetTitle(widgetInstance);
        dbesp.propagation.propagationManager.performWidgetSync(widgetInstance);
    };

    /**
     * Failed render post routine common to all render strategies
     */
    PropagationBehaviour.prototype.postRenderError = function ($container) {
        var widgetInstance = this;
        if ($container.is($(widgetInstance.widget.body))) {
            widgetInstance._nextWidgetContext = widgetInstance._widgetContext;
            widgetInstance._widgetContext = null;
        }
    };

    /**
     * @return {WidgetContext} A cloned copy of the widget's current context
     */
    PropagationBehaviour.prototype.getWidgetContextCopy = function () {
        return _.cloneDeep(this._widgetContext) || {};
    };

    /**
     * Handler for 'menu query' operations.
     * Filters the widget's available actions for matching types and broadcasts them
     * @param  {Object} propagationContext
     *
     * @protected
     */
    PropagationBehaviour.prototype.operationMenuQueryHandler = function (propagationContext) {
        var widgetInstance = this;
        var actionsTobroadcast = [];
        var action, i;
        for (i = widgetInstance.availableActions.length; i--;) {
            action = widgetInstance.availableActions[i];
            // Filter actions by propagation type
            if (action.respondsToType === propagationContext.type) {
                // call optional evaluatorFn to check if action should be disabled.
                var evalResult = action.evaluate && action.evaluate.call(widgetInstance, propagationContext);
                // first clone the object
                var actionToPropagate = $.extend({}, action);
                if (action.evaluate && !evalResult) {
                    actionToPropagate = disableAction(actionToPropagate);
                    if (actionToPropagate) { // disableAction can return null if the action shouldn't be shown when disabled
                        actionsTobroadcast.push(actionToPropagate);
                    }
                } else {
                    // Evaluator can reply with a String (truthy expression) to append a dynamic  suffix to the default label
                    if (action.evaluate && evalResult !== true) {
                        actionToPropagate.title += evalResult;
                    }
                    actionsTobroadcast.push(actionToPropagate);
                }
            }
        }
        dbesp.propagation.propagationManager.broadcastMenuItem(propagationContext, widgetInstance, actionsTobroadcast);
    };

    /**
     * Handler for 'execute action' operations.
     * Looks for the source of the action, evaluates and executes it.
     * @param  {Object} propagationContext
     * @param  {Object} actionToExecute
     *
     * @protected
     */
    PropagationBehaviour.prototype.operationExecuteActionHandler = function (propagationContext, actionToExecute) {
        // Reminder: fireFunctionSafe executes argument if function and returns its results or returns the argument if not a function
        var fireFunctionSafe = dbesp.utils.commons.fireFunctionSafe;
        var widgetInstance = this;
        var action, i;
        var getExecuteFn = function (executor) {
            return function () {
                executor(propagationContext);
            };
        };

        for (i = widgetInstance.availableActions.length; i--;) {
            action = widgetInstance.availableActions[i];
            /* jshint eqeqeq: false */
            //(force type coertion of relevance)
            if (action.id === actionToExecute.id && fireFunctionSafe(widgetInstance, actionToExecute.relevance) == fireFunctionSafe(widgetInstance, action.relevance)) {
                /* jshint eqeqeq: true */
                // This is the correspoding source of the actionToExecute. Reevaluate it to check if it is not disabled
                if (!action.evaluate || action.evaluate.call(widgetInstance, propagationContext)) {
                    var saveResult = dbesp.context.contextManager.save(propagationContext, false);
                    if (!saveResult.wasLast || saveResult.wasInactive) {
                        if (saveResult.wasLast && saveResult.wasInactive) {
                            dbesp.context.contextManager.last(propagationContext.type).inactive = false;
                        }
                        dbesp.propagation.propagationManager.performGlobalSync(propagationContext);
                    }
                    if (widgetInstance.isTabChanger) {
                        widgetInstance.revealWidget();
                    }
                    if (action.execute) { // if action has an execution callback, call it
                        $.when(widgetInstance.preRender())
                            .then($.proxy(widgetInstance.restoreIfMinimized, widgetInstance))
                            .then(getExecuteFn(action.execute));
                    } else {
                        widgetInstance._nextWidgetContext = propagationContext;
                        widgetInstance.preRender();
                    }
                }
            }
        }
    };

    /**
     * Handler for 'notify event' operations.
     * Looks for if the widget listens for this events and executes the specified callback or a full render as default action
     * @param  {Object} propagationContext
     * @param  {Object} eventReceived
     *
     * @protected
     */
    PropagationBehaviour.prototype.operationNotifyEventHandler = function (propagationContext, eventReceived) {
        var widgetInstance = this;
        var event, i;
        for (i = widgetInstance.listenedEvents.length; i--;) {
            event = widgetInstance.listenedEvents[i];
            if (event.id === eventReceived) {
                if (event.callback) { // if event has an execution callback, call it
                    event.callback(propagationContext);
                } else {
                    widgetInstance.refresh();
                }
                break;
            }
        }
    };

    /**
     * Manages a correct refresh of the widget
     * @return {Promise|undefined}
     */
    PropagationBehaviour.prototype.refresh = function () {
        var widgetInstance = this;
        if (widgetInstance._widgetContext) {
            widgetInstance._widgetContext.refresh = true;
        } else {
            dbesp.context.contextManager.remove(widgetInstance.widgetId);
        }
        return this.preRender();
    };

    PropagationBehaviour.prototype.destroy = function () {
        //this.widget.destroyHTML(); this line detroys the whole widget when chromeless
        this._widgetContext = null;
        $(this.widget.body).html('');
    };

    /**
     * TODO: Document
     *
     * @param operation
     *
     * @protected
     */
    PropagationBehaviour.prototype.retrieveOperationHandler = function (operation) {
        return this.operationHandler[operation];
    };


    /**
     * TODO: Document
     *
     * @param operation
     *
     * @protected
     */
    PropagationBehaviour.prototype.attachOperationHandler = function (operation, handler) {
        this.operationHandler[operation] = handler;
    };

    /**
     * TODO: Document
     *
     * @param operation
     *
     * @protected
     */
    PropagationBehaviour.prototype.detachOperationHandler = function (operation) {
        delete this.operationHandler[operation];
    };

    /**
     * Calculates the relevance of the widget based on simple calculations
     * Inspect this implementation to understand
     * @return {number} the calculated relevance
     */
    PropagationBehaviour.prototype.basicRelevanceResolver = function () {
        var widgetInstance = this;
        var relevance = 3;
        if (widgetInstance.isVisible()) {
            relevance -= 1;
        }
        if (widgetInstance.isTabChanger) {
            relevance -= 0.5;
        }
        return relevance;
    };


    // ****************************** //
    // ** Private helper functions ** //
    // ****************************** //


    /**
     * Stores widget's available propagation actions
     * @param {BaseWidget} widgetInstance The widget instance we are initializing
     *
     * @private
     */
    function initActionsAndEvents(widgetInstance) {
        widgetInstance.availableActions = widgetInstance.getWidgetPropagationActions() || [];
        widgetInstance.listenedEvents = widgetInstance.getWidgetPropagationEventsSubscriptions() || [];
    }

    /**
     * Sets the operations supported by default
     * @param {BaseWidget} widgetInstance The widget instance we are initializing
     *
     * @private
     */
    function initOperationHandlers(widgetInstance) {
        widgetInstance.attachOperationHandler(dbesp.propagation.propagationManager.OPERATION.MENU_QUERY, widgetInstance.operationMenuQueryHandler);
        widgetInstance.attachOperationHandler(dbesp.propagation.propagationManager.OPERATION.EXECUTE_ACTION, widgetInstance.operationExecuteActionHandler);
        if (widgetInstance.listenedEvents[0]) {
            widgetInstance.attachOperationHandler(dbesp.propagation.propagationManager.OPERATION.NOTIFY_EVENT, widgetInstance.operationNotifyEventHandler);
        }
    }

    /**
     *  Initializes propagation specific click handling
     * @param {BaseWidget} widgetInstance
     *
     * @private
     */
    function bindPropagationEvents(widgetInstance) {
        var widget = widgetInstance.widget;
        var widgetBody = $(widget.body);

        // When a propagation icon is clicked, get JSON data and broadcast for
        // actions to do using that data
        widgetBody.on('click', '[data-prop-action="propagation-proxy"]', handlePropagation(widgetInstance));
    }

    /**
     *  Initializes propagation specific event subscription
     * @param {BaseWidget} widgetInstance
     *
     * @private
     */
    function initPropagationSubscriptions(widgetInstance) {
        // subscribe to all propagation operations
        dbesp.propagation.propagationManager.subscribeToPropagation(widgetInstance);

        // Subscribe to tab page change to update visibility
        $.subscribe('dbcde-tab-page-change', function (selectedTab) {
            if (widgetInstance.isVisible(selectedTab)) {
                widgetInstance.preRender(true);
            }
            return true;
        }, widgetInstance.widgetId);
    }

    /**
     * Handles propagation button click & double click events
     * @param  {BaseWidget} widgetInstance The widget instance source of the event
     *
     * @private
     */
    function handlePropagation(widgetInstance) {
        var $propagationTpl;
        // isSecondClick is sent by dbesp.propagation.propagationManager.createPropagation click handler
        return function (evt) {

            var $self = $(this);
            if ($self.data('prop-class') !== 'prop-propagation-button') {
                // This case was added to permit clicking on a parent element for propagation.
                // i.e, in personal agenda clicking the event should trigger a click into its propagation button.
                // For this to work the parent element should have a [data-prop-action="propagation-proxy"] and a single [data-prop-class="prop-propagation-button"] inside.
                $self = $self.find('[data-prop-class="prop-propagation-button"]:first');
            }
            var isSecondClick = $self.hasClass('active');
            $self.addClass('active');
            var propagationContext = dbesp.propagation.propagationManager.buildPropagationContext($self);
            // propagationManager triggers the second click and passes the isSecondClick as an event param
            if (!isSecondClick) {
                // we cache the template, as we need it for the double click.
                $propagationTpl = dbesp.propagation.propagationManager.broadcastMenuQuery(propagationContext, widgetInstance, $self);
            } else {
                // if a second (double) click on the propagation button is triggered, trigger a click event on the first available action of the menu
                var $firstActiveButton = $propagationTpl.find('[data-prop-type="propagator"]:enabled:first');
                if ($firstActiveButton[0]) {
                    $firstActiveButton.click();
                    $self.removeClass('active');
                    $propagationTpl = null;
                }
            }
            // Avoid bubbling actions when propagation is clicked
            evt.stopPropagation();
        };
    }

    /**
     * TODO: Document
     * @param  {BaseWidget} widgetInstance The widget instance to parse for context
     *
     * @private
     */
    function parseServerSideWidgetContext(widgetInstance) {
        var $wBody = $(widgetInstance.widget.body);
        var $widgetContext = $wBody.find('[data-prop-class="widget-context"]');
        if ($widgetContext.length > 0) {
            widgetInstance._widgetContext = {
                id: $widgetContext.data('prop-context-id'),
                description: $widgetContext.data('prop-context-description'),
                type: $widgetContext.data('prop-context-type')
            };
            dbesp.context.contextManager.save(widgetInstance._widgetContext);
        }
    }


    /**
     * TODO: Document
     * @param  {BaseWidget} widgetInstance The widget instance to parse for context
     *
     * @private
     */
    function setWidgetTitle(widgetInstance) {
        if (widgetInstance.widget.getPreference(PREFERENCES.SHOW_CONTEXT_HEADER)) {
            var $wBody = $(widgetInstance.widget.body);
            var $titleContainer = $wBody.find('[data-prop-class="prop-title-container"]');
            if ($titleContainer[0] && widgetInstance._widgetContext) {
                dbesp.utils.ui.populateEmtyIcon($titleContainer[0], widgetInstance._widgetContext);
            }
        }
    }

    /**
     * @param {Object} action action to disable
     * @return {Object}  a disabled  version of the passed action
     */
    function disableAction(action) {
        if (action.hideWhenDisabled) {
            return void(0);
        }
        action.enabled = false;
        return action;
    }


    // ********************** //
    // ** Abstract methods ** //
    // ********************** //

    /**
     * Defines the actions that the widget can offer for propagation
     * @returns {Array} propagation actions
     * @abstract
     */
    PropagationBehaviour.prototype.getWidgetPropagationActions = function () {
        this.showAbstractMethodWarn('PropagationBehaviour', 'getWidgetPropagationActions');
        return [];
    };

    /**
     * Defines the events that the widget wants to subscribe to
     * @returns {Array} propagation events
     * @abstract
     */
    PropagationBehaviour.prototype.getWidgetPropagationEventsSubscriptions = function () {
        this.showAbstractMethodWarn('PropagationBehaviour', 'getWidgetPropagationEventsSubscriptions');
    };

    /**
     * Does the necessary logic to render the widget.
     * By default, just calls PropagationBehaviour#renderWidget
     * This method could be invoked anytime
     * @abstract
     */
    PropagationBehaviour.prototype.render = function () {
        this.showAbstractMethodWarn('PropagationBehaviour', 'render');
        this.renderWidget();
    };


    /**
     * Main render of the widget.
     * Implemented by the render strategies.
     *
     * @abstract
     */
    PropagationBehaviour.prototype.renderWidget = function () {
        this.showAbstractMethodWarn('PropagationBehaviour', 'renderWidget');
        var renderDeferred = $.Deferred();
        renderDeferred.resolve();
        return renderDeferred.promise();
    };

    dbesp.widgets.mixins = dbesp.widgets.mixins || {};
    dbesp.widgets.mixins.PropagationBehaviour = PropagationBehaviour;
})();

/**
 * Client side render
 * @module core/widgets/renderStrategies/clientRenderable
 *
 * @augments module:core/widgets/baseWidget
 *
 * @requires module:jquery
 * @requires module:core/utils/service
 * @requires module:core/widgets/mixins/propagationBehaviour
 *
 * @example Usage:
 *
 define(['core/utils/fn', 'core/widgets/baseWidget', 'core/widgets/mixins/clientRenderable'], function (fn, BaseWidget, ClientRenderable) {
         var ExampleWidget = fn.inherit(function () {

         }, BaseWidget, [ClientRenderable]);

         return function (bbwidget) {
            fn.createInstance(SampleWidget, bbwidget).init();
        };
     });

 */

// BB parser does not allow mime-types different from "text/javascript" or "application/javascript"
// on script tags and throws an error.
// Here, "text/template" mime-type is added to the allowed list providing support for mustache templating
// inside script tags on widget's html files.
var bbTypes = b$._private.resourceManager.types;
var resType;
for (var i = bbTypes.length; i--;){
    resType = bbTypes[i];
    if (resType.label === "JavaScript Resource") {
        resType.mimeArray.push("text/template");
        break;
    }
}

(function() {
    'use strict';

    /**
     * @constructor
     * @private
     * @alias module:core/widgets/renderStrategies/clientRenderable
     */
    var ClientRenderable = function ClientRenderable() {}

    ClientRenderable.dependencies = [dbesp.widgets.mixins.PropagationBehaviour];

    /**
     * @this ClientRenderable
     * @private
     */
    ClientRenderable.mixinInitializer = function () {

    }

    // Renders a mustache template, on the whole widget body. The mustache view
    // is obtained from the implementation of the getJSONView abstract method.
    // @param templateId: The id of the template to render.
    // @returns the promise/deferred object returned making possible to callers
    // to add callbacks.
    ClientRenderable.prototype.renderWidget = function (templateId, partialIds, responseProcessor) {
        return this.renderContent($(this.widget.body), this.getJSONView, templateId, partialIds, responseProcessor);
    };

    // Renders a mustache template, on the specified jQuery container. The mustache
    //  view is obtained from the specified function.
    // @param $container: A jQuery container where the template will be rendered
    // @param getJSONView: A function which returns the mustache view or the
    // view itself
    // @param templateId: The id of the template to render.
    // @returns the promise/deferred object returned making possible to callers
    // to add callbacks.
    ClientRenderable.prototype.renderContent = function ($container, getJSONView, templateId, partialIds, responseProcessor) {
        var widgetInstance = this;
        var clientSideDef = $.Deferred();
        var template = $(document).find('[data-prop-id="' + templateId + '"]').html();
        try {
            widgetInstance.clearWidgetMessages(true);
            widgetInstance.showLoading($container);
            var jqXHR = typeof getJSONView === 'function' ? getJSONView.call(widgetInstance) : getJSONView;
            $.when(jqXHR)
                .always($.proxy(widgetInstance.hideLoading, widgetInstance))
                .done(function (response) {
                    if (responseProcessor) {
                        response = responseProcessor(response);
                    }
                    var partials = dbesp.utils.ui.getMustachePartials(partialIds);
                    /*jshint camelcase: false */
                    $container.html(Mustache.to_html(template, response, partials));
                    /*jshint camelcase: true */
                    widgetInstance.postRender();
                    clientSideDef.resolveWith(widgetInstance);
                })
                .fail(widgetInstance.renderError($container));
        } catch (error) {
            widgetInstance.hideLoading();
            clientSideDef.rejectWith(widgetInstance, [error]);
        }
        return clientSideDef;
    };

    // ********************** //
    // ** Abstract methods ** //
    // ********************** //

    // Returns an object representing the view which will be applied to mustache
    // template.
    // See https://github.com/janl/mustache.js#mustachejs---logic-less-mustache-templates-with-javascript
    // @returns JSON object having mustache variables
    // @abstract
    ClientRenderable.prototype.getJSONView = function () {
        this.showAbstractMethodWarn('propagation.widget.client-side.js', 'getJSONView');
        return {};
    };

    // Updates the widgets body showing the error returned by web service
    // @param ajaxCtxDef: The promise oject to return using widget context
    // @param widgetInstance: The widget instance that will be specified for
    // promise
    ClientRenderable.prototype.renderError = function ($container) {
        var widgetInstance = this;
        return function (xhr, status, error) {
            var message;
            if (status === 'timeout') {
                message = 'Request aborted: Timeout limit reached (' + (dbesp.utils.service.DEFAULT_TIMEOUT / 1000) + ' seconds)';
            } else if (status === 'error' && !error) {
                message = 'Couldn\'t reach Portal Server';
            } else {
                message = 'Web service returned status ' + status + ' ' + xhr.status + ' - ' + error;
            }
            widgetInstance.postRenderError($container);
            var errorContainer = widgetInstance.showWidgetMessage(message, true);
            errorContainer.on('dblclick', function () {
                if (event.ctrlKey) {
                    widgetInstance.refresh();
                }
            });
        };
    };

    dbesp.widgets.renderStrategies = dbesp.widgets.renderStrategies || {};
    dbesp.widgets.renderStrategies.ClientRenderable = ClientRenderable;

})();

/**
 * Server side render
 * @module core/widgets/renderStrategies/serverRenderable
 *
 * @augments module:core/widgets/baseWidget
 *
 * @requires module:jquery
 * @requires module:lodash
 * @requires module:core/log
 * @requires module:core/utils/service
 * @requires module:core/utils/commons
 * @requires module:core/widgets/mixins/propagationBehaviour
 *
 * @example Usage:
 *
 define(['core/utils/fn', 'core/widgets/baseWidget', 'core/widgets/renderStrategies/serverRenderable'], function (fn, BaseWidget, ServerRenderable) {
         var ExampleWidget = fn.inherit(function () {

         }, BaseWidget, [ServerRenderable]);

         return function (bbwidget) {
            fn.createInstance(SampleWidget, bbwidget).init();
        };
     });

 */
(function () {
    'use strict';

    /**
     * @constructor
     * @private
     * @alias module:core/widgets/renderStrategies/serverRenderable
     */
    var ServerRenderable = function ServerRenderable() {
    }

    ServerRenderable.dependencies = [dbesp.widgets.mixins.PropagationBehaviour];

    /**
     * @this ServerRenderable
     * @private
     */
    ServerRenderable.mixinInitializer = function () {
        var widgetInstance = this;
        // Request object necessary for widget rendering
        widgetInstance.request = {
            // All request should use method POST due that core architecture
            // uses the method of the source request to invoke SOAP WS
            type: 'POST',
            // Provides WS custom error response
            url: 'undefined',
            // Empty object is serialized by default
            data: dbesp.utils.service.serializeRequestData({}),
            // It is necessary to specify the data type since portal core does
            // not return HTML text but XML #document node
            dataType: 'html',
            // Default timeout is set to 20 seconds for all requests
            timeout: dbesp.utils.service.DEFAULT_TIMEOUT
        };
    };

    /**
     * Renders the response, returned by a WS using an AJAX call, on the whole
     * widget body.
     *
     * @param {Object|Function} [requestData=widgetInstance.getJSONRequestData]
     *
     * @return {Promise} a chainable promise resolved when render is done
     */
    ServerRenderable.prototype.renderWidget = function (requestData) {
        var widgetInstance = this;
        requestData = requestData || widgetInstance.getJSONRequestData
        // This method is a common shorthand for the renderContent method
        return widgetInstance.renderContent($(widgetInstance.widget.body), requestData);
    };

    /**
     * Renders the response, returned by a WS using an AJAX call, on the specified
     * jQuery container. The request is obtained from the specified function.
     * @param {jQuery|Function} $container A DOM element or a function that return one where the response will be rendered
     * @param {Object|Function} jQueryRequest A jQuery request or a function that return one
     * @param {jQuery|Function} [$loaderContainer=widget.body] A DOM element or a function that return one where the loader will be displayed
     * @param {Promise} [dependingPromise] a promise that permits launching async requests but synchronous chained renders
     * @returns {Promise} the promise of a render making possible to callers to add callbacks and chain requests sequentially
     */
    ServerRenderable.prototype.renderContent = function (container, jQueryRequest, loaderContainer, dependingPromise) {
        // Reminder: fireFunctionSafe executes argument if function and returns its results or returns the argument if not a function
        var fireFunctionSafe = dbesp.utils.commons.fireFunctionSafe;
        var widgetInstance = this;
        // A new deferred is created to wrap handlers within
        // widget instance context
        var ajaxCtxDef = $.Deferred();
        // Show loading before AJAX starts
        $.when(dependingPromise).done(function () {
            var $loaderContainer = fireFunctionSafe(loaderContainer);
            if ($loaderContainer !== false) {
                widgetInstance.clearWidgetMessages(true);
                widgetInstance.showLoading($loaderContainer);
            }
        });
        // Merge defaults with obtained request either as object or as a
        // function return value
        var request = $.extend(widgetInstance.request, fireFunctionSafe(widgetInstance, jQueryRequest));
        // Serialize data from request
        var serializedData = dbesp.utils.service.serializeRequestData(request.data);
        // Put serialized data back to request
        request.data = serializedData;
        // Do the AJAX call
        var jqXHR = $.ajax(request);
        $.when(dependingPromise).done(function () {
            var $container = fireFunctionSafe(container);
            jqXHR
                .always($.proxy(widgetInstance.hideLoading, widgetInstance))
                .done(renderSuccess(ajaxCtxDef, $container, widgetInstance))
                .fail(renderError(ajaxCtxDef, $container, widgetInstance));
        });
        // Return ajax promise for callers to be able to add handlers within
        // widget instance context
        return ajaxCtxDef.promise();
    };

    // ****************************** //
    // ** Private helper functions ** //
    // ****************************** //


    /**
     * Updates the widgets body using the response HTML returned by web service
     * @param {Deferred} ajaxCtxDef The promise oject to return using widget context
     * @param {jQuery} $container: The jQuery container on which to render response
     * @param {BaseWidget} widgetInstance: The widget instance that will be specified for promise
     */
    function renderSuccess(ajaxCtxDef, $container, widgetInstance) {
        return function (responseHTML, status, xhr) {
            if (status === 'error') {
                // Reject using widget instance context
                return ajaxCtxDef.rejectWith(widgetInstance, [xhr, status, responseHTML]);
            }
            // Animation provides show error in case of service validations
            $container.html(responseHTML);
            widgetInstance.postRender();
            // Resolve using widget instance context
            ajaxCtxDef.resolveWith(widgetInstance, [responseHTML, status, xhr]);
        };
    }


    /**
     * Updates the widgets body showing the error returned by web service
     * @param {Deferred} ajaxCtxDef The promise oject to return using widget context
     * @param {jQuery} $container: The jQuery container on which to render response
     * @param {BaseWidget} widgetInstance: The widget instance that will be specified for promise
     */
    function renderError(ajaxCtxDef, $container, widgetInstance) {
        return function (xhr, status, error) {
            var message;
            if (status === 'timeout') {
                message = 'Request aborted: Timeout limit reached (' + (dbesp.utils.service.DEFAULT_TIMEOUT / 1000) + ' seconds)';
            } else if (status === 'error' && !error) {
                message = 'Couldn\'t reach Portal Server';
            } else {
                message = 'Web service returned status ' + status + ' ' + xhr.status + ' - ' + error;
            }
            widgetInstance.postRenderError($container);
            var errorContainer = widgetInstance.showWidgetMessage(message, true);
            errorContainer.on('dblclick', function () {
                if (event.ctrlKey) {
                    widgetInstance.refresh();
                }
            });

            // Reject using widget instance context
            ajaxCtxDef.rejectWith(widgetInstance, [xhr, status, error]);
        };
    }

    // ********************** //
    // ** Abstract methods ** //
    // ********************** //

    /**
     *
     * This method is invoked normally by ServerRenderable#renderWidget
     * @return {{}} An object representing the request to use on AJAX.  All attributes are optional. It should be invoked by renderWidget method.
     * @see https://api.jquery.com/jQuery.ajax/#jQuery-ajax-settings
     *
     * @abstract
     */
    ServerRenderable.prototype.getJSONRequestData = function () {
        this.showAbstractMethodWarn('propagation.widget.mustache-transformer.js', 'getJSONRequestData');
        return {};
    };

    dbesp.widgets.renderStrategies = dbesp.widgets.renderStrategies || {};
    dbesp.widgets.renderStrategies.ServerRenderable = ServerRenderable;
})();

b$.module("b$.portal.view.bdom.container.original", function() {
    var Class = b$.Class;


    //	var DefaultView = b$.portal.view.bdom.default;
    //	var NS = DefaultView.NS;
    //	var Container = NS.classes.container;
    //	var portalViewElement = DefaultView.portalViewElement;

    var NS = b$.bdom.getNamespace('http://backbase.com/2012/portalView');
    var Container = NS.getClass('container');
    var Box = NS.getClass('Box');
    var portalViewElement = NS.getClass('portalViewElement');
    var htmlAPI = b$._private.htmlAPI;

    var layouts = b$.view.bdom.layout;
        


    /*

		- Relative
		- Absolute
		- AbsolutePool

	*/
    getCoordinates = function (elm) {
        var r = $(elm).offset();
        var c = {
            x:r.left,
            y:r.top,
            left:r.left,
            top:r.top,
            w:elm.offsetWidth,
            h:elm.offsetHeight
        }
        return c;
    };
    findParentByClass = function (elm, className) {
        while (elm) {
            if (jQuery(elm).hasClass(className))return elm;
            elm = elm.parentNode;
        }
    };



    var ContainerPpal = NS.registerElement('Container_ppal', Container.extend(function (bdomDocument, namespaceURI, localName, node) {
        Container.call(this, bdomDocument, namespaceURI, localName, node);
        this.isPossibleDragTarget = false;
    }, {
        buildHTML: function(elm){
            var oDocument = document;
            //console.log('this', this);
            //console.log('elm 01', elm);
            elm = Container.prototype.buildHTML.call(this, elm);
                                
            this.htmlAreas = jQuery('> table > tbody > tr > td', elm);
            //elm.removeClass("bp-ui-dragRoot");
            //console.log('elm rt', elm);
			//Remove dragDrop behaviour from defaultDragHandlers
			this.local_listeners.dragDrop.splice(0,1);
			this.parentNode.local_listeners.dragDrop.splice(0,1);
            return elm;
        },
        readyHTML: function(elm){
            var body = $('html');
            this.addEventListener('PerspectiveModified', function(aEvent) {
                var widgetBody = $(aEvent.target.body);
                switch (aEvent.newValue) {
                    case 'Maximized' :
                        if(!body.hasClass('fixed')){ body.addClass('fixed'); }
                        if(!widgetBody.hasClass('bp-widget-body-maximized')){ widgetBody.addClass('bp-widget-body-maximized'); }
                        break;
                    //case 'Minimized':
                    case 'Widget':
                        if(body.hasClass('fixed')){ body.removeClass('fixed'); }
                        if(widgetBody.hasClass('bp-widget-body-maximized')){ widgetBody.removeClass('bp-widget-body-maximized'); }
                        break;
                }
            }, false, this);
            return elm;
        }, 
        getContainerTemplate: function() {
            var oData = this.model.getJSON(),
            aPreferences = oData.preferences,
            columnNumber = 1,
            fallbackContainerTmpl,
            i, oPreference;

            for (i = 0; i < aPreferences.length; i++) {
                oPreference = aPreferences[i];
                if (oPreference.name == 'numberOfColumns') {
                    columnNumber = oPreference.value;
                    break;
                }
            }
            fallbackContainerTmpl = '<div>'
            + '<table cellspacing="0" >' + '<tbody>' + '<tr>';
            for (i = 0; i < columnNumber; i++) {
                fallbackContainerTmpl += '<td>' + '</td>';
            }
            fallbackContainerTmpl += '</tr>' + '</tbody>' + '</table>' + '</div>';
            if (console) console.log(fallbackContainerTmpl);
            return fallbackContainerTmpl;
        }

    })
    );
    
    
    var YourCustomLayout = NS.registerElement('custom_layout_technical_name',
        Container.extend(function (bbDocument, namespaceURI, localName, node) {
            Container.call(this, bbDocument, namespaceURI, localName, node);
            this.isPossibleDragTarget = true;
        }, {
            buildHTML: function (htmlElement) {
                var oDocument = document;
                var oData = this.model.getJSON();
                if(!htmlElement) {
                    var template = '<div>' +
                        '<style type="text/css">' +
                        '    body {width: 650px;}' +
                        '    .leftcolumn {float:left}' +
                        '    .bp-area {height:100px; width:260px; border:1px solid grey}' +
                        '    .bp-page {height:500px; width:600px;}' +
                        '    .rightcolumn {float:right}' +
                        '    .clear {clear:both}' +
                        '</style>' +
                        '<div class="leftcolumn">' +
                        '    <div class="bp-area"></div>' +
                        '    <div class="bp-area"></div>' +
                        '    <div class="bp-area"></div>' +
                        '</div>' +
                        '<div class="rightcolumn">' +
                        '    <div class="bp-area"></div>' +
                        '    <div class="bp-area"></div>' +
                        '    <div class="bp-area"></div>' +
                        '</div>' +
                        '<br class="clear"/>' +
                        '</div>';
                    htmlElement = jQuery(Mustache.to_html(template, oData), oDocument)[0];
                }
                this.appendPreferencesForm(htmlElement, this.model, oDocument);
                return htmlElement;
            }
        })
    );


    function OrderSort(a, b) {
        a = parseInt(a.getOrderPreference()) || 0;
        b = parseInt(b.getOrderPreference()) || 0;
        return a - b;
    };

    function isInside (tx,ty,x,y,w,h) {
        //		console.log(x>=x2 , x<=x2+w , y>=y2 , y<=y2+h)
        if(tx>=x && tx<=x+w && ty>=y && ty<=y+h )
            return true;
        return false;
    }



    function findModel (doc, model) {
        for (var n in doc.all) {
            if (doc.all[n].model == model) {
                return doc.all[n];
            }
        }
    }

});
(function(){


    var originalContainer= '';
    
    function isHorizMenuOnPage(containerName) {
    	var $container = $('[data-pid="' + containerName + '"]>.bp-tabContFn-header');
    	if ($container) return true;
    	return false;
    }

    /**
     * Get the external links related with an obj
     * @param {type} containerName
     * @returns {undefined}
     */
    function getExternalLinks2Container(/*String*/containerName) {
    	if (!isHorizMenuOnPage(containerName)) return;
        $.ajax({
            type: 'GET',
            url: dbesp.contextRoot + '/rest/navigation/horizontalMenulinks/' + containerName,
            dataType: "html",
            cache: false,
            success: function (data, textStatus, jqXHR) {
                console.log(data);
                //create object to append html
                var $container = $('[data-pid="' + containerName + '"]>.bp-tabContFn-header');
                $container.append($(data));
                originalContainer=containerName;

                $container.on('click', '[data-linkType="parametersLink"]', function (event) {
                    event.preventDefault();
                    event.stopImmediatePropagation();
                    createForm(this);
                });
            },
            error: function (data, textStatus, jqXHR) {
                dbesp.log.error('core-utilsHorizontalMenu.getExternalLinks2Container', 'Error getting external links to container: [' +data+ ']');
            }
        });
    }

    $.subscribe(dbesp.i18n.changeLanguageEventName, function(message) {
        if(message && isHorizMenuOnPage(originalContainer)){
            dbesp.log.debug('core-utilsHorizonalMenu.subscribe', 'Listen : ' + message);
            dbesp.log.debug('core-utilsHorizonalMenu.subscribe', 'ContainerName : ' + originalContainer);
            //Remove external links DIV
            //$("DIV[index]").remove();
            //$('[data-pid="' + containerName + '"]>.bp-tabContFn-header>DIV[index]').remove();
            $(".bp-TabCont-link-horizontal-external.bp-tabContFn-link-external" ).parent().remove();
            getExternalLinks2Container(originalContainer);
        }
        return true;
    }, 'menu');

    function createExtraZone(/*String*/ containerName) {
        var htmlExtraZone = '<div class="bp-TabCont-tab-horizontal bp-ui-dragRoot bp-tabContFn-tab " index="applicativeExtraZone" id="applicativeExtraZone" style="float:right"></div>';
        $('[data-pid="' + containerName + '"]>.bp-tabContFn-header').append(htmlExtraZone);
    }

    function createForm(/*Object*/ object) {
        dbesp.log.debug('core-utilsHoriontalMenu.createForm', 'CREATE FORM INIT');
        var typeMethod = object.getAttribute("data-linkMethod");
        var submitable = true;
        var emptyParametersJSON = [];
        //Window title text
        var message = "No enough parameters.";

        if ($.trim(typeMethod) === "") {
            typeMethod = "GET";
        }

        dbesp.log.debug('core-utilsHoriontalMenu.createForm', 'typeMethod' + typeMethod);

        var targetName = object.getAttribute("target");
        if (targetName == null || targetName === "") {
            targetName = "_blank";
        }

       /*
         * Specific functionality for NCO link
         * 
         * The url for NCO contains a variable in the middle of the url
         * This variable has to be resolved in order to create (depending the language)
         * a url looks like: https://nco.pbc.be.intranet.db.com/#/fr/bankingExpectations
         */
        
        var url = object.getAttribute("href");
		var isNCO = false;
        
		while (url.indexOf("[[") > 0){
			var beginIndex = url.indexOf("[[");
			var endIndex = url.indexOf("]]");
			var wordToChange = url.substring(beginIndex + 2, endIndex); 
			isNCO = true;
			
			 dbesp.esc.findESC(wordToChange,
                function (data) {
                    if (data !== '') {
						/*TODO: As method findESC with the fourth parameter "true" doesn't work from here
						         in order to ensure we are getting the updated language value as workaround
								 is got from dbesp.PORTAL_CORE_LANG as this is updated in the method
								 changeLanguage.js.init()
								 For any other value is normally retrieved from ESC*/
                         if (wordToChange === "LANG"){
							data = dbesp.PORTAL_CORE_LANG;
							data = data.substring(0,2);
						 } 
						 
						 url = url.replace("[["+ wordToChange + "]]", data);
                    }
                },
                function () {
                    dbesp.log.error('[core-changeLanguage.init]', 'Error finding language in ESC');
				//param true is used to ignore ESC cache
                }
			);	  
	
		}       
        /* END
         * Specific functionality for NCO link
         */
		 
		 
		 
		 /*
			TODO: under study why is always including parameter q=1 in the url
				  for external links. We don't know why is for.
				  For NCO it is neccesary do not include it. Thats why this conditional
				  is used for.
		 */
		if (isNCO == true){
			var newForm = $('<form>', {
				'action': url,
				'target': targetName,
				'method': typeMethod
			});
		}else{
			var newForm = $('<form>', {
				'action': url,
				'target': targetName,
				'method': typeMethod
			
			}).append($('<input>', {
				'name': 'q',
				'value': '1',
				'type': 'hidden'
			}));
		}
        //alert(newForm);
        var params = object.getAttribute("data-linkParams");
        console.log(params);
        params = params.replace("},]", "}]");
        params = JSON.parse(params);
        dbesp.log.debug('core-utilsHoriontalMenu.createForm', params);
        console.log(params);
        //as many inputs as params contained
        for (var i = 0; i < params.param.length; i++) {

            var postparam = params.param[i].POSTparam;
            var typeParam = params.param[i].TYPE;
            var escparam = params.param[i].ESCparam;
            var label = params.param[i].LABEL;
            var fixedValueParam = params.param[i].FIXEDVALUE;

            if(typeParam != null && typeParam != '' && typeParam != undefined && typeParam.toUpperCase() == 'FIXED' && fixedValueParam != null && fixedValueParam != undefined){
                //"fixed" parameters set on the horizontalMenuLinks xml config file
                newForm.append($('<input>', {
                        'name': postparam, //postparam
                        'value': fixedValueParam, //value of param
                        'type': 'hidden'
                }));
            }else if(escparam != null && escparam != '' && escparam != undefined &&  label != null && label != undefined){
                //parameters whose value is taken from ESC
                dbesp.esc.findESCSync(escparam, function (data) {
                    dbesp.log.debug('core-utilsHoriontalMenu.createForm', 'data ok' + escparam + ': ' + data);
                    if (data) {
                        newForm.append($('<input>', {
                            'name': postparam, //postparam
                            'value': data, //value of param escparam in esc
                            'type': 'hidden'
                        }));
                    } else {
                        submitable = false;
                        var item = {};
                        item ["emptyValue"] = label;
                        emptyParametersJSON.push(item);
                    }
                }, function (dataKO) {

                    dbesp.log.debug('core-utilsHoriontalMenu.createForm', 'data ko' + escparam + ': ' + dataKO);
                    submitable = false;
                    var item = {};
                    item ["emptyValue"] = label;
                    emptyParametersJSON.push(item);
                });
            }else{
                //This param has no enough non mandatory sub parameters to work with
                console.log('For postparam: '+postparam+', some parameters are missed or wrong: typeParam: '+typeParam+', escparam: '+escparam+', label: '+label+', fixedValueParam: '+fixedValueParam);
            }
        }
        if (submitable) {
            newForm.append($('<input>', {'type': 'submit', 'value': 'submit'}));
            newForm.appendTo('body');
            newForm.submit();
            newForm.remove();
        } else {
            // list of Params (delete last ",")
            console.log(emptyParametersJSON);
            var ulList = "<ul>";
            for (var i = 0; i < emptyParametersJSON.length; i++) {
                //Every param generates a new line in error list
                if(emptyParametersJSON[i].emptyValue!= ''){
                    ulList += "<li>" + emptyParametersJSON[i].emptyValue + "</li>";
                }

                console.log(ulList);
            }
            ulList += "</ul>";
            //var postparam = params.param[i].POSTparam;

            //Calculate multi-language overlay title
            if (dbesp.PORTAL_CORE_LANG !== "") {
                var rootURL = dbesp.contextRoot + "/rest/lang/props/" + dbesp.PORTAL_CORE_LANG;
                dbesp.log.debug('[core-utilsHorizontalMenu.createForm]', 'rootURL ' + rootURL);
                $.ajax({
                    type: "GET",
                    contentType: "application/json",
                    url: rootURL,
                    async: false,
                    cache: false,
                    //processData: false,
                    success: function (data, textStatus, jqXHR) {
                        var pLang = "horizontalLinks.text.alertMessage";
                        alertMessage = dbesp.utils.misc.getjSonValueUnic(data, pLang);

                        if (alertMessage != null && alertMessage != '' && alertMessage != undefined){
                            message = alertMessage ;
                        }
                    },
                    error: function (jqXHR, textStatus, errorThrown) {
                        //alert('findDOM error getting literal in object\n' + object.html() + '\n language ' + language) ;
                        dbesp.log.error('[core-utilsHorizontalMenu.createForm]', 'Error :' + textStatus + ' , ' + errorThrown);

                    }
                });
            }
            dbesp.overlay.showMsg(message + ulList, true);
        }
    }

    dbesp.containers = dbesp.containers || {};
    dbesp.containers.menuUtils = {
        getExternalLinks2Container: getExternalLinks2Container,
        // used from tabContainer.js to add extra buttons
        createExtraZone: createExtraZone
    };
})();
(function () {
    function init() {
        // Init multi-language change listerner

        // Horizontal menu will be subscribed to pubsub changeLanguage event
        $(document).ready(function () {
        	// register horizontal tab to be refreshed when language changes
        	dbesp.changeLanguage.registerWidgetToLanguageChangeMonitoring($('.bp-TabCont-tab-horizontal.bp-ui-dragRoot.bp-tabContFn-tab'));
//            $.subscribe('changeLanguage', function (message) {
//                dbesp.changeLanguage.changeLanguageDOM($('.bp-TabCont-tab-horizontal.bp-ui-dragRoot.bp-tabContFn-tab'));
//                return true;
//            }, 'tabContainer');

            $('body').on('click', '.bp-TabCont-link', function (evt) {
                var $tab = $(this).parent();
                var tabName = $tab.data('index');
                dbesp.utils.navigation.setSelectedTab(tabName);
                $.publish('dbcde-tab-page-change', [tabName], 'tabContainer');
            });
        });
// no more necessary once registered to be updated. changeLanguage module will change labels
//        /*After creating the html menu structure:
//         1.- Get the default language
//         2.- Change text content with its multilanguage value
//         */
//        dbesp.esc.findESC("LANG",
//            function (data) {
//                if (data !== '') {
//                    dbesp.PORTAL_CORE_LANG = data;
//                    dbesp.changeLanguage.findDOM($('.bp-TabCont-tab-horizontal.bp-ui-dragRoot.bp-tabContFn-tab'), data);
//                }
//            },
//            function () {
//                dbesp.log.error('[core-dbesp.changeLanguage.init]', 'Error finding language in ESC');
//            }
//        );
//        */
        /*
         Remove edit/drop/remove horizontal menu tab properties in Belgium Portal
        */
        var tabHrzClass = ".bp-TabCont-link.bp-TabCont-link-horizontal.bp-tabContFn-link";
        if($(tabHrzClass)[0]){
        	$(tabHrzClass).unbind('dblclick');            
            $(tabHrzClass).dblclick(function(e){
                e.stopPropagation();
                e.preventDefault();
                return false;
            });
        }       
        
    }

    dbesp.containers = dbesp.containers || {};
    dbesp.containers.tabContainer = function (tabName, havePpalMenu) {
        init();
        if (havePpalMenu) {
            dbesp.containers.menuUtils.getExternalLinks2Container(tabName);
        }
        dbesp.containers.menuUtils.createExtraZone(tabName);
    }
})();


define('b-core/widgets/contextualMenu/contextualMenu', function () {
    return function() {
        dbesp.common.contextualMenuController.init();
    };
});
/*
 * @class 
 * @memberOf contextualMenuFAB
 * @namespace 
 * @description The purpose of this function is to be a constructor for the pageMenuControllerFAB
 * object. pageMenuControllerFAB encapsulates access to NavigationFacade in the backend
 */
define('b-core/widgets/contextualMenuFAB/contextualMenuFAB', function () {
    return function() {
        dbesp.common.contextualMenuController.init();
    };
});
/**
 *
 * Manage all functions of Contextual Menu Tab.
 *
 *
 */

define('b-core/widgets/contextualMenuTAB/contextualMenuTAB', function () {
    'use strict';
    var contextualMenuTAB = (function () {

        var _stopedTypping;
        var _className = 'core-contextualMenu';
        var _usingFilter = false;

        /**
         * Load and configure the menu.
         *
         * @param {Object} widget
         * @returns void
         */
        function init(widget) {
            //setTimeout necesari to work correctly, the widget.id property is empty without this setTimeout.
            setTimeout(function () {
                dbesp.log.debug('contextualMenu.init');
                load(widget);
            }, 0);
        }

        /**
         * Function to publish a menu event
         * @private
         * @param {String} channel Channel
         * @param {String} message Message
         */
        function publishToWidget(channel, message) {
            dbesp.log.debug(_className + '.publishToWidget', 'Channel -> ' + channel + ' ::  message -> ' + message);
            $.publish('chnn_' + channel, [message]);
        }

        /**
         * Function to subscribe to the menu channel for invocation from widgets
         * @private
         */
        function subscribe(widget) {
            $.subscribe(dbesp.i18n.changeLanguageEventName, function (message) {
                dbesp.log.info(_className + '.subscribe', 'Listen : ' + message);
                getMenuData(widget);
                return true;
            });
        }

        /**
         * Get menu data via RETS
         *
         * @param {String} widget
         * @returns void
         */
        function getMenuData(widget) {
            var rootRest = dbesp.contextRoot + '/rest/navigation';
            var rootRestMenu = rootRest + '/contextualMenu/' + widget.id;
            $.ajax({
                type: 'GET',
                url: rootRestMenu,
                contentType: 'application/x-www-form-urlencoded',
                //disable cahche IE
                cache: false,
                requestHeaders: {
                    'If-Modified-Since': 'Sat, 1 Jan 2000 00:00:00 GMT'
                },
                success: function (data) {
                    //delete old menu if exist
                    $(widget.body).find('.principalContainerContextualMenuTAB>img').hide();
                    $(widget.body).find('.principalContainerContextualMenuTAB>.menuSearch').remove();
                    $(widget.body).find('.principalContainerContextualMenuTAB>#itemsVerticalMenu').remove();


                    //add menu data
                    $(widget.body).find('.principalContainerContextualMenuTAB').append(data);

                    configRecursiveChildren(widget, $(widget.body).find('#itemsVerticalMenu>ul').children('li'));
                    setKeyup(widget);
                },
                error: function (data) {
                    //add menu data on error
                    $(widget.body).find('.principalContainerContextualMenuTAB>img').hide();
                    $(widget.body).find('.principalContainerContextualMenuTAB').append("<div id='errorLoadMenu'>Error getting menu to " + widget.id + ". Please click <a data-action=\"widget-refresh\">here</a> to reload.</div>")
                }
            });
        }

        /**
         * Set functionality on keyup of menusearch.
         *
         * @param {String} widget
         * @returns void
         */
        function setKeyup(widget) {
            $(widget.body).find('#inputMenuSearch').keyup(function () {
                var minLenght = 3;
                var filter = $(this).val();

                //wile user writing no rise the event search.
                if (_stopedTypping) {
                    clearTimeout(_stopedTypping);
                    _stopedTypping = null;
                }

                //delay search event
                _stopedTypping = setTimeout(function () {
                    if (filter.length >= minLenght) {

                        //search items
                        $(widget.body).find('#itemsVerticalMenu li').each(function () {
                            if ($(this).text().search(new RegExp(filter, "i")) < 0) {

                                //attr to control if user use search
                                $(widget.body).find('.principalContainerContextualMenuTAB').attr('isSearched', true);

                                $(this).hide();
                                $(this).find('>div>#unselectedIcon').show();
                                $(this).find('>div>#selectedIcon').hide()
                            } else {
                                $(this).parent().show();
                                $(this).show();
                                $(this).find('>div>#unselectedIcon').hide();
                                $(this).find('>div>#selectedIcon').show()
                            }
                        });

                        //if child is visible show parent
                        $(widget.body).find('#itemsVerticalMenu li').each(function () {
                            var anyVisible = false;

                            //search if parent have childs visible
                            $(this).find('>ul>li').each(function () {
                                if ($(this).is(':visible')) {
                                    anyVisible = true
                                }
                            });

                            //if parent have visible childs it is shown
                            if (anyVisible) {
                                $(this).find('>div>#unselectedIcon').hide();
                                $(this).find('>div>#selectedIcon').show()
                            } else {
                                $(this).find('>div>#unselectedIcon').show();
                                $(this).find('>div>#selectedIcon').hide()
                            }
                        })
                    } else {
                        //hide if not equals with menu text
                        if ($(widget.body).find('.principalContainerContextualMenuTAB').attr('isSearched') == 'true') {
                            $(widget.body).find('.principalContainerContextualMenuTAB').attr('isSearched', false);
                            resetList(widget)
                        }
                    }
                }, 500)

            })
        }

        /**
         * Load menu
         *
         * @param {String} widget
         * @returns void
         */
        function load(widget) {
            subscribe(widget);
            getMenuData(widget);
        }


        /**
         * Set visibility on first visualization
         *
         * @param {String} widget
         * @returns void
         */
        function resetList(widget) {
            $(widget.body).find('#itemsVerticalMenu>ul').find('ul').show();
            $(widget.body).find('#itemsVerticalMenu>ul').find('li').show();
            collapseRecursiveChildren($(widget.body).find('#itemsVerticalMenu>ul').children('li').children('ul'))
        }

        /**
         *
         * @param {String} urlStr
         * @returns String
         */
        function relativeUrl(urlStr) {
            var hash = urlStr;
            //SEPARO EL HASH DE LA URL PARA IE7
            hash = hash.replace(/^.*?#(.*?)$/, "#$1");
            hash = hash.substring(1, hash.length);
            return hash;
        }

        /**
         * Set click function on all items.
         *
         * @param {String} widget
         * @param {HTMLElement} value
         * @returns void
         */
        function configRecursiveChildren(widget, value) {
            if (value.find('>ul').children('li').length > 0) {

                setClickMenuItem(widget, value);

                value.find('>ul').children('li').each(function () {
                    configRecursiveChildren(widget, $(this))
                })
            } else {
                setClickMenuItem(widget, value);
            }
        }

        /**
         * Click function of item menu
         *
         * @param {String} widget
         * @param {HTMLElement} value
         * @returns void
         */
        function setClickMenuItem(widget, value) {
            value.find('>div').off('click');
            value.find('>div').on('click', function (event) {
                if (event.preventDefault) {
                    event.preventDefault();
                } else {
                    event.returnValue = false;
                }

                if (!$(this).next('ul').is(':visible')) {
                    //onClick visible the items
                    showElements(widget, $(this));
                    if (!_usingFilter) {
                        publishToWidget($(this).find('>a').attr('channel'), relativeUrl($(this).find('>a').attr('href')));
                    }
                } else {
                    //onClick hide the items
                    collapseRecursiveChildren($(this).next('ul'))
                }
            })
        }


        /**
         * Collapse all items
         *
         * @param {HTMLElement} value
         * @returns void
         */
        function collapseRecursiveChildren(value) {

            hideElements(value);
            if (value.children('li').length > 0) {
                value.children('li').each(function () {
                    collapseRecursiveChildren($(this).children('ul'))
                })
            }
        }

        /**
         * Show element
         *
         * @param widget
         * @param {Element} value
         * @returns void
         */
        function showElements(widget, value) {
            if (value.parent().find('>div').attr('principal')) {
                collapseRecursiveChildren($(widget.body).find('#itemsVerticalMenu>ul').children('li').children('ul'));
            }
            value.next('ul').attr('visible', 'true');
            value.next('ul').slideDown('slow');
            value.find('>#unselectedIcon').hide();
            value.find('>#selectedIcon').show();
        }

        /**
         * Hide Element.
         *
         * @param {Element} value
         * @returns void
         */
        function hideElements(value) {
            value.removeAttr('visible', 'true');
            value.slideUp('slow');
            value.parent().children().children('#unselectedIcon').show();
            value.parent().children().children('#selectedIcon').hide();
        }

        return {
            init: init,
            publishToWidget: publishToWidget
        };
    })();

    return function(widget) {
        contextualMenuTAB.init(widget);
    };
});

/**
 * @class
 * @memberOf dbesp.footerConfiguration
 * @namespace 
 * @description Functions to manage the footer values. 
 */

define('b-core/widgets/footer/footer', function () {
    'use strict';
    var footerConfiguration = (function () {
        var rootURL = dbesp.contextRoot + "/rest/footer";
        var isLang = false;
        var jsName = "core-footer";

        function createUtilities(jsonIterator) {
            var idDiv = '.utilitiesFooter';
            var data;

            if (jsonIterator) {
                var li = '';
                var path = '';
                var ulIni = '<ul id="list_utility_footer" class="horNav">';
                var ulEnd = '</ul>';
                for (var i = 0; i < jsonIterator.length; i++) {
                    var uItem = jsonIterator[i];
                    //check if element is visible or not
                    if (uItem.enabled) {
                        //check the type of element
                        if (uItem.type == dbesp.UTILITY_TYPE_NO_LINK) {
                            li = '<li>' + uItem.displayedName + '</li>';
                        } else if (uItem.type == dbesp.UTILITY_TYPE_EXTERNAL_LINK) {
                            path = uItem.path;
                            path = path.toLowerCase();
                            if (path.indexOf('http://') < 0) {
                                path = 'http://' + uItem.path;
                            }
                            li = '<li> <a href="' + path + '">' + uItem.displayedName + '</a></li>';

                        } else if (uItem.type == dbesp.UTILITY_TYPE_INTERNAL_LINK) {
                            li = '<li> <a href="' + uItem.path + '">' + uItem.displayedName + '</a></li>';

                        } else if (uItem.type == dbesp.UTILITY_TYPE_FILE) {
                            li = '<li> <a href="' + uItem.path + '>' + uItem.displayedName + '</a></li>';

                        } else if (uItem.type == dbesp.UTILITY_TYPE_LANG) {
                            isLang = true;
                            li = '<li> <a href="#" class="lang" language="' + uItem.description + '">' + uItem.displayedName + '</a></li>';

                        } else {
                            li = null;
                            dbesp.log.debug('core-header.createUtilities', 'Type of utility is not valid : ' + uItem.type);
                        }
                    }
                }
                data = ulIni + li + ulEnd
            }
            $(idDiv).html(data);

        }

        function createStaticContent(content) {
            var idDiv = '.contentFooter';
            var data;
            data = content;
            $(idDiv).html(data);
        }

        function writeFooter() {
            //alert("Writing footer")
            $.ajax({
                type: 'GET',
                contentType: 'application/json',
                url: rootURL,
                cache: false,
                //processData: false,
                success: function (data) {
                    //alert("");
                    if (data != null && data.footer != null && data.footer.several != null) {
                        if (data.footer.several.footerUtilities != null && data.footer.several.footerUtilities.utilityItem != null) {
                            createUtilities(data.footer.several.footerUtilities.utilityItem);
                        }
                        if (data.footer.several.staticContent != null) {
                            createStaticContent(data.footer.several.staticContent);
                        }
                    }

                    if (isLang) {
                            dbesp.changeLanguage.init();
                    }
                },
                error: function (xhr, textStatus, errorThrown) {
                        dbesp.log.error(jsName + '.writeFooter', 'Error :' + textStatus + ' , ' + errorThrown);
                }

            });

        }

        function subscribe() {
            $.subscribe(dbesp.i18n.changeLanguageEventName, function (message) {
                dbesp.log.debug(jsName + '.subscribe', 'Listen : ' + message);
                writeFooter();
                return true;
            });
        }

        function init() {
            writeFooter();
            subscribe();
        }


        return {
            init: init
        }

    })();

    return function() {
        footerConfiguration.init();
    };
});
/**
 * @class
 * @memberOf dbesp.headerConfiguration
 * @namespace
 * @description Class to manage the values and parameters for the header.
 */

define('b-core/widgets/header/header', function () {
    'use strict';
    var headerConfiguration = (function () {
        var rootURL = dbesp.contextRoot + "/rest/header";
        var isLang = false;
        var isOvelayLink = false;

        /**
         *
         * @private
         */
        function createPortalName(jsonObject) {
            //identifierName
            var idDiv = '.portalName';
            var data;
            data = jsonObject.portalName;
            $(idDiv).html(data);
            idDiv = ".identifierName";
            data = jsonObject.identifierName;
            $(idDiv).html(data);

        }

        /**
         *
         * @param type name description
         * @param jsonObject name description
         * @private
         */
        function createUserData(type, jsonObject) {
            var idDiv = '.userData';
            var idListUtilities = '.list_utilityH';
            var data;
            var lastConexion = jsonObject.lastConexion;
            //alert (lastConexion);
            if (lastConexion === null || lastConexion === "") {
                lastConexion = new Date();

            }

            if (type === dbesp.TYPE_STYLE_HEADER_BRANDING) {
                data = jsonObject.idUser + '<br/>' + lastConexion;
                $(idDiv).html(data);
            } else if (type === dbesp.TYPE_STYLE_HEADER_CUSTOM) {
                //$(idDiv).remove();
                data = '<li>' + jsonObject.idUser + '</li><li>' + lastConexion + '</li>';
                $(idListUtilities).append(data);
            } else {

            }
            changeUserNameCssIfHasRoleAdmin($(idDiv));
        }

        /*
         *  If logged-on user is ADMIN, the user name div class is changed so that it looks like a warning
         */
        function changeUserNameCssIfHasRoleAdmin(div) {
        	if (div) {
	        	// This feature is enabled/disabled by configuration. By default, if the property is empty or has any
        		// value different from 'true', we consider it disabled.
	            dbesp.configService.getParameter('loggedOnAdminAlert.enabled', function(paramValue) {
	            	if (paramValue && paramValue.toLowerCase() == 'true' && isLoggedOnUserAdmin()) {
	            		div.addClass('b-core-header-admin-user');
	            	}
		        });
        	}
        }
        
        function isLoggedOnUserAdmin() {
        	var isAdmin = false;
            if (dbesp.userGroupName) {
	        	var groups = dbesp.userGroupName.split(',');
	        	for (var i=0; i < groups.lenght; i++) {
	        		var group = groups[i];
	        		if (group.indexOf('role_') >= 0) {
	        			var groupParts = group.split('role_');
	        			if (groupParts.length > 1) {
	        				if (new String('ADMIN').toLowerCase() == groupParts[1].toLowerCase()) {
	        					isAdmin = true;
	        					break;
	        				}
	        			}
	        		}
	        	}
            }
        	return isAdmin;
        }
        
        /**
         *
         * @param object
         * @private
         */
        function createOverlayLink(object) {
            var path = object.path;
            isOvelayLink = true;
            return '<li> <a href="' + path + '" rel=\".overlay\">' + object.displayedName + '</a></li>';

        }

        /**
         *
         * @private
         */
        function createLi(uItem) {
            //alert ('uitem\n' + uItem.enabled + '\n' + uItem.displayedName);
            var pathStr = '';
            var pathStrLC = '';
            var li = '';
            //check if element is visible or not
            if (uItem.enabled) {
                //check the type of element
                pathStr = $.trim(uItem.path);
                if (uItem.type == dbesp.UTILITY_TYPE_OVERLAY_LINK) {
                    li = li + createOverlayLink(uItem);
                } else if (uItem.type == dbesp.UTILITY_TYPE_NO_LINK) {
                    li = '<li>' + uItem.displayedName + '</li>';
                } else if (uItem.type == dbesp.UTILITY_TYPE_EXTERNAL_LINK) {
                    pathStrLC = pathStr.toLowerCase();
                    if ((pathStrLC.indexOf('http://') < 0) && (pathStrLC.indexOf('https://') < 0)) {
                        pathStr = 'http://' + pathStr;
                    }
                    li = '<li> <a href="' + pathStr + '" target="_blank">' + uItem.displayedName + '</a></li>';

                } else if (uItem.type == dbesp.UTILITY_TYPE_INTERNAL_LINK) {
                    li = '<li> <a href="' + pathStr + '">' + uItem.displayedName + '</a></li>';

                } else if (uItem.type == dbesp.UTILITY_TYPE_FILE) {
                    li = '<li> <a href="' + pathStr + '>' + uItem.displayedName + '</a></li>';

                } else if (uItem.type == dbesp.UTILITY_TYPE_LANG) {
                    isLang = true;
                    li = '<li> <a href="#" class="lang" language="' + uItem.description + '">' + uItem.displayedName + '</a></li>';
                } else if (uItem.type == dbesp.UTILITY_TYPE_LANG_SELECTED) {
                    isLang = true;
                    li = '<li> <span class="active">' + uItem.displayedName + '</span></li>';
                } else if (uItem.type == dbesp.UTILITY_TYPE_LOGOUT_LINK) {
                    li = '<li> <a href="' + pathStr + '" ><span style="color:red">' + uItem.displayedName + '</span></a></li>';

                } else {
                    li = null;
                    dbesp.log.debug('core-header.createUtilities', 'Type of utility is not valid : ' + uItem.type);
                }
            }
            return li;
        }

        /**
         *
         * @private
         */
        function createUtilities(jsonIterator) {
            var idDiv = '.utilitiesHeader';
            var data;

            if (jsonIterator) {
                var li = '';
                var ulIni = '<ul id="list_utilityH" class="horNav">';
                var ulEnd = '</ul>';
                //check if is iterator or only has one element
                if (jsonIterator.length != undefined) {
                    for (var i = 0; i < jsonIterator.length; i++) {
                        var uItem = jsonIterator[i];
                        var auxLi = createLi(uItem);
                        if (auxLi != null) {
                            li = li + auxLi;
                        }
                    }
                } else {
                    li = li + createLi(jsonIterator);
                }
                data = ulIni + li + ulEnd
            }
            $(idDiv).html(data);

        }

        /**
         *
         * @private
         */
        function createLinks(jsonIterator) {
            var idDiv = '.linksHeader';
            var data;

            if (jsonIterator) {
                var li = '';
                var ulIni = '<ul id="list_linksH" class="horNav">';
                var ulEnd = '</ul>';
                //check if is iterator or only has one element
                if (jsonIterator.length != undefined) {
                    for (var i = 0; i < jsonIterator.length; i++) {
                        var uItem = jsonIterator[i];
                        li = li + createLi(uItem);
                    }
                } else {
                    li = li + createLi(jsonIterator);
                }
                data = ulIni + li + ulEnd
            }
            $(idDiv).html(data);

        }

        /**
         *
         * @private
         */
        function modifieAlign(type) {
            if (type == dbesp.TYPE_STYLE_HEADER_BRANDING) {
                //$(idDiv).addClass(".portal-external-group"); 
            } else if (type == dbesp.TYPE_STYLE_HEADER_CUSTOM) {
                $('.centralPart').removeClass("portal-external-group").addClass("portal-external-group-custom");
                $(".utilitiesHeader").removeClass("portal-external-utilities").addClass("portal-external-utilities-custom");
            }
        }

        /**
         *
         * @private
         */
        function writeHeader() {

            $.ajax({
                type: 'GET',
                contentType: 'application/json',
                url: rootURL,
                //processData: false,
                cache: false,
                success: function (data) {
                    modifieAlign(data.commonHeader.styleHeader.type);
                    createPortalName(data.commonHeader.several.generalPortal);
                    createUtilities(data.commonHeader.several.headerUtilities.utilityItem);
                    createLinks(data.commonHeader.several.headerLinks.utilityItem);
                    createUserData(data.commonHeader.styleHeader.type, data.commonHeader.userData);

                    if (isLang) {
                        dbesp.changeLanguage.init();
                    }
                    if (isOvelayLink) {
                        var htmlExternal;
                        htmlExternal = '<div class="apple_overlay" id="overlay">';
                        htmlExternal = htmlExternal + '<!-- the external content is loaded inside this tag -->';
                        htmlExternal = htmlExternal + '<div class="contentWrap"></div>';
                        htmlExternal = htmlExternal + '</div>';
                        $('.utilitiesHeader').append(htmlExternal);
                        dbesp.overlay.overlayThis();
                    }
                    if (data.commonHeader.error && data.commonHeader.error.text != '') {
                        //window.location.href =dbesp.contextRoot + "/errorPage/session.jsp";
                        dbesp.overlay.showMsg(data.commonHeader.error.text, false);
                    }
                },
                error: function (jqXHR, textStatus, errorThrown) {
                    dbesp.log.error('core-header.writeHeader', 'Error :' + textStatus + ' , ' + errorThrown);
                    //thrownError is an event.
//                var event = jqXHR.responseText;
//                dbesp.errorHandler.printEventToHeader(event);
                    //Execute the custom onError callback.
//                onError();
                }
            });

        }

        /**
         * Function to initialize the renderization of the Header.
         */
        function init() {

            writeHeader();
            $.subscribe(dbesp.i18n.changeLanguageEventName, function (message) {
                dbesp.log.debug('core-header.init', 'Listen : ' + message);
                writeHeader();
                return true;
            });

        }

        return {
            init: init
        }

    })();
    return function (widget) {
        headerConfiguration.init();
    };
});
/**
 * @class
 * @memberOf dbesp.headerDBDirect
 * @namespace 
 * @description Class to manage the values and parameters for the dbdirect header.
 */
define('b-core/widgets/headerDBD/headerDBD', function () {

    var headerDBDirect = (function () {

        var rootURL = dbesp.contextRoot + "/rest/headerdbdirect";
        var isLang = false;
        var isOvelayLink = false;
        var idDivContact = "#dbdirect_contact_text";
        var idDivPhone = "#dbdirect_contact_phone";
        var idDivUtilities = '#dbdirect_utilities';
        var idDivUserInfo = '#dbd_user_info';
        var idDivTabs = "#dbd_menu_tabs";

        /**
         * Function to initialize the renderization of the Header.
         */
        function init() {
            checkSession();
            writeHeaderDB();
            $.subscribe(dbesp.i18n.changeLanguageEventName, function (message) {
                dbesp.log.debug('core-header-dbDirect.init', 'Listen : ' + message);
                writeHeaderDB();
                return true;
            },'headerDBD');
            dbesp.changeLanguage.registerWidgetToLanguageChangeMonitoring('dbd-header', $('.bp-widget'));
          
            
        }

        /**
         *
         * @private
         */
        function writeLoader() {
            var data = '<img src="' + dbesp.contextRoot + '/static/b-core/css/img/loader.gif">';

            //contact
            $(idDivContact).html(data);
            $(idDivPhone).html(data);

            //utilities
            $(idDivUtilities).html(data);

            //userInfo
            $(idDivUserInfo).html(data);

            //userInfo
            $(idDivTabs).html(data);
        }

        /**
         *
         * @private
         */
        function writeHeaderDB() {
            writeLoader();
            dbesp.log.info('core-headerDBD.writeHeaderDB', 'rootURL ' + rootURL);
            $.ajax({
                type: 'GET',
                contentType: 'application/json',
                url: rootURL,
                //processData: false,
                cache: false,
                success: function (data) {
                        createUtilities(data.commonHeader.several.headerUtilities.utilityItem);
                        createContact(data.commonHeader.several.contact);
                        createUserData(data.commonHeader.userData);
                        createTabTitles(data.commonHeader.several.tabs.tabItem);

                        if (isLang) {
                        	//dbesp.changeLanguage.init();

                        	dbesp.i18n.registerWidgetLanguageButtons($('.dbd-header'));                          	
                        }

                        if (isOvelayLink) {
                            var htmlExternal;
                            htmlExternal = '<div class="apple_overlay" id="overlay">';
                            htmlExternal = htmlExternal + '<!-- the external content is loaded inside this tag -->';
                            htmlExternal = htmlExternal + '<div class="contentWrap"></div>';
                            htmlExternal = htmlExternal + '</div>';
                            $(idDivUtilities).append(htmlExternal);

                            dbesp.overlay.overlayThis();

                        }
     
                        //dbesp.changeLanguage.changeLanguageDOM($('.dbd-header'));
                     
                       
                        return true;
                },
                error: function (jqXHR, textStatus, errorThrown) {
                    dbesp.log.error('core-header-dbDirect.init', 'Error :' + textStatus + ' , ' + errorThrown);
                }
            });
        }

        /**
         *
         * @private
         */
        function createContact(jsonObject) {
            var idDiv = idDivContact;
            var data = jsonObject.contactText + " ";
            $(idDiv).html(data);

            idDiv = idDivPhone;
            data = jsonObject.contactPhone;
            $(idDiv).html(data);

        }

        /**
         *
         * @private
         */
        function createOverlayLink(object) {
            var path = object.path;
            isOvelayLink = true;
            return '<li> <a href="' + path + '" rel=\"#overlay\">' + object.displayedName + '</a></li>';

        }

        /**
         *
         * @private
         */
        function createExternalLink(object) {
            var path = $.trim(object.path);
            var pathStrLC = path.toLowerCase();
            if ((pathStrLC.indexOf('http://') < 0) && (pathStrLC.indexOf('https://') < 0)) {
                path = 'http://' + path;
            }
            return '<li> <a href="' + path + '" target="_blank">' + object.displayedName + '</a></li>';

        }

        /**
         *
         * @private
         */
        function createUtilities(jsonIterator) {
            var idDiv = idDivUtilities;
            var data;
            if (jsonIterator) {
                var li = '';
                var pathStr = '';
                var ulIni = '<ul id="list_dbdUtilies" class="horNav">';
                var ulEnd = '</ul>';
                for (var i = 0; i < jsonIterator.length; i++) {
                    var uItem = jsonIterator[i];
                    //check if element is visible or not
                    pathStr = $.trim(uItem.path);
                    if (pathStr == null || pathStr == '' || pathStr.length < 1) pathStr = '#';
                    if (uItem.enabled) {
                        //check the type of element
                        if (uItem.type == dbesp.UTILITY_TYPE_OVERLAY_LINK) {
                            li = li + createOverlayLink(uItem);
                        } else if (uItem.type == dbesp.UTILITY_TYPE_EXTERNAL_LINK) {
                            li = li + createExternalLink(uItem);

                        } else if (uItem.type == dbesp.UTILITY_TYPE_INTERNAL_LINK) {
                            li = li + '<li> <a href="' + pathStr + '">' + uItem.displayedName + '</a></li>';

                        } else if (uItem.type == dbesp.UTILITY_TYPE_FILE) {
                            li = li + '<li> <a href="' + pathStr + '">' + uItem.displayedName + '</a></li>';

                        } else if (uItem.type == dbesp.UTILITY_TYPE_LANG) {
                            isLang = true;
                            li = li + '<li> <a href="#" class="lang" language="' + uItem.description + '">' + uItem.displayedName + '</a></li>';

                        } else if (uItem.type == dbesp.UTILITY_TYPE_LOGOUT_LINK) {
                            li = li + '<li> <a href="' + pathStr + '" ><span style="color:red">' + uItem.displayedName + '</span></a></li>';

                        } else {
                            dbesp.log.debug('core-header-dbDirect.createUtilities', 'Type of utility is not valid : ' + uItem.type);
                        }
                    }
                }
                data = ulIni + li + ulEnd;
            }
            $(idDiv).html(data);


        }

        /**
         *
         * @private
         */
        function createUserData(jsonObject) {
            var idDiv = idDivUserInfo;
            var data;
            var lastConexion = jsonObject.lastConexion;
            //alert (lastConexion);
            if (lastConexion == null || lastConexion == "") {
                lastConexion = new Date();
            }
            data = jsonObject.idUser + '<br />' + lastConexion;

            $(idDiv).html(data);

        }

        /**
         *
         * @private
         */
        function createTabTitles(jsonIterator) {
            //general div we must create element ul/li to write tabs
            var idDiv = idDivTabs;
            var data;
            if (jsonIterator) {
                var li = '';
                var pathStr = '';
                var pathStrLC = '';
                var ulIni = '<ul id="dbd_tab_menu" class="">';
                var ulEnd = '</ul>';
                for (var i = 0; i < jsonIterator.length; i++) {
                    var uItem = jsonIterator[i];
                    //check if element is visible or not
                    if (uItem.enabled) {
                        //check the type of element
                        li = li + '<li><span class="tab_title">';
                        pathStr = $.trim(uItem.path);
                        if (pathStr == null || pathStr == '' || pathStr.length < 1) pathStr = '#';
                        if (uItem.type == dbesp.UTILITY_TYPE_EXTERNAL_LINK) {
                            pathStrLC = pathStr.toLowerCase();
                            if ((pathStrLC.indexOf('http://') < 0) && (pathStrLC.indexOf('https://') < 0)) {
                                pathStr = 'http://' + pathStr;
                            }
                            li = li + '<a href="' + $.trim(pathStr) + '" target="_blank">' + uItem.displayedName + '</a>';

                        } else if (uItem.type == dbesp.UTILITY_TYPE_INTERNAL_LINK) {
                            li = li + '<a href="' + pathStr + '">' + uItem.displayedName + '</a>';

                        } else if (uItem.type == dbesp.UTILITY_TYPE_FILE) {
                            li = li + '<a href="' + pathStr + '>' + uItem.displayedName + '</a>';

                        } else if (uItem.type == dbesp.UTILITY_TYPE_LANG) {
                            isLang = true;
                            li = li + '<a href="#" class="lang" language="' + uItem.description + '">' + uItem.displayedName + '</a>';

                        } else {
                            dbesp.log.debug('core-header.createTabTitles', 'Type of utility is not valid : ' + uItem.type);
                        }
                        li = li + '</span></li>';
                    }
                }
                data = ulIni + li + ulEnd;
            }
            $(idDiv).html(data);
        }

        /**
         *
         * @private
         */
        function checkSession() {

            // On browser closed, we clean the session
            // Not very trustable, as it also does logout on page refresh, page change, etc...
            /*window.onbeforeunload = function (e) {
             logout.internetLogout();
             };*/

            setInterval(function () {
                require(['./logout'], function (logout) {
                    $.ajax({
                        url: dbesp.contextRoot + '/rest/session',
                        cache: false,
                        requestHeaders: {
                            'If-Modified-Since': 'Sat, 1 Jan 2000 00:00:00 GMT'
                        },
                        success: function (data) {
                            if (data != dbesp.sessionId) {
                                logout.internetLogout();
                            }
                        },
                        error: function () {
                            logout.internetLogout();
                        }
                    });
                });

            }, 22 * 60 * 1000);


        }

        return {
            init: init
        }

    })();

    return function() {
        headerDBDirect.init();
    };
});
define('b-core/widgets/portalmenu/makeCatalogWidget', function () {
    'use strict';

    var widget = {
        //        isCatalog : true,//Relevant?¿?
        catalogName: "",
        categoriesObj: null,
        list: null,
        widgets: [],
        widgetsJSON: null,
        preferedArea: 0,
        preferedOrder: 0,
        isInstantiable: function (categories) {
            //indexOf returns the position of the string in the other string. If not found, it will return -1:
            if (categories.indexOf("NOTINSTANTIABLE") > -1 || categories.indexOf("NOT_CATEGORIZED") > -1) {
                return false;
            }
            return true;

        },
        initialize: function () {
            var This = this;
            var _failGetExcludedPages = function () {
                dbesp.log.warn('core-widgetCatalogBrowser.initialize', 'Failed to retrieve the excluded pages.');
            };
            var _okGetExcludedPages = function (/*String*/excludedPagesWCB) {
                //Define for which pages the widget store is going to be disabled
                if (excludedPagesWCB.indexOf(dbesp.pageName) != -1) {//Not checked as an array with a bucle for better performance.
                    dbesp.log.info("core-widgetCatalogBrowser.initialize", "Widget store disabled.", true);
                } else {
                    document.getElementById("wcb_access").style.display = 'inline';
                    //Attach event to show/hide the widgetstore

                    $('body').on("click", '#wcb_access', function () {
                        This.openCloseWCB();
                    });

                    var callback = function () {
                        $('#ALL').parent().addClass('cat-selected');
                    };
                    This.updateHTML(callback);
                }
            };
            dbesp.configService.getParameter('excludedPagesWCB',
                _okGetExcludedPages,
                _failGetExcludedPages
            );

            // Making sure catalog dropdown stays on top of other widgets
            $(This.htmlNode).css({'z-index': 2});

        },
        openCloseWCB: function () {
            if (document.getElementById("wcb_hidden_div").style.display == 'none') {
                document.getElementById("wcb_hidden_div").style.display = 'block';
                // TODO: DELETE WHEN IE8 will be deprecated
                if ($.browser && $.browser.msie && $.browser.version == "8.0") {
                    $(".level1Navi").css("position", "inherit");
                    $(".be-advancedNav").css("margin", "-18px");
                }
            } else {
                document.getElementById("wcb_hidden_div").style.display = 'none';
                this.catalogFilter("ALL");
                $("#ALL").parent().addClass('cat-selected');
            }
            //level1Navi -> position relative
            //be-advancedNav -> margin -20px
        },
        updateHTML: function (onSuccess) {
            var This = this;
            var portalServer = _portal;//b$.portal.portalServer;
            //Call the catalog for the widgets to show.
            $.ajax({
                url: this.getCatalogRequestURL(),
                cache: false,
                success: function (data) {
                    //INFO: Here we have all the widgets filtered
                    var item = portalServer.itemXMLDOC2JSON(data);
                    This.widgetsJSON = item.children;

                    //Sorting the widgets by title
                    This.widgetsJSON.sort(
                        function (a, b) {
                            var ta = This.getValue(a.preferences['title']);
                            var tb = This.getValue(b.preferences['title']);
                            return ta > tb ? 1 : ta < tb ? -1 : 0;
                        }
                    );

                    This.buildWidgetsCatalog(This.widgetsJSON);
                    if (onSuccess && typeof(onSuccess) === "function") {
                        onSuccess();
                    }
                },
                error: function (jqXHR, textStatus, errorThrown) {
                    dbesp.log.error("core-widgetCatalogBrowser.updateHTML", "An error occurred when we tried to get the catalog data. \n Error: " + errorThrown, true);
                }
            });

        },
        buildWidgetsCatalog: function (jsonData) {

            var _wcb =
                '<div id="wcb_widgets_catalog" class="wcb_widgets_catalog">'
                + '<ul class="wcb_widgets_catalog_ul">'
                + '<li class="wcb_widgets_catalog_li cat-col col_title">Categories</li>'
                + '<li class="wcb_widgets_catalog_li widget-col col_title">Select a widget</li>'
                + '<li class="wcb_widgets_catalog_li cat-col"><div class="wcb_div_col_cat">' + this.createListCategories(jsonData) + '</div></li>'
                + '<li class="wcb_widgets_catalog_li widget-col"><div class="wcb_div_col_widgets">' + this.createTableThumbnails(jsonData) + '</div></li>'
                + '</ul>'
                + '</div>';

            $("#wcb_widgets_catalog").remove();
            $("#wcb_hidden_div").append(_wcb);
            this.attachEvents();

        },
        createTableThumbnails: function (jsonData) {
            //
            //   Create a table with the thumbnails of the widgets. (Three columns)
            //
            var _thumbnails = '';
            var i = 0;
            for (; i < jsonData.length; i++) {
                if (jsonData[i].tags['category'] && jsonData[i].tags['category'].value && this.isInstantiable(jsonData[i].tags['category'].value)) {
                    _thumbnails += '<li class="wcb_col_widget_li">' + this.createTableWidget(jsonData[i]) + '</li>';
                }
            }

            return '<ul class="wcb_col_widget_ul">' + _thumbnails + '</ul>';
        },
        createListCategories: function (jsonData) {
            //
            //   Create a table with the categories of the widgets.
            //
            var categories = "";
            var all_widgets = "ALL";

            //We make use of the GLOBAL variable list to save some information about the widgets in categories.
            if (!this.categoriesObj) {
                this.list = [];
                this.categoriesObj = {};
                var i = 0;
                this.categoriesObj[all_widgets] = {};
                this.categoriesObj[all_widgets].count = 0;
                this.categoriesObj[all_widgets].category = all_widgets;
                this.list.push(all_widgets);
                var widgetsName = '';
                var separator = ' ';
                var error = false;
                for (; i < jsonData.length; i++) {
                    if (jsonData[i].tags['category'] && jsonData[i].tags['category'].value && this.isInstantiable(jsonData[i].tags['category'].value)) {
                        this.categoriesObj[all_widgets].count++;
                        var cats = jsonData[i].tags['category'].value.split(",");

                        for (var j = 0; j < cats.length; j++) {
                            var cat = cats[j];

                            if (!this.categoriesObj[cat]) {
                                this.list.push(cat);
                                this.categoriesObj[cat] = {};
                                this.categoriesObj[cat].count = 0;
                                this.categoriesObj[cat].category = cat;

                            }
                            this.categoriesObj[cat].count++;
                        }
                    } else {
                        //No category found.
                        var _name = jsonData[i].preferences['title'] && jsonData[i].preferences['title'].value ? jsonData[i].preferences['title'].value + ' ' : '';
                        widgetsName += _name + separator;
                        error = true;
                        //dbesp.log.error("core-widgetCatalogBrowser.createListCategories", "The widget " + _name + "has no category defined, it wouldn't be included in the widget store.",true);
                    }
                }
                if (error) {
                    dbesp.log.errorServer("core-widgetCatalogBrowser.checkPermisions", "INFO", "WIDGET_NOT_CATEGORY_ERROR", widgetsName);
                }


                this.list.sort();
            }

            //We create the table of categories using the GLOBAL variable list.

            for (i = 0; i < this.list.length; i++) {
                var item = this.list[i];
                var itemId = dbesp.utils.misc.replaceAll(item, " ", "_");
                //alert(itemId);
                categories += '<li class="wcb_col_cat_li">';
                categories += '<a href="#" id="' + itemId + '">' + item + '  <font color="grey">[' + this.categoriesObj[item].count + ']</font></a>';
                categories += '</li>';
            }

            return '<ul class="wcb_col_cat_ul">' + categories + '</ul>';

        },
        createTableWidget: function (json) {

            var imgSrc = this.getValue(json.preferences['thumbnailUrl'], "not_defined");
            imgSrc = imgSrc.replace("$(contextRoot)", dbesp.contextRoot);

            if (json.preferences['area'] && this.preferedArea < json.preferences['area'].value) {
                this.preferedArea = json.preferences['area'].value;
            }
            if (json.preferences['order'] && this.preferedOrder < json.preferences['order'].value) {
                this.preferedOrder = json.preferences['order'].value;
            }

            //We are going to truncate the description to a 20 char maximum.
            var _title = this.getValue(json.preferences['title'], "none").substring(0, 20);
            //We are going to truncate the description to a 48 char maximum.
            var _description = this.getValue(json.preferences['Description'], "none").substring(0, 48);
            var _uuid = json.uuid;

            var widget =
                '<div class="wcb_widget_box"><ul class="wcb_widget_box_ul">'
                + '<li class="wcb_widget_box_li box_thumbnail"><img src="' + imgSrc + '" alt="Default" width="87" height="63"></li>'
                + '<li class="wcb_widget_box_li box_title">' + _title + '</li>'
                + '<li class="wcb_widget_box_li box_description">' + _description + '</li>'
                + '<li class="wcb_widget_box_li box_button"><input type="button" value="add" style="height: 25px; width: 90px" '
                + ' id="' + _uuid + '";"/></li>'
                + '</ul></div>';

            this.widgets[_uuid] = _uuid;

            return widget;
        },
        catalogFilter: function (catalogName, onSuccess) {
            if (catalogName == "ALL") {
                catalogName = "";
            }
            this.catalogName = catalogName;
            this.updateHTML(onSuccess);
        },
        attachEvents: function () {
            var This = this;
            for (var i = 0; i < this.list.length; i++) {
                var cat = this.list[i];
                var catId = dbesp.utils.misc.replaceAll(cat, " ", "_");
                var $catId = $("#" + catId);
                //$("#" + catId).click(function() {
                $catId.on('click', function () {
                    //Change style to old
                    $('.cat-selected').removeClass('cat-selected');

                    //Change style.
                    var _id = dbesp.utils.misc.replaceAll(this.id, " ", "_");
                    //alert("_id " + _id);
                    var callback = function () {
                        $('#' + _id).parent().addClass('cat-selected');
                    };

                    //Do the needed filtering.
                    This.catalogFilter(this.id, callback);

                });
            }

            for (var uuid in this.widgets) {
                var $uuid = $("#" + uuid);
                $uuid.on('click', function () {
                    This.insertWidget(this.id);
                });
            }
        },
        insertWidget: function (uuid) {
            var This = this;
            var jSon = this.widgetsJSON;
            var jSonWidget = null;
            for (var i = 0; i < jSon.length; i++) {
                if (jSon[i].uuid === uuid) {
                    jSonWidget = jSon[i];
                }
            }

            //Check if he has auth on this page and more...
            if (this.checkPermisions(jSonWidget)) {

                var contextItemName = dbesp.portalName;//"testportal"; //Portal Name
                var extendedItemName = this.getValue(jSonWidget.extendedItemName, "not_defined");
                var parentItemName = this.getValue(jSonWidget.parentItemName, "not_defined");
                //TODO: Find the name of the widget with the extended name "jSonWidget.name"
//                dbesp.log.info('TO KNOW', b$.portal.config.serverRoot +'/portals/'+ encodeURI(b$.portal.portalName) + '/widgets.xml?f=property.extendedItemName(eq)' + jSonWidget.name + '');
//                $.ajax({
//                    url: b$.portal.config.serverRoot +'/portals/'+ encodeURI(b$.portal.portalName) + '/widgets.xml',
//                    success:function (data){
//                        //List of widgets
//                        for(var i = 0; i < data.childNodes[0].childNodes.length; i++){
//                            xmlDefinitionObject.xmlDefinitionObject(data.childNodes[0].childNodes[i].childNodes);
//                            if (xmlDefinitionObject.extendedItemName == jSonWidget.name){
//                                //jSonWidget.name = xmlDefinitionObject.name;
//                                dbesp.log.info("core-widgetCatalogBrowser.insertWidget", "Widget encontrado con el nombre: " + xmlDefinitionObject.name);
//                                //If we find it, we stop and do things.
//                            }
//                        }
//                    },
//                    error:function(jqXHR, textStatus, errorThrown) {
//                        //alert(textStatus);
//                    }
//                });


                var itemName = this.getValue(jSonWidget.name, "not_defined");
                var pref_TemplateName = this.getValue(jSonWidget.preferences['TemplateName'], "not_defined");
                var pref_Description = this.getValue(jSonWidget.preferences['Description'], "not_defined");
                var pref_title = this.getValue(jSonWidget.preferences['title'], "not_defined");
                //The area and order has to be calculated in some way.
                //If only remains the menu, this functions don't work properly. It puts the widget on top of the menu.
                var pref_area = "";
                var pref_order = "";
                var pref_thumbnailUrl = this.getValue(jSonWidget.preferences['thumbnailUrl'], "not_defined");
                var pref_widgetChrome = this.getValue(jSonWidget.preferences['widgetChrome'], "$(contextRoot)/static/backbase.com.2012.aurora/html/chromes/widget_default.html");
                var pref_src = this.getValue(jSonWidget.preferences['src'], "not_defined");//"$(contextRoot)/static/testportal/widgets/branding/index.html";

                var securityProfile = this.getValue(jSonWidget.securityProfile, "not_defined");//"ADMIN";//ROLE?¿?

                var json = '{"tag":"widget",'
                    + '"contextItemName":"' + contextItemName + '",'
                    + '"extendedItemName":"' + extendedItemName + '",'
                    + '"parentItemName":"' + parentItemName + '",'
                    + '"name":"' + itemName + '",'
                    + '"preferences":{'
                    + '"TemplateName":{"name":"TemplateName","itemName":"' + itemName + '","label":"","viewHint":"","value":"' + pref_TemplateName + '","type":"string"},'
                    + '"Description":{"name":"Description","itemName":"' + itemName + '","label":"","viewHint":"","value":"' + pref_Description + '","type":"string"},'
                    + '"title":{"name":"title","itemName":"' + itemName + '","label":"","viewHint":"","value":"' + pref_title + '","type":"string"},'
                    + '"area":{"name":"area","itemName":"' + itemName + '","label":"","viewHint":"","value":"' + pref_area + '","type":"string"},'
                    + '"order":{"name":"order","itemName":"' + itemName + '","label":"","viewHint":"","value":"' + pref_order + '","type":"double"},'
                    + '"thumbnailUrl":{"name":"thumbnailUrl","itemName":"' + itemName + '","label":"","viewHint":"","value":"' + pref_thumbnailUrl + '","type":"string"},'
                    + '"widgetChrome":{"name":"widgetChrome","itemName":"' + itemName + '","label":"Widget Chrome","viewHint":"","value":"' + pref_widgetChrome + '","type":"string"},'
                    + '"src":{"name":"src","itemName":"' + itemName + '","label":"","viewHint":"","value":"' + pref_src + '","type":"string"}'
                    + '},'
                    + '"securityProfile":"' + securityProfile + '",'
                    + '"uuid":"' + uuid + '"}';

                //B.dragOptions.htmlNode.catalogItemJson
                //var json = '{"tag":"widget","contextItemName":"testportal","extendedItemName":"","parentItemName":"","name":"brandingWidget","preferences":{"TemplateName":{"name":"TemplateName","itemName":"brandingWidget","label":"","viewHint":"","value":"Standard_Widget","type":"string"},"Description":{"name":"Description","itemName":"brandingWidget","label":"","viewHint":"","value":"Widget for testing change of style in portal","type":"string"},"title":{"name":"title","itemName":"brandingWidget","label":"","viewHint":"","value":"Branding","type":"string"},"area":{"name":"area","itemName":"brandingWidget","label":"","viewHint":"","value":"1","type":"string"},"order":{"name":"order","itemName":"brandingWidget","label":"","viewHint":"","value":"2.0","type":"double"},"thumbnailUrl":{"name":"thumbnailUrl","itemName":"brandingWidget","label":"","viewHint":"","value":"$(contextRoot)/static/dashboard/media/icons/icons-widgets_01-default.png","type":"string"},"widgetChrome":{"name":"widgetChrome","itemName":"brandingWidget","label":"Widget Chrome","viewHint":"","value":"$(contextRoot)/static/backbase.com.2012.aurora/html/chromes/widget_default.html","type":"string"},"src":{"name":"src","itemName":"brandingWidget","label":"","viewHint":"","value":"$(contextRoot)/static/testportal/widgets/branding/index.html","type":"string"}},"securityProfile":"ADMIN","uuid":"' + uuid + '"}';
                var jsonObj = JSON.parse(json);

                //Dinamic model.
                var containerName = "";
                if (dbesp.IS_UNIPAGE_PORTAL) {
                    containerName = dbesp.utils.navigation.getSelectedTab();
                } else {
                    containerName = dbesp.widgetContainerCenter.getWidgetContainerCenter();
                }
                var C = this.ownerDocument.all['VIEW-' + containerName].model;
                var D = C.createExtendedElementFromJSON(jsonObj);
                pref_area = This.getAreaPreference();//"2";
                pref_order = This.getOrderPreference();//"10.0";
                D.parentItemName = C.name;
                //D.createPreference("area", pref_area + "", "string");
                //D.createPreference("order", parseFloat(pref_order).toFixed(2), "double");
                D.setPreference("area", pref_area + "");
                D.setPreference("order", parseFloat(pref_order).toFixed(2));
                var w = this.ownerDocument.all['VIEW-' + containerName];
                D.save(function () {
                    This.o(D, w.htmlNode, function () {
                            C.appendChild(D);
							$(w.htmlNode).addClass("bp-TabCont-tab-selected");
                            This.openCloseWCB();
                        },
                        function () {
                            This.openCloseWCB();
                        })
                });
            } else {
                //Here we can close the Widget Store if we wish to.
                this.openCloseWCB();
            }
        },
        getValue: function (obj, ifundefined, name, log) {
            var _default = ifundefined ? ifundefined : '';
            var ret_value = obj ? obj : _default;
            if (!(ret_value.constructor === String)) {
                ret_value = ret_value.value ? ret_value.value : _default;
            }
            if (log && ret_value == _default) {
                dbesp.log.warn("core-widgetCatalogBrowser.getValue", "The value " + name + " is not defined.");
            }
            return ret_value;
        },
        //Function based on one of portal-view.js (BackBase)
        o: function (u, x, w, wrong) {
            var This = this;
            //Added dependency
            var b = b$._private.htmlAPI;
            var s = b$._private.xml;
            //End dependency

            b$.portal.portalServer.loadItemHTML(u.originalItem, function (B) {
                    var A = B.substring(0, B.indexOf("<body>")) + "</html>";
                    var y = B.substring(B.indexOf("<body>") + 6, B.indexOf('<script type="text/backbase-xml'));
                    var C = "";
                    if (B.indexOf('<script type="text/backbase-xml">') !== -1) {
                        C = B.substring(B.indexOf('<script type="text/backbase-xml">') + 33, B.indexOf("<\/script>", B.indexOf('<script type="text/backbase-xml">') + 33))
                    }
                    var z = s.parse(A);
                    b$.portal._private.definition.getResourcesFromDefinition(z, "", function () {
                            var F = b.createElementFromString(y);
                            if (!F) {
                                F = b.createElementFromString("<span>" + y + "</span>")
                            }
                            F.viewController = x.viewController;
                            /*Append new child not rendered*/
							//x.appendChild(F);
                            var D = s.parse(C);
                            var E = b$.portal.portalServer.itemXMLDOC2JSON(D);                            
							//E.htmlNode = F;
							E.htmlNode = "";
                            u.setItem(E);
                            if (w) {
                                w()
                            }
                        }, function () {
                            var F = b.createElementFromString("<span>This part of the page can't be rendered please contact your administrator </span>");
                            F.viewController = x.viewController;
                            x.appendChild(F);
                            var D = s.parse(C);
                            var E = b$.portal.portalServer.itemXMLDOC2JSON(D);
                            u.setItem(E);
                            if (w) {
                                w()
                            }
                        }
                    )
                },
                function (k, obj) {
                    dbesp.log.warn("core-widgetCatalogBrowser.o", "This widget (" + k.name + ") has not been loaded properly, contact the administrator.", true);
                    b$.portal.portalServer.deleteItem(u.originalItem, wrong);
                },
                true
            );
        },
        getAreaPreference: function () {
            var prefArea = this.ownerDocument.all['VIEW-' + dbesp.widgetContainerCenter.getWidgetContainerCenter()].htmlAreas.length - 1;
            return prefArea;
        },
        getOrderPreference: function () {
            var prefArea = this.ownerDocument.all['VIEW-' + dbesp.widgetContainerCenter.getWidgetContainerCenter()].htmlAreas.length - 1;
            var container = this.ownerDocument.all['VIEW-' + dbesp.widgetContainerCenter.getWidgetContainerCenter()].htmlAreas[prefArea];
            var childCount = 0;
            if ('childElementCount' in container) {
                childCount = container.childElementCount;
            }
            else {
                if (container.children) {
                    childCount = container.children.length;
                }
                else {  // Firefox before version 3.5 and IE
                    var child = container.firstChild;
                    while (child) {
                        if (child.nodeType == 1 /*Node.ELEMENT_NODE*/) {
                            childCount++;
                        }
                        child = child.nextSibling;
                    }
                }
            }
            var prefOrder = childCount + 1;
            return prefOrder;
        },
        checkPermisions: function (jSonWidget) {

            //START DEMO LOG
            dbesp.log.info("core-widgetCatalogBrowser.insertWidget", jSonWidget.name, true);

            var logActivaGroup = this.getValue(jSonWidget.preferences['activaGroup'], 'not_defined');
            var logApplication = this.getValue(jSonWidget.preferences['application'], 'not_defined');
            var hasInstantiabilityPref = null;
            
            if(jSonWidget.preferences.instantiability !== undefined){
            	hasInstantiabilityPref = jSonWidget.preferences.instantiability.itemName;
            }
            
            dbesp.log.info(
                "core-widgetCatalogBrowser.insertWidget",
                "WIDGET:: activaGroup: [" + logActivaGroup + "]"
                + ", instantiability: [" + hasInstantiabilityPref + "]"
                + ", application: [" + logApplication + "]"
                , true);
            dbesp.log.info(
                "core-widgetCatalogBrowser.insertWidget",
                "USER:: activaGroup: [" + dbesp.userGroupName + "]"
                + ", application: [" + dbesp.pageName + "]"
                , true);
            //END DEMO LOG

            //If notinsantiable, ERROR.
            if (this.getValue(jSonWidget.preferences['instantiability']).indexOf('notinstantiable') !== -1) {
                dbesp.log.warnServer("core-widgetCatalogBrowser.checkPermisions", "WIDGET_NOT_INSTANTIABLE", jSonWidget.name);
                return false;
                //If pageinsantiable, check APP.
            } else if (this.getValue(jSonWidget.preferences['instantiability']).indexOf('pageinstantiable') !== -1) {
                //If app not found, ERROR.
                if (this.getValue(jSonWidget.preferences['application']).indexOf(dbesp.pageName) !== -1) {
                    dbesp.log.warnServer("core-widgetCatalogBrowser.checkPermisions", "WIDGET_NOT_INSTANTIABLE_IN_PAGE", jSonWidget.name);
                    return false;
                }
                //If portalinsantiable, check activaGroup.
            } else if (this.getValue(jSonWidget.preferences['instantiability']).indexOf('portalinstantiable') !== -1) {
                //If exists activaGroup, check group names
                if (jSonWidget.preferences['activaGroup']) {
                    //If one of our group is not in the list, ERROR.
                    var existsGroup = false;
                    var userGroupName = dbesp.userGroupName.split(",");
                    for (var i = 0; i < userGroupName.length && !existsGroup; i++) {
                        if (this.getValue(jSonWidget.preferences['activaGroup']).indexOf(userGroupName[i]) !== -1) {
                            existsGroup = true;
                        }
                    }
                    if (!existsGroup) {
                        dbesp.log.warnServer("core-widgetCatalogBrowser.checkPermisions", "WIDGET_NOT_INSTANTIABLE_PERMISIONS", jSonWidget.name);
                        return false;
                    }
                }
            } else {
                //dbesp.log.warn("core-widgetCatalogBrowser.checkPermisions", "Instantiability of the widget not properly setted.", true);
                dbesp.log.warnServer("core-widgetCatalogBrowser.checkPermisions", "WIDGET_INSTANTIABILITY_NO_PROPERLY", jSonWidget.name);
                return false;
            }

            return true;
        },
        getCatalogRequestURL: function () {
            var sType = 'WIDGET';//'CONTAINTER'. //Not necessary. We do not have container in the catadbesp.log.
            var sUrl = b$.portal.config.serverRoot + '/portals/' + encodeURI(b$.portal.portalName) + '/catalog.xml?';

            //Add BB filters.
            sUrl += 'f=type(eq)' + sType + '&ps=-1';

            //Add Custom Filter #1.
            sUrl += this.createFilter('category', this.catalogName);
            this.catalogName = '';

            //Add Custom Filter #2.
            //sUrl += this.createFilter('category', this.catalogName);
            //this.catalogName = '';
            console.log(sUrl);
            return sUrl;
        },
        createFilter: function (tag_type, tag_name) {
            var filter = tag_name ? '&f=tag.type(eq)' + tag_type + '&f=tag.name(like)' + tag_name : '';
            return filter;
        }
    };

    var xmlDefinitionObject = {
        name: '',
        contextItemName: '',
        parentItemName: '',
        extendedItemName: '',
        properties: '',
        itemHandlerBeanName: '',
        createdBy: '',
        createdTimestamp: '',
        lastModifiedBy: '',
        lastModifiedTimestamp: '',
        securityProfile: '',
        contents: '',
        tags: '',
        publishState: '',
        uuid: '',
        /**
         * Function to create a xmlDefinition with a list
         * @constructs
         * @private
         * @param {Array} nodeList List with the names and mor
         */
        xmlDefinitionObject: function (/*Array*/nodeList) {


            for (var i = 0; i < nodeList.length; i++) {
                //Usually name is in position 0.
                //Usually parentName is in position 3.

                switch (nodeList[i].tagName) {
                    case "name":
                        this.name = nodeList[i].textContent;
                        break;
                    case "contextItemName":
                        this.contextItemName = nodeList[i].textContent;
                        break;
                    case "parentItemName":
                        this.parentItemName = nodeList[i].textContent;
                        break;
                    case "extendedItemName":
                        this.extendedItemName = nodeList[i].textContent;
                        break;
                    case "properties":
                        this.properties = nodeList[i].textContent;
                        break;
                    case "itemHandlerBeanName":
                        this.itemHandlerBeanName = nodeList[i].textContent;
                        break;
                    case "createdBy":
                        this.createdBy = nodeList[i].textContent;
                        break;
                    case "createdTimestamp":
                        this.createdTimestamp = nodeList[i].textContent;
                        break;
                    case "lastModifiedBy":
                        this.lastModifiedBy = nodeList[i].textContent;
                        break;
                    case "lastModifiedTimestamp":
                        this.lastmodifiedtimestamp = nodeList[i].textContent;
                        break;
                    case "securityProfile":
                        this.securityProfile = nodeList[i].textContent;
                        break;
                    case "contents":
                        this.contents = nodeList[i].textContent;
                        break;
                    case "tags":
                        this.tags = nodeList[i].textContent;
                        break;
                    case "publishState":
                        this.publishState = nodeList[i].textContent;
                        break;
                    case "uuid":
                        this.uuid = nodeList[i].textContent;
                        break;
                }
            }
        }
    };


    var _portal = {

        itemXMLDOC2JSON: function (e) {
            var g = e.documentElement;
            var f = this.itemXML2JSON(g);
            return f;
        },
        itemXML2JSON: function (h) {
            var m = {};
            m.tag = h.tagName;
            if (m.tag == "links") {
                m = this.itemXML2JSON(h.firstChild);
                this.itemChildrenXML2JSON(m, h);
                return m;
            }
            if (m.tag == "portals" || m.tag == "catalog") {
                if (m.tag == "portals") {
                    m.tag = "host";
                }
                this.itemChildrenXML2JSON(m, h);
                return m;
            }
            m.contextItemName = "";
            m.extendedItemName = "";
            m.parentItemName = "";
            var k = h.firstChild;
            while (k) {
                var e = (k.tagName || k.baseName);
                switch (e) {
                    case"name":
                        m.name = k.textContent || k.text;
                        break;
                    case"contextItemName":
                        m.contextItemName = k.textContent || k.text;
                        break;
                    case"extendedItemName":
                        m.extendedItemName = k.textContent || k.text;
                        break;
                    case"parentItemName":
                        m.parentItemName = k.textContent || k.text;
                        break;
                    case"securityProfile":
                        m.securityProfile = k.textContent || k.text;
                        break;
                    case"uuid":
                        m.uuid = k.textContent || k.text;
                        break;
                    case"finalUrl":
                        m.finalUrl = k.textContent || k.text;
                        break;
                    case"properties":
                        m.preferences = {};
                        var g = k.firstChild;
                        while (g) {
                            var j = (g.tagName || g.baseName);
                            switch (j) {
                                case"property":
                                    var l = {};
                                    l.name = g.getAttribute("name");
                                    l.itemName = g.getAttribute("itemName");
                                    l.label = g.getAttribute("label");
                                    if (!l.label) {
                                        l.label = "";
                                    }
                                    l.viewHint = "";
                                    if (g.getAttribute("viewHint")) {
                                        l.viewHint = g.getAttribute("viewHint");
                                    }
                                    var f = g.firstChild;
                                    while (f) {
                                        var i = (f.tagName || f.baseName);
                                        switch (i) {
                                            case"value":
                                                l.value = f.textContent || f.text || "";
                                                l.value = this.decodeXML(l.value);
                                                l.type = f.getAttribute("type");
                                                break;
                                        }
                                        f = f.nextSibling;
                                    }
                                    m.preferences[l.name] = l;
                                    break;
                            }
                            g = g.nextSibling;
                        }
                        break;
                    case"children":
                        m.children = [];
                        var g = k.firstChild;
                        while (g) {
                            if (g.nodeType == 1) {
                                m.children.push(this.itemXML2JSON(g));
                            }
                            g = g.nextSibling;
                        }
                        break;
                    case"tags":
                        m.tags = {};
                        var g = k.firstChild;
                        while (g) {
                            var j = (g.tagName || g.baseName);
                            switch (j) {
                                case"tag":
                                    var l = {};
                                    l.type = g.getAttribute("type");
                                    l.value = g.textContent || g.text || "";
                                    m.tags[l.type] = l;
                                    break;
                            }
                            g = g.nextSibling;
                        }
                        break;
                }
                k = k.nextSibling;
            }
            return m
        },
        itemChildrenXML2JSON: function (g, e) {
            g.children = [];
            var f = e.firstChild;
            while (f) {
                if (f.nodeType == 1) {
                    g.children.push(this.itemXML2JSON(f))
                }
                f = f.nextSibling;
            }
        },
        encodeXML: function (e) {
            return typeof e === "string" ? e.replace(/&/g, "&amp;").replace(/"/g, "&quot;").replace(/</g, "&lt;").replace(/>/g, "&gt;") : e;
        },
        decodeXML: function (e) {
            return typeof e === "string" ? e.replace(/&amp;/g, "&").replace(/&quot;/g, '"').replace(/&lt;/g, "<").replace(/&gt;/g, ">") : e;
        }

    };


    return function (oWidget) {
        b$.mixin(oWidget, widget);
        oWidget.initialize();
    };
});
/**
 * @class
 * @memberOf dbesp.portalmenu
 * @namespace
 * @description Class to manage the control navigation menu.
 */
define('b-core/widgets/portalmenu/portalmenu', ['./resetPreferences', './makeCatalogWidget'],
    function (resetPreferences, makeCatalogWidget) {


    var Portalmenu = dbesp.utils.fn.inherit(function () {
        // Bind this to a variable for private methods to be able
        // to access widget instance
        var widgetInstance = this;
        // Cache body DOM element for faster traversing and limiting context
        var $body = $(widgetInstance.widget.body);

        var title = 'title';
        /**
         *
         * @private
         */
        var rest_getObject = function (objetUri, callback) {
            var url = dbesp.contextRoot + "/portals/" + dbesp.portalName;
            url += "/" + objetUri;
            dbesp.log.debug('core-navigationController.rest_getObject', 'Menu page url: ' + url);
            $.ajax({
                url: url,
                cache: false,
                success: function (data) {
                    if (callback) {
//call to remote xml
// work with JSON, as XML is hasbeen
                        callback(xmlToJson({
                            xml: data
                        }));
                    }
                },
                error: function (jqXHR, textStatus, errorThrown) {
                    dbesp.log.error('core-navigationController.rest_getObject', 'Error obtaining portal pages:' + textStatus + ',' + errorThrown);
                }
            });
        };

        /**
         *
         *
         */
        function subscribe() {
            $.subscribe('changeLanguage', function (message) {
                getPortalPages();
                return true;
            }, widgetInstance.widgetId);
        }

        /**
         *  Function that creates the links for the internal pages in the portal.
         *  @private
         *  @param {Object} elt Object that has the information to create the link.
         */
        function buildLinks(elt) {
            if (dbesp.pageName == elt.name) {
                $body.find(".myPortalNavigation").append($('<li class="active">' + elt.title.replace("_", " ") + '</li>'));
            } else {
                var hrefStr = dbesp.contextRoot + "/portals/" + dbesp.portalName + '/pages/' + elt.name;
                //alert(hrefStr);
                $body.find(".myPortalNavigation").append($('<li><a class="' + elt.name + ' internalNavigation" href="' + hrefStr + '">' + elt.title.replace("_", " ") + '</a></li>'));
            }
        }

        /**
         *
         *
         */
        function getPortalPages() {

// get pages in portal
            rest_getObject("pages.xml?s=createdTimestamp(asc)", function (json) {
// create an array of json object ordered by position
                var res = [];
                // single page
                if (!json.pages.page.length) {
                    var e = json.pages.page;
                    res.push({
                        name: e.name,
                        title: e.properties.Title.value
                    });
                } else {
                    $.each(json.pages.page, function (i, e) {
                        if (typeof(e.properties.Position.value) != "undefined" && e.properties.Position.value) {
                            var ind = parseInt(e.properties.Position.value) - 1;
                            res[ind] = {
                                name: e.name,
                                title: e.properties.Title.value
                            };
                        } else {
                            res.push({
                                name: e.name,
                                title: e.properties.Title.value
                            });
                        }
                    })
                }

                //Build links for internal pages
                $body.find(".myPortalNavigation").html('');
                $.each(res, function (i, elt) {
                    if (elt != null || elt != undefined) {
                        if (dbesp.country == 'it' && elt.name != 'ecdlPage') {
                            dbesp.aAuthorities = dbesp.userGroupName.split(',');
                            for (var j = 0; j < dbesp.aAuthorities.length; j++) {
                                if ((dbesp.aAuthorities[j].indexOf('_') < 0) || (dbesp.aAuthorities[j].indexOf('group_') >= 0 && dbesp.aAuthorities[j].indexOf(dbesp.groupNameDefault) < 0)) {
                                    buildLinks(elt);
                                }
                            }
                        } else {
                            buildLinks(elt)
                        }
                    }
                });
                //Bind onclick event to the links created before.
                $body.find(".myPortalNavigation").on('click', '.internalNavigation', function (event) {
                    if (event.preventDefault) {
                        event.preventDefault();
                    } else {
                        event.returnValue = false;
                    }
                    var _class = event.target.className.replace('internalNavigation', '');

                    //We subscribe to a channel to know if we can leave or not.
                    $.subscribe(dbesp.CHANNEL_PERFORM_NAVIGATION, function (param) {
                        dbesp.utils.navigation.goToPage(param);
                        return true;
                    });

                    //Publish an ALERT to give a page a way to do something before leave. 
                    $.publish(dbesp.CHANNEL_PAGE_NAVIGATION_ALERT, [_class]);

                    //If I do not have subscribers, navigate
                    if (!dbesp.eps.subscribers) {
                        dbesp.utils.navigation.goToPage(_class);
                    }
                    return false;
                });
                //Create external links from configuration
                getLinks();

                //Call to build upperMenu
                //getApplicationMenu();
            });
        }

        /**
         *
         *
         */
        var setup = function () {
            getPortalPages();
            subscribe();
        };

        var isBelongToGroup = function (item) {
            if (item.groups && item.groups.group) {
                if (item.groups.group.length > 0) {
                    dbesp.log.info('[core-navigationController].isBelongToGroup', item.label + " has " + item.groups.group.length + "groups");
                    for (var _r = 0; _r < item.groups.group.length; _r++) {
                        if (dbesp.userGroupName.indexOf(item.groups.group[_r].name) !== -1) {
                            return true;
                        }
                    }
                } else {
                    dbesp.log.info('[core-navigationController].isBelongToGroup', item.label + " has 1 group");
                    if (dbesp.userGroupName.indexOf(item.groups.group.name) !== -1) {
                        return true;
                    }

                }
            } else {
                dbesp.log.info('[core-navigationController].isBelongToGroup', item.label + " has not group");
                return true;
            }

            return false;
        };
        /**
         * Function to get the links from configuration and add them to the menu.
         * @private
         */
        var getLinks = function () {
            $.ajax({
                url: dbesp.contextRoot + '/rest/navigation/menuLinks/' + dbesp.pageName,
                cache: false,
                requestHeaders: {
                    'If-Modified-Since': 'Sat, 1 Jan 2000 00:00:00 GMT'
                },
                success: function (data, textStatus, jqXHR) {
                    //build links
                    if (data && data.menu && data.menu.items) {
                        //check if is iterator or only has one element
                        if (data.menu.items.item && data.menu.items.item.length) {
                            for (var i = 0; i < data.menu.items.item.length; i++) {
                                var item = data.menu.items.item[i];
                                //Check if it belongs to the proper group.
                                var _belongsToGroup = isBelongToGroup(item);

                                //If it belongs to the proper group, we print the link.
                                if (_belongsToGroup) {
                                    var target = "_blank";
                                    if (item.target) {
                                        target = item.target;
                                    }
                                    $body.find(".myPortalNavigation").append($('<li><a href="' + item.link + '" target="' + target + '">' + item.label + '</a></li>'));
                                }
                            }
                        } else if (data.menu.items.item) {
                            var item = data.menu.items.item;
                            //Check if it belongs to the proper group.
                            var _belongsToGroup = isBelongToGroup(item);

                            //If it belongs to the proper group, we print the link.
                            if (_belongsToGroup) {
                                var target = "_blank";
                                if (item.target) {
                                    target = item.target;
                                }
                                $body.find(".myPortalNavigation").append($('<li><a href="' + item.link + '" target="' + target + '">' + item.label + '</a></li>'));
                            }
                        } else {
                            dbesp.log.error('core-navigationController.getLinks', 'data.menu.items is empty');
                        }
                    }
                },
                error: function (data, textStatus, jqXHR) {
                    dbesp.log.error('core-navigationController.getLinks', 'Error getting portal links');
                }
            });
        };

        /**
         * Util function to get application upper menu
         * @param {String} type Type of menu: 'menu', 'stub' or 'local'
         * @param {String} role Role of the user
         * @param {String} app Application name
         */
        var getApplicationMenu = function () {
            // get application menu
            //        var rootRest = dbesp.utils.getRootRest();
            var app = dbesp.portalName;
            var rootRest = dbesp.contextRoot + '/rest/navigation/menu';
            rootRest = rootRest + '/' + loggedInUserId + '/' + dbesp.pageName;
            dbesp.log.info('[core-navigationController].getApplicationMenu', ' rootRest to upperMenu: ' + rootRest);
            $.ajax({
                url: rootRest,
                cache: false,
                requestHeaders: {
                    'If-Modified-Since': 'Sat, 1 Jan 2000 00:00:00 GMT'
                },
                success: function (data, textStatus, jqXHR) {
                    //build links
                    dbesp.log.info('[core-navigationController].getApplicationMenu', 'sucess to upperMenu');
                    $body.find(".myAppNavigation").html('');
                    if (data != null && data.menu != null && data.menu.itemsUpper) {
                        dbesp.log.info('[core-navigationController].getApplicationMenu', 'data.menu.itemsUpper');
                        for (var i = 0; i < data.menu.itemsUpper.item.length; i++) {
                            appendChildUpperMenu(data.menu.itemsUpper.item[i], $body.find(".myAppNavigation"));
                        }
                        $body.find('.bd-nav-hor a').bind('click', function (event) {
                            if (event.preventDefault) {
                                event.preventDefault();
                            } else {
                                event.returnValue = false;
                            }
                            var $el = $(this);
                            if ($el.attr("data-linkType") == dbesp.MENU_LINK_TYPE_MENU) {
                                $.publish(dbesp.CHANNEL_GO_TO_MENU_OPTION, [$el.attr('hrefMenu')]);
                            } else {
                                dbesp.common.contextualMenuController.publishToWidget($el.attr('channel'), $el.attr('href'));
                            }
                        });
                    } else {
                        //remove div if there is no data to show.
                        $body.find(".myAppNavigation").remove();
                    }
                },
                error: function (data, textStatus, jqXHR) {
                    dbesp.log.error('core-navigationController.getApplicationMenu', 'Error getting upper menu:' + app);
                }
            });
        };

        /**
         * Function to build children of upper menu
         * @param item item with menu definition
         * @param appendTo JQuey item with html to append to
         */
        var appendChildUpperMenu = function (item, appendTo) {
            var linkType;
            /*= 'externalLink';
             if (item.style.length >= title.length && item.style.substring(0,title.length) == title) {
             linkType = 'menuHeader';
             }*/
            linkType = item.type;
            var varHref;
            if (linkType != dbesp.MENU_LINK_TYPE_MENU) {
                varHref = 'href="' + item.link + '"';
            } else {
                varHref = 'href="#" hrefMenu= "' + item.link + '"';
            }
            var itemHtml = '<li class="bd-nav-children">' +
                '<a ' + varHref + ' channel="' + item.target + '" class="bd-navPage-link phe-foldoutMenu-head" data-linkType="' + linkType +
                '">' + item.label + '</a></li>';
            var itemJquery = $(itemHtml);
            appendTo.append(itemJquery);
            appendChildrenUpperMenu(item, itemJquery);
        };

        /**
         * Function to build sublevels of upper menu
         * @param item item with menu definition
         * @param appendTo JQuey item with html to append to
         */
        var appendChildrenUpperMenu = function (item, appendTo) {
            if (item.items && item.items.item.length > 0) {
                var ul = $('<ul>');
                appendTo.append(ul);
                for (var i = 0; i < item.items.item.length; i++) {
                    appendChildUpperMenu(item.items.item[i], ul);
                }
                ul = $('</ul>');
                appendTo.append(ul);
            }
        };

        /**
         * Util function from dashboard
         * @param params
         */
        var xmlToJson = function (params) {

            var dataFormatter = params.dataFormatter;
            var xml = params.xml;
            // Create the return object
            var obj = {};
            if (xml.nodeType == 1) { // element
// do attributes
                if (xml.attributes.length > 0) {
                    for (var j = 0; j < xml.attributes.length; j++) {
                        var attribute = xml.attributes.item(j);
                        if (attribute.nodeValue != null && attribute.nodeValue != "")
                            obj[attribute.nodeName] = attribute.nodeValue;
                        //workaround for empty string value with a type produce by the server.
                        //this is breaking the templating engine and the importer
                        if (attribute.nodeName == "type" && attribute.nodeValue == "String" && (xml.nodeValue == null || xml.nodeValue == ""))
                            return null;
                    }
                }
            } else if (xml.nodeType == 3 && xml.nodeValue != null && xml.nodeValue != "") { // text
                obj = xml.nodeValue;
            }

// do children
            if (xml.hasChildNodes()) {
                for (var i = 0; i < xml.childNodes.length; i++) {
                    var item = xml.childNodes.item(i);
                    var nodeName = item.nodeName;
                    if (nodeName == "#text") {
                        if (item.nodeValue != null)
                            obj = item.nodeValue;
                        break;
                    }
                    else if (nodeName == "properties") {
                        obj.properties = {};
                        obj.propertiesArray = [];
                        for (var p = 0; p < item.childNodes.length; p++) {
                            var item2 = item.childNodes.item(p);
                            var nodeName2 = item2.getAttribute("name");
                            var childOjb = xmlToJson({
                                xml: item2,
                                dataFormatter: dataFormatter
                            });
                            obj.properties[nodeName2] = childOjb;
                            obj.propertiesArray.push(childOjb);
                        }

                        if (dataFormatter != null)
                            dataFormatter(obj);
                    }
                    else if (typeof(obj[nodeName]) == "undefined") {
                        obj[nodeName] = xmlToJson({
                            xml: item,
                            dataFormatter: dataFormatter
                        });
                    } else {
                        if (typeof(obj[nodeName].length) == "undefined") {
                            var old = obj[nodeName];
                            obj[nodeName] = [];
                            obj[nodeName].push(old);
                        }
                        obj[nodeName].push(xmlToJson({
                            xml: item,
                            dataFormatter: dataFormatter
                        }));
                    }
                }
            }
            return obj;
        };
        /**
         *   Method that allows to navigate thorugh pages. Optionally it can execute
         *   a function before the navigation.
         *   @param {{}} context
         *   @param {{}} params
         *   @param {Function} doSthBefore Function to execute something before the navigation.
         */
        var navigate = function (context, params, /* Function */doSthBefore) {

            //Execute function before if needed.
            if (doSthBefore) {
                doSthBefore.apply(this);
            }

            //The logic of the old function is in the dbesp.utils.navigation.goToPage function, called by the binding of following 'click'
            $body.find('.myPortalNavigation .' + context).click();
        };

        widgetInstance.navigate = navigate;
        widgetInstance.setup = setup;
    }, dbesp.widgets.BaseWidget);

    return function (bbwidget) {
        resetPreferences.init(bbwidget);
        makeCatalogWidget(bbwidget);
        dbesp.utils.fn.createInstance(Portalmenu, bbwidget).init();
    };
});
/**
* @class 
* @memberOf dbesp.resetPreferences
* @namespace 
* @description The purpose of this function is to allow to manage the reseting 
* of the preferences of the portal. 
*/
define('b-core/widgets/portalmenu/resetPreferences', function () {
    var resetPreferences = (function () {

        // The root URL for the RESTful services for contexts
        var resetRootURL = dbesp.contextRoot + "/rest/reset";

        /**
         * Function to get if a portal has the button reset preferences or not
         * @param {Function} onSuccess Function to execute on a successful operation
         * @param {Function} onError Function to execute on error
         */
        function getHasResetPreferences(/* Function */onSuccess, /* Function */onError) {
            console.log("resetRootURL: " + resetRootURL);
        	$.ajax({
                type: "GET",
                contentType: "text/plain",
                url: resetRootURL,
                dataType: "text",
                cache: false,
                success: function (data){
                	onSuccess && onSuccess(data);
                },
                error: onError
            });
        }

        /**
         * Function to reset the preferences of the given user/portal
         * @param {String} user User that want to reset their preferences.
         * @param {String} portal Portal afected for this reset of preferences.
         * @param {Function} onSuccess Function to execute on a successful operation
         * @param {Function} onError Function to execute on error
         */
        function resetPreferences(/* String */user, /* String */portal, /* Function */onSuccess, /* Function */onError) {
        	console.log("resetPreferences: " + user + " - " + portal);
            $.ajax({
                type: "POST",
                contentType: "text/plain",
                url: resetRootURL + '/' + user + '/' + portal,
                cache: false,
                success: function (data){
                	onSuccess && onSuccess(data);
                },
                error: onError
            });
        }
		
		function itemsFromUserREST(/* String */user, /* String */portal, /* Function */onSuccess, /* Function */onError) {
        	console.log("itemsFromUserREST: " + user + " - " + portal);
        	var extendedItemNameTag = "extendedItemName";
			var div= document.createElement("div");
			div.className += "overlay";
			document.body.appendChild(div);
			
            return $.ajax({
				type: "GET",
				url: dbesp.contextRoot + '/' + 'portals/' + portal + '/widgets/',
				cache: false,
				success: function (data){
					var promises = [], extendedItemNameList = data.getElementsByTagName(extendedItemNameTag);
					for (i = 0; i <extendedItemNameList.length; i++) {
						var item = $(extendedItemNameList[i]).text();
						promises.push(
							$.ajax({
								type: "DELETE",
								url: dbesp.contextRoot + '/' + 'portals/' + portal + '/widgets/' + item + '.xml',
								cache: false,
								success: onSuccess,
								error: onError
							})						
						);
					}
					
					$.when.apply($, promises).then(function() {
						//IN41540710: Clear previous comminication variable in order to be able to land on main page
						dbesp.communication = null;
						//We recharge the main page of the portal.
						setTimeout(function(){
							document.location = dbesp.contextRoot + "/portals/" + dbesp.portalName;
							onSuccess && onSuccess(data);
						},20000);
						
					}, function() {
						// error occurred
						dbesp.communication = null;
						setTimeout(function(){
							document.location = dbesp.contextRoot + "/portals/" + dbesp.portalName;
						},20000);
						dbesp.log.error("core-resetPreferences.itemsFromUserREST", "We couldn't remove some items.");
					});										
				},
				error: onError
			});
        }
		
        /**
         * Function to initialize the Reset button, in case its necessary.
         */
        function init() {
            getHasResetPreferences(
                function (hasReset) {
                    if (hasReset == "true" && dbesp.pageName !== "globalPositionPage") {
                        $(".reset_preferences").show();
                        $(".reset_preferences").bind('click', function () {
                            dbesp.configService.getParameter('confirmMessageResetPreferences',
                                function (message) {
                                    if (confirm(message)) {
                                    	//added div overlay for disable click over the screen until reset preferences function it is done
										var overlay = $('<div id="overlay" style="background-color: white; opacity: 0.5; width: 100%; height: 100%; position: absolute; top: 0;  left: 0; z-index: 1000;" />');
										$('body').append(overlay);										
                                        itemsFromUserREST(dbesp.loggedInUserId, dbesp.portalName,
                                            function () {
                                                dbesp.log.info("core-resetPreferences.init", "The preferences were reseted for the default preferences.");
                                            },
                                            function () {
                                                dbesp.log.error("core-resetPreferences.init", "We could'nt reset the preferences.");
                                            }
                                        );
                                    } else {
                                        dbesp.log.info("core-resetPreferences.init", "The user canceled resetion of preferences.");
                                    }
                                },
                                function () {
                                    dbesp.log.error("core-resetPreferences.init", "We could'nt get the message to confirm reset preferences, so we are going to cancel it.");
                                }
                            );
                        });
                    }
                },
                function () {
                    dbesp.log.error("core-resetPreferences.init", "We could'nt get if the portal has reset preferences, so we are not going to allow it.");
                }
            );
        }

        return {
            getHasResetPreferences: getHasResetPreferences,
            resetPreferences: resetPreferences,
            init: init
        }
    })();

    return resetPreferences;
});

/**
 * @class
 * @memberOf dbesp.portalmenuOnlyUpper
 * @namespace
 * @description Class to manage the upper menu.
 */
define('b-core/widgets/portalmenuOnlyUpper/portalmenuOnlyUpper', function () {
    var portalmenuOnlyUpper = (function () {
    	
    	var txtMyAppNavFilter="#txtMyAppNavigation";
    	var btnUtilityFilter="#btnUtility";
    	var myAppNavigationFilter="#myAppNavigation";


        var init = function (widget) {
        	// TODO: store widget refference and do DOM modifications only in widget. 
//call to build upperMenu
            getApplicationMenu();
            doPrint();
            $(txtMyAppNavFilter).html('<span class=\"lang\" plang=\"menuOnlyUpper.text.myAppNavigation\"></span>');
            dbesp.changeLanguage.changeLanguageDOM($(txtMyAppNavFilter));
            $.subscribe('changeLanguage', function (message) {
                dbesp.log.debug('core-header-dbDirect.init', 'Listen : ' + message);
                getApplicationMenu();
                dbesp.changeLanguage.changeLanguageDOM($(txtMyAppNavFilter));
                dbesp.changeLanguage.changeLanguageDOM($(btnUtilityFilter));
                return true;
            });
        };

        /**
         *
         *
         */
        function doPrint() {
//se manda a imprimir lo que nos digan en el selector
            $.ajax({
                type: 'GET',
                contentType: 'text/plain',
                url: dbesp.contextRoot + "/rest/config/idFramePrint",
                dataType: "text",
                //data: parameter, 
                cache: false,
                success: function (data, textStatus, jqXHR) {
                    if (data && data != null && data != "") {
//var dHtml 
                        dbesp.changeLanguage.changeLanguageDOM($(btnUtilityFilter));
                        document.getElementById('btnUtility').style.visibility = "visible";
                        $('#btnPrint').bind('click', function (event) {
                            if (event.preventDefault) {
                                event.preventDefault();
                            } else {
                                event.returnValue = false;
                            }
                            $.publish("print_channel", ["print"]);
                        });
                    }

                },
                error: function (data, textStatus, jqXHR) {
                    dbesp.log.error('core-navigationController-onlyUpper.getApplicationMenu', 'Error getting print property:' + app);
                }
            });
        }

        /**
         * Util function to get application upper menu
         * @param {String} type Type of menu: 'menu', 'stub' or 'local'
         * @param {String} role Role of the user
         * @param {String} app Application name
         */
        var getApplicationMenu = function () {
// get application menu
            var rootRest = dbesp.contextRoot + '/rest/navigation/menu';
        	
            var app;
            rootRest = rootRest + '/' + dbesp.loggedInUserId + '/' + dbesp.pageName;
            dbesp.log.debug('core-navigationController-onlyUpper.getApplicationMenu', 'RootRest : ' + rootRest);
           // alert("rootRest=" + rootRest);
            $.ajax({
                url: rootRest,
                cache: false,
                requestHeaders: {
                    'If-Modified-Since': 'Sat, 1 Jan 2000 00:00:00 GMT'
                },
                success: function (data, textStatus, jqXHR) {
                	//build links
                	
                    if (data != null && data.menu!= null && data.menu.itemsUpper!= null) {
                
                    	$(myAppNavigationFilter).html('');
      
                        //var itemHtml = '<li class="bd-nav-children-first">ACCESOS DIRECTOS:</li>';
                        //var itemHtml = '<li class="bd-nav-children"><b>ACCESOS DIRECTOS:</b></li>';
                        var itemHtml = '';
                        
                        var itemJquery = $(itemHtml);
                        
                        $(myAppNavigationFilter).append(itemJquery);
                        for (var i = 0; i < data.menu.itemsUpper.item.length; i++) {
                        	//alert("data.menu.itemsUpper.item[i]=" + data.menu.itemsUpper.item[i] );
                            appendChildUpperMenu(data.menu.itemsUpper.item[i], $(myAppNavigationFilter));
                        }
                        $('.bd-nav-hor a').bind('click', function (event) {
                            if (event.preventDefault) {
                                event.preventDefault();
                            } else {
                                event.returnValue = false;
                            }
                            var $el = $(this);
                            if ($el.attr("data-linkType") == dbesp.MENU_LINK_TYPE_MENU) {
                                $.publish(dbesp.CHANNEL_GO_TO_MENU_OPTION, [$el.attr('hrefMenu')]);
                                $el.addClass('selected');
                            } else {
                                dbesp.common.contextualMenuController.publishToWidget($el.attr('channel'),$el.attr('href'));
                                $el.addClass('selected');
                            }
                        });
                    }
                },
                error: function (data, textStatus, jqXHR) {
                    dbesp.log.error('core-navigationController-onlyUpper.getApplicationMenu', 'Error getting upper menu:' + app);
                }
            });
        };

        /**
         * Function to build children of upper menu
         * @param item item with menu definition
         * @param appendTo JQuey item with html to append to
         */
        var appendChildUpperMenu = function (item, appendTo) {
            var linkType;
            /*= 'externalLink';
             if (item.style.length >= title.length && item.style.substring(0,title.length) == title) {
             linkType = 'menuHeader';
             }*/
            linkType = item.type;
            var varHref;
            if (linkType != dbesp.MENU_LINK_TYPE_MENU) {
                varHref = 'href="' + item.link + '"';
            } else {
                varHref = 'href="#" hrefMenu= "' + item.link + '"'
            }
            var itemHtml = '<li class="bd-nav-children">' +
                '<a ' + varHref + ' channel="' + item.target + '" class="bd-navPage-link phe-foldoutMenu-head" data-linkType="' + linkType +
                '">' + item.label + '</a></li>';
            var itemJquery = $(itemHtml);
            appendTo.append(itemJquery);
           // appendChildrenUpperMenu(item, itemJquery); infinite recursive function
        };

        /**
         * Function to build sublevels of upper menu
         * @param item item with menu definition
         * @param appendTo JQuey item with html to append to
         */
        var appendChildrenUpperMenu = function (item, appendTo) {
            if (item.items && item.items.item.length > 0) {
                var ul = $('<ul>');
                appendTo.append(ul);
                for (var i = 0; i < item.items.item.length; i++) {
                    appendChildUpperMenu(item.items.item[i], ul);
                }
                ul = $('</ul>');
                appendTo.append(ul);
            }else  if (item &&  item.items.length == 0){
            	var ul = $('<ul>');
	            appendTo.append(ul);
	            appendChildUpperMenu(item, ul);
	            ul = $('</ul>');
	            appendTo.append(ul);
            }
        };

        /**
         * Util function from dashboard
         * @param params
         */
        var xmlToJson = function (params) {

            var dataFormatter = params.dataFormatter;
            var xml = params.xml;
            // Create the return object
            var obj = {};
            if (xml.nodeType == 1) { // element
// do attributes
                if (xml.attributes.length > 0) {
                    for (var j = 0; j < xml.attributes.length; j++) {
                        var attribute = xml.attributes.item(j);
                        if (attribute.nodeValue != null && attribute.nodeValue != "")
                            obj[attribute.nodeName] = attribute.nodeValue;
                        //workaround for empty string value with a type produce by the server.
                        //this is breaking the templating engine and the importer
                        if (attribute.nodeName == "type" && attribute.nodeValue == "String" && (xml.nodeValue == null || xml.nodeValue == ""))
                            return null;
                    }
                }
            } else if (xml.nodeType == 3 && xml.nodeValue != null && xml.nodeValue != "") { // text
                obj = xml.nodeValue;
            }

// do children
            if (xml.hasChildNodes()) {
                for (var i = 0; i < xml.childNodes.length; i++) {
                    var item = xml.childNodes.item(i);
                    var nodeName = item.nodeName;
                    if (nodeName == "#text") {
                        if (item.nodeValue != null)
                            obj = item.nodeValue;
                        break;
                    }
                    else if (nodeName == "properties") {
                        obj.properties = {};
                        obj.propertiesArray = [];
                        for (var p = 0; p < item.childNodes.length; p++) {
                            var item2 = item.childNodes.item(p);
                            var nodeName2 = item2.getAttribute("name");
                            var childOjb = xmlToJson({
                                xml: item2,
                                dataFormatter: dataFormatter
                            });
                            obj.properties[nodeName2] = childOjb;
                            obj.propertiesArray.push(childOjb);
                        }

                        if (dataFormatter != null)
                            dataFormatter(obj);
                    }
                    else if (typeof(obj[nodeName]) == "undefined") {
                        obj[nodeName] = xmlToJson({
                            xml: item,
                            dataFormatter: dataFormatter
                        });
                    } else {
                        if (typeof(obj[nodeName].length) == "undefined") {
                            var old = obj[nodeName];
                            obj[nodeName] = [];
                            obj[nodeName].push(old);
                        }
                        obj[nodeName].push(xmlToJson({
                            xml: item,
                            dataFormatter: dataFormatter
                        }));
                    }
                }
            }
            return obj;
        };
        /**
         *   Method that allows to navigate thorugh pages. Optionally it can execute
         *   a function before the navigation.
         *   @param {} context
         *   @param {} params
         *   @param {Function} doSthBefore Function to execute something before the navigation.
         */
        var navigate = function (context, params, /* Function */doSthBefore) {

        	// TODO: myPortalNavigation does not exist as class. the filter must be replaced
            //Execute function before if needed.
            if (doSthBefore)
                doSthBefore.apply(this);
            //Navigation
            var link = $('.myPortalNavigation > a.' + context);
            if (link.length != 0) {
                document.location = link.attr('href');
            }


            //In the portalmenuOnlyUpper there are no 'click' bindings 
            //$('#myPortalNavigation a.' + context ).click();
        };

        //public functions
        return {
            init: init,
            navigate: navigate,
            xmlToJson: xmlToJson
        };
    }());

    return function (widget) {
        portalmenuOnlyUpper.init(widget);
    };
});
define('b-core/widgets/propagationSpy/propagationSpy', function () {
    var PropagationSpy = dbesp.utils.fn.inherit(function () {
        // Bind this to a variable for private methods to be able
        // to access widget instance
        var widgetInstance = this;
        widgetInstance.isRenderWithoutContext = true;
        // Cache body DOM element for faster traversing and limiting context
        var $body = $(widgetInstance.widget.body);

        widgetInstance.setup = function () {
        };


        widgetInstance.render = function () {
            setTimeout(parseActions, 0);
        };

        widgetInstance.bindEvents = function () {
            var $body = $(widgetInstance.widget.body);
            // Handle click events via delegation
            $body.on('click', '[data-prop-action]', handleClickActionEvents);
            $body.on('keypress', 'input', handleKeyActionEvents);
        };

        widgetInstance.initSubscriptions = function () {
            // log all event in propagation_channel for debug purposes
            $.subscribeWithPriority('propagation_channel', function () {
                console.log(
                    '%cPropagation: ' +
                    " operation: " + JSON.stringify(arguments[0]) +
                    " context: " + JSON.stringify(arguments[1]) +
                    " action: " + JSON.stringify(arguments[2]),
                    '  background: #222; color: #bada55'
                );
                return true;
            }, 0, widgetInstance.widgetId);
        };

        widgetInstance.getWidgetPropagationActions = function () {
            var executorCallback = function (propagationContext) {
                dbesp.log.debug(propagationContext);
            };
            var evaluatorCallback = function (propagationContext) {
                return false;
            };
            var actions = [];
            _.forOwn(dbesp.repository.actions.listActions(), function (value, key) {
                actions.push(dbesp.repository.actions.retrieve(key, executorCallback, 50, evaluatorCallback));
            });
            return actions;
        };

        function handleClickActionEvents(evt) {
            var action = $(this).data('prop-action');
            switch (action) {
                // Retrieve publishing data and just publish it on the
                // specified channel
                case 'propagate':
                    evt.preventDefault();
                    publishTestingData();
                    break;
                default:
                    dbesp.log.warn('unhandled action:', action);
                    break;
            }
        }

        // Handles the click events produced on elements as result user input
        // @param evt: The event object generated by the DOM interaction
        function handleKeyActionEvents(evt) {
            var id = $(this).data('prop-id');
            var code = (evt.keyCode ? evt.keyCode : evt.which);
            if (code === 13) {
                publishTestingData();
            }
        }

        // Publishes data introduced on the selected channel
        function publishTestingData() {
            var actionJsonString = $body.find('[data-prop-id="action-type"] :selected').val();
            if (actionJsonString) {
                var action = JSON.parse(actionJsonString);
                var propagationContext = {
                    id: $body.find('[data-prop-id="context-id"]').val(),
                    type: action.respondsToType,
                    refresh: !!$body.find('[data-prop-id="refresh"]:checked')[0]
                };
                //propagationContext.description = 'Dummy ' + action.respondsToType + ' (' + propagationContext.id + ')';
                action.relevance = $body.find('[data-prop-id="action-relevance"]').val();
                if (action.relevance) {
                    dbesp.propagation.propagationManager.broadcastExecuteAction(propagationContext, action);
                } else {
                    dbesp.propagation.propagationManager.broadcastMenuQueryAndExecuteAction(propagationContext, widgetInstance, action.id);
                }
            }
        }

        function parseActions() {
            var $actionCombo = $body.find('[data-prop-id="action-type"]');
            var first = true;

            _.forOwn(dbesp.repository.actions.listActions(), function (value, key) {
                value.id = key;
                $actionCombo.append(
                    $('<option ' + (first ? 'selected="true"' : '') + ' >'
                    + value.respondsToType + ' - ' + key
                    + '</option>').attr('value', JSON.stringify(value))
                );
                first = false;
            });
        }


    }, dbesp.widgets.BaseWidget, [dbesp.widgets.mixins.PropagationBehaviour]);

    return function (bbwidget) {
        dbesp.utils.fn.createInstance(PropagationSpy, bbwidget).init();
    };
});


